# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

FONTFAMILY_DEFAULT: int

FONTFAMILY_DECORATIVE: int

FONTFAMILY_ROMAN: int

FONTFAMILY_SCRIPT: int

FONTFAMILY_SWISS: int

FONTFAMILY_MODERN: int

FONTFAMILY_TELETYPE: int

FONTFAMILY_MAX: int

FONTFAMILY_UNKNOWN: int

FONTWEIGHT_INVALID: int

FONTWEIGHT_THIN: int

FONTWEIGHT_EXTRALIGHT: int

FONTWEIGHT_LIGHT: int

FONTWEIGHT_NORMAL: int

FONTWEIGHT_MEDIUM: int

FONTWEIGHT_SEMIBOLD: int

FONTWEIGHT_BOLD: int

FONTWEIGHT_EXTRABOLD: int

FONTWEIGHT_HEAVY: int

FONTWEIGHT_EXTRAHEAVY: int

FONTWEIGHT_MAX: int

CURSOR_NONE: int

CURSOR_ARROW: int

CURSOR_RIGHT_ARROW: int

CURSOR_BULLSEYE: int

CURSOR_CHAR: int

CURSOR_CROSS: int

CURSOR_HAND: int

CURSOR_IBEAM: int

CURSOR_LEFT_BUTTON: int

CURSOR_MAGNIFIER: int

CURSOR_MIDDLE_BUTTON: int

CURSOR_NO_ENTRY: int

CURSOR_PAINT_BRUSH: int

CURSOR_PENCIL: int

CURSOR_POINT_LEFT: int

CURSOR_POINT_RIGHT: int

CURSOR_QUESTION_ARROW: int

CURSOR_RIGHT_BUTTON: int

CURSOR_SIZENESW: int

CURSOR_SIZENS: int

CURSOR_SIZENWSE: int

CURSOR_SIZEWE: int

CURSOR_SIZING: int

CURSOR_SPRAYCAN: int

CURSOR_WAIT: int

CURSOR_WATCH: int

CURSOR_BLANK: int

CURSOR_DEFAULT: int

CURSOR_COPY_ARROW: int

CURSOR_ARROWWAIT: int

CURSOR_MAX: int

ID_AUTO_LOWEST: int

ID_ANY: int

ID_AUTO_HIGHEST: int

ID_NONE: int

ID_SEPARATOR: int

ID_LOWEST: int

ID_OPEN: int

ID_CLOSE: int

ID_NEW: int

ID_SAVE: int

ID_SAVEAS: int

ID_REVERT: int

ID_EXIT: int

ID_UNDO: int

ID_REDO: int

ID_HELP: int

ID_PRINT: int

ID_PRINT_SETUP: int

ID_PAGE_SETUP: int

ID_PREVIEW: int

ID_ABOUT: int

ID_HELP_CONTENTS: int

ID_HELP_INDEX: int

ID_HELP_SEARCH: int

ID_HELP_COMMANDS: int

ID_HELP_PROCEDURES: int

ID_HELP_CONTEXT: int

ID_CLOSE_ALL: int

ID_PREFERENCES: int

ID_EDIT: int

ID_CUT: int

ID_COPY: int

ID_PASTE: int

ID_CLEAR: int

ID_FIND: int

ID_DUPLICATE: int

ID_SELECTALL: int

ID_DELETE: int

ID_REPLACE: int

ID_REPLACE_ALL: int

ID_PROPERTIES: int

ID_VIEW_DETAILS: int

ID_VIEW_LARGEICONS: int

ID_VIEW_SMALLICONS: int

ID_VIEW_LIST: int

ID_VIEW_SORTDATE: int

ID_VIEW_SORTNAME: int

ID_VIEW_SORTSIZE: int

ID_VIEW_SORTTYPE: int

ID_FILE: int

ID_FILE1: int

ID_FILE2: int

ID_FILE3: int

ID_FILE4: int

ID_FILE5: int

ID_FILE6: int

ID_FILE7: int

ID_FILE8: int

ID_FILE9: int

ID_OK: int

ID_CANCEL: int

ID_APPLY: int

ID_YES: int

ID_NO: int

ID_STATIC: int

ID_FORWARD: int

ID_BACKWARD: int

ID_DEFAULT: int

ID_MORE: int

ID_SETUP: int

ID_RESET: int

ID_CONTEXT_HELP: int

ID_YESTOALL: int

ID_NOTOALL: int

ID_ABORT: int

ID_RETRY: int

ID_IGNORE: int

ID_ADD: int

ID_REMOVE: int

ID_UP: int

ID_DOWN: int

ID_HOME: int

ID_REFRESH: int

ID_STOP: int

ID_INDEX: int

ID_BOLD: int

ID_ITALIC: int

ID_JUSTIFY_CENTER: int

ID_JUSTIFY_FILL: int

ID_JUSTIFY_RIGHT: int

ID_JUSTIFY_LEFT: int

ID_UNDERLINE: int

ID_INDENT: int

ID_UNINDENT: int

ID_ZOOM_100: int

ID_ZOOM_FIT: int

ID_ZOOM_IN: int

ID_ZOOM_OUT: int

ID_UNDELETE: int

ID_REVERT_TO_SAVED: int

ID_CDROM: int

ID_CONVERT: int

ID_EXECUTE: int

ID_FLOPPY: int

ID_HARDDISK: int

ID_BOTTOM: int

ID_FIRST: int

ID_LAST: int

ID_TOP: int

ID_INFO: int

ID_JUMP_TO: int

ID_NETWORK: int

ID_SELECT_COLOR: int

ID_SELECT_FONT: int

ID_SORT_ASCENDING: int

ID_SORT_DESCENDING: int

ID_SPELL_CHECK: int

ID_STRIKETHROUGH: int

ID_SYSTEM_MENU: int

ID_CLOSE_FRAME: int

ID_MOVE_FRAME: int

ID_RESIZE_FRAME: int

ID_MAXIMIZE_FRAME: int

ID_ICONIZE_FRAME: int

ID_RESTORE_FRAME: int

ID_MDI_WINDOW_FIRST: int

ID_MDI_WINDOW_CASCADE: int

ID_MDI_WINDOW_TILE_HORZ: int

ID_MDI_WINDOW_TILE_VERT: int

ID_MDI_WINDOW_ARRANGE_ICONS: int

ID_MDI_WINDOW_PREV: int

ID_MDI_WINDOW_NEXT: int

ID_MDI_WINDOW_LAST: int

ID_FILEDLGG: int

ID_FILECTRL: int

ID_HIGHEST: int

FONTENCODING_SYSTEM: int

FONTENCODING_DEFAULT: int

FONTENCODING_ISO8859_1: int

FONTENCODING_ISO8859_2: int

FONTENCODING_ISO8859_3: int

FONTENCODING_ISO8859_4: int

FONTENCODING_ISO8859_5: int

FONTENCODING_ISO8859_6: int

FONTENCODING_ISO8859_7: int

FONTENCODING_ISO8859_8: int

FONTENCODING_ISO8859_9: int

FONTENCODING_ISO8859_10: int

FONTENCODING_ISO8859_11: int

FONTENCODING_ISO8859_12: int

FONTENCODING_ISO8859_13: int

FONTENCODING_ISO8859_14: int

FONTENCODING_ISO8859_15: int

FONTENCODING_ISO8859_MAX: int

FONTENCODING_KOI8: int

FONTENCODING_KOI8_U: int

FONTENCODING_ALTERNATIVE: int

FONTENCODING_BULGARIAN: int

FONTENCODING_CP437: int

FONTENCODING_CP850: int

FONTENCODING_CP852: int

FONTENCODING_CP855: int

FONTENCODING_CP866: int

FONTENCODING_CP874: int

FONTENCODING_CP932: int

FONTENCODING_CP936: int

FONTENCODING_CP949: int

FONTENCODING_CP950: int

FONTENCODING_CP1250: int

FONTENCODING_CP1251: int

FONTENCODING_CP1252: int

FONTENCODING_CP1253: int

FONTENCODING_CP1254: int

FONTENCODING_CP1255: int

FONTENCODING_CP1256: int

FONTENCODING_CP1257: int

FONTENCODING_CP1258: int

FONTENCODING_CP1361: int

FONTENCODING_CP12_MAX: int

FONTENCODING_UTF7: int

FONTENCODING_UTF8: int

FONTENCODING_EUC_JP: int

FONTENCODING_UTF16BE: int

FONTENCODING_UTF16LE: int

FONTENCODING_UTF32BE: int

FONTENCODING_UTF32LE: int

FONTENCODING_MACROMAN: int

FONTENCODING_MACJAPANESE: int

FONTENCODING_MACCHINESETRAD: int

FONTENCODING_MACKOREAN: int

FONTENCODING_MACARABIC: int

FONTENCODING_MACHEBREW: int

FONTENCODING_MACGREEK: int

FONTENCODING_MACCYRILLIC: int

FONTENCODING_MACDEVANAGARI: int

FONTENCODING_MACGURMUKHI: int

FONTENCODING_MACGUJARATI: int

FONTENCODING_MACORIYA: int

FONTENCODING_MACBENGALI: int

FONTENCODING_MACTAMIL: int

FONTENCODING_MACTELUGU: int

FONTENCODING_MACKANNADA: int

FONTENCODING_MACMALAJALAM: int

FONTENCODING_MACSINHALESE: int

FONTENCODING_MACBURMESE: int

FONTENCODING_MACKHMER: int

FONTENCODING_MACTHAI: int

FONTENCODING_MACLAOTIAN: int

FONTENCODING_MACGEORGIAN: int

FONTENCODING_MACARMENIAN: int

FONTENCODING_MACCHINESESIMP: int

FONTENCODING_MACTIBETAN: int

FONTENCODING_MACMONGOLIAN: int

FONTENCODING_MACETHIOPIC: int

FONTENCODING_MACCENTRALEUR: int

FONTENCODING_MACVIATNAMESE: int

FONTENCODING_MACARABICEXT: int

FONTENCODING_MACSYMBOL: int

FONTENCODING_MACDINGBATS: int

FONTENCODING_MACTURKISH: int

FONTENCODING_MACCROATIAN: int

FONTENCODING_MACICELANDIC: int

FONTENCODING_MACROMANIAN: int

FONTENCODING_MACCELTIC: int

FONTENCODING_MACGAELIC: int

FONTENCODING_MACKEYBOARD: int

FONTENCODING_ISO2022_JP: int

FONTENCODING_MAX: int

FONTENCODING_MACMIN: int

FONTENCODING_MACMAX: int

FONTENCODING_UTF16: int

FONTENCODING_UTF32: int

FONTENCODING_UNICODE: int

FONTENCODING_GB2312: int

FONTENCODING_BIG5: int

FONTENCODING_SHIFT_JIS: int

FONTENCODING_EUC_KR: int

FONTENCODING_JOHAB: int

FONTENCODING_VIETNAMESE: int

FONTSTYLE_NORMAL: int

FONTSTYLE_ITALIC: int

FONTSTYLE_SLANT: int

FONTSTYLE_MAX: int

def Abort() -> None:
    """ Exits the program immediately.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def AutoBufferedPaintDCFactory(window: 'Window') -> 'DC':
    """ Check if the window is natively double buffered and will return a   wx.PaintDC  if it is, a   wx.BufferedPaintDC  otherwise.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def BeginBusyCursor(cursor: 'Cursor'=HOURGLASS_CURSOR) -> None:
    """ Changes the cursor to the given cursor for all windows in the application.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Bell() -> None:
    """ Ring the system bell.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def BitmapFromBuffer(width, height, dataBuffer, alphaBuffer=None) -> None:
    """ A compatibility wrapper for wx.Bitmap.FromBuffer and wx.Bitmap.FromBufferAndAlpha

        Source: https://docs.wxpython.org/wx.functions.html
    """


def BitmapFromBufferRGBA(width, height, dataBuffer) -> None:
    """ A compatibility wrapper for wx.Bitmap.FromBufferRGBA

        Source: https://docs.wxpython.org/wx.functions.html
    """


def BitmapFromImage(image) -> None:
    """ A compatibility wrapper for the wx.Bitmap(wx.Image) constructor

        Source: https://docs.wxpython.org/wx.functions.html
    """


def CallAfter(callableObj, *args, **kw) -> None:
    """ Call the specified function after the current and pending event
handlers have been completed.  This is also good for making GUI
method calls from non-GUI threads.  Any extra positional or
keyword args are passed on to the callable when it is called.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def CheckOsVersion(majorVsn, minorVsn=0, microVsn=0) -> bool:
    """ Returns True if the version of the operating system on which the program is running under is the same or later than the given version.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def ClientDisplayRect() -> tuple:
    """ Returns the dimensions of the work area on the display.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def ColourDisplay() -> bool:
    """ Returns True if the display is colour, False otherwise.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def date2pydate(date) -> None:
    """ Convert a DateTime object to a Python datetime.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DateTimeFromDMY(day, month, year=DateTime.Inv_Year, hour=0, minute=0, second=0, millisecond=0) -> None:
    """ Compatibility wrapper for DateTime.FromDMY

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DateTimeFromHMS(hour, minute=0, second=0, millisecond=0) -> None:
    """ Compatibility wrapper for DateTime.FromHMS

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DateTimeFromJDN(jdn) -> None:
    """ Compatibility wrapper for DateTime.FromJDN

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DateTimeFromTimeT(timet) -> None:
    """ Compatibility wrapper for DateTime.FromTimeT

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DecToHex(*args, **kw) -> None:
    """ Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DirSelector(message=DirSelectorPromptStr, default_path="", style=0, pos=DefaultPosition, parent=None) -> str:
    """ Pops up a directory selector dialog.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DisableAsserts() -> None:
    """ Disable the condition checks in the assertions.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DisplayDepth() -> int:
    """ Returns the depth of the display (a value of 1 denotes a monochrome display).

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DisplaySize() -> tuple:
    """ Returns the display size in pixels.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DisplaySizeMM() -> tuple:
    """ Returns the display size in millimeters.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def DumpWindow(window: 'Window') -> str:
    """ Return a string with human-readable platform-specific description of the window useful for diagnostic purposes.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def EmptyBitmap(width, height, depth=BITMAP_SCREEN_DEPTH) -> None:
    """ A compatibility wrapper for the wx.Bitmap(width, height, depth) constructor

        Source: https://docs.wxpython.org/wx.functions.html
    """


def EmptyBitmapRGBA(width, height, red=0, green=0, blue=0, alpha=0) -> None:
    """ A compatibility wrapper for wx.Bitmap.FromRGBA

        Source: https://docs.wxpython.org/wx.functions.html
    """


def EmptyIcon() -> None:
    """ A compatibility wrapper for the Icon constructor

        Source: https://docs.wxpython.org/wx.functions.html
    """


def EmptyImage(width=0, height=0, clear=True) -> None:
    """ A compatibility wrapper for the wx.Image(width, height) constructor

        Source: https://docs.wxpython.org/wx.functions.html
    """


def EnableTopLevelWindows(enable: bool=True) -> None:
    """ This function enables or disables all top level windows.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def EndBusyCursor() -> None:
    """ Changes the cursor back to the original cursor, for all windows in the application.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Execute(command, flags=EXEC_ASYNC, callback=None, env=None) -> int:
    """ Executes another program in Unix or Windows.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Exit() -> None:
    """ Exits application after calling wx.App.OnExit .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FFont(pointSize, family, flags=FONTFLAG_DEFAULT, faceName="", encoding=FONTENCODING_DEFAULT) -> None:
    """ 

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FileSelector(message, default_path="", default_filename="", default_extension="", wildcard=FileSelectorDefaultWildcardStr, flags=0, parent=None, x=DefaultCoord, y=DefaultCoord) -> str:
    """ Pops up a file selector box.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FileSelectorEx(message=FileSelectorPromptStr, default_path="", default_filename="", indexDefaultExtension=None, wildcard=FileSelectorDefaultWildcardStr, flags=0, parent=None, x=DefaultCoord, y=DefaultCoord) -> str:
    """ An extended version of wx.FileSelector

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FindMenuItemId(frame, menuString, itemString) -> int:
    """ Find a menu item identifier associated with the given frameâs menu bar.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FindWindowAtPoint(pt: Union[tuple[int, int], 'Point']) -> 'Window':
    """ Find the deepest window at the given mouse position in screen coordinates, returning the window if found, or None if not.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FindWindowAtPointer() -> tuple:
    """ Find the deepest window at the mouse pointer position, returning the window and current pointer position in screen coordinates.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FindWindowById(id, parent=None) -> 'Window':
    """ FindWindowById(id, parent=None) . Window

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FindWindowByLabel(label, parent=None) -> 'Window':
    """ Find a window by its label. Depending on the type of window, the label may be a window title or panel item label. If parent  is None, the search will start from all top-level frames and dialog boxes; if not None, the search will be limited to the given window hierarchy. The search is recursive in both cases.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def FindWindowByName(name, parent=None) -> 'Window':
    """ Find a window by its name (as given in a window constructor or Create  function call). If parent  is None, the search will start from all top-level frames and dialog boxes; if not None, the search will be limited to the given window hierarchy. The search is recursive in both cases.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetAccelFromString(label) -> None:
    """ 

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetActiveWindow() -> 'Window':
    """ Gets the currently active window (implemented for MSW and GTK only currently, always returns None in the other ports).

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetApp() -> 'App':
    """ Returns the current application object.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetBatteryState() -> 'BatteryState':
    """ Returns battery state as one of  BATTERY_NORMAL_STATE ,   BATTERY_LOW_STATE ,   BATTERY_CRITICAL_STATE ,   BATTERY_SHUTDOWN_STATE   or   BATTERY_UNKNOWN_STATE .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetClientDisplayRect() -> 'Rect':
    """ Returns the dimensions of the work area on the display.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetColourFromUser(parent, colInit, caption="", data=None) -> 'Colour':
    """ Shows the colour selection dialog and returns the colour selected by user or invalid colour (use wx.Colour.IsOk   to test whether a colour is valid) if the dialog was cancelled.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetCpuArchitectureName() -> str:
    """ Returns the CPU architecture name.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetDisplayPPI() -> 'Size':
    """ Returns the display resolution in pixels per inch.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetDisplaySize() -> 'Size':
    """ Returns the display size in pixels.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetDisplaySizeMM() -> 'Size':
    """ Returns the display size in millimeters.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetEmailAddress() -> str:
    """ Copies the userâs email address into the supplied buffer, by concatenating the values returned by wx.GetFullHostName       and wx.GetUserId     .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetFontFromUser(parent, fontInit, caption="") -> 'Font':
    """ Shows the font selection dialog and returns the font selected by user or invalid font (use wx.Font.IsOk   to test whether a font is valid) if the dialog was cancelled.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetFullHostName() -> str:
    """ Returns the FQDN (fully qualified domain host name) or an empty string on error.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetHomeDir() -> str:
    """ Return the (current) userâs home directory.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetHostName() -> str:
    """ Copies the current host machineâs name into the supplied buffer.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetKeyState(key: KeyCode) -> bool:
    """ For normal keys, returns True if the specified key is currently down.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetLibraryVersionInfo() -> 'VersionInfo':
    """ Get wxWidgets version information.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetLocale() -> 'Locale':
    """ Get the current locale object (note that it may be None!)

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetMousePosition() -> 'Point':
    """ Returns the mouse position in screen coordinates.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetMouseState() -> 'MouseState':
    """ Returns the current state of the mouse.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetNativeCpuArchitectureName() -> str:
    """ In some situations the current process and native CPU architecture may be different.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetNumberFromUser(message, prompt, caption, value, min=0, max=100, parent=None, pos=DefaultPosition) -> int:
    """ Shows a dialog asking the user for numeric input.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetOsDescription() -> str:
    """ Returns the string containing the description of the current platform in a user-readable form.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetOsVersion(micro: Optional[int]=None) -> tuple:
    """ Gets the version and the operating system ID for currently running OS.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetPasswordFromUser(message, caption=GetPasswordFromUserPromptStr, default_value="", parent=None, x=DefaultCoord, y=DefaultCoord, centre=True) -> str:
    """ Similar to wx.GetTextFromUser       but the text entered in the dialog is not shown on screen but replaced with stars.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetPowerType() -> 'PowerType':
    """ Returns the type of power source as one of  POWER_SOCKET ,   POWER_BATTERY   or   POWER_UNKNOWN .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetProcessId() -> int:
    """ Returns the number uniquely identifying the current process in the system.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetSingleChoice(*args, **kw) -> str:
    """ Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetStockLabel(id, flags=STOCK_WITH_MNEMONIC) -> str:
    """ Returns label that should be used for given id  element.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetTextFromUser(message, caption=GetTextFromUserPromptStr, default_value="", parent=None, x=DefaultCoord, y=DefaultCoord, centre=True) -> str:
    """ Pop up a dialog box with title set to caption,  message , and a   default_value .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetTopLevelParent(window: 'Window') -> 'Window':
    """ Returns the first top level parent of the given window, or in other words, the frame or dialog containing it, or None.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetTopLevelWindows() -> WindowList:
    """ Returns a list-like object of the the applicationâs top-level windows, (frames,dialogs, etc.)

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetTranslation(*args, **kw) -> str:
    """ Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetUserHome(user: str="") -> str:
    """ Returns the home directory for the given user.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetUserId() -> str:
    """ This function returns the âuser idâ also known as âlogin nameâ under Unix (i.e.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def GetUserName() -> str:
    """ This function returns the full user name (something like âMr. John Smithâ).

        Source: https://docs.wxpython.org/wx.functions.html
    """


def HandleFatalExceptions(doIt: bool=True) -> bool:
    """ If doIt  is True, the fatal exceptions (also known as general protection faults under Windows or segmentation violations in the Unix world) will be caught and passed to wx.App.OnFatalException .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def HelpController(parentWindow=None) -> None:
    """ Rather than being an alias for some class, the Python version of
HelpController is a factory function that creates and returns an
instance of the best Help Controller for the platform.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def HexToDec(*args, **kw) -> int:
    """ Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.functions.html
    """


def ImageFromBitmap(bitmap) -> None:
    """ Create a Image from a wx.Bitmap

        Source: https://docs.wxpython.org/wx.functions.html
    """


def ImageFromBuffer(width, height, dataBuffer, alphaBuffer=None) -> None:
    """ Creates a Image from the data in dataBuffer.  The dataBuffer
parameter must be a Python object that implements the buffer interface,
such as a string, array, etc.  The dataBuffer object is expected to
contain a series of RGB bytes and be width*height*3 bytes long.  A buffer
object can optionally be supplied for the imageâs alpha channel data, and
it is expected to be width*height bytes long.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def ImageFromData(width, height, data) -> None:
    """ Compatibility wrapper for creating an image from RGB data

        Source: https://docs.wxpython.org/wx.functions.html
    """


def ImageFromDataWithAlpha(width, height, data, alpha) -> None:
    """ Compatibility wrapper for creating an image from RGB and Alpha data

        Source: https://docs.wxpython.org/wx.functions.html
    """


def ImageFromStream(stream, type=BITMAP_TYPE_ANY, index=-1) -> None:
    """ Load an image from a stream (file-like object)

        Source: https://docs.wxpython.org/wx.functions.html
    """


def InfoMessageBox(parent: 'Window') -> None:
    """ Shows a message box with the information about the wxWidgets build used, including its version, most important build parameters and the version of the underlying GUI toolkit.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def InitAllImageHandlers() -> None:
    """ Initializes all available image handlers.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def IntersectRect(r1, r2) -> Any:
    """ Calculate and return the intersection of r1 and r2.  Returns None if there
is no intersection.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def IsBusy() -> bool:
    """ Returns True if between two wx.BeginBusyCursor       and wx.EndBusyCursor       calls.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def IsDragResultOk(res: DragResult) -> bool:
    """ Returns True if res indicates that something was done during a DnD operation, i.e.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def IsMainThread() -> bool:
    """ Returns True if the current thread is what  considers the GUI thread.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def IsPlatform64Bit() -> bool:
    """ Returns True if the operating system the program is running under is 64 bit.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def IsPlatformLittleEndian() -> bool:
    """ Returns True if the current platform is little endian (instead of big endian).

        Source: https://docs.wxpython.org/wx.functions.html
    """


def IsRunningUnderWine() -> bool:
    """ Returns True only for MSW programs running under Wine.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Kill(pid, sig=SIGTERM, rc=None, flags=KILL_NOCHILDREN) -> int:
    """ Equivalent to the Unix kill function: send the given signal sig  to the process with PID pid.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LaunchDefaultApplication(document, flags=0) -> bool:
    """ Opens the document  in the application associated with the files of this type.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LaunchDefaultBrowser(url, flags=0) -> bool:
    """ Opens the url  in userâs default browser.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LoadFileSelector(what, extension, default_name="", parent=None) -> str:
    """ Shows a file dialog asking the user for a file name for opening a file.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogDebug(message: str) -> None:
    """ The right functions for debug output.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogError(message: str) -> None:
    """ The functions to use for error messages, i.e.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogFatalError(message: str) -> None:
    """ Like wx.LogError     , but also terminates the program with the exit code 3.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogGeneric(level, message) -> None:
    """ Logs a message with the given LogLevel.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogInfo(formatString) -> None:
    """ For low priority messages.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogMessage(message: str) -> None:
    """ For all normal, informational messages.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogStatus(*args, **kw) -> None:
    """ Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogSysError(message: str) -> None:
    """ Mostly used by wxWidgets itself, but might be handy for logging errors after system call (API function) failure.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogVerbose(message: str) -> None:
    """ For verbose output.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def LogWarning(message: str) -> None:
    """ For warnings - they are also normally shown to the user, but donât interrupt the program work.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def MacThemeColour(themeBrushID) -> 'Colour':
    """ wx.Colour

        Source: https://docs.wxpython.org/wx.functions.html
    """


def MessageBox(message, caption=MessageBoxCaptionStr, style=OK|CENTRE, parent=None, x=DefaultCoord, y=DefaultCoord) -> int:
    """ Show a general purpose message dialog.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def MicroSleep(microseconds: int) -> None:
    """ Sleeps for the specified number of microseconds.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def MilliSleep(milliseconds: int) -> None:
    """ Sleeps for the specified number of milliseconds.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def NewEventType() -> int:
    """ Generates a new unique event type.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def NewId() -> int:
    """ Generates an integer identifier unique to this run of the program.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def NewIdRef(count=1) -> int:
    """ Reserves a new Window ID (or range of WindowIDs) and returns a
wx.WindowIDRef object (or list of them) that will help
manage the reservation of that ID.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Now() -> str:
    """ Returns a string representing the current date and time.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def PostEvent(dest, event) -> None:
    """ In a GUI application, this function posts event  to the specified dest  object using wx.EvtHandler.AddPendingEvent .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def pydate2wxdate(date) -> None:
    """ Convert a Python date or datetime to a DateTime object

        Source: https://docs.wxpython.org/wx.functions.html
    """


def QueueEvent(dest, event) -> None:
    """ Queue an event for processing on the given object.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def RegisterId(id: int) -> None:
    """ Ensures that Ids subsequently generated by wx.NewId       do not clash with the given id.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SafeShowMessage(title, text) -> bool:
    """ This function shows a message to the user in a safe way and should be safe to call even before the application has been initialized or if it is currently in some other strange state (for example, about to crash).

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SafeYield(win=None, onlyIfNeeded=False) -> bool:
    """ Calls wx.App.SafeYield .

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SaveFileSelector(what, extension, default_name="", parent=None) -> str:
    """ Shows a file dialog asking the user for a file name for saving a file.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SecureZeroMemory(p, n) -> None:
    """ Fills the memory block with zeros in a way that is guaranteed not to be optimized away by the compiler.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SetCursor(cursor: 'Cursor') -> None:
    """ Globally sets the cursor; only has an effect on Windows, Mac and GTK+.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Shell(command: str="") -> bool:
    """ Executes a command in an interactive shell window.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Shutdown(flags: int=SHUTDOWN_POWEROFF) -> bool:
    """ This function shuts down or reboots the computer depending on the value of the flags.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Sleep(secs: int) -> None:
    """ Sleeps for the specified number of seconds.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def StripMenuCodes(str, flags=Strip_All) -> str:
    """ Strips any menu codes from str  and returns the result.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SysErrorCode() -> int:
    """ Returns the error code from the last system call.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SysErrorMsg(errCode: int=0) -> str:
    """ Returns the error message corresponding to the given system error code.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def SysErrorMsgStr(errCode: int=0) -> str:
    """ Returns the error message corresponding to the given system error code.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Trap() -> None:
    """ Generate a debugger exception meaning that the control is passed to the debugger if one is attached to the process.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def version() -> None:
    """ Returns a string containing version and port info

        Source: https://docs.wxpython.org/wx.functions.html
    """


def WakeUpIdle() -> None:
    """ This function wakes up the (internal and platform dependent) idle system, i.e.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def Yield() -> bool:
    """ Calls wx.AppConsole.Yield   if there is an existing application object.

        Source: https://docs.wxpython.org/wx.functions.html
    """


def YieldIfNeeded() -> None:
    """ Convenience function for wx.GetApp().Yield(True)

        Source: https://docs.wxpython.org/wx.functions.html
    """


KILL_CHILDREN: int

EXEC_ASYNC: int

EXEC_SYNC: int

EXEC_SHOW_CONSOLE: int

EXEC_HIDE_CONSOLE: int

EXEC_MAKE_GROUP_LEADER: int

EXEC_NODISABLE: int

EXEC_NOEVENTS: int

EXEC_BLOCK: int

FD_OPEN: int

FD_SAVE: int

FD_OVERWRITE_PROMPT: int

FD_FILE_MUST_EXIST: int

FD_MULTIPLE: int

OK: int

KILL_NOCHILDREN: int

class AcceleratorEntry:
    """ An object used by an application wishing to create an accelerator
table (see AcceleratorTable).

        Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def FromString(self, str: str) -> bool:
        """ Parses the given string and sets the accelerator accordingly.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def GetCommand(self) -> int:
        """ Returns the command identifier for the accelerator table entry.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def GetFlags(self) -> int:
        """ Returns the flags for the accelerator table entry.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def GetKeyCode(self) -> int:
        """ Returns the keycode for the accelerator table entry.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def GetMenuItem(self) -> 'MenuItem':
        """ Returns the menu item associated with this accelerator entry.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def IsOk(self) -> bool:
        """ Returns True if this object is correctly initialized.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def Set(self, flags, keyCode, cmd, item=None) -> None:
        """ Sets the accelerator entry parameters.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def ToRawString(self) -> str:
        """ Returns a textual representation of this accelerator which is appropriate for saving in configuration files.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def ToString(self) -> str:
        """ Returns a textual representation of this accelerator.

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def __ne__(self, item: Any) -> bool:
        """ entry (wx.AcceleratorEntry) â

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    def __eq__(self, item: Any) -> bool:
        """ entry (wx.AcceleratorEntry) â

            Source: https://docs.wxpython.org/wx.AcceleratorEntry.html
        """

    Command: int  # See GetCommand
    Flags: int  # See GetFlags
    KeyCode: int  # See GetKeyCode
    MenuItem: 'MenuItem'  # See GetMenuItem



class AcceleratorTable(Object):
    """ An accelerator table allows the application to specify a table of
keyboard shortcuts for menu or button commands.

        Source: https://docs.wxpython.org/wx.AcceleratorTable.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AcceleratorTable.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the accelerator table is valid.

            Source: https://docs.wxpython.org/wx.AcceleratorTable.html
        """



class Accessible(Object):
    """ The Accessible class allows wxWidgets applications, and wxWidgets
itself, to return extended information about user interface elements
to client applications such as screen readers.

        Source: https://docs.wxpython.org/wx.Accessible.html
    """
    def __init__(self, win: Optional['Window']=None) -> None:
        """ Constructor, taking an optional window.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def DoDefaultAction(self, childId: int) -> int:
        """ Performs the default action for the object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetChild(self, childId: int) -> tuple:
        """ Gets the specified child (starting from 1).

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetChildCount(self) -> tuple:
        """ Returns the number of children in childCount.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetDefaultAction(self, childId: int) -> tuple:
        """ Gets the default action for this object (0) or a child (greater than 0).

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetDescription(self, childId: int) -> tuple:
        """ Returns the description for this object or a child.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetFocus(self, childId: int) -> tuple:
        """ Gets the window with the keyboard focus.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetHelpText(self, childId: int) -> tuple:
        """ Returns help text for this object or a child, similar to tooltip text.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetKeyboardShortcut(self, childId: int) -> tuple:
        """ Returns the keyboard shortcut for this object or child.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetLocation(self, elementId: int) -> tuple:
        """ Returns the rectangle for this object (id is 0) or a child element (id is greater than 0).

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetName(self, childId: int) -> tuple:
        """ Gets the name of the specified object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetParent(self) -> tuple:
        """ Returns the parent of this object, or None.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetRole(self, childId: int) -> tuple:
        """ Returns a role constant describing this object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetSelections(self) -> tuple:
        """ Gets a variant representing the selected children of this object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetState(self, childId: int) -> tuple:
        """ Returns a state constant.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetValue(self, childId: int) -> tuple:
        """ Returns a localized string representing the value for the object or child.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def GetWindow(self) -> 'Window':
        """ Returns the window associated with this object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def HitTest(self, pt, childId, childObject) -> int:
        """ Returns a status value and object id to indicate whether the given point was on this or a child object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def Navigate(self, navDir, fromId, toId, toObject) -> int:
        """ Navigates from fromId  to toId  or to toObject.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    @staticmethod
    def NotifyEvent(eventType, window, objectType, objectId) -> None:
        """ Allows the application to send an event when something changes in an accessible object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def Select(self, childId, selectFlags) -> int:
        """ Selects the object or child.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    def SetWindow(self, window: 'Window') -> None:
        """ Sets the window associated with this object.

            Source: https://docs.wxpython.org/wx.Accessible.html
        """

    Window: 'Window'  # See GetWindow and SetWindow



ACC_NOT_SUPPORTED: int

ACC_OK: int

class ActivateEvent(Event):
    """ An activate event is sent when a window or application is being
activated or deactivated.

        Source: https://docs.wxpython.org/wx.ActivateEvent.html
    """
    def __init__(self, eventType=wxEVT_NULL, active=True, id=0, ActivationReason=Reason_Unknown) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ActivateEvent.html
        """

    def GetActivationReason(self) -> 'ActivateEvent.Reason':
        """ Allows checking if the window was activated by clicking it with the mouse or in some other way.

            Source: https://docs.wxpython.org/wx.ActivateEvent.html
        """

    def GetActive(self) -> bool:
        """ Returns True if the application or window is being activated, False otherwise.

            Source: https://docs.wxpython.org/wx.ActivateEvent.html
        """

    Active: bool  # See GetActive



EVT_ACTIVATE: int  # Process a  wxEVT_ACTIVATE   event.

EVT_ACTIVATE_APP: int  # Process a  wxEVT_ACTIVATE_APP   event. This event is received by the App-derived instance only.

EVT_HIBERNATE: int  # Process a hibernate event, supplying the member function. This event applies to   wx.App  only, and only on Windows SmartPhone and PocketPC. It is generated when the system is low on memory; the application should free up as much memory as possible, and restore full working state when it receives a  wxEVT_ACTIVATE   or   wxEVT_ACTIVATE_APP   event. ^^

class ActivityIndicator(Control):
    """ Small control showing an animation indicating that the program is
currently busy performing some background task.

        Source: https://docs.wxpython.org/wx.ActivityIndicator.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ActivityIndicator.html
        """

    def Create(self, parent, winid=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name="activityindicator") -> bool:
        """ Create the control initialized using the default constructor.

            Source: https://docs.wxpython.org/wx.ActivityIndicator.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ActivityIndicator.html
        """

    def IsRunning(self) -> bool:
        """ Returns True if the control is currently showing activity.

            Source: https://docs.wxpython.org/wx.ActivityIndicator.html
        """

    def Start(self) -> None:
        """ Starts animation of the indicator.

            Source: https://docs.wxpython.org/wx.ActivityIndicator.html
        """

    def Stop(self) -> None:
        """ Stops the animation of the indicator.

            Source: https://docs.wxpython.org/wx.ActivityIndicator.html
        """



class AffineMatrix2D(AffineMatrix2DBase):
    """ A 3x2 matrix representing an affine 2D transformation.

        Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Concat(self, t: 'AffineMatrix2DBase') -> None:
        """ Concatenate this matrix with another one.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Get(self) -> tuple:
        """ Get the component values of the matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Invert(self) -> bool:
        """ Invert this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def IsEqual(self, t: 'AffineMatrix2DBase') -> None:
        """ Check that this matrix is identical with t.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def IsIdentity(self) -> bool:
        """ Check if this is the identity matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Mirror(self, direction: int=HORIZONTAL) -> None:
        """ Add mirroring to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Rotate(self, cRadians: 'Double') -> None:
        """ Add clockwise rotation to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Scale(self, xScale, yScale) -> None:
        """ Add scaling to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Set(self, mat2D, tr) -> None:
        """ Set all elements of this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def TransformDistance(self, *args, **kw) -> Point2DDouble:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def TransformPoint(self, *args, **kw) -> Point2DDouble:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def Translate(self, dx, dy) -> None:
        """ Add the translation to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Check that this matrix differs from t.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Check that this matrix is identical with t.

            Source: https://docs.wxpython.org/wx.AffineMatrix2D.html
        """



HORIZONTAL: int

VERTICAL: int

BOTH: int

class AffineMatrix2DBase:
    """ A 2x3 matrix representing an affine 2D transformation.

        Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Concat(self, t: 'AffineMatrix2DBase') -> None:
        """ Concatenate this matrix with another one.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Get(self) -> tuple:
        """ Get the component values of the matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Invert(self) -> bool:
        """ Invert this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def IsEqual(self, t: 'AffineMatrix2DBase') -> bool:
        """ Check that this matrix is identical with t.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def IsIdentity(self) -> bool:
        """ Check if this is the identity matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Mirror(self, direction: int=HORIZONTAL) -> None:
        """ Add mirroring to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Rotate(self, cRadians: 'Double') -> None:
        """ Add clockwise rotation to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Scale(self, xScale, yScale) -> None:
        """ Add scaling to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Set(self, mat2D, tr) -> None:
        """ Set all elements of this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def TransformDistance(self, *args, **kw) -> Point2DDouble:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def TransformPoint(self, *args, **kw) -> Point2DDouble:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def Translate(self, dx, dy) -> None:
        """ Add the translation to this matrix.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Check that this matrix differs from t.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Check that this matrix is identical with t.

            Source: https://docs.wxpython.org/wx.AffineMatrix2DBase.html
        """



class AlphaPixelData:
    """ A class providing direct access to a wx.Bitmapâs
internal data including the alpha channel (RGBA).

        Source: https://docs.wxpython.org/wx.AlphaPixelData.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AlphaPixelData.html
        """

    def GetPixels(self) -> 'AlphaPixelData_Accessor':
        """ wx.AlphaPixelData_Accessor

            Source: https://docs.wxpython.org/wx.AlphaPixelData.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.AlphaPixelData.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.AlphaPixelData.html
        """

    Pixels: 'AlphaPixelData_Accessor'  # See GetPixels



class Bitmap(GDIObject):
    """ This class encapsulates the concept of a platform-dependent bitmap,
either monochrome or colour or colour with alpha channel support.

        Source: https://docs.wxpython.org/wx.Bitmap.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def ConvertToDisabled(self, brightness: int=255) -> 'Bitmap':
        """ Returns disabled (dimmed) version of the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def ConvertToImage(self) -> 'Image':
        """ Creates an image from a platform-dependent bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def CopyFromBuffer(self, data, format=BitmapBufferFormat_RGB, stride=-1) -> None:
        """ Copy data from a buffer object to replace the bitmap pixel data.
Default format is plain RGB, but other formats are now supported as
well.  The following symbols are used to specify the format of the
bytes in the buffer:

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def CopyFromIcon(self, icon: 'Icon') -> bool:
        """ Creates the bitmap from an icon.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def CopyToBuffer(self, data, format=BitmapBufferFormat_RGB, stride=-1) -> None:
        """ Copy pixel data to a buffer object.  See CopyFromBuffer for buffer
format details.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def Create(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def CreateScaled(self, width, height, depth, logicalScale) -> bool:
        """ Create a bitmap with a scale factor.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def CreateWithDIPSize(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    @staticmethod
    def FromBuffer(width, height, data) -> 'Bitmap':
        """ Creates a wx.Bitmap from in-memory data.  The data parameter
must be a Python object that implements the buffer interface, such
as a string, bytearray, etc.  The data object is expected to contain
a series of RGB bytes and be at least (widthÂ  heightÂ  3) bytes long.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    @staticmethod
    def FromBufferAndAlpha(width, height, data, alpha) -> 'Bitmap':
        """ Creates a wx.Bitmap from in-memory data.  The data and alpha
parameters must be a Python object that implements the buffer
interface, such as a string, bytearray, etc.  The data object
is expected to contain a series of RGB bytes and be at least
(widthÂ  heightÂ  3) bytes long, while the alpha object is expected
to be (widthÂ  height) bytes long and represents the imageâs alpha
channel.  On Windows and Mac the RGB values will be
âpremultipliedâ by the alpha values.  (The other platforms do
the multiplication themselves.)

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    @staticmethod
    def FromBufferRGBA(width, height, data) -> 'Bitmap':
        """ Creates a wx.Bitmap from in-memory data.  The data parameter
must be a Python object that implements the buffer interface, such
as a string, bytearray, etc.  The data object is expected to contain
a series of RGBA bytes and be at least (widthÂ  heightÂ  4) bytes long.
On Windows and Mac the RGB values will be âpremultipliedâ by the
alpha values.  (The other platforms do the multiplication themselves.)

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    @staticmethod
    def FromPNGData(data) -> 'Bitmap':
        """ Like NewFromPNGData, but with a simpler API accepting a Python
buffer-compatible object.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    @staticmethod
    def FromRGBA(width, height, red=0, green=0, blue=0, alpha=0) -> 'Bitmap':
        """ Creates a new empty 32-bit wx.Bitmap where every pixel has been
initialized with the given RGBA values.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetDIPSize(self) -> 'Size':
        """ Returns the size of bitmap in DPI-independent units.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetDepth(self) -> int:
        """ Gets the colour depth of the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetHandle(self) -> int:
        """ MSW-only method to fetch the windows handle for the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetHeight(self) -> int:
        """ Returns the height of the bitmap in physical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetLogicalHeight(self) -> float:
        """ Returns the height of the bitmap in logical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetLogicalSize(self) -> 'Size':
        """ Returns the size of the bitmap in logical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetLogicalWidth(self) -> float:
        """ Returns the width of the bitmap in logical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetMask(self) -> 'Mask':
        """ Gets the associated mask (if any) which may have been loaded from a file or set for the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetPalette(self) -> 'Palette':
        """ Gets the associated palette (if any) which may have been loaded from a file or set for the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetScaleFactor(self) -> float:
        """ Returns the scale factor of this bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetScaledHeight(self) -> float:
        """ Returns the height of the bitmap in logical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetScaledSize(self) -> 'Size':
        """ Returns the size of the bitmap in logical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetScaledWidth(self) -> float:
        """ Returns the width of the bitmap in logical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetSize(self) -> 'Size':
        """ Returns the size of the bitmap in physical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetSubBitmap(self, rect: 'Rect') -> 'Bitmap':
        """ Returns a sub bitmap of the current one as long as the rect belongs entirely to the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def GetWidth(self) -> int:
        """ Returns the width of the bitmap in physical pixels.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def HasAlpha(self) -> bool:
        """ Returns True if the bitmap has an alpha channel.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def IsOk(self) -> bool:
        """ Returns True if bitmap data is present.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def LoadFile(self, name, type=BITMAP_TYPE_ANY) -> bool:
        """ Loads a bitmap from a file or resource.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    @staticmethod
    def NewFromPNGData(data, size) -> 'Bitmap':
        """ Loads a bitmap from the memory containing image data in PNG format.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    @staticmethod
    def Rescale(bmp, sizeNeeded) -> None:
        """ Rescale the given bitmap to the requested size.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def ResetAlpha(self) -> None:
        """ Remove alpha channel from the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SaveFile(self, name, type, palette=None) -> bool:
        """ Saves a bitmap in the named file.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetDepth(self, depth: int) -> None:
        """ Sets the depth member (does not affect the bitmap data).

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetHandle(self, handle) -> None:
        """ MSW-only method to set the windows handle for the bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetHeight(self, height: int) -> None:
        """ Sets the height member (does not affect the bitmap data).

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetMask(self, mask: 'Mask') -> None:
        """ Sets the mask for this bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetMaskColour(self, colour) -> None:
        """ Create a mask for this bitmap based on the pixels with the given colour.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetPalette(self, palette: 'Palette') -> None:
        """ Sets the associated palette.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetScaleFactor(self, scale: float) -> None:
        """ Sets the bitmap scale factor.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetSize(self, size) -> None:
        """ Set the bitmap size (does not alter the existing native bitmap data or image size).

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def SetWidth(self, width: int) -> None:
        """ Sets the width member (does not affect the bitmap data).

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def UseAlpha(self, use: bool=True) -> None:
        """ Enable or disable use of alpha channel in this bitmap.

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Bitmap.html
        """

    DIPSize: 'Size'  # See GetDIPSize
    Depth: int  # See GetDepth and SetDepth
    Handle: int  # See GetHandle and SetHandle
    Height: int  # See GetHeight and SetHeight
    LogicalHeight: float  # See GetLogicalHeight
    LogicalSize: 'Size'  # See GetLogicalSize
    LogicalWidth: float  # See GetLogicalWidth
    Mask: 'Mask'  # See GetMask and SetMask
    Palette: 'Palette'  # See GetPalette and SetPalette
    ScaleFactor: float  # See GetScaleFactor and SetScaleFactor
    ScaledHeight: float  # See GetScaledHeight
    ScaledSize: 'Size'  # See GetScaledSize
    ScaledWidth: float  # See GetScaledWidth
    Size: 'Size'  # See GetSize and SetSize
    Width: int  # See GetWidth and SetWidth



ALPHA_OPAQUE: int

class AlphaPixelData_Accessor:
    """  Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def Get(self) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def IsOk(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def MoveTo(self, data, x, y) -> None:
        """ data (AlphaPixelData) â

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def Offset(self, data, x, y) -> None:
        """ data (AlphaPixelData) â

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def OffsetX(self, data, x) -> None:
        """ data (AlphaPixelData) â

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def OffsetY(self, data, y) -> None:
        """ data (AlphaPixelData) â

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def Reset(self, data: AlphaPixelData) -> None:
        """ data (AlphaPixelData) â

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def Set(self, red, green, blue, alpha) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """

    def nextPixel(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.AlphaPixelData_Accessor.html
        """



class AnyButton(Control):
    """ A class for common button functionality used as the base for the
various button classes.

        Source: https://docs.wxpython.org/wx.AnyButton.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def GetBitmap(self) -> 'Bitmap':
        """ Return the bitmap shown by the button.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def GetBitmapCurrent(self) -> 'Bitmap':
        """ Returns the bitmap used when the mouse is over the button.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def GetBitmapDisabled(self) -> 'Bitmap':
        """ Returns the bitmap used for the disabled state.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def GetBitmapFocus(self) -> 'Bitmap':
        """ Returns the bitmap used for the focused state.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def GetBitmapLabel(self) -> 'Bitmap':
        """ Returns the bitmap for the normal state.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def GetBitmapMargins(self) -> 'Size':
        """ Get the margins between the bitmap and the text of the button.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def GetBitmapPressed(self) -> 'Bitmap':
        """ Returns the bitmap used when the button is pressed.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmap(self, bitmap, dir=LEFT) -> None:
        """ Sets the bitmap to display in the button.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmapCurrent(self, bitmap: 'BitmapBundle') -> None:
        """ Sets the bitmap to be shown when the mouse is over the button.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmapDisabled(self, bitmap: 'BitmapBundle') -> None:
        """ Sets the bitmap for the disabled button appearance.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmapFocus(self, bitmap: 'BitmapBundle') -> None:
        """ Sets the bitmap for the button appearance when it has the keyboard focus.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmapLabel(self, bitmap: 'BitmapBundle') -> None:
        """ Sets the bitmap label for the button.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmapMargins(self, *args, **kw) -> None:
        """ Set the margins between the bitmap and the text of the button.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmapPosition(self, dir: int) -> None:
        """ Set the position at which the bitmap is displayed.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    def SetBitmapPressed(self, bitmap: 'BitmapBundle') -> None:
        """ Sets the bitmap for the selected (depressed) button appearance.

            Source: https://docs.wxpython.org/wx.AnyButton.html
        """

    Bitmap: 'Bitmap'  # See GetBitmap and SetBitmap
    BitmapCurrent: 'BitmapBundle'  # See GetBitmapCurrent and SetBitmapCurrent
    BitmapDisabled: 'BitmapBundle'  # See GetBitmapDisabled and SetBitmapDisabled
    BitmapFocus: 'BitmapBundle'  # See GetBitmapFocus and SetBitmapFocus
    BitmapLabel: 'BitmapBundle'  # See GetBitmapLabel and SetBitmapLabel
    BitmapMargins: 'Size'  # See GetBitmapMargins and SetBitmapMargins
    BitmapPressed: 'BitmapBundle'  # See GetBitmapPressed and SetBitmapPressed



RIGHT: int

TOP: int

BOTTOM: int

LEFT: int

class App(PyApp,AppConsole):
    """ The wx.App class represents the application and is used to:

        Source: https://docs.wxpython.org/wx.App.html
    """
    def __init__(self, redirect=False, filename=None, useBestVisual=False, clearSigInt=True) -> None:
        """ Construct a wx.App object.

            Source: https://docs.wxpython.org/wx.App.html
        """

    @staticmethod
    def Get() -> 'App':
        """ A staticmethod returning the currently active application object.
Essentially just a more pythonic version of GetApp.

            Source: https://docs.wxpython.org/wx.App.html
        """

    def InitLocale(self) -> None:
        """ Starting with version 3.8 on Windows, Python is now setting the locale
to what is defined by the system as the default locale. This causes
problems with wxWidgets which expects to be able to manage the locale
via the wx.Locale class, so the locale will be reset here to be the
default âCâ locale settings.

            Source: https://docs.wxpython.org/wx.App.html
        """

    def MainLoop(self) -> None:
        """ Execute the main GUI event loop

            Source: https://docs.wxpython.org/wx.App.html
        """

    def OnPreInit(self) -> None:
        """ Things that must be done after _BootstrapApp has done its thing, but
would be nice if they were already done by the time that OnInit is
called.  This can be overridden in derived classes, but be sure to call
this method from there.

            Source: https://docs.wxpython.org/wx.App.html
        """

    def RedirectStdio(self, filename=None) -> None:
        """ Redirect sys.stdout and sys.stderr to a file or a popup window.

            Source: https://docs.wxpython.org/wx.App.html
        """

    def ResetLocale(self) -> None:
        """ This method is now a NOP and will be deprecated.

            Source: https://docs.wxpython.org/wx.App.html
        """

    def RestoreStdio(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.App.html
        """

    def SetOutputWindowAttributes(self, title=None, pos=None, size=None) -> None:
        """ Set the title, position and/or size of the output window if the stdio
has been redirected. This should be called before any output would
cause the output window to be created.

            Source: https://docs.wxpython.org/wx.App.html
        """

    def SetTopWindow(self, frame) -> None:
        """ Set the âmainâ top level window, which will be used for the parent of
the on-demand output window as well as for dialogs that do not have
an explicit parent set.

            Source: https://docs.wxpython.org/wx.App.html
        """

    def __del__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.App.html
        """



class PyApp(AppConsole):
    """ The App class represents the application itself when USE_GUI=1.

        Source: https://docs.wxpython.org/wx.PyApp.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    @staticmethod
    def GTKSuppressDiagnostics(flags: int=-1) -> None:
        """ Disables the printing of various GTK messages.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def GetAssertMode(self) -> 'AppAssertMode':
        """ Returns the current mode for how the application responds to  asserts.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    @staticmethod
    def GetComCtl32Version() -> int:
        """ Returns 400, 470, 471, etc. for comctl32.dll 4.00, 4.70, 4.71 or 0 if
it wasnât found at all.  Raises an exception on non-Windows platforms.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def GetDisplayMode(self) -> 'VideoMode':
        """ Get display mode that is used use.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def GetExitOnFrameDelete(self) -> bool:
        """ Returns True if the application will exit when the top-level frame is deleted.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def GetLayoutDirection(self) -> int:
        """ Return the layout direction for the current locale or  Layout_Default   if itâs unknown.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    @staticmethod
    def GetMainTopWindow() -> 'Window':
        """ Returns a pointer to the top application window if any.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def GetTopWindow(self) -> 'Window':
        """ Returns a pointer to the top window.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def GetUseBestVisual(self) -> bool:
        """ Returns True if the application will use the best visual on systems that support different visuals, False otherwise.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def IsActive(self) -> bool:
        """ Returns True if the application is active, i.e. if one of its windows is currently in the foreground.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    @staticmethod
    def IsDisplayAvailable() -> bool:
        """ Returns True if the application is able to connect to the systemâs
display, or whatever the equivallent is for the platform.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def MacHideApp(self) -> None:
        """ Hide all application windows just as the user can do with the
system Hide command.  Mac only.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def MacNewFile(self) -> None:
        """ Called in response of an âopen-applicationâ Apple event.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def MacOpenFile(self, fileName: str) -> None:
        """ Called in response of an âopen-documentâ Apple event.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def MacOpenFiles(self, fileNames: list[str]) -> None:
        """ Called in response of an openFiles message.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def MacOpenURL(self, url: str) -> None:
        """ Called in response of a âget-urlâ Apple event.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def MacPrintFile(self, fileName: str) -> None:
        """ Called in response of a âprint-documentâ Apple event.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def MacReopenApp(self) -> None:
        """ Called in response of a âreopen-applicationâ Apple event.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def OSXEnableAutomaticTabbing(self, enable: bool) -> None:
        """ Enable the automatic tabbing features of macOS.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def OSXIsGUIApplication(self) -> bool:
        """ May be overridden to indicate that the application is not a foreground GUI application under macOS.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SafeYield(self, win, onlyIfNeeded) -> bool:
        """ This function is similar to wx.Yield     , except that it disables the user input to all program windows before calling wx.AppConsole.Yield   and re-enables it again afterwards.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SafeYieldFor(self, win, eventsToProcess) -> bool:
        """ Works like wx.SafeYield       with onlyIfNeeded  == True except that it allows the caller to specify a mask of events to be processed.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SetAssertMode(self, wxAppAssertMode: AppAssertMode) -> None:
        """ Set the mode indicating how the application responds to  assertion
statements. Valid settings are a combination of these flags:

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SetDisplayMode(self, info: 'VideoMode') -> bool:
        """ Set display mode to use.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SetExitOnFrameDelete(self, flag: bool) -> None:
        """ Allows the programmer to specify whether the application will exit when the top-level frame is deleted.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SetNativeTheme(self, theme: str) -> bool:
        """ Allows runtime switching of the UI environment theme.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SetTopWindow(self, window: 'Window') -> None:
        """ Sets the âtopâ window.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    def SetUseBestVisual(self, flag, forceTrueColour=False) -> None:
        """ Allows the programmer to specify whether the application will use the best visual on systems that support several visual on the same display.

            Source: https://docs.wxpython.org/wx.PyApp.html
        """

    AssertMode: AppAssertMode  # See GetAssertMode and SetAssertMode
    DisplayMode: 'VideoMode'  # See GetDisplayMode and SetDisplayMode
    ExitOnFrameDelete: bool  # See GetExitOnFrameDelete and SetExitOnFrameDelete
    LayoutDirection: int  # See GetLayoutDirection
    TopWindow: 'Window'  # See GetTopWindow and SetTopWindow
    UseBestVisual: bool  # See GetUseBestVisual and SetUseBestVisual



class AppConsole(EvtHandler,EventFilter):
    """ This class is essential for writing console-only or hybrid apps
without having to define USE_GUI=0.

        Source: https://docs.wxpython.org/wx.AppConsole.html
    """
    def DeletePendingEvents(self) -> None:
        """ Deletes the pending events of all EvtHandlers of this application.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def ExitMainLoop(self) -> None:
        """ Call this to explicitly exit the main message (event) loop.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def FilterEvent(self, event: 'Event') -> int:
        """ Overridden   wx.EventFilter  method.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def GetAppDisplayName(self) -> str:
        """ Returns the user-readable application name.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def GetAppName(self) -> str:
        """ Returns the application name.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def GetClassName(self) -> str:
        """ Gets the class name of the application.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    @staticmethod
    def GetInstance() -> 'AppConsole':
        """ Returns the one and only global application object.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def GetMainLoop(self) -> 'EventLoopBase':
        """ Returns the main event loop instance, i.e. the event loop which is started by OnRun   and which dispatches all events sent from the native toolkit to the application (except when new event loops are temporarily set-up).

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def GetTraits(self) -> 'AppTraits':
        """ Returns a pointer to the   wx.AppTraits  object for the application.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def GetVendorDisplayName(self) -> str:
        """ Returns the user-readable vendor name.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def GetVendorName(self) -> str:
        """ Returns the applicationâs vendor name.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def HasPendingEvents(self) -> bool:
        """ Returns True if there are pending events on the internal pending event list.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    @staticmethod
    def IsMainLoopRunning() -> bool:
        """ Returns True if the main event loop is currently running, i.e. if the application is inside OnRun .

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def IsScheduledForDestruction(self, object: 'Object') -> bool:
        """ Check if the object had been scheduled for destruction with ScheduleForDestruction .

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def MainLoop(self) -> int:
        """ Called by wxWidgets on creation of the application.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def OnEventLoopEnter(self, loop: 'EventLoopBase') -> None:
        """ Called by wx.EventLoopBase.SetActive : you can override this function and put here the code which needs an active event loop.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def OnEventLoopExit(self, loop: 'EventLoopBase') -> None:
        """ Called by wx.EventLoopBase.OnExit   for each event loop which is exited.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def OnExit(self) -> int:
        """ Override this member function for any processing which needs to be done as the application is about to exit.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def OnInit(self) -> bool:
        """ This must be provided by the application, and will usually create the applicationâs main window, optionally calling SetTopWindow().

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def OnRun(self) -> int:
        """ This virtual function is where the execution of a program written in wxWidgets starts.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def ProcessPendingEvents(self) -> None:
        """ Process all pending events; it is necessary to call this function to process events posted with wx.EvtHandler.QueueEvent   or wx.EvtHandler.AddPendingEvent .

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def ResumeProcessingOfPendingEvents(self) -> None:
        """ Resume processing of the pending events previously stopped because of a call to SuspendProcessingOfPendingEvents .

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def ScheduleForDestruction(self, object: 'Object') -> None:
        """ Delayed objects destruction.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def SetAppDisplayName(self, name: str) -> None:
        """ Set the application name to be used in the user-visible places such as window titles.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def SetAppName(self, name: str) -> None:
        """ Sets the name of the application.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def SetCLocale(self) -> None:
        """ Sets the C locale to the default locale for the current environment.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def SetClassName(self, name: str) -> None:
        """ Sets the class name of the application.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    @staticmethod
    def SetInstance(app: 'AppConsole') -> None:
        """ Allows external code to modify global wx.TheApp     , but you should really know what youâre doing if you call it.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def SetVendorDisplayName(self, name: str) -> None:
        """ Set the vendor name to be used in the user-visible places.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def SetVendorName(self, name: str) -> None:
        """ Sets the name of applicationâs vendor.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def SuspendProcessingOfPendingEvents(self) -> None:
        """ Temporary suspends processing of the pending events.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def UsesEventLoop(self) -> bool:
        """ Returns True if the application is using an event loop.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    def Yield(self, onlyIfNeeded: bool=False) -> bool:
        """ Yields control to pending messages in the event loop.

            Source: https://docs.wxpython.org/wx.AppConsole.html
        """

    AppDisplayName: str  # See GetAppDisplayName and SetAppDisplayName
    AppName: str  # See GetAppName and SetAppName
    ClassName: str  # See GetClassName and SetClassName
    Traits: 'AppTraits'  # See GetTraits
    VendorDisplayName: str  # See GetVendorDisplayName and SetVendorDisplayName
    VendorName: str  # See GetVendorName and SetVendorName



class AppTraits:
    """ The AppTraits class defines various configurable aspects of a App.

        Source: https://docs.wxpython.org/wx.AppTraits.html
    """
    def CreateConfig(self) -> 'ConfigBase':
        """ Called by wxWidgets to create the default configuration object for the application.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def CreateEventLoop(self) -> 'EventLoopBase':
        """ Used by wxWidgets to create the main event loop used by wx.App.OnRun .

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def CreateLogTarget(self) -> 'Log':
        """ Creates a   wx.Log  class for the application to use for logging errors.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def GetAssertStackTrace(self) -> str:
        """ Helper function mostly useful for derived classes ShowAssertDialog   implementation.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def GetDesktopEnvironment(self) -> str:
        """ This method returns the name of the desktop environment currently running in a Unix desktop.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def GetStandardPaths(self) -> 'StandardPaths':
        """ Returns the   wx.StandardPaths  object for the application.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def GetToolkitVersion(self) -> tuple:
        """ Returns the wxWidgets port ID used by the running program and eventually fills the given pointers with the values of the major, minor, and micro digits of the native toolkit currently used.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def HasStderr(self) -> bool:
        """ Returns True if  fprintf(stderr)   goes somewhere, False otherwise.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def IsUsingUniversalWidgets(self) -> bool:
        """ Returns True if the library was built as wxUniversal.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def SafeMessageBox(self, text, title) -> bool:
        """ Shows a message box with the given text and title if possible.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    def ShowAssertDialog(self, msg: str) -> bool:
        """ Shows the assert dialog with the specified message in GUI mode or just prints the string to stderr in console mode.

            Source: https://docs.wxpython.org/wx.AppTraits.html
        """

    AssertStackTrace: str  # See GetAssertStackTrace
    DesktopEnvironment: str  # See GetDesktopEnvironment
    StandardPaths: 'StandardPaths'  # See GetStandardPaths
    ToolkitVersion: tuple  # See GetToolkitVersion



PORT_GTK: int

class ArchiveFSHandler(FileSystemHandler):
    """ A file system handler for accessing files inside of archives.

        Source: https://docs.wxpython.org/wx.ArchiveFSHandler.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ArchiveFSHandler.html
        """

    def Cleanup(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ArchiveFSHandler.html
        """



class ArtProvider(Object):
    """ ArtProvider class is used to customize the look of wxWidgets
application.

        Source: https://docs.wxpython.org/wx.ArtProvider.html
    """
    def CreateBitmap(self, id, client, size) -> 'Bitmap':
        """ Derived art provider classes may override this method to create requested art resource.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    def CreateIconBundle(self, id, client) -> 'IconBundle':
        """ This method is similar to CreateBitmap   but can be used when a bitmap (or an icon) exists in several sizes.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def Delete(provider: 'ArtProvider') -> bool:
        """ Delete the given provider.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetBitmap(id, client=ART_OTHER, size=DefaultSize) -> 'Bitmap':
        """ Query registered providers for bitmap with given ID.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetBitmapBundle(id, client=ART_OTHER, size=DefaultSize) -> 'BitmapBundle':
        """ Query registered providers for a bundle of bitmaps with given ID.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetDIPSizeHint(client: 'ArtClient') -> 'Size':
        """ Returns a suitable size hint for the given ArtClient  in DIPs.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetIcon(id, client=ART_OTHER, size=DefaultSize) -> 'Icon':
        """ Same as wx.ArtProvider.GetBitmap , but return a   wx.Icon  object (or wx.NullIcon       on failure).

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetIconBundle(id, client=ART_OTHER) -> 'IconBundle':
        """ Query registered providers for icon bundle with given ID.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetMessageBoxIcon(flags: int) -> 'Icon':
        """ Helper used by several generic classes: return the icon corresponding to the standard ICON_INFORMATION/WARNING/ERROR/QUESTION flags (only one can be set)

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetMessageBoxIconId(flags: int) -> int:
        """ Helper used by GetMessageBoxIcon : return the art id corresponding to the standard ICON_INFORMATION/WARNING/ERROR/QUESTION flags (only one can be set)

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetNativeDIPSizeHint(client: 'ArtClient') -> 'Size':
        """ Returns native icon size for use specified by client  hint in DIPs.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetNativeSizeHint(client, win=None) -> 'Size':
        """ Returns native icon size for use specified by client  hint.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def GetSizeHint(client, win=None) -> 'Size':
        """ Returns a suitable size hint for the given ArtClient.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def HasNativeProvider() -> bool:
        """ Returns True if the platform uses native icons provider that should take precedence over any customizations.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def Pop() -> bool:
        """ Remove latest added provider and delete it.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def Push(provider: 'ArtProvider') -> None:
        """ Register new art provider and add it to the top of providers stack (i.e.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def PushBack(provider: 'ArtProvider') -> None:
        """ Register new art provider and add it to the bottom of providers stack.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """

    @staticmethod
    def Remove(provider: 'ArtProvider') -> bool:
        """ Remove a provider from the stack if it is on it.

            Source: https://docs.wxpython.org/wx.ArtProvider.html
        """



ART_ERROR: int

ART_GOTO_LAST: int

ART_FILE_SAVE_AS: int

ART_QUESTION: int

ART_PRINT: int

ART_DELETE: int

ART_WARNING: int

ART_HELP: int

ART_COPY: int

ART_INFORMATION: int

ART_TIP: int

ART_CUT: int

ART_ADD_BOOKMARK: int

ART_REPORT_VIEW: int

ART_PASTE: int

ART_DEL_BOOKMARK: int

ART_LIST_VIEW: int

ART_UNDO: int

ART_HELP_SIDE_PANEL: int

ART_NEW_DIR: int

ART_REDO: int

ART_HELP_SETTINGS: int

ART_FOLDER: int

ART_PLUS: int

ART_HELP_BOOK: int

ART_FOLDER_OPEN: int

ART_MINUS: int

ART_HELP_FOLDER: int

ART_GO_DIR_UP: int

ART_CLOSE: int

ART_HELP_PAGE: int

ART_EXECUTABLE_FILE: int

ART_QUIT: int

ART_GO_BACK: int

ART_NORMAL_FILE: int

ART_FIND: int

ART_GO_FORWARD: int

ART_TICK_MARK: int

ART_FIND_AND_REPLACE: int

ART_GO_UP: int

ART_CROSS_MARK: int

ART_HARDDISK: int

ART_GO_DOWN: int

ART_MISSING_IMAGE: int

ART_FLOPPY: int

ART_GO_TO_PARENT: int

ART_NEW: int

ART_CDROM: int

ART_GO_HOME: int

ART_FILE_OPEN: int

ART_GOTO_FIRST: int

ART_FILE_SAVE: int

ART_OTHER: int

ART_FRAME_ICON: int

class AutoBufferedPaintDC(BufferedPaintDC):
    """ This DC derivative can be used inside of an EVT_PAINT() event
handler to achieve double-buffered drawing.

        Source: https://docs.wxpython.org/wx.AutoBufferedPaintDC.html
    """
    def __init__(self, window: 'Window') -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.AutoBufferedPaintDC.html
        """



BG_STYLE_PAINT: int

class DC(Object):
    """ A DC is a âdevice contextâ onto which graphics and text can be
drawn.

        Source: https://docs.wxpython.org/wx.DC.html
    """
    def Blit(self, xdest, ydest, width, height, source, xsrc, ysrc, logicalFunc=COPY, useMask=False, xsrcMask=DefaultCoord, ysrcMask=DefaultCoord) -> bool:
        """ Copy from a source DC to this DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def CalcBoundingBox(self, x, y) -> None:
        """ Adds the specified point to the bounding box which can be retrieved with MinX , MaxX   and MinY , MaxY   functions.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def CanDrawBitmap(self) -> bool:
        """ Does the DC support drawing bitmaps?

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def CanGetTextExtent(self) -> bool:
        """ Does the DC support calculating the size required to draw text?

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def CanUseTransformMatrix(self) -> bool:
        """ Check if the use of transformation matrix is supported by the current system.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def Clear(self) -> None:
        """ Clears the device context using the current background brush.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def CopyAttributes(self, dc: 'DC') -> None:
        """ Copy attributes from another DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def CrossHair(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DestroyClippingRegion(self) -> None:
        """ Destroys the current clipping region so that none of the DC is clipped.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DeviceToLogical(self, *args, **kw) -> 'Point':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DeviceToLogicalRel(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DeviceToLogicalX(self, x: int) -> 'Coord':
        """ Convert device  X coordinate to logical coordinate, using the current mapping mode, user scale factor, device origin and axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DeviceToLogicalXRel(self, x: int) -> 'Coord':
        """ Convert device  X coordinate to relative logical coordinate, using the current mapping mode and user scale factor but ignoring the axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DeviceToLogicalY(self, y: int) -> 'Coord':
        """ Converts device  Y coordinate to logical coordinate, using the current mapping mode, user scale factor, device origin and axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DeviceToLogicalYRel(self, y: int) -> 'Coord':
        """ Convert device  Y coordinate to relative logical coordinate, using the current mapping mode and user scale factor but ignoring the axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawArc(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawBitmap(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawCheckMark(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawCircle(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawEllipse(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawEllipseList(self, ellipses, pens=None, brushes=None) -> None:
        """ Draw a list of ellipses as quickly as possible.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawEllipticArc(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawIcon(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawLabel(self, *args, **kw) -> 'Rect':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawLine(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawLineList(self, lines, pens=None) -> None:
        """ Draw a list of lines as quickly as possible.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawLines(self, points, xoffset=0, yoffset=0) -> None:
        """ This method uses a list of Points, adding the optional offset coordinate.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawLinesFromBuffer(self, pyBuff: Any) -> None:
        """ Implementation of DrawLines that can use numpy arrays, or anything else that uses the
python buffer protocol directly without any element conversion.  This provides a
significant performance increase over the standard DrawLines function.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawPoint(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawPointList(self, points, pens=None) -> None:
        """ Draw a list of points as quickly as possible.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawPolygon(self, points, xoffset=0, yoffset=0, fill_style=ODDEVEN_RULE) -> None:
        """ This method draws a filled polygon using a list of Points, adding the optional offset coordinate.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawPolygonList(self, polygons, pens=None, brushes=None) -> None:
        """ Draw a list of polygons, each of which is a list of points.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawRectangle(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawRectangleList(self, rectangles, pens=None, brushes=None) -> None:
        """ Draw a list of rectangles as quickly as possible.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawRotatedText(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawRoundedRectangle(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawSpline(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawText(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def DrawTextList(self, textList, coords, foregrounds=None, backgrounds=None) -> None:
        """ Draw a list of strings using a list of coordinants for positioning each string.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def EndDoc(self) -> None:
        """ Ends a document (only relevant when outputting to a printer).

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def EndPage(self) -> None:
        """ Ends a document page (only relevant when outputting to a printer).

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def FloodFill(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def FromDIP(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetAsBitmap(self, subrect: Optional['Rect']=None) -> 'Bitmap':
        """ If supported by the platform and the type of DC, fetch the contents of the DC, or a subset of it, as a bitmap.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetBackground(self) -> 'Brush':
        """ Gets the brush used for painting the background.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetBackgroundMode(self) -> int:
        """ Returns the current background mode:  BRUSHSTYLE_SOLID   or   BRUSHSTYLE_TRANSPARENT .

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetBoundingBox(self) -> None:
        """ Returns the min and max points used in drawing commands so far.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetBrush(self) -> 'Brush':
        """ Gets the current brush.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetCGContext(self) -> 'UIntPtr':
        """ wx.UIntPtr

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetCharHeight(self) -> 'Coord':
        """ Gets the character height of the currently set font.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetCharWidth(self) -> 'Coord':
        """ Gets the average character width of the currently set font.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetClippingBox(self) -> tuple:
        """ Gets the rectangle surrounding the current clipping region.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetClippingRect(self) -> None:
        """ Returns the rectangle surrounding the current clipping region as a wx.Rect.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetContentScaleFactor(self) -> float:
        """ Returns the factor used for converting logical pixels to physical ones.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetDepth(self) -> int:
        """ Returns the depth (number of bits/pixel) of this DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetDeviceOrigin(self) -> 'Point':
        """ Returns the current device origin.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetFont(self) -> 'Font':
        """ Gets the current font.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetFontMetrics(self) -> 'FontMetrics':
        """ Returns the various font characteristics.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetGdkDrawable(self) -> 'UIntPtr':
        """ wx.UIntPtr

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetGraphicsContext(self) -> 'GraphicsContext':
        """ If supported by the platform and the  `   wx.DC `   implementation, this method will return the  `   wx.GraphicsContext `   associated with the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetHDC(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetHandle(self) -> 'UIntPtr':
        """ Returns a value that can be used as a handle to the native drawing context, if this   wx.DC  has something that could be thought of in that way.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetLayoutDirection(self) -> int:
        """ Gets the current layout direction of the device context.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetLogicalFunction(self) -> 'RasterOperationMode':
        """ Gets the current logical function.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetLogicalOrigin(self) -> tuple:
        """ Return the coordinates of the logical point (0, 0).

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetLogicalScale(self) -> tuple:
        """ Return the scale set by the last call to SetLogicalScale .

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetMapMode(self) -> 'MappingMode':
        """ Gets the current mapping mode for the device context.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetFullMultiLineTextExtent(self, string, font=None) -> tuple:
        """ Gets the dimensions of the string as it would be drawn.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetMultiLineTextExtent(self, st: Any) -> None:
        """ Return the dimensions of the given stringâs text extent using the
currently selected font, taking into account multiple lines if
present in the string.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetPPI(self) -> 'Size':
        """ Returns the resolution of the device in pixels per inch.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetPartialTextExtents(self, text) -> None:
        """ Fills the widths  array with the widths from the beginning of text  to the corresponding character of text.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetPen(self) -> 'Pen':
        """ Gets the current pen.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetPixel(self, x, y) -> 'Colour':
        """ Gets the colour at the specified location on the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetSize(self) -> 'Size':
        """ This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetSizeMM(self) -> 'Size':
        """ This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetTextBackground(self) -> 'Colour':
        """ Gets the current text background colour.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetFullTextExtent(self, string, font=None) -> tuple:
        """ Gets the dimensions of the string as it would be drawn.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetTextExtent(self, st: Any) -> None:
        """ Return the dimensions of the given stringâs text extent using the
currently selected font.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetTextForeground(self) -> 'Colour':
        """ Gets the current text foreground colour.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetTransformMatrix(self) -> 'AffineMatrix2D':
        """ Return the transformation matrix used by this device context.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GetUserScale(self) -> None:
        """ Gets the current user scale factor.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GradientFillConcentric(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def GradientFillLinear(self, rect, initialColour, destColour, nDirection=RIGHT) -> None:
        """ Fill the area specified by rect  with a linear gradient, starting from initialColour  and eventually fading to destColour.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the DC is ok to use.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def LogicalToDevice(self, *args, **kw) -> 'Point':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def LogicalToDeviceRel(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def LogicalToDeviceX(self, x: int) -> 'Coord':
        """ Converts logical X coordinate to device coordinate, using the current mapping mode, user scale factor, device origin and axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def LogicalToDeviceXRel(self, x: int) -> 'Coord':
        """ Converts logical X coordinate to relative device coordinate, using the current mapping mode and user scale factor but ignoring the axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def LogicalToDeviceY(self, y: int) -> 'Coord':
        """ Converts logical Y coordinate to device coordinate, using the current mapping mode, user scale factor, device origin and axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def LogicalToDeviceYRel(self, y: int) -> 'Coord':
        """ Converts logical Y coordinate to relative device coordinate, using the current mapping mode and user scale factor but ignoring the axis orientation.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def MaxX(self) -> 'Coord':
        """ Gets the maximum horizontal extent used in drawing commands so far.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def MaxY(self) -> 'Coord':
        """ Gets the maximum vertical extent used in drawing commands so far.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def MinX(self) -> 'Coord':
        """ Gets the minimum horizontal extent used in drawing commands so far.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def MinY(self) -> 'Coord':
        """ Gets the minimum vertical extent used in drawing commands so far.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def ResetBoundingBox(self) -> None:
        """ Resets the bounding box: after a call to this function, the bounding box doesnât contain anything.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def ResetTransformMatrix(self) -> None:
        """ Revert the transformation matrix to identity matrix.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetAxisOrientation(self, xLeftRight, yBottomUp) -> None:
        """ Sets the x and y axis orientation (i.e. the direction from lowest to highest values on the axis).

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetBackground(self, brush: 'Brush') -> None:
        """ Sets the current background brush for the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetBackgroundMode(self, mode: int) -> None:
        """ Change the current background mode.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetBrush(self, brush: 'Brush') -> None:
        """ Sets the current brush for the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetClippingRegion(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetDeviceClippingRegion(self, region: 'Region') -> None:
        """ Sets the clipping region for this device context.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetDeviceOrigin(self, x, y) -> None:
        """ Sets the device origin (i.e. the origin in pixels after scaling has been applied).

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetFont(self, font: 'Font') -> None:
        """ Sets the current font for the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetGraphicsContext(self, ctx: 'GraphicsContext') -> None:
        """ Associate a   wx.GraphicsContext  with the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetLayoutDirection(self, dir: int) -> None:
        """ Sets the current layout direction for the device context.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetLogicalFunction(self, function: RasterOperationMode) -> None:
        """ Sets the current logical function for the device context.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetLogicalOrigin(self, x, y) -> None:
        """ Change the offset used for translating   wx.DC  coordinates.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetLogicalScale(self, x, y) -> None:
        """ Set the scale to use for translating   wx.DC  coordinates to the physical pixels.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetMapMode(self, mode: MappingMode) -> None:
        """ The mapping mode of the device context defines the unit of measurement used to convert logical  units to device  units.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetPalette(self, palette: 'Palette') -> None:
        """ If this is a window DC or memory DC, assigns the given palette to the window or bitmap associated with the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetPen(self, pen: 'Pen') -> None:
        """ Sets the current pen for the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetTextBackground(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the current text background colour for the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetTextForeground(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the current text foreground colour for the DC.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetTransformMatrix(self, matrix: 'AffineMatrix2D') -> bool:
        """ Set the transformation matrix.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def SetUserScale(self, xScale, yScale) -> None:
        """ Sets the user scaling factor, useful for applications which require âzoomingâ.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def StartDoc(self, message: str) -> bool:
        """ Starts a document (only relevant when outputting to a printer).

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def StartPage(self) -> None:
        """ Starts a document page (only relevant when outputting to a printer).

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def StretchBlit(self, xdest, ydest, dstWidth, dstHeight, source, xsrc, ysrc, srcWidth, srcHeight, logicalFunc=COPY, useMask=False, xsrcMask=DefaultCoord, ysrcMask=DefaultCoord) -> bool:
        """ Copy from a source DC to this DC possibly changing the scale.

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def ToDIP(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def _DrawEllipseList(self, pyCoords, pyPens, pyBrushes) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def _DrawLineList(self, pyCoords, pyPens, pyBrushes) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def _DrawLinesFromBuffer(self, pyBuff) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def _DrawPointList(self, pyCoords, pyPens, pyBrushes) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def _DrawPolygonList(self, pyCoords, pyPens, pyBrushes) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def _DrawRectangleList(self, pyCoords, pyPens, pyBrushes) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def _DrawTextList(self, textList, pyPoints, foregroundList, backgroundList) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DC.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.DC.html
        """

    AsBitmap: 'Bitmap'  # See GetAsBitmap
    Background: 'Brush'  # See GetBackground and SetBackground
    BackgroundMode: int  # See GetBackgroundMode and SetBackgroundMode
    BoundingBox: None  # See GetBoundingBox
    Brush: 'Brush'  # See GetBrush and SetBrush
    CGContext: 'UIntPtr'  # See GetCGContext
    CharHeight: 'Coord'  # See GetCharHeight
    CharWidth: 'Coord'  # See GetCharWidth
    ClippingRect: None  # See GetClippingRect
    ContentScaleFactor: float  # See GetContentScaleFactor
    Depth: int  # See GetDepth
    DeviceOrigin: 'Point'  # See GetDeviceOrigin and SetDeviceOrigin
    Font: 'Font'  # See GetFont and SetFont
    FontMetrics: 'FontMetrics'  # See GetFontMetrics
    GdkDrawable: 'UIntPtr'  # See GetGdkDrawable
    GraphicsContext: 'GraphicsContext'  # See GetGraphicsContext and SetGraphicsContext
    HDC: int  # See GetHDC
    Handle: 'UIntPtr'  # See GetHandle
    LayoutDirection: int  # See GetLayoutDirection and SetLayoutDirection
    LogicalFunction: RasterOperationMode  # See GetLogicalFunction and SetLogicalFunction
    MapMode: MappingMode  # See GetMapMode and SetMapMode
    MultiLineTextExtent: None  # See GetMultiLineTextExtent
    PPI: 'Size'  # See GetPPI
    Pen: 'Pen'  # See GetPen and SetPen
    Pixel: 'Colour'  # See GetPixel
    Size: 'Size'  # See GetSize
    SizeMM: 'Size'  # See GetSizeMM
    TextBackground: Union[int, str, 'Colour']  # See GetTextBackground and SetTextBackground
    TextExtent: None  # See GetTextExtent
    TextForeground: Union[int, str, 'Colour']  # See GetTextForeground and SetTextForeground
    TransformMatrix: 'AffineMatrix2D'  # See GetTransformMatrix and SetTransformMatrix



BLACK: int

WHITE: int

ODDEVEN_RULE: int

WINDING_RULE: int

FLOOD_SURFACE: int

FLOOD_BORDER: int

class PostScriptDC(DC):
    """ This defines the wxWidgets Encapsulated PostScript device context,
which can write PostScript files on any platform.

        Source: https://docs.wxpython.org/wx.PostScriptDC.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PostScriptDC.html
        """



class MetafileDC(DC):
    """ This is a type of device context that allows a metafile object to be
created (Windows only), and has most of the characteristics of a
normal DC.

        Source: https://docs.wxpython.org/wx.MetafileDC.html
    """
    def __init__(self, filename: str="") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MetafileDC.html
        """

    def Close(self) -> 'Metafile':
        """ This must be called after the device context is finished with.

            Source: https://docs.wxpython.org/wx.MetafileDC.html
        """



NullColour: int

class PaintDC(ClientDC):
    """ A PaintDC must be constructed if an application wishes to paint on
the client area of a window from within an EVT_PAINT() event handler.

        Source: https://docs.wxpython.org/wx.PaintDC.html
    """
    def __init__(self, window: 'Window') -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PaintDC.html
        """



class BitmapBundle:
    """ Contains representations of the same bitmap in different resolutions.

        Source: https://docs.wxpython.org/wx.BitmapBundle.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def Clear(self) -> None:
        """ Clear the existing bundle contents.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromBitmap(bitmap: 'Bitmap') -> 'BitmapBundle':
        """ Create a bundle from a single bitmap.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromBitmaps(*args, **kw) -> 'BitmapBundle':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromFiles(*args, **kw) -> 'BitmapBundle':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromIconBundle(iconBundle: 'IconBundle') -> 'BitmapBundle':
        """ Create a bundle from an icon bundle.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromImage(image: 'Image') -> 'BitmapBundle':
        """ Create a bundle from a single image.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromImpl(impl: 'BitmapBundleImpl') -> 'BitmapBundle':
        """ Create a bundle from a custom bitmap bundle implementation.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromResources(name: str) -> 'BitmapBundle':
        """ Create a bundle from the bitmaps in the application resources.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromSVG(data, sizeDef) -> 'BitmapBundle':
        """ This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromSVGFile(path, sizeDef) -> 'BitmapBundle':
        """ Create a bundle from the SVG image loaded from the given file.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    @staticmethod
    def FromSVGResource(name, sizeDef) -> 'BitmapBundle':
        """ Create a bundle from the SVG image loaded from an application resource.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetBitmap(self, size: Union[tuple[int, int], 'Size']) -> 'Bitmap':
        """ Get bitmap of the specified size, creating a new bitmap from the closest available size by rescaling it if necessary.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetBitmapFor(self, window: 'Window') -> 'Bitmap':
        """ Get bitmap of the size appropriate for the DPI scaling used by the given window.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetDefaultSize(self) -> 'Size':
        """ Get the size of the bitmap represented by this bundle in default resolution or, equivalently, at 100% scaling.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetIcon(self, size: Union[tuple[int, int], 'Size']) -> 'Icon':
        """ Get icon of the specified size.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetIconFor(self, window: 'Window') -> 'Icon':
        """ Get icon of the size appropriate for the DPI scaling used by the given window.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetPreferredBitmapSizeAtScale(self, scale: float) -> 'Size':
        """ Get the size that would be best to use for this bundle at the given DPI scaling factor.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetPreferredBitmapSizeFor(self, window: 'Window') -> 'Size':
        """ Get the size that would be best to use for this bundle at the DPI scaling factor used by the given window.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def GetPreferredLogicalSizeFor(self, window: 'Window') -> 'Size':
        """ Get the size that would be best to use for this bundle at the DPI scaling factor used by the given window in logical size.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def IsOk(self) -> bool:
        """ Check if bitmap bundle is non-empty.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    def IsSameAs(self, other: 'BitmapBundle') -> bool:
        """ Check if the two bundles refer to the same object.

            Source: https://docs.wxpython.org/wx.BitmapBundle.html
        """

    DefaultSize: 'Size'  # See GetDefaultSize



class BitmapBundleImpl(RefCounter):
    """ Base class for custom implementations of BitmapBundle.

        Source: https://docs.wxpython.org/wx.BitmapBundleImpl.html
    """
    def DoGetPreferredSize(self, scale: float) -> 'Size':
        """ Helper for implementing GetPreferredBitmapSizeAtScale   in the derived classes.

            Source: https://docs.wxpython.org/wx.BitmapBundleImpl.html
        """

    def GetBitmap(self, size: Union[tuple[int, int], 'Size']) -> 'Bitmap':
        """ Retrieve the bitmap of exactly the given size.

            Source: https://docs.wxpython.org/wx.BitmapBundleImpl.html
        """

    def GetDefaultSize(self) -> 'Size':
        """ Return the size of the bitmaps represented by this bundle in the default DPI.

            Source: https://docs.wxpython.org/wx.BitmapBundleImpl.html
        """

    def GetIndexToUpscale(self, size: Union[tuple[int, int], 'Size']) -> int:
        """ Return the index of the available scale most suitable to be upscaled to the given size.

            Source: https://docs.wxpython.org/wx.BitmapBundleImpl.html
        """

    def GetNextAvailableScale(self, idx: int) -> tuple:
        """ Return information about the available bitmaps.

            Source: https://docs.wxpython.org/wx.BitmapBundleImpl.html
        """

    def GetPreferredBitmapSizeAtScale(self, scale: float) -> 'Size':
        """ Return the preferred size that should be used at the given scale.

            Source: https://docs.wxpython.org/wx.BitmapBundleImpl.html
        """

    DefaultSize: 'Size'  # See GetDefaultSize



class BitmapButton(Button):
    """ A bitmap button is a control that contains a bitmap.

        Source: https://docs.wxpython.org/wx.BitmapButton.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BitmapButton.html
        """

    def Create(self, parent, id=ID_ANY, bitmap=NullBitmap, pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=ButtonNameStr) -> bool:
        """ Button creation function for two-step creation.

            Source: https://docs.wxpython.org/wx.BitmapButton.html
        """

    def CreateCloseButton(self, parent, winid, name="") -> bool:
        """ Creation function for two-step creation of âCloseâ button.

            Source: https://docs.wxpython.org/wx.BitmapButton.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.BitmapButton.html
        """

    @staticmethod
    def NewCloseButton(parent, winid, name="") -> 'BitmapButton':
        """ Helper function creating a standard-looking âCloseâ button.

            Source: https://docs.wxpython.org/wx.BitmapButton.html
        """



BU_LEFT: int  # Left-justifies the bitmap label.

BU_TOP: int  # Aligns the bitmap label to the top of the button.

BU_RIGHT: int  # Right-justifies the bitmap label.

BU_BOTTOM: int  # Aligns the bitmap label to the bottom of the button. ^^

EVT_BUTTON: int  # Process a  wxEVT_BUTTON   event, when the button is clicked. ^^

BU_EXACTFIT: int

class BitmapDataObject(DataObjectSimple):
    """ BitmapDataObject is a specialization of DataObject for bitmap
data.

        Source: https://docs.wxpython.org/wx.BitmapDataObject.html
    """
    def __init__(self, bitmap: 'Bitmap'=NullBitmap) -> None:
        """ Constructor, optionally passing a bitmap (otherwise use SetBitmap   later).

            Source: https://docs.wxpython.org/wx.BitmapDataObject.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.BitmapDataObject.html
        """

    def GetBitmap(self) -> 'Bitmap':
        """ Returns the bitmap associated with the data object.

            Source: https://docs.wxpython.org/wx.BitmapDataObject.html
        """

    def SetBitmap(self, bitmap: 'Bitmap') -> None:
        """ Sets the bitmap associated with the data object.

            Source: https://docs.wxpython.org/wx.BitmapDataObject.html
        """

    def SetData(self, format, buf) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.BitmapDataObject.html
        """

    AllFormats: None  # See GetAllFormats
    Bitmap: 'Bitmap'  # See GetBitmap and SetBitmap



class DataObject:
    """ A DataObject represents data that can be copied to or from the
clipboard, or dragged and dropped.

        Source: https://docs.wxpython.org/wx.DataObject.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def GetAllFormats(self, dir=Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def GetDataHere(self, format, buf) -> bool:
        """ Copies this data objectâs data in the requested format to the buffer provided.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def GetDataSize(self, format: 'DataFormat') -> int:
        """ Returns the data size of the given format format.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def GetFormatCount(self, dir: int=Get) -> int:
        """ Returns the number of available formats for rendering or setting the data.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def GetPreferredFormat(self, dir: int=Get) -> 'DataFormat':
        """ Returns the preferred format for either rendering the data (if dir  is  Get , its default value) or for setting it.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def IsSupported(self, format, dir=Get) -> bool:
        """ Returns True if this format is supported.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def SetData(self, format, buf) -> bool:
        """ Copies data from the provided buffer to this data object for the specified format.

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    def _testGetAllFormats(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DataObject.html
        """

    AllFormats: None  # See GetAllFormats
    DataHere: bool  # See GetDataHere
    FormatCount: int  # See GetFormatCount
    PreferredFormat: 'DataFormat'  # See GetPreferredFormat



class BitmapToggleButton(ToggleButton):
    """ BitmapToggleButton is a ToggleButton that contains a bitmap
instead of text.

        Source: https://docs.wxpython.org/wx.BitmapToggleButton.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BitmapToggleButton.html
        """

    def Create(self, parent, id=ID_ANY, label=NullBitmap, pos=DefaultPosition, size=DefaultSize, style=0, val=DefaultValidator, name=CheckBoxNameStr) -> bool:
        """ Create method for two-step construction.

            Source: https://docs.wxpython.org/wx.BitmapToggleButton.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.BitmapToggleButton.html
        """

    def GetValue(self) -> bool:
        """ Gets the state of the toggle button.

            Source: https://docs.wxpython.org/wx.BitmapToggleButton.html
        """

    def SetValue(self, state: bool) -> None:
        """ Sets the toggle button to the given state.

            Source: https://docs.wxpython.org/wx.BitmapToggleButton.html
        """

    Value: bool  # See GetValue and SetValue



EVT_TOGGLEBUTTON: int  # Handles a wxEVT_TOGGLEBUTTON event. ^^

class ToggleButton(AnyButton):
    """ ToggleButton is a button that stays pressed when clicked by the
user.

        Source: https://docs.wxpython.org/wx.ToggleButton.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ToggleButton.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=0, val=DefaultValidator, name=CheckBoxNameStr) -> bool:
        """ Creates the toggle button for two-step construction.

            Source: https://docs.wxpython.org/wx.ToggleButton.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ToggleButton.html
        """

    def GetValue(self) -> bool:
        """ Gets the state of the toggle button.

            Source: https://docs.wxpython.org/wx.ToggleButton.html
        """

    def SetValue(self, state: bool) -> None:
        """ Sets the toggle button to the given state.

            Source: https://docs.wxpython.org/wx.ToggleButton.html
        """

    Value: bool  # See GetValue and SetValue



class BookCtrlBase(Control,WithImages):
    """ A book control is a convenient way of displaying multiple pages of
information, displayed one page at a time.

        Source: https://docs.wxpython.org/wx.BookCtrlBase.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def AddPage(self, page, text, select=False, imageId=NO_IMAGE) -> bool:
        """ Adds a new page.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def AdvanceSelection(self, forward: bool=True) -> None:
        """ Cycles through the tabs.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def ChangeSelection(self, page: int) -> int:
        """ Changes the selection to the given page, returning the previous selection.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def Create(self, parent, winid, pos=DefaultPosition, size=DefaultSize, style=0, name="") -> bool:
        """ Constructs the book control with the given parameters.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def DeleteAllPages(self) -> bool:
        """ Deletes all pages.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def DeletePage(self, page: int) -> bool:
        """ Deletes the specified page, and the associated window.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def FindPage(self, page: 'Window') -> int:
        """ Returns the index of the specified tab window or  NOT_FOUND   if not found.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def GetCurrentPage(self) -> 'Window':
        """ Returns the currently selected page or None.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def GetPage(self, page: int) -> 'Window':
        """ Returns the window at the given page position.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def GetPageCount(self) -> int:
        """ Returns the number of pages in the control.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def GetPageImage(self, nPage: int) -> int:
        """ Returns the image index for the given page.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def GetPageText(self, nPage: int) -> str:
        """ Returns the string for the given page.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def GetSelection(self) -> int:
        """ Returns the currently selected page, or  NOT_FOUND   if none was selected.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def HitTest(self, pt: Union[tuple[int, int], 'Point']) -> tuple:
        """ Returns the index of the tab at the specified position or  NOT_FOUND   if none.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def InsertPage(self, index, page, text, select=False, imageId=NO_IMAGE) -> bool:
        """ Inserts a new page at the specified position.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def RemovePage(self, page: int) -> bool:
        """ Deletes the specified page, without deleting the associated window.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def SetPageImage(self, page, image) -> bool:
        """ Sets the image index for the given page.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def SetPageSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the width and height of the pages.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def SetPageText(self, page, text) -> bool:
        """ Sets the text for the given page.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    def SetSelection(self, page: int) -> int:
        """ Sets the selection to the given page, returning the previous selection.

            Source: https://docs.wxpython.org/wx.BookCtrlBase.html
        """

    CurrentPage: 'Window'  # See GetCurrentPage
    PageCount: int  # See GetPageCount
    Selection: int  # See GetSelection and SetSelection



class BookCtrlEvent(NotifyEvent):
    """ This class represents the events generated by book controls
(wxNotebook, Listbook, Choicebook, Treebook, AuiNotebook).

        Source: https://docs.wxpython.org/wx.BookCtrlEvent.html
    """
    def __init__(self, eventType=wxEVT_NULL, id=0, sel=NOT_FOUND, oldSel=NOT_FOUND) -> None:
        """ Constructor (used internally by wxWidgets only).

            Source: https://docs.wxpython.org/wx.BookCtrlEvent.html
        """

    def GetOldSelection(self) -> int:
        """ Returns the page that was selected before the change,  NOT_FOUND   if none was selected.

            Source: https://docs.wxpython.org/wx.BookCtrlEvent.html
        """

    def GetSelection(self) -> int:
        """ Returns the currently selected page, or  NOT_FOUND   if none was selected.

            Source: https://docs.wxpython.org/wx.BookCtrlEvent.html
        """

    def SetOldSelection(self, page: int) -> None:
        """ Sets the id of the page selected before the change.

            Source: https://docs.wxpython.org/wx.BookCtrlEvent.html
        """

    def SetSelection(self, page: int) -> None:
        """ Sets the selection member variable.

            Source: https://docs.wxpython.org/wx.BookCtrlEvent.html
        """

    OldSelection: int  # See GetOldSelection and SetOldSelection
    Selection: int  # See GetSelection and SetSelection



class Notebook(BookCtrlBase):
    """ This class represents a notebook control, which manages multiple
windows with associated tabs.

        Source: https://docs.wxpython.org/wx.Notebook.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def ChangeSelection(self, page: int) -> int:
        """ Changes the selection to the given page, returning the previous selection.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name=NotebookNameStr) -> bool:
        """ Creates a notebook control.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def GetPageImage(self, nPage: int) -> int:
        """ Returns the image index for the given page.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def GetPageText(self, nPage: int) -> str:
        """ Returns the string for the given page.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def GetRowCount(self) -> int:
        """ Returns the number of rows in the notebook control.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def GetSelection(self) -> int:
        """ Returns the currently selected page, or  NOT_FOUND   if none was selected.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def GetThemeBackgroundColour(self) -> 'Colour':
        """ If running under Windows and themes are enabled for the application, this function returns a suitable colour for painting the background of a notebook page, and can be passed to SetBackgroundColour .

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def InsertPage(self, index, page, text, select=False, imageId=NO_IMAGE) -> bool:
        """ Inserts a new page at the specified position.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def SetPadding(self, padding: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the amount of space around each pageâs icon and label, in pixels.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def SetPageImage(self, page, image) -> bool:
        """ Sets the image index for the given page.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def SetPageText(self, page, text) -> bool:
        """ Sets the text for the given page.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    def SetSelection(self, page: int) -> int:
        """ Sets the selection to the given page, returning the previous selection.

            Source: https://docs.wxpython.org/wx.Notebook.html
        """

    RowCount: int  # See GetRowCount
    Selection: int  # See GetSelection and SetSelection
    ThemeBackgroundColour: 'Colour'  # See GetThemeBackgroundColour



NB_TOP: int  # Place tabs on the top side.

NB_LEFT: int  # Place tabs on the left side.

NB_RIGHT: int  # Place tabs on the right side.

NB_BOTTOM: int  # Place tabs under instead of above the notebook pages.

NB_FIXEDWIDTH: int  # (Windows only) All tabs will have same width.

NB_MULTILINE: int  # (Windows only) There can be several rows of tabs.

NB_NOPAGETHEME: int  # (Windows only) Display a solid colour on notebook pages, and not a gradient, which can reduce performance. ^^

EVT_NOTEBOOK_PAGE_CHANGED: int  # The page selection was changed. Processes a  wxEVT_NOTEBOOK_PAGE_CHANGED   event.

EVT_NOTEBOOK_PAGE_CHANGING: int  # The page selection is about to be changed. Processes a  wxEVT_NOTEBOOK_PAGE_CHANGING   event. This event can be vetoed. ^^

CLIP_CHILDREN: int

class Listbook(BookCtrlBase):
    """ Listbook is a class similar to Notebook but which uses a
ListCtrl to show the labels instead of the tabs.

        Source: https://docs.wxpython.org/wx.Listbook.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Listbook.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name="") -> bool:
        """ Create the list book control that has already been constructed with the default constructor.

            Source: https://docs.wxpython.org/wx.Listbook.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Listbook.html
        """

    def GetListView(self, *args, **kw) -> 'ListView':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Listbook.html
        """

    ListView: 'ListView'  # See GetListView



LB_DEFAULT: int  # Choose the default location for the labels depending on the current platform (left everywhere except Mac where it is top).

LB_TOP: int  # Place labels above the page area.

LB_LEFT: int  # Place labels on the left side.

LB_RIGHT: int  # Place labels on the right side.

LB_BOTTOM: int  # Place labels below the page area. ^^

EVT_LISTBOOK_PAGE_CHANGED: int  # The page selection was changed. Processes a  wxEVT_LISTBOOK_PAGE_CHANGED   event.

EVT_LISTBOOK_PAGE_CHANGING: int  # The page selection is about to be changed. Processes a  wxEVT_LISTBOOK_PAGE_CHANGING   event. This event can be vetoed. ^^

class Choicebook(BookCtrlBase):
    """ Choicebook is a class similar to Notebook, but uses a Choice
control to show the labels instead of the tabs.

        Source: https://docs.wxpython.org/wx.Choicebook.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Constructs a choicebook control.

            Source: https://docs.wxpython.org/wx.Choicebook.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name="") -> bool:
        """ Create the choicebook control that has already been constructed with the default constructor.

            Source: https://docs.wxpython.org/wx.Choicebook.html
        """

    def GetChoiceCtrl(self, *args, **kw) -> 'Choice':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Choicebook.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Choicebook.html
        """

    ChoiceCtrl: 'Choice'  # See GetChoiceCtrl



CHB_DEFAULT: int  # Choose the default location for the labels depending on the current platform (but currently itâs the same everywhere, namely wx.CHB_TOP).

CHB_TOP: int  # Place labels above the page area.

CHB_LEFT: int  # Place labels on the left side.

CHB_RIGHT: int  # Place labels on the right side.

CHB_BOTTOM: int  # Place labels below the page area. ^^

EVT_CHOICEBOOK_PAGE_CHANGED: int  # The page selection was changed. Processes a  wxEVT_CHOICEBOOK_PAGE_CHANGED   event.

EVT_CHOICEBOOK_PAGE_CHANGING: int  # The page selection is about to be changed. Processes a  wxEVT_CHOICEBOOK_PAGE_CHANGING   event. This event can be vetoed (using  wx.NotifyEvent.Veto ). ^^

class Treebook(BookCtrlBase):
    """ This class is an extension of the Notebook class that allows a tree
structured set of pages to be shown in a control.

        Source: https://docs.wxpython.org/wx.Treebook.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def AddPage(self, page, text, bSelect=False, imageId=NOT_FOUND) -> bool:
        """ Adds a new page.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def AddSubPage(self, page, text, bSelect=False, imageId=NOT_FOUND) -> bool:
        """ Adds a new child-page to the last top-level page.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def CollapseNode(self, pageId: int) -> bool:
        """ Shortcut for ExpandNode ( pageId, False ).

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=BK_DEFAULT, name="") -> bool:
        """ Creates a treebook control.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def DeletePage(self, pagePos: int) -> bool:
        """ Deletes the page at the specified position and all its children.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def ExpandNode(self, pageId, expand=True) -> bool:
        """ Expands (collapses) the pageId  node.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def GetPageParent(self, page: int) -> int:
        """ Returns the parent page of the given one or  NOT_FOUND   if this is a top-level page.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def GetSelection(self) -> int:
        """ Returns the currently selected page, or  NOT_FOUND   if none was selected.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def GetTreeCtrl(self) -> 'TreeCtrl':
        """ Returns the tree control used for selecting pages.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def InsertPage(self, pagePos, page, text, bSelect=False, imageId=NOT_FOUND) -> bool:
        """ Inserts a new page just before the page indicated by pagePos.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def InsertSubPage(self, pagePos, page, text, bSelect=False, imageId=NOT_FOUND) -> bool:
        """ Inserts a sub page under the specified page.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    def IsNodeExpanded(self, pageId: int) -> bool:
        """ Returns True if the page represented by pageId  is expanded.

            Source: https://docs.wxpython.org/wx.Treebook.html
        """

    Selection: int  # See GetSelection
    TreeCtrl: 'TreeCtrl'  # See GetTreeCtrl



EVT_TREEBOOK_PAGE_CHANGED: int  # The page selection was changed. Processes a  wxEVT_TREEBOOK_PAGE_CHANGED   event.

EVT_TREEBOOK_PAGE_CHANGING: int  # The page selection is about to be changed. Processes a  wxEVT_TREEBOOK_PAGE_CHANGING   event. This event can be  vetoed.

EVT_TREEBOOK_NODE_COLLAPSED: int  # The page node is going to be collapsed. Processes a  wxEVT_TREEBOOK_NODE_COLLAPSED   event.

EVT_TREEBOOK_NODE_EXPANDED: int  # The page node is going to be expanded. Processes a  wxEVT_TREEBOOK_NODE_EXPANDED   event. ^^

class BoxSizer(Sizer):
    """ The basic idea behind a box sizer is that windows will most often be
laid out in rather simple basic geometry, typically in a row or a
column or several hierarchies of either.

        Source: https://docs.wxpython.org/wx.BoxSizer.html
    """
    def __init__(self, orient: int=HORIZONTAL) -> None:
        """ Constructor for a   wx.BoxSizer.

            Source: https://docs.wxpython.org/wx.BoxSizer.html
        """

    def AddSpacer(self, size: int) -> 'SizerItem':
        """ Adds non-stretchable space to the main orientation of the sizer only.

            Source: https://docs.wxpython.org/wx.BoxSizer.html
        """

    def CalcMin(self) -> 'Size':
        """ Implements the calculation of a box sizerâs minimal.

            Source: https://docs.wxpython.org/wx.BoxSizer.html
        """

    def GetOrientation(self) -> int:
        """ Returns the orientation of the box sizer, either wx.VERTICAL or wx.HORIZONTAL.

            Source: https://docs.wxpython.org/wx.BoxSizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Method which must be overridden in the derived sizer classes.

            Source: https://docs.wxpython.org/wx.BoxSizer.html
        """

    def SetOrientation(self, orient: int) -> None:
        """ Sets the orientation of the box sizer, either wx.VERTICAL or wx.HORIZONTAL.

            Source: https://docs.wxpython.org/wx.BoxSizer.html
        """

    Orientation: int  # See GetOrientation and SetOrientation



class Brush(GDIObject):
    """ A brush is a drawing tool for filling in areas.

        Source: https://docs.wxpython.org/wx.Brush.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def GetColour(self) -> 'Colour':
        """ Returns a reference to the brush colour.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def GetStipple(self) -> 'Bitmap':
        """ Gets a pointer to the stipple bitmap.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def GetStyle(self) -> 'BrushStyle':
        """ Returns the brush style, one of the   wx.BrushStyle  values.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def IsHatch(self) -> bool:
        """ Returns True if the style of the brush is any of hatched fills.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def IsNonTransparent(self) -> bool:
        """ Returns True if the brush is a valid non-transparent brush.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the brush is initialised.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def IsTransparent(self) -> bool:
        """ Returns True if the brush is transparent.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def MacSetTheme(self, macThemeBrushID) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def SetColour(self, *args, **kw) -> None:
        """ Sets the brush colour using red, green and blue values.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def SetStipple(self, bitmap: 'Bitmap') -> None:
        """ Sets the stipple bitmap.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def SetStyle(self, style: BrushStyle) -> None:
        """ Sets the brush style.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def _copyFrom(self, other) -> None:
        """ For internal use only.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Inequality operator.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Equality operator.

            Source: https://docs.wxpython.org/wx.Brush.html
        """

    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour
    Stipple: 'Bitmap'  # See GetStipple and SetStipple
    Style: BrushStyle  # See GetStyle and SetStyle



BRUSHSTYLE_TRANSPARENT: int

class BrushList:
    """ A brush list is a list containing all brushes which have been created.

        Source: https://docs.wxpython.org/wx.BrushList.html
    """
    def FindOrCreateBrush(self, colour, style=BRUSHSTYLE_SOLID) -> 'Brush':
        """ Finds a brush with the specified attributes and returns it, else creates a new brush, adds it to the brush list, and returns it.

            Source: https://docs.wxpython.org/wx.BrushList.html
        """



class BufferedDC(MemoryDC):
    """ This class provides a simple way to avoid flicker: when drawing on it,
everything is in fact first drawn on an in-memory buffer (a Bitmap)
and then copied to the screen, using the associated DC, only once,
when this object is destroyed.

        Source: https://docs.wxpython.org/wx.BufferedDC.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BufferedDC.html
        """

    def GetStyle(self) -> int:
        """ Get the style.

            Source: https://docs.wxpython.org/wx.BufferedDC.html
        """

    def Init(self, *args, **kw) -> None:
        """ Initializes the object created using the default constructor.

            Source: https://docs.wxpython.org/wx.BufferedDC.html
        """

    def SetStyle(self, style: int) -> None:
        """ Set the style.

            Source: https://docs.wxpython.org/wx.BufferedDC.html
        """

    def UnMask(self) -> None:
        """ Blits the buffer to the dc, and detaches the dc from the buffer (so it can be effectively used once only).

            Source: https://docs.wxpython.org/wx.BufferedDC.html
        """

    Style: int  # See GetStyle and SetStyle



BUFFER_CLIENT_AREA: int

BUFFER_VIRTUAL_AREA: int

class BufferedPaintDC(BufferedDC):
    """ This is a subclass of BufferedDC which can be used inside of an
EVT_PAINT() event handler to achieve double-buffered drawing.

        Source: https://docs.wxpython.org/wx.BufferedPaintDC.html
    """
    def __init__(self, *args, **kw) -> None:
        """ As with   wx.BufferedDC, you may either provide the bitmap to be used for buffering or let this object create one internally (in the latter case, the size of the client part of the window is used).

            Source: https://docs.wxpython.org/wx.BufferedPaintDC.html
        """



class BusyCursor:
    """ This class makes it easy to tell your user that the program is
temporarily busy.

        Source: https://docs.wxpython.org/wx.BusyCursor.html
    """
    def __init__(self, cursor: 'Cursor'=HOURGLASS_CURSOR) -> None:
        """ Constructs a busy cursor object, calling wx.BeginBusyCursor     .

            Source: https://docs.wxpython.org/wx.BusyCursor.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.BusyCursor.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.BusyCursor.html
        """



class BusyInfo:
    """ This class makes it easy to tell your user that the program is
temporarily busy.

        Source: https://docs.wxpython.org/wx.BusyInfo.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.BusyInfo.html
        """

    def UpdateLabel(self, str: str) -> None:
        """ Same as UpdateText   but doesnât interpret the string as containing markup.

            Source: https://docs.wxpython.org/wx.BusyInfo.html
        """

    def UpdateText(self, str: str) -> None:
        """ Update the information text.

            Source: https://docs.wxpython.org/wx.BusyInfo.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.BusyInfo.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.BusyInfo.html
        """



class BusyInfoFlags:
    """ Parameters for BusyInfo.

        Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
    """
    def __init__(self) -> None:
        """ Default constructor initializes all attributes to default values.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Background(self, background: Union[int, str, 'Colour']) -> 'BusyInfoFlags':
        """ Sets the background colour of   wx.BusyInfo  window.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Foreground(self, foreground: Union[int, str, 'Colour']) -> 'BusyInfoFlags':
        """ Sets the foreground colour of the title and text strings.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Icon(self, icon: 'Icon') -> 'BusyInfoFlags':
        """ Sets the icon to show in   wx.BusyInfo.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Label(self, label: str) -> 'BusyInfoFlags':
        """ Same as Text   but doesnât interpret the string as containing markup.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Parent(self, parent: 'Window') -> 'BusyInfoFlags':
        """ Sets the parent for   wx.BusyInfo.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Text(self, text: str) -> 'BusyInfoFlags':
        """ Sets the more detailed text, shown under the title, if any.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Title(self, title: str) -> 'BusyInfoFlags':
        """ Sets the title, shown prominently in   wx.BusyInfo  window.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """

    def Transparency(self, alpha: 'Byte') -> 'BusyInfoFlags':
        """ Sets the transparency of   wx.BusyInfo  window.

            Source: https://docs.wxpython.org/wx.BusyInfoFlags.html
        """



ALPHA_TRANSPARENT: int

class Button(AnyButton):
    """ A button is a control that contains a text string, and is one of the
most common elements of a GUI.

        Source: https://docs.wxpython.org/wx.Button.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Button.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=ButtonNameStr) -> bool:
        """ Button creation function for two-step creation.

            Source: https://docs.wxpython.org/wx.Button.html
        """

    def GetAuthNeeded(self) -> bool:
        """ Returns True if an authentication needed symbol is displayed on the button.

            Source: https://docs.wxpython.org/wx.Button.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Button.html
        """

    @staticmethod
    def GetDefaultSize(win: Optional['Window']=None) -> 'Size':
        """ Returns the default size for the buttons.

            Source: https://docs.wxpython.org/wx.Button.html
        """

    def GetLabel(self) -> str:
        """ Returns the string label for the button.

            Source: https://docs.wxpython.org/wx.Button.html
        """

    def SetAuthNeeded(self, needed: bool=True) -> None:
        """ Sets whether an authentication needed symbol should be displayed on the button.

            Source: https://docs.wxpython.org/wx.Button.html
        """

    def SetDefault(self) -> 'Window':
        """ This sets the button to be the default item in its top-level window (e.g.

            Source: https://docs.wxpython.org/wx.Button.html
        """

    def SetLabel(self, label: str) -> None:
        """ Sets the string label for the button.

            Source: https://docs.wxpython.org/wx.Button.html
        """

    AuthNeeded: bool  # See GetAuthNeeded and SetAuthNeeded
    Label: str  # See GetLabel and SetLabel



BU_NOTEXT: int  # Disables the display of the text label in the button even if it has one or its id is one of the standard stock ids with an associated label: without using this style a button which is only supposed to show a bitmap but uses a standard id would display a label too.

BORDER_NONE: int  # Creates a button without border. This is currently implemented in MSW, GTK2 and OSX/Cocoa. ^^

class CallLater:
    """ A convenience class for wx.Timer, that calls the given callable
object once after the given amount of milliseconds, passing any
positional or keyword args.  The return value of the callable is
available after it has been run with the GetResult
method.

        Source: https://docs.wxpython.org/wx.CallLater.html
    """
    def __init__(self, millis, callableObj, *args, **kwargs) -> None:
        """ Constructs a new wx.CallLater object.

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def GetInterval(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def GetResult(self) -> Any:
        """ Returns the value of the callable.

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def HasRun(self) -> bool:
        """ Returns whether or not the callable has run.

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def IsRunning(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def Notify(self) -> None:
        """ The timer has expired so call the callable.

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def SetArgs(self, *args, **kwargs) -> None:
        """ (Re)set the args passed to the callable object.  This is
useful in conjunction with Start if
you want to schedule a new call to the same callable
object but with different parameters.

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def Start(self, millis=None, *args, **kwargs) -> None:
        """ (Re)start the timer

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def Stop(self) -> None:
        """ Stop and destroy the timer.

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    def __del__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.CallLater.html
        """

    Interval: None  # See GetInterval
    Result: Any  # See GetResult



class Timer(EvtHandler):
    """ The Timer class allows you to execute code at specified intervals.

        Source: https://docs.wxpython.org/wx.Timer.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def GetId(self) -> int:
        """ Returns the ID of the events generated by this timer.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def GetInterval(self) -> int:
        """ Returns the current interval for the timer (in milliseconds).

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def GetOwner(self) -> 'EvtHandler':
        """ Returns the current owner  of the timer.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def IsOneShot(self) -> bool:
        """ Returns True if the timer is one shot, i.e. if it will stop after firing the first notification automatically.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def IsRunning(self) -> bool:
        """ Returns True if the timer is running, False if it is stopped.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def Notify(self) -> None:
        """ This member should be overridden by the user if the default constructor was used and SetOwner   wasnât called.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def SetOwner(self, owner, id=-1) -> None:
        """ Associates the timer with the given owner  object.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def Start(self, milliseconds=-1, oneShot=TIMER_CONTINUOUS) -> bool:
        """ (Re)starts the timer.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def StartOnce(self, milliseconds: int=-1) -> bool:
        """ Starts the timer for a once-only notification.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    def Stop(self) -> None:
        """ Stops the timer.

            Source: https://docs.wxpython.org/wx.Timer.html
        """

    Id: int  # See GetId
    Interval: int  # See GetInterval
    Owner: 'EvtHandler'  # See GetOwner and SetOwner



TIMER_CONTINUOUS: int

TIMER_ONE_SHOT: int

class Caret:
    """ A caret is a blinking cursor showing the position where the typed text
will appear.

        Source: https://docs.wxpython.org/wx.Caret.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def Create(self, *args, **kw) -> bool:
        """ Creates a caret with the given size (in pixels) and associates it with the window  (same as the equivalent constructors).

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    @staticmethod
    def GetBlinkTime() -> int:
        """ Returns the blink time which is measured in milliseconds and is the time elapsed between 2 inversions of the caret (blink time of the caret is the same for all carets, so this functions is static).

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def GetPosition(self) -> None:
        """ Get the caret position (in pixels).

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def GetSize(self) -> None:
        """ Get the caret size.

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def GetWindow(self) -> 'Window':
        """ Get the window the caret is associated with.

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def Hide(self) -> None:
        """ Hides the caret, same as Show(false).

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the caret was created successfully.

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def IsVisible(self) -> bool:
        """ Returns True if the caret is visible and False if it is permanently hidden (if it is blinking and not shown currently but will be after the next blink, this method still returns True).

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def Move(self, *args, **kw) -> None:
        """ Move the caret to given position (in logical coordinates).

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    @staticmethod
    def SetBlinkTime(milliseconds: int) -> None:
        """ Sets the blink time for all the carets.

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def SetSize(self, *args, **kw) -> None:
        """ Changes the size of the caret.

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def Show(self, show: bool=True) -> None:
        """ Shows or hides the caret.

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Caret.html
        """

    Position: None  # See GetPosition
    Size: None  # See GetSize and SetSize
    Window: 'Window'  # See GetWindow



class CheckBox(Control):
    """ A checkbox is a labelled box which by default is either on (checkmark
is visible) or off (no checkmark).

        Source: https://docs.wxpython.org/wx.CheckBox.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=CheckBoxNameStr) -> bool:
        """ Creates the checkbox for two-step construction.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def Get3StateValue(self) -> 'CheckBoxState':
        """ Gets the state of a 3-state checkbox.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def GetValue(self) -> bool:
        """ Gets the state of a 2-state checkbox.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def Is3State(self) -> bool:
        """ Returns whether or not the checkbox is a 3-state checkbox.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def Is3rdStateAllowedForUser(self) -> bool:
        """ Returns whether or not the user can set the checkbox to the third state.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def IsChecked(self) -> bool:
        """ This is just a maybe more readable synonym for GetValue : just as the latter, it returns True if the checkbox is checked and False otherwise.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def Set3StateValue(self, state: CheckBoxState) -> None:
        """ Sets the checkbox to the given state.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    def SetValue(self, state: bool) -> None:
        """ Sets the checkbox to the given state.

            Source: https://docs.wxpython.org/wx.CheckBox.html
        """

    ThreeStateValue: Any  # See Get3StateValue and Set3StateValue
    Value: bool  # See GetValue and SetValue



CHK_2STATE: int  # Create a 2-state checkbox. This is the default.

CHK_3STATE: int  # Create a 3-state checkbox.

CHK_ALLOW_3RD_STATE_FOR_USER: int  # By default a user canât set a 3-state checkbox to the third state. It can only be done from code. Using this flags allows the user to set the checkbox to the third state by clicking.

ALIGN_RIGHT: int  # Makes the text appear on the left of the checkbox. ^^

EVT_CHECKBOX: int  # Process a  wxEVT_CHECKBOX   event, when the checkbox is clicked. ^^

CHK_UNDETERMINED: int

class CheckListBox(ListBox):
    """ A CheckListBox is like a ListBox, but allows items to be checked
or unchecked.

        Source: https://docs.wxpython.org/wx.CheckListBox.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def Check(self, item, check=True) -> None:
        """ Checks the given item.

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, choices=[], style=0, validator=DefaultValidator, name=ListBoxNameStr) -> bool:
        """ parent (wx.Window) â

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def GetCheckedItems(self) -> None:
        """ GetCheckedItems()

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def GetCheckedStrings(self) -> None:
        """ GetCheckedStrings()

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def GetSelections(self) -> list[int]:
        """ Returns a list of the indices of the currently selected items.

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def IsChecked(self, item: int) -> bool:
        """ Returns True if the given item is checked, False otherwise.

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def SetCheckedItems(self, indexes) -> None:
        """ SetCheckedItems(indexes)

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    def SetCheckedStrings(self, strings) -> None:
        """ SetCheckedStrings(strings)

            Source: https://docs.wxpython.org/wx.CheckListBox.html
        """

    Checked: Any  # See GetChecked and SetChecked
    CheckedItems: None  # See GetCheckedItems and SetCheckedItems
    CheckedStrings: None  # See GetCheckedStrings and SetCheckedStrings



EVT_CHECKLISTBOX: int  # Process a  wxEVT_CHECKLISTBOX   event, when an item in the check list box is checked or unchecked.  wx.CommandEvent.GetInt   will contain the index of the item that was checked or unchecked. wx.CommandEvent.IsChecked   is not valid! Use wx.CheckListBox.IsChecked   instead. ^^

class ListBox(Control,ItemContainer):
    """ A listbox is used to select one or more of a list of strings.

        Source: https://docs.wxpython.org/wx.ListBox.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, choices=[], style=0, validator=DefaultValidator, name=ListBoxNameStr) -> bool:
        """ Creates the listbox for two-step construction.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def Deselect(self, n: int) -> None:
        """ Deselects an item in the list box.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def EnsureVisible(self, n: int) -> None:
        """ Ensure that the item with the given index is currently shown.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def FindString(self, string, caseSensitive=False) -> int:
        """ Finds an item whose label matches the given string.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def GetCount(self) -> int:
        """ Returns the number of items in the control.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def GetCountPerPage(self) -> int:
        """ Return the number of items that can fit vertically in the visible area of the listbox.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def GetSelection(self) -> int:
        """ Returns the index of the selected item or  NOT_FOUND   if no item is selected.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def GetSelections(self) -> list[int]:
        """ Fill an array of ints with the positions of the currently selected items.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def GetString(self, n: int) -> str:
        """ Returns the label of the item with the given index.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def GetTopItem(self) -> int:
        """ Return the index of the topmost visible item.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def HitTest(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def InsertItems(self, items, pos) -> None:
        """ Insert the given number of strings before the specified position.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def IsSelected(self, n: int) -> bool:
        """ Determines whether an item is selected.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def IsSorted(self) -> bool:
        """ Return True if the listbox has LB_SORT  style.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def MSWSetTabStops(self, tabStops) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def SetFirstItem(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def SetItemBackgroundColour(self, item, c) -> None:
        """ Set the background colour of an item in the ListBox.
Only valid on MSW and if the wx.LB_OWNERDRAW flag is set.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def SetItemFont(self, item, f) -> None:
        """ Set the font of an item in the ListBox.
Only valid on MSW and if the wx.LB_OWNERDRAW flag is set.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def SetItemForegroundColour(self, item, c) -> None:
        """ Set the foreground colour of an item in the ListBox.
Only valid on MSW and if the wx.LB_OWNERDRAW flag is set.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def SetSelection(self, n: int) -> None:
        """ Sets the selection to the given item n  or removes the selection entirely if n  ==  NOT_FOUND .

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def SetString(self, n, string) -> None:
        """ Sets the label for the given item.

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    def SetStringSelection(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListBox.html
        """

    Count: int  # See GetCount
    CountPerPage: int  # See GetCountPerPage
    Selection: int  # See GetSelection and SetSelection
    Selections: list[int]  # See GetSelections
    TopItem: int  # See GetTopItem



LB_SINGLE: int  # Single-selection list.

LB_MULTIPLE: int  # Multiple-selection list: the user can toggle multiple items on and off. This is the same as wx.LB_EXTENDED in wxGTK2 port.

LB_EXTENDED: int  # Extended-selection list: the user can extend the selection by using  SHIFT   or   CTRL   keys together with the cursor movement keys or the mouse.

LB_HSCROLL: int  # Create horizontal scrollbar if contents are too wide (Windows only).

LB_ALWAYS_SB: int  # Always show a vertical scrollbar.

LB_NEEDED_SB: int  # Only create a vertical scrollbar if needed.

LB_NO_SB: int  # Donât create vertical scrollbar (wxMSW and wxGTK only).

LB_SORT: int  # The listbox contents are sorted in alphabetical order. ^^

EVT_LISTBOX: int  # Process a  wxEVT_LISTBOX   event, when an item on the list is selected or the selection changes.

EVT_LISTBOX_DCLICK: int  # Process a  wxEVT_LISTBOX_DCLICK   event, when the listbox is double-clicked. On some platforms (notably wxGTK2) pressing the enter key is handled as an equivalent of a double-click. ^^

NOT_FOUND: int

LB_OWNERDRAW: int

class ChildFocusEvent(CommandEvent):
    """ A child focus event is sent to a (parent-)window when one of its child
windows gains focus, so that the window could restore the focus back
to its corresponding child if it loses it now and regains later.

        Source: https://docs.wxpython.org/wx.ChildFocusEvent.html
    """
    def __init__(self, win: Optional['Window']=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ChildFocusEvent.html
        """

    def GetWindow(self) -> 'Window':
        """ Returns the direct child which receives the focus, or a (grand-)parent of the control receiving the focus.

            Source: https://docs.wxpython.org/wx.ChildFocusEvent.html
        """

    Window: 'Window'  # See GetWindow



EVT_CHILD_FOCUS: int  # Process a  wxEVT_CHILD_FOCUS   event. ^^

class Choice(Control,ItemContainer):
    """ A choice item is used to select one of a list of strings.

        Source: https://docs.wxpython.org/wx.Choice.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, choices=[], style=0, validator=DefaultValidator, name=ChoiceNameStr) -> bool:
        """ Creates the choice for two-step construction.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def FindString(self, string, caseSensitive=False) -> int:
        """ Finds an item whose label matches the given string.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def GetColumns(self) -> int:
        """ Gets the number of columns in this choice item.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def GetCount(self) -> int:
        """ Returns the number of items in the control.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def GetCurrentSelection(self) -> int:
        """ Unlike wx.ControlWithItems.GetSelection   which only returns the accepted selection value (the selection in the control once the user closes the dropdown list), this function returns the current selection.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def GetSelection(self) -> int:
        """ Returns the index of the selected item or  NOT_FOUND   if no item is selected.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def GetString(self, n: int) -> str:
        """ Returns the label of the item with the given index.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def IsSorted(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def SetColumns(self, n: int=1) -> None:
        """ Sets the number of columns in this choice item.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def SetSelection(self, n: int) -> None:
        """ Sets the selection to the given item n  or removes the selection entirely if n  ==  NOT_FOUND .

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    def SetString(self, n, string) -> None:
        """ Sets the label for the given item.

            Source: https://docs.wxpython.org/wx.Choice.html
        """

    Columns: int  # See GetColumns and SetColumns
    Count: int  # See GetCount
    CurrentSelection: int  # See GetCurrentSelection
    Selection: int  # See GetSelection and SetSelection



CB_SORT: int  # Sorts the entries alphabetically. ^^

EVT_CHOICE: int  # Process a  wxEVT_CHOICE   event, when an item on the list is selected. ^^

class ClassInfo:
    """ This class stores meta-information about classes.

        Source: https://docs.wxpython.org/wx.ClassInfo.html
    """
    def CreateObject(self) -> 'Window':
        """ Creates an object of the appropriate kind.

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    @staticmethod
    def FindClass(className: str) -> 'ClassInfo':
        """ Finds the   wx.ClassInfo  object for a class with the given name.

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    def GetBaseClassName1(self) -> 'Char':
        """ Returns the name of the first base class (None if none).

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    def GetBaseClassName2(self) -> 'Char':
        """ Returns the name of the second base class (None if none).

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    def GetClassName(self) -> 'Char':
        """ Returns the string form of the class name.

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    def GetSize(self) -> int:
        """ Returns the size of the class.

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    def IsDynamic(self) -> bool:
        """ Returns True if this class info can create objects of the associated class.

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    def IsKindOf(self, info: 'ClassInfo') -> bool:
        """ Returns True if this class is a kind of (inherits from) the given class.

            Source: https://docs.wxpython.org/wx.ClassInfo.html
        """

    BaseClassName1: 'Char'  # See GetBaseClassName1
    BaseClassName2: 'Char'  # See GetBaseClassName2
    ClassName: 'Char'  # See GetClassName
    Size: int  # See GetSize



class ClientDataContainer:
    """ This class is a mixin that provides storage and management of âclient
dataâ.

        Source: https://docs.wxpython.org/wx.ClientDataContainer.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.ClientDataContainer.html
        """

    def GetClientData(self) -> ClientData:
        """ Get a pointer to the client data object.

            Source: https://docs.wxpython.org/wx.ClientDataContainer.html
        """

    def GetClientObject(self) -> Any:
        """ Alias for GetClientData

            Source: https://docs.wxpython.org/wx.ClientDataContainer.html
        """

    def SetClientData(self, data: ClientData) -> None:
        """ Set the client data object.

            Source: https://docs.wxpython.org/wx.ClientDataContainer.html
        """

    def SetClientObject(self, data) -> Any:
        """ Alias for SetClientData

            Source: https://docs.wxpython.org/wx.ClientDataContainer.html
        """

    ClientData: ClientData  # See GetClientData and SetClientData



class ClientDC(WindowDC):
    """ ClientDC is primarily useful for obtaining information about the
window from outside EVT_PAINT() handler.

        Source: https://docs.wxpython.org/wx.ClientDC.html
    """
    def __init__(self, window: 'Window') -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ClientDC.html
        """



class Clipboard(Object):
    """ A class for manipulating the clipboard.

        Source: https://docs.wxpython.org/wx.Clipboard.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def AddData(self, data: 'DataObject') -> bool:
        """ Call this function to add the data object to the clipboard.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def Clear(self) -> None:
        """ Clears the global clipboard object and the systemâs clipboard if possible.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def Close(self) -> None:
        """ Call this function to close the clipboard, having opened it with Open .

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def Flush(self) -> bool:
        """ Flushes the clipboard: this means that the data which is currently on clipboard will stay available even after the application exits (possibly eating memory), otherwise the clipboard will be emptied on exit.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    @staticmethod
    def Get() -> 'Clipboard':
        """ Returns the global instance (wxTheClipboard) of the clipboard object.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def GetData(self, data: 'DataObject') -> bool:
        """ Call this function to fill data  with data on the clipboard, if available in the required format.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def IsOpened(self) -> bool:
        """ Returns True if the clipboard has been opened.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def IsSupported(self, format: 'DataFormat') -> bool:
        """ Returns True if there is data which matches the data format of the given data object currently available  on the clipboard.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def IsUsingPrimarySelection(self) -> bool:
        """ Returns True if we are using the primary selection, False if clipboard one.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def Open(self) -> bool:
        """ Call this function to open the clipboard before calling SetData   and GetData .

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def SetData(self, data: 'DataObject') -> bool:
        """ Call this function to set the data object to the clipboard.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """

    def UsePrimarySelection(self, primary: bool=False) -> None:
        """ On platforms supporting it (all X11-based ports),   wx.Clipboard  uses the CLIPBOARD X11 selection by default.

            Source: https://docs.wxpython.org/wx.Clipboard.html
        """



class ClipboardTextEvent(CommandEvent):
    """ This class represents the events generated by a control (typically a
TextCtrl but other windows can generate these events as well) when
its content gets copied or cut to, or pasted from the clipboard.

        Source: https://docs.wxpython.org/wx.ClipboardTextEvent.html
    """
    def __init__(self, commandType=wxEVT_NULL, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ClipboardTextEvent.html
        """



EVT_TEXT_COPY: int  # Some or all of the controls content was copied to the clipboard.

EVT_TEXT_CUT: int  # Some or all of the controls content was cut (i.e. copied and deleted).

EVT_TEXT_PASTE: int  # Clipboard content was pasted into the control. ^^

COPY: int

CB_READONLY: int

class TextCtrl(Control,TextEntry):
    """ A text control allows text to be displayed and edited.

        Source: https://docs.wxpython.org/wx.TextCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def Create(self, parent, id=ID_ANY, value="", pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=TextCtrlNameStr) -> bool:
        """ Creates the text control for two-step construction.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def DiscardEdits(self) -> None:
        """ Resets the internal modified flag as if the current changes had been saved.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def EmptyUndoBuffer(self) -> None:
        """ Delete the undo history.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def EmulateKeyPress(self, event: 'KeyEvent') -> bool:
        """ This function inserts into the control the character which would have been inserted if the given key event had occurred in the text control.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def GetDefaultStyle(self) -> 'TextAttr':
        """ Returns the style currently used for the new text.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def GetLineLength(self, lineNo: int) -> int:
        """ Gets the length of the specified line, not including any trailing newline character(s).

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def GetLineText(self, lineNo: int) -> str:
        """ Returns the contents of a given line in the text control, not including any trailing newline character(s).

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def GetNumberOfLines(self) -> int:
        """ Returns the number of lines in the text control buffer.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def GetStyle(self, position, style) -> bool:
        """ Returns the style at this position in the text control.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def HideNativeCaret(self) -> bool:
        """ Turn off the widgetâs native caret on Windows.
Ignored on other platforms.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def HitTestPos(self, pt) -> None:
        """ Finds the position of the character at the specified point.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def HitTest(self, pt) -> None:
        """ Finds the row and column of the character at the specified point.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def IsModified(self) -> bool:
        """ Returns True if the text has been modified by user.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def IsMultiLine(self) -> bool:
        """ Returns True if this is a multi line edit control and False otherwise.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def IsSingleLine(self) -> bool:
        """ Returns True if this is a single line edit control and False otherwise.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def LoadFile(self, filename, fileType=TEXT_TYPE_ANY) -> bool:
        """ Loads and displays the named file, if it exists.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def MacCheckSpelling(self, check) -> None:
        """ Turn on the native spell checking for the text widget on
OSX.  Ignored on other platforms.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def MarkDirty(self) -> None:
        """ Mark text as modified (dirty).

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def OSXDisableAllSmartSubstitutions(self) -> None:
        """ Mac-only method to disable all automatic text substitutions.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def OSXEnableAutomaticDashSubstitution(self, enable) -> None:
        """ Mac-only method for turning on/off automatic dash substitutions.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def OSXEnableAutomaticQuoteSubstitution(self, enable) -> None:
        """ Mac-only method for turning on/off automatic quote substitutions.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def OSXEnableNewLineReplacement(self, enable: bool) -> None:
        """ Enable the automatic replacement of new lines characters in a single-line text field with spaces under macOS.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def PositionToCoords(self, pos: int) -> 'Point':
        """ Converts given text position to client coordinates in pixels.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def PositionToXY(self, pos: int) -> tuple:
        """ Converts given position to a zero-based column, line number pair.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def SaveFile(self, filename="", fileType=TEXT_TYPE_ANY) -> bool:
        """ Saves the contents of the control in a text file.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def SetDefaultStyle(self, style: 'TextAttr') -> bool:
        """ Changes the default style to use for the new text which is going to be added to the control.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def SetModified(self, modified: bool) -> None:
        """ Marks the control as being modified by the user or not.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def SetStyle(self, start, end, style) -> bool:
        """ Changes the style of the given range.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def ShowNativeCaret(self, show=True) -> bool:
        """ Turn on the widgetâs native caret on Windows.
Ignored on other platforms.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def ShowPosition(self, pos: int) -> None:
        """ Makes the line containing the given position visible.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def XYToPosition(self, x, y) -> int:
        """ Converts the given zero based column and line number to a position.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def flush(self) -> None:
        """ NOP, for file-like compatibility.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    def write(self, text) -> None:
        """ Append text to the textctrl, for file-like compatibility.

            Source: https://docs.wxpython.org/wx.TextCtrl.html
        """

    DefaultStyle: 'TextAttr'  # See GetDefaultStyle and SetDefaultStyle
    NumberOfLines: int  # See GetNumberOfLines



TE_PROCESS_ENTER: int  # The control will generate the event  wxEVT_TEXT_ENTER   that can be handled by the program. Otherwise, i.e. either if this style not specified at all, or it is used, but there is no event handler for this event or the event handler called  wx.Event.Skip   to avoid overriding the default handling, pressing Enter key is either processed internally by the control or used to activate the default button of the dialog, if any.

TE_PROCESS_TAB: int  # Normally, TAB key is used for keyboard navigation and pressing it in a control switches focus to the next one. With this style, this wonât happen and if the TAB is not otherwise processed (e.g. by  wxEVT_CHAR   event handler), a literal TAB character is inserted into the control. Notice that this style has no effect for single-line text controls when using wxGTK.

TE_MULTILINE: int  # The text control allows multiple lines. If this style is not specified, line break characters should not be used in the controls value.

TE_PASSWORD: int  # The text will be echoed as asterisks.

TE_READONLY: int  # The text will not be user-editable.

TE_RICH: int  # Use rich text control under MSW, this allows having more than 64KB of text in the control. This style is ignored under other platforms and it is recommended to use wx.TE_RICH2 instead of it under MSW.

TE_RICH2: int  # Use rich text control version 2.0 or higher under MSW, this style is ignored under other platforms. Note that this style may be turned on automatically even if it is not used explicitly when creating a text control with a long (i.e. much more than 64KiB) initial text, as creating the control would simply fail in this case under MSW if neither this style nor wx.TE_RICH is used.

TE_AUTO_URL: int  # Highlight the URLs and generate the TextUrlEvents when mouse events occur over them.

TE_NOHIDESEL: int  # By default, the Windows text control doesnât show the selection when it doesnât have focus - use this style to force it to always show it. It doesnât do anything under other platforms.

HSCROLL: int  # A horizontal scrollbar will be created and used, so that text wonât be wrapped.

TE_NO_VSCROLL: int  # For multiline controls only: vertical scrollbar will never be created. This limits the amount of text which can be entered into the control to what can be displayed in it under wxMSW but not under wxGTK or wxOSX. Currently not implemented for the other platforms.

TE_LEFT: int  # The text in the control will be left-justified (default).

TE_CENTRE: int  # The text in the control will be centered (wxMSW, wxGTK, wxOSX).

TE_RIGHT: int  # The text in the control will be right-justified (wxMSW, wxGTK, wxOSX).

TE_DONTWRAP: int  # Same as wx.HSCROLL style: donât wrap at all, show horizontal scrollbar instead.

TE_CHARWRAP: int  # For multiline controls only: wrap the lines too long to be shown entirely at any position (wxUniv, wxGTK, wxOSX).

TE_WORDWRAP: int  # For multiline controls only: wrap the lines too long to be shown entirely at word boundaries (wxUniv, wxMSW, wxGTK, wxOSX).

TE_BESTWRAP: int  # For multiline controls only: wrap the lines at word boundaries or at any other character if there are words longer than the window width (this is the default).

TE_CAPITALIZE: int  # On PocketPC and Smartphone, causes the first letter to be capitalized. ^^

EVT_TEXT: int  # Respond to a  wxEVT_TEXT   event, generated when the text changes. Notice that this event will be sent when the text controls contents changes  â wx.TextCtrl.SetValue   is called); see wx.TextCtrl.ChangeValue   for a function which does not send this event. This event is however not sent during the control creation.

EVT_TEXT_ENTER: int  # Respond to a  wxEVT_TEXT_ENTER   event, generated when enter is pressed in a text control which must have wx.TE_PROCESS_ENTER style for this event to be generated.

EVT_TEXT_URL: int  # A mouse event occurred over an URL in the text control.

EVT_TEXT_MAXLEN: int  # This event is generated when the user tries to enter more text into the control than the limit set by wx.TextCtrl.SetMaxLength , see its description. ^^

class CloseEvent(Event):
    """ This event class contains information about window and session close
events.

        Source: https://docs.wxpython.org/wx.CloseEvent.html
    """
    def __init__(self, commandEventType=wxEVT_NULL, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.CloseEvent.html
        """

    def CanVeto(self) -> bool:
        """ Returns True if you can veto a system shutdown or a window close event.

            Source: https://docs.wxpython.org/wx.CloseEvent.html
        """

    def GetLoggingOff(self) -> bool:
        """ Returns True if the user is just logging off or False if the system is shutting down.

            Source: https://docs.wxpython.org/wx.CloseEvent.html
        """

    def GetVeto(self) -> bool:
        """ Returns whether the Veto flag was set.

            Source: https://docs.wxpython.org/wx.CloseEvent.html
        """

    def SetCanVeto(self, canVeto: bool) -> None:
        """ Sets the âcan vetoâ flag.

            Source: https://docs.wxpython.org/wx.CloseEvent.html
        """

    def SetLoggingOff(self, loggingOff: bool) -> None:
        """ Sets the âlogging offâ flag.

            Source: https://docs.wxpython.org/wx.CloseEvent.html
        """

    def Veto(self, veto: bool=True) -> None:
        """ Call this from your event handler to veto a system shutdown or to signal to the calling application that a window close did not happen.

            Source: https://docs.wxpython.org/wx.CloseEvent.html
        """

    LoggingOff: bool  # See GetLoggingOff and SetLoggingOff



EVT_CLOSE: int  # Process a  wxEVT_CLOSE_WINDOW   command event, supplying the member function. This event applies to    wx.Frame  and   wx.Dialog  classes.

EVT_QUERY_END_SESSION: int  # Process a  wxEVT_QUERY_END_SESSION   session event, supplying the member function. This event can be handled in App-derived class only.

EVT_END_SESSION: int  # Process a  wxEVT_END_SESSION   session event, supplying the member function. This event can be handled in App-derived class only. ^^

class CollapsibleHeaderCtrl(Control):
    """ Header control above a collapsible pane.

        Source: https://docs.wxpython.org/wx.CollapsibleHeaderCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.CollapsibleHeaderCtrl.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=BORDER_NONE, validator=DefaultValidator, name=CollapsibleHeaderCtrlNameStr) -> bool:
        """ Create the control initialized using the default constructor.

            Source: https://docs.wxpython.org/wx.CollapsibleHeaderCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.CollapsibleHeaderCtrl.html
        """

    def IsCollapsed(self) -> bool:
        """ Returns  true   if the control is collapsed.

            Source: https://docs.wxpython.org/wx.CollapsibleHeaderCtrl.html
        """

    def SetCollapsed(self, collapsed: bool=True) -> None:
        """ Set collapsed state of the header.

            Source: https://docs.wxpython.org/wx.CollapsibleHeaderCtrl.html
        """



EVT_COLLAPSIBLEHEADER_CHANGED: int  # User changed the collapsed state. ^^

class CollapsiblePane(Control):
    """ A collapsible pane is a container with an embedded button-like control
which can be used by the user to collapse or expand the paneâs
contents.

        Source: https://docs.wxpython.org/wx.CollapsiblePane.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    def Collapse(self, collapse: bool=True) -> None:
        """ Collapses or expands the pane window.

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=CP_DEFAULT_STYLE, validator=DefaultValidator, name=CollapsiblePaneNameStr) -> bool:
        """ parent (wx.Window) â Parent window, must not be not None.

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    def Expand(self) -> None:
        """ Same as calling Collapse(false).

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    def GetPane(self) -> 'Window':
        """ Returns a pointer to the pane window.

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    def IsCollapsed(self) -> bool:
        """ Returns True if the pane window is currently hidden.

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    def IsExpanded(self) -> bool:
        """ Returns True if the pane window is currently shown.

            Source: https://docs.wxpython.org/wx.CollapsiblePane.html
        """

    Pane: 'Window'  # See GetPane



CP_DEFAULT_STYLE: int  # The default style. It includes wx.TAB_TRAVERSAL and wx.BORDER_NONE.

CP_NO_TLW_RESIZE: int  # By default   wx.CollapsiblePane  resizes the top level window containing it when its own size changes. This allows easily implementing dialogs containing an optionally shown part, for example, and so is the default behaviour but can be inconvenient in some specific cases â

EVT_COLLAPSIBLEPANE_CHANGED: int  # The user expanded or collapsed the collapsible pane.

EVT_NAVIGATION_KEY: int  # Process a navigation key event. ^^

TAB_TRAVERSAL: int

class CollapsiblePaneEvent(CommandEvent):
    """ This event class is used for the events generated by
CollapsiblePane.

        Source: https://docs.wxpython.org/wx.CollapsiblePaneEvent.html
    """
    def __init__(self, generator, id, collapsed) -> None:
        """ The constructor is not normally used by the user code.

            Source: https://docs.wxpython.org/wx.CollapsiblePaneEvent.html
        """

    def GetCollapsed(self) -> bool:
        """ Returns True if the pane has been collapsed.

            Source: https://docs.wxpython.org/wx.CollapsiblePaneEvent.html
        """

    def SetCollapsed(self, collapsed: bool) -> None:
        """ Sets this as a collapsed pane event (if collapsed  is True) or as an expanded pane event (if collapsed  is False).

            Source: https://docs.wxpython.org/wx.CollapsiblePaneEvent.html
        """

    Collapsed: bool  # See GetCollapsed and SetCollapsed



class Colour(Object):
    """ A colour is an object representing a combination of Red, Green, and
Blue (RGB) intensity values and an Alpha value, and is used to
determine drawing colours.

        Source: https://docs.wxpython.org/wx.Colour.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def Alpha(self) -> int:
        """ Returns the alpha value, on platforms where alpha is not yet supported, this always returns wx.ALPHA_OPAQUE.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    @staticmethod
    def AlphaBlend(fg, bg, alpha) -> int:
        """ Blend colour, taking alpha into account.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def Blue(self) -> int:
        """ Returns the blue intensity.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def ChangeLightness(self, *args, **kw) -> 'Colour':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def Get(self, includeAlpha=True) -> tuple:
        """ Returns the RGB intensity values as a tuple, optionally the alpha value as well.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetAlpha(self) -> int:
        """ Returns the alpha value, on platforms where alpha is not yet supported, this always returns wx.ALPHA_OPAQUE.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetAsString(self, flags: int=C2S_NAME|C2S_CSS_SYNTAX) -> str:
        """ Converts this colour to a String       using the given flags.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetBlue(self) -> int:
        """ Returns the blue intensity as  int.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetGreen(self) -> int:
        """ Returns the green intensity as  int.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.Colour object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetLuminance(self) -> float:
        """ Return the perceived brightness of the colour.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetPixel(self) -> 'IntPtr':
        """ wx.IntPtr

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetRGB(self) -> 'int':
        """ Gets the RGB or RGBA colour values as a single 32 bit value.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetRGBA(self) -> 'int':
        """ Gets the RGB or RGBA colour values as a single 32 bit value.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def GetRed(self) -> int:
        """ Returns the red intensity as  int.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def Green(self) -> int:
        """ Returns the green intensity.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the colour object is valid (the colour has been initialised with RGB values).

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def IsSolid(self) -> bool:
        """ Returns True if the color can be described using RGB values, i.e.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def MakeDisabled(self, *args, **kw) -> 'Colour':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    @staticmethod
    def MakeGrey(*args, **kw) -> tuple:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    @staticmethod
    def MakeMono(on: bool) -> tuple:
        """ Assigns the same value to r, g, b:  0 if on  is  false , 255 otherwise.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def Red(self) -> int:
        """ Returns the red intensity.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def Set(self, *args, **kw) -> None:
        """ Sets the RGB intensity values using the given values (first overload), extracting them from the packed long (second overload), using the given string (third overload).

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def SetRGB(self, colRGB: 'int') -> None:
        """ Sets the RGB or RGBA colour values from a single 32 bit value.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def SetRGBA(self, colRGBA: 'int') -> None:
        """ Sets the RGB or RGBA colour values from a single 32 bit value.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def _copyFrom(self, other) -> None:
        """ For internal use only.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Tests the inequality of two colours by comparing individual red, green, blue intensities and alpha values.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Tests the equality of two colours by comparing individual red, green, blue intensities and alpha values.

            Source: https://docs.wxpython.org/wx.Colour.html
        """

    Pixel: 'IntPtr'  # See GetPixel
    RGB: 'int'  # See GetRGB and SetRGB
    RGBA: 'int'  # See GetRGBA and SetRGBA
    alpha: Any  # See Alpha
    blue: Any  # See Blue
    green: Any  # See Green
    red: Any  # See Red



class ColourData(Object):
    """ This class holds a variety of information related to colour dialogs.

        Source: https://docs.wxpython.org/wx.ColourData.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def FromString(self, str: str) -> bool:
        """ Decodes the given string, which should be in the same format returned by wx.ToString     , and sets the internal colours.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def GetChooseAlpha(self) -> bool:
        """ Indicates whether the colour dialog will display alpha values and an opacity selector.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def GetChooseFull(self) -> bool:
        """ Under Windows, determines whether the Windows colour dialog will display the full dialog with custom colour selection controls.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def GetColour(self) -> 'Colour':
        """ Gets the current colour associated with the colour dialog.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def GetCustomColour(self, i: int) -> 'Colour':
        """ Returns custom colours associated with the colour dialog.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def SetChooseAlpha(self, flag: bool) -> None:
        """ Tells the colour dialog to show alpha values and an opacity selector (slider).

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def SetChooseFull(self, flag: bool) -> None:
        """ Under Windows, tells the Windows colour dialog to display the full dialog with custom colour selection controls.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def SetColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the default colour for the colour dialog.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def SetCustomColour(self, i, colour) -> None:
        """ Sets custom colours for the colour dialog.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    def ToString(self) -> str:
        """ Converts the colours saved in this class in a string form, separating the various colours with a comma.

            Source: https://docs.wxpython.org/wx.ColourData.html
        """

    ChooseAlpha: bool  # See GetChooseAlpha and SetChooseAlpha
    ChooseFull: bool  # See GetChooseFull and SetChooseFull
    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour



class ColourDatabase:
    """ wxWidgets maintains a database of standard RGB colours for a
predefined set of named colours.

        Source: https://docs.wxpython.org/wx.ColourDatabase.html
    """
    def __init__(self) -> None:
        """ Constructs the colour database.

            Source: https://docs.wxpython.org/wx.ColourDatabase.html
        """

    def AddColour(self, colourName, colour) -> None:
        """ Adds a colour to the database.

            Source: https://docs.wxpython.org/wx.ColourDatabase.html
        """

    def Find(self, colourName: str) -> 'Colour':
        """ Finds a colour given the name.

            Source: https://docs.wxpython.org/wx.ColourDatabase.html
        """

    def FindColour(self, colour) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ColourDatabase.html
        """

    def FindName(self, colour: Union[int, str, 'Colour']) -> str:
        """ Finds a colour name given the colour.

            Source: https://docs.wxpython.org/wx.ColourDatabase.html
        """



class ColourDialog(Dialog):
    """ This class represents the colour chooser dialog.

        Source: https://docs.wxpython.org/wx.ColourDialog.html
    """
    def __init__(self, parent, data=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ColourDialog.html
        """

    def Create(self, parent, data=None) -> bool:
        """ Same as   wx.ColourDialog.

            Source: https://docs.wxpython.org/wx.ColourDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ColourDialog.html
        """

    def GetColourData(self) -> 'ColourData':
        """ Returns the colour data associated with the colour dialog.

            Source: https://docs.wxpython.org/wx.ColourDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning wx.ID_OK if the user pressed wx.OK, and wx.ID_CANCEL otherwise.

            Source: https://docs.wxpython.org/wx.ColourDialog.html
        """

    ColourData: 'ColourData'  # See GetColourData



class ColourDialogEvent(CommandEvent):
    """ This event class is used for the events generated by ColourDialog.

        Source: https://docs.wxpython.org/wx.ColourDialogEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ColourDialogEvent.html
        """

    def GetColour(self) -> 'Colour':
        """ Retrieve the colour the user has just selected.

            Source: https://docs.wxpython.org/wx.ColourDialogEvent.html
        """

    def SetColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Set the colour to be sent with the event.

            Source: https://docs.wxpython.org/wx.ColourDialogEvent.html
        """

    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour



EVT_COLOUR_CHANGED: int  # Generated whenever the currently selected colour in the dialog changes. This event is currently only implemented in wxMSW. ^^

class ColourPickerCtrl(PickerBase):
    """ This control allows the user to select a colour.

        Source: https://docs.wxpython.org/wx.ColourPickerCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ColourPickerCtrl.html
        """

    def Create(self, parent, id=ID_ANY, colour=BLACK, pos=DefaultPosition, size=DefaultSize, style=CLRP_DEFAULT_STYLE, validator=DefaultValidator, name=ColourPickerCtrlNameStr) -> bool:
        """ Creates a colour picker with the given arguments.

            Source: https://docs.wxpython.org/wx.ColourPickerCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ColourPickerCtrl.html
        """

    def GetColour(self) -> 'Colour':
        """ Returns the currently selected colour.

            Source: https://docs.wxpython.org/wx.ColourPickerCtrl.html
        """

    def SetColour(self, *args, **kw) -> None:
        """ Sets the currently selected colour.

            Source: https://docs.wxpython.org/wx.ColourPickerCtrl.html
        """

    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour



CLRP_DEFAULT_STYLE: int  # The default style: 0.

CLRP_USE_TEXTCTRL: int  # Creates a text control to the left of the picker button which is completely managed by the   wx.ColourPickerCtrl  and which can be used by the user to specify a colour (see SetColour). The text control is automatically synchronized with buttonâs value. Use functions defined in   wx.PickerBase  to modify the text control.

CLRP_SHOW_LABEL: int  # Shows the colour in HTML form (AABBCC) as colour button label (instead of no label at all).

CLRP_SHOW_ALPHA: int  # Allows selecting opacity in the colour-chooser (effective under wxGTK and wxOSX). ^^

EVT_COLOURPICKER_CHANGED: int  # The user changed the colour selected in the control either using the button or using text control (see  CLRP_USE_TEXTCTRL ; note that in this case the event is fired only if the userâs input is valid, i.e. recognizable). When using a popup dialog for changing the colour, this event is sent only when the changes in the dialog are accepted by the user, unlike   EVT_COLOURPICKER_CURRENT_CHANGED .

EVT_COLOURPICKER_CURRENT_CHANGED: int  # The user changed the currently selected colour in the dialog associated with the control. This event is sent immediately when the selection changes and you must also handle  EVT_COLOUR_CANCELLED   to revert to the previously selected colour if the selection ends up not being accepted. This event is new since wxWidgets 3.1.3 and currently is only implemented in wxMSW.

EVT_COLOURPICKER_DIALOG_CANCELLED: int  # The user cancelled the colour dialog associated with the control, i.e. closed it without accepting the selection. This event is new since wxWidgets 3.1.3 and currently is only implemented in wxMSW. ^^

class ColourPickerEvent(CommandEvent):
    """ This event class is used for the events generated by
ColourPickerCtrl.

        Source: https://docs.wxpython.org/wx.ColourPickerEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ColourPickerEvent.html
        """

    def GetColour(self) -> 'Colour':
        """ Retrieve the colour the user has just selected.

            Source: https://docs.wxpython.org/wx.ColourPickerEvent.html
        """

    def SetColour(self, pos: Union[int, str, 'Colour']) -> None:
        """ Set the colour associated with the event.

            Source: https://docs.wxpython.org/wx.ColourPickerEvent.html
        """

    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour



class ComboBox(Control,ItemContainer,TextEntry):
    """ A combobox is like a combination of an edit control and a listbox.

        Source: https://docs.wxpython.org/wx.ComboBox.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def Create(self, parent, id=ID_ANY, value="", pos=DefaultPosition, size=DefaultSize, choices=[], style=0, validator=DefaultValidator, name=ComboBoxNameStr) -> bool:
        """ Creates the combobox for two-step construction.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def Dismiss(self) -> None:
        """ Hides the list box portion of the combo box.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def FindString(self, string, caseSensitive=False) -> int:
        """ Finds an item whose label matches the given string.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def GetCount(self) -> int:
        """ Returns the number of items in the control.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def GetCurrentSelection(self) -> int:
        """ Returns the item being selected right now.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def GetInsertionPoint(self) -> int:
        """ Same as wx.TextEntry.GetInsertionPoint .

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def GetSelection(self) -> int:
        """ Returns the index of the selected item or  NOT_FOUND   if no item is selected.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def GetTextSelection(self) -> tuple:
        """ Gets the current selection span.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def GetString(self, n: int) -> str:
        """ Returns the label of the item with the given index.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def GetStringSelection(self) -> str:
        """ Gets the text currently selected in the control.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def IsListEmpty(self) -> bool:
        """ Returns True if the list of combobox choices is empty.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def IsTextEmpty(self) -> bool:
        """ Returns True if the text of the combobox is empty.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def Popup(self) -> None:
        """ Shows the list box portion of the combo box.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def SetSelection(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def SetString(self, n, text) -> None:
        """ Changes the text of the specified combobox item.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def SetTextSelection(self, from_, to_) -> None:
        """ Same as wx.TextEntry.SetSelection .

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    def SetValue(self, text: str) -> None:
        """ Sets the text for the combobox text field.

            Source: https://docs.wxpython.org/wx.ComboBox.html
        """

    Count: int  # See GetCount
    CurrentSelection: int  # See GetCurrentSelection
    InsertionPoint: int  # See GetInsertionPoint
    Selection: int  # See GetSelection and SetSelection
    StringSelection: str  # See GetStringSelection



CB_SIMPLE: int  # Creates a combobox with a permanently displayed list. Windows only.

CB_DROPDOWN: int  # Creates a combobox with a drop-down list. MSW and Motif only.

EVT_COMBOBOX: int  # Process a  wxEVT_COMBOBOX   event, when an item on the list is selected. Note that calling  GetValue  returns the new value of selection.

EVT_COMBOBOX_DROPDOWN: int  # Process a  wxEVT_COMBOBOX_DROPDOWN   event, which is generated when the list box part of the combo box is shown (drops down). Notice that this event is only supported by wxMSW, wxGTK with GTK+ 2.10 or later, and OSX/Cocoa.

EVT_COMBOBOX_CLOSEUP: int  # Process a  wxEVT_COMBOBOX_CLOSEUP   event, which is generated when the list box of the combo box disappears (closes up). This event is only generated for the same platforms as   wxEVT_COMBOBOX_DROPDOWN   above. ^^

class ComboCtrl(Control,TextEntry):
    """ A combo control is a generic combobox that allows totally custom
popup.

        Source: https://docs.wxpython.org/wx.ComboCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def AnimateShow(self, rect, flags) -> bool:
        """ This member function is not normally called in application code.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Copy(self) -> None:
        """ Copies the selected text to the clipboard.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Create(self, parent, id=ID_ANY, value="", pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=ComboBoxNameStr) -> bool:
        """ Creates the combo control for two-step construction.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Cut(self) -> None:
        """ Copies the selected text to the clipboard and removes the selection.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Dismiss(self) -> None:
        """ Dismisses the popup window.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def DoSetPopupControl(self, popup: 'ComboPopup') -> None:
        """ This member function is not normally called in application code.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def DoShowPopup(self, rect, flags) -> None:
        """ This member function is not normally called in application code.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def EnablePopupAnimation(self, enable: bool=True) -> None:
        """ Enables or disables popup animation, if any, depending on the value of the argument.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetBitmapDisabled(self) -> 'Bitmap':
        """ Returns disabled button bitmap that has been set with SetButtonBitmaps .

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetBitmapHover(self) -> 'Bitmap':
        """ Returns button mouse hover bitmap that has been set with SetButtonBitmaps .

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetBitmapNormal(self) -> 'Bitmap':
        """ Returns default button bitmap that has been set with SetButtonBitmaps .

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetBitmapPressed(self) -> 'Bitmap':
        """ Returns depressed button bitmap that has been set with SetButtonBitmaps .

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetButtonSize(self) -> 'Size':
        """ Returns current size of the dropdown button.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetCustomPaintWidth(self) -> int:
        """ Returns custom painted area in control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    @staticmethod
    def GetFeatures() -> int:
        """ Returns features supported by   wx.ComboCtrl.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetHint(self) -> str:
        """ Returns the current hint string.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetInsertionPoint(self) -> int:
        """ Returns the insertion point for the combo controlâs text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetLastPosition(self) -> int:
        """ Returns the last position in the combo control text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetMargins(self) -> 'Point':
        """ Returns the margins used by the control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetPopupControl(self) -> 'ComboPopup':
        """ Returns current popup interface that has been set with SetPopupControl .

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetPopupWindow(self) -> 'Window':
        """ Returns popup window containing the popup control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetTextCtrl(self) -> 'TextCtrl':
        """ Get the text control which is part of the combo control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetTextRect(self) -> 'Rect':
        """ Returns area covered by the text field (includes everything except borders and the dropdown button).

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def GetValue(self) -> str:
        """ Returns text representation of the current value.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def HidePopup(self, generateEvent: bool=False) -> None:
        """ Dismisses the popup window.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def IsKeyPopupToggle(self, event: 'KeyEvent') -> bool:
        """ Returns True if given key combination should toggle the popup.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def IsPopupShown(self) -> bool:
        """ Returns True if the popup is currently shown.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def IsPopupWindowState(self, state: int) -> bool:
        """ Returns True if the popup window is in the given state.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def OnButtonClick(self) -> None:
        """ Implement in a derived class to define what happens on dropdown button click.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Paste(self) -> None:
        """ Pastes text from the clipboard to the text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Popup(self) -> None:
        """ Shows the popup portion of the combo control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def PrepareBackground(self, dc, rect, flags) -> None:
        """ Prepare background of combo control or an item in a dropdown list in a way typical on platform.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Remove(self, frm, to) -> None:
        """ Removes the text between the two positions in the combo control text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Replace(self, frm, to, text) -> None:
        """ Replaces the text between two positions with the given text, in the combo control text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetButtonBitmaps(*args, **kwargs) -> None:
        """ Sets custom dropdown button graphics.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetButtonPosition(self, width=-1, height=-1, side=RIGHT, spacingX=0) -> None:
        """ Sets size and position of dropdown button.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetCustomPaintWidth(self, width: int) -> None:
        """ Set width, in pixels, of custom painted area in control without  CB_READONLY   style.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetHint(self, hint: str) -> bool:
        """ Sets a hint shown in an empty unfocused combo control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetInsertionPoint(self, pos: int) -> None:
        """ Sets the insertion point in the text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetInsertionPointEnd(self) -> None:
        """ Sets the insertion point at the end of the combo control text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetMainControl(self, win: 'Window') -> None:
        """ Uses the given window instead of the default text control as the main window of the combo control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetMargins(self, *args, **kw) -> None:
        """ Attempts to set the control margins.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetPopupAnchor(self, anchorSide: int) -> None:
        """ Set side of the control to which the popup will align itself.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetPopupControl(self, popup: 'ComboPopup') -> None:
        """ Set popup interface class derived from   wx.ComboPopup.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetPopupExtents(self, extLeft, extRight) -> None:
        """ Extends popup size horizontally, relative to the edges of the combo control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetPopupMaxHeight(self, height: int) -> None:
        """ Sets preferred maximum height of the popup.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetPopupMinWidth(self, width: int) -> None:
        """ Sets minimum width of the popup.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetSelection(self, frm, to) -> None:
        """ Selects the text between the two positions, in the combo control text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetText(self, value: str) -> None:
        """ Sets the text for the text field without affecting the popup.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetTextCtrlStyle(self, style: int) -> None:
        """ Set a custom window style for the embedded   wx.TextCtrl.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetValue(self, value: str) -> None:
        """ Sets the text for the combo control text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def SetValueByUser(self, value: str) -> None:
        """ Changes value of the control as if user had done it by selecting an item from a combo box drop-down list.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def ShouldDrawFocus(self) -> bool:
        """ Returns True if focus indicator should be drawn in the control.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def ShowPopup(self) -> None:
        """ Show the popup.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def Undo(self) -> None:
        """ Undoes the last edit in the text field.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    def UseAltPopupWindow(self, enable: bool=True) -> None:
        """ Enable or disable usage of an alternative popup window, which guarantees ability to focus the popup control, and allows common native controls to function normally.

            Source: https://docs.wxpython.org/wx.ComboCtrl.html
        """

    BitmapDisabled: 'Bitmap'  # See GetBitmapDisabled
    BitmapHover: 'Bitmap'  # See GetBitmapHover
    BitmapNormal: 'Bitmap'  # See GetBitmapNormal
    BitmapPressed: 'Bitmap'  # See GetBitmapPressed
    ButtonSize: 'Size'  # See GetButtonSize
    CustomPaintWidth: int  # See GetCustomPaintWidth and SetCustomPaintWidth
    Hint: str  # See GetHint and SetHint
    InsertionPoint: int  # See GetInsertionPoint and SetInsertionPoint
    LastPosition: int  # See GetLastPosition
    Margins: 'Point'  # See GetMargins and SetMargins
    PopupControl: 'ComboPopup'  # See GetPopupControl and SetPopupControl
    PopupWindow: 'Window'  # See GetPopupWindow
    TextCtrl: 'TextCtrl'  # See GetTextCtrl
    TextRect: 'Rect'  # See GetTextRect
    Value: str  # See GetValue and SetValue



CC_SPECIAL_DCLICK: int  # Double-clicking triggers a call to popupâs OnComboDoubleClick. Actual behaviour is defined by a derived class. For instance,   wx.adv.OwnerDrawnComboBox  will cycle an item. This style only applies if wx.CB_READONLY is used as well.

CC_STD_BUTTON: int  # Drop button will behave more like a standard push button. ^^

CONTROL_ISSUBMENU: int

CONTROL_SELECTED: int

CONTROL_DISABLED: int

class ComboCtrlFeatures:
    """ Features enabled for ComboCtrl.

        Source: https://docs.wxpython.org/wx.ComboCtrlFeatures.html
    """


class ComboPopup:
    """ In order to use a custom popup with ComboCtrl, an interface class
must be derived from ComboPopup.

        Source: https://docs.wxpython.org/wx.ComboPopup.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def Create(self, parent: 'Window') -> bool:
        """ The derived class must implement this to create the popup control.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def DestroyPopup(self) -> None:
        """ You only need to implement this member function if you create your popup class in non-standard way.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def Dismiss(self) -> None:
        """ Utility function that hides the popup.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def FindItem(self, item, trueItem=None) -> bool:
        """ Implement to customize matching of value string to an item container entry.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def GetAdjustedSize(self, minWidth, prefHeight, maxHeight) -> 'Size':
        """ The derived class may implement this to return adjusted size for the popup control, according to the variables given.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def GetComboCtrl(self) -> 'ComboCtrl':
        """ Returns pointer to the associated parent   wx.ComboCtrl.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def GetControl(self) -> 'Window':
        """ The derived class must implement this to return pointer to the associated control created in Create .

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def GetStringValue(self) -> str:
        """ The derived class must implement this to return string representation of the value.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def Init(self) -> None:
        """ The derived class must implement this to initialize its internal variables.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def IsCreated(self) -> bool:
        """ Utility method that returns True if Create has been called.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def LazyCreate(self) -> bool:
        """ The derived class may implement this to return True if it wants to delay call to Create   until the popup is shown for the first time.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def OnComboDoubleClick(self) -> None:
        """ The derived class may implement this to do something when the parent   wx.ComboCtrl  gets double-clicked.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def OnComboKeyEvent(self, event: 'KeyEvent') -> None:
        """ The derived class may implement this to receive key events from the parent   wx.ComboCtrl.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def OnDismiss(self) -> None:
        """ The derived class may implement this to do special processing when popup is hidden.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def OnPopup(self) -> None:
        """ The derived class may implement this to do special processing when popup is shown.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def PaintComboControl(self, dc, rect) -> None:
        """ The derived class may implement this to paint the parent   wx.ComboCtrl.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    def SetStringValue(self, value: str) -> None:
        """ The derived class must implement this to receive string value changes from   wx.ComboCtrl.

            Source: https://docs.wxpython.org/wx.ComboPopup.html
        """

    ComboCtrl: 'ComboCtrl'  # See GetComboCtrl
    Control: 'Window'  # See GetControl
    StringValue: str  # See GetStringValue and SetStringValue



class Command(Object):
    """ Command is a base class for modelling an application command, which
is an action usually performed by selecting a menu item, pressing a
toolbar button or any other means provided by the application to
change the data or view.

        Source: https://docs.wxpython.org/wx.Command.html
    """
    def __init__(self, canUndo=False, name="") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.Command.html
        """

    def CanUndo(self) -> bool:
        """ Returns True if the command can be undone, False otherwise.

            Source: https://docs.wxpython.org/wx.Command.html
        """

    def Do(self) -> bool:
        """ Override this member function to execute the appropriate action when called.

            Source: https://docs.wxpython.org/wx.Command.html
        """

    def GetName(self) -> str:
        """ Returns the command name.

            Source: https://docs.wxpython.org/wx.Command.html
        """

    def Undo(self) -> bool:
        """ Override this member function to un-execute a previous Do.

            Source: https://docs.wxpython.org/wx.Command.html
        """

    Name: str  # See GetName



class CommandEvent(Event):
    """ This event class contains information about command events, which
originate from a variety of simple controls.

        Source: https://docs.wxpython.org/wx.CommandEvent.html
    """
    def __init__(self, commandEventType=wxEVT_NULL, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def GetClientData(self) -> ClientData:
        """ Returns client object pointer for a listbox or choice selection event (not valid for a deselection).

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def GetClientObject(self) -> Any:
        """ Alias for GetClientData

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def GetExtraLong(self) -> int:
        """ Returns extra information dependent on the event objects type.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def GetInt(self) -> int:
        """ Returns the integer identifier corresponding to a listbox, choice or radiobox selection (only if the event was a selection, not a deselection), or a boolean value representing the value of a checkbox.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def GetSelection(self) -> int:
        """ Returns item index for a listbox or choice selection event (not valid for a deselection).

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def GetString(self) -> str:
        """ Returns item string for a listbox or choice selection event.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def IsChecked(self) -> bool:
        """ This method can be used with checkbox and menu events: for the checkboxes, the method returns True for a selection event and False for a deselection one.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def IsSelection(self) -> bool:
        """ For a listbox or similar event, returns True if it is a selection, False if it is a deselection.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def SetClientData(self, data: ClientData) -> None:
        """ Sets the client object for this event.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def SetClientObject(self, data) -> Any:
        """ Alias for SetClientData

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def SetExtraLong(self, extraLong: int) -> None:
        """ Sets the m_extraLong  member.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def SetInt(self, intCommand: int) -> None:
        """ Sets the m_commandInt  member.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    def SetString(self, string: str) -> None:
        """ Sets the m_commandString  member.

            Source: https://docs.wxpython.org/wx.CommandEvent.html
        """

    ClientData: ClientData  # See GetClientData and SetClientData
    ExtraLong: int  # See GetExtraLong and SetExtraLong
    Int: int  # See GetInt and SetInt
    Selection: int  # See GetSelection
    String: str  # See GetString and SetString



EVT_COMMAND: int  # Process a command, supplying the window identifier, command event identifier, and member function.

EVT_COMMAND_RANGE: int  # Process a command for a range of window identifiers, supplying the minimum and maximum window identifiers, command event identifier, and member function.

EVT_MENU: int  # Process a  wxEVT_MENU   command, which is generated by a menu item.

EVT_MENU_RANGE: int  # Process a  wxEVT_MENU   command, which is generated by a range of menu items.

EVT_CONTEXT_MENU: int  # Process the event generated when the user has requested a popup menu to appear by pressing a special keyboard key (under Windows) or by right clicking the mouse.

EVT_RADIOBOX: int  # Process a  wxEVT_RADIOBOX   command, which is generated by a    wx.RadioBox  control.

EVT_RADIOBUTTON: int  # Process a  wxEVT_RADIOBUTTON   command, which is generated by a    wx.RadioButton  control.

EVT_SCROLLBAR: int  # Process a  wxEVT_SCROLLBAR   command, which is generated by a    wx.ScrollBar  control. This is provided for compatibility only; more specific scrollbar event macros should be used instead (see   wx.ScrollEvent).

EVT_SLIDER: int  # Process a  wxEVT_SLIDER   command, which is generated by a    wx.Slider  control.

EVT_TOOL: int  # Process a  wxEVT_TOOL   event (a synonym for   wxEVT_MENU ). Pass the id of the tool.

EVT_TOOL_RANGE: int  # Process a  wxEVT_TOOL   event for a range of identifiers. Pass the ids of the tools.

EVT_TOOL_RCLICKED: int  # Process a  wxEVT_TOOL_RCLICKED   event. Pass the id of the tool. (Not available on wxOSX.)

EVT_TOOL_RCLICKED_RANGE: int  # Process a  wxEVT_TOOL_RCLICKED   event for a range of ids. Pass the ids of the tools. (Not available on wxOSX.)

EVT_TOOL_ENTER: int  # Process a  wxEVT_TOOL_ENTER   event. Pass the id of the toolbar itself. The value of  wx.CommandEvent.GetSelection   is the tool id, or -1 if the mouse cursor has moved off a tool. (Not available on wxOSX.)

EVT_COMMAND_LEFT_CLICK: int  # Process a  wxEVT_COMMAND_LEFT_CLICK   command, which is generated by a control (wxMSW only).

EVT_COMMAND_LEFT_DCLICK: int  # Process a  wxEVT_COMMAND_LEFT_DCLICK   command, which is generated by a control (wxMSW only).

EVT_COMMAND_RIGHT_CLICK: int  # Process a  wxEVT_COMMAND_RIGHT_CLICK   command, which is generated by a control (wxMSW only).

EVT_COMMAND_SET_FOCUS: int  # Process a  wxEVT_COMMAND_SET_FOCUS   command, which is generated by a control (wxMSW only).

EVT_COMMAND_KILL_FOCUS: int  # Process a  wxEVT_COMMAND_KILL_FOCUS   command, which is generated by a control (wxMSW only).

EVT_COMMAND_ENTER: int  # Process a  wxEVT_COMMAND_ENTER   command, which is generated by a control. ^^

class CommandProcessor(Object):
    """ CommandProcessor is a class that maintains a history of Commands,
with undo/redo functionality built-in.

        Source: https://docs.wxpython.org/wx.CommandProcessor.html
    """
    def __init__(self, maxCommands: int=-1) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def CanRedo(self) -> bool:
        """ Returns True if the currently-active command can be redone, False otherwise.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def CanUndo(self) -> bool:
        """ Returns True if the currently-active command can be undone, False otherwise.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def ClearCommands(self) -> None:
        """ Deletes all commands in the list and sets the current command pointer to None.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetCommands(self) -> CommandList:
        """ Returns the list of commands.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetCurrentCommand(self) -> 'Command':
        """ Returns the current command.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetEditMenu(self) -> 'Menu':
        """ Returns the edit menu associated with the command processor.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetMaxCommands(self) -> int:
        """ Returns the maximum number of commands that the command processor stores.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetRedoAccelerator(self) -> str:
        """ Returns the string that will be appended to the Redo menu item.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetRedoMenuLabel(self) -> str:
        """ Returns the string that will be shown for the redo menu item.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetUndoAccelerator(self) -> str:
        """ Returns the string that will be appended to the Undo menu item.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def GetUndoMenuLabel(self) -> str:
        """ Returns the string that will be shown for the undo menu item.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def Initialize(self) -> None:
        """ Initializes the command processor, setting the current command to the last in the list (if any), and updating the edit menu (if one has been specified).

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def IsDirty(self) -> bool:
        """ Returns a boolean value that indicates if changes have been made since the last save operation.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def MarkAsSaved(self) -> None:
        """ You must call this method whenever the project is saved if you plan to use IsDirty .

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def Redo(self) -> bool:
        """ Executes (redoes) the current command (the command that has just been undone if any).

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def SetEditMenu(self, menu: 'Menu') -> None:
        """ Tells the command processor to update the Undo and Redo items on this menu as appropriate.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def SetMenuStrings(self) -> None:
        """ Sets the menu labels according to the currently set menu and the current command state.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def SetRedoAccelerator(self, accel: str) -> None:
        """ Sets the string that will be appended to the Redo menu item.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def SetUndoAccelerator(self, accel: str) -> None:
        """ Sets the string that will be appended to the Undo menu item.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def Store(self, command: 'Command') -> None:
        """ Just store the command without executing it.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def Submit(self, command, storeIt=True) -> bool:
        """ Submits a new command to the command processor.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    def Undo(self) -> bool:
        """ Undoes the last command executed.

            Source: https://docs.wxpython.org/wx.CommandProcessor.html
        """

    Commands: CommandList  # See GetCommands
    CurrentCommand: 'Command'  # See GetCurrentCommand
    EditMenu: 'Menu'  # See GetEditMenu and SetEditMenu
    MaxCommands: int  # See GetMaxCommands
    RedoAccelerator: str  # See GetRedoAccelerator and SetRedoAccelerator
    RedoMenuLabel: str  # See GetRedoMenuLabel
    UndoAccelerator: str  # See GetUndoAccelerator and SetUndoAccelerator
    UndoMenuLabel: str  # See GetUndoMenuLabel



class ConfigBase(Object):
    """ ConfigBase defines the basic interface of all config classes.

        Source: https://docs.wxpython.org/wx.ConfigBase.html
    """
    def __init__(self, appName="", vendorName="", localFilename="", globalFilename="", style=0) -> None:
        """ This is the default and only constructor of the   wx.ConfigBase  class, and derived classes.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    @staticmethod
    def Create() -> 'ConfigBase':
        """ Create a new config object and sets it as the current one.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def DeleteAll(self) -> bool:
        """ Delete the whole underlying object (disk file, registry key, â¦).

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def DeleteEntry(self, key, bDeleteGroupIfEmpty=True) -> bool:
        """ Deletes the specified entry and the group it belongs to if it was the last key in it and the second parameter is True.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def DeleteGroup(self, key: str) -> bool:
        """ Delete the group (with all subgroups).

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    @staticmethod
    def DontCreateOnDemand() -> None:
        """ Calling this function will prevent  ` Get  `   from automatically creating a new config object if the current one is None.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def Exists(self, strName: str) -> bool:
        """ strName (string) â

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def Flush(self, bCurrentOnly: bool=False) -> bool:
        """ Permanently writes all changes (otherwise, theyâre only written from objectâs destructor).

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    @staticmethod
    def Get(CreateOnDemand: bool=True) -> 'ConfigBase':
        """ Get the current config object.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetAppName(self) -> str:
        """ Returns the application name.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetEntryType(self, name: str) -> 'ConfigBase.EntryType':
        """ Returns the type of the given entry or Unknown  if the entry doesnât exist.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetFirstEntry(self) -> Any:
        """ GetFirstEntry() . (more, value, index)

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetFirstGroup(self) -> Any:
        """ GetFirstGroup() . (more, value, index)

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetNextEntry(self, index) -> Any:
        """ GetNextEntry() . (more, value, index)

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetNextGroup(self, index) -> Any:
        """ GetNextGroup(long index) . (more, value, index)

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetNumberOfEntries(self, bRecursive: bool=False) -> int:
        """ Get number of entries in the current group.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetNumberOfGroups(self, bRecursive: bool=False) -> int:
        """ Get number of entries/subgroups in the current group, with or without its subgroups.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetPath(self) -> str:
        """ Retrieve the current path (always as absolute path).

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def GetVendorName(self) -> str:
        """ Returns the vendor name.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def HasEntry(self, strName: str) -> bool:
        """ strName (string) â

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def HasGroup(self, strName: str) -> bool:
        """ strName (string) â

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def IsExpandingEnvVars(self) -> bool:
        """ Returns True if we are expanding environment variables in key values.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def IsRecordingDefaults(self) -> bool:
        """ Returns True if we are writing defaults back to the config file.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def Read(self, key, defaultVal="") -> None:
        """ Another version of Read , returning the string value directly.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def ReadBool(self, key, defaultVal=False) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def ReadDouble(self, key, defaultVal) -> float:
        """ Reads a float value from the key and returns it.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def ReadFloat(self, key, defaultVal=0.0) -> float:
        """ float

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def ReadInt(self, key, defaultVal=0) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def ReadLong(self, key, defaultVal) -> int:
        """ Reads a long value from the key and returns it.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def ReadLongLong(self, key, defaultVal) -> LongLong_t:
        """ Reads a 64-bit long long value from the key and returns it.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def RenameEntry(self, oldName, newName) -> bool:
        """ Renames an entry in the current group.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def RenameGroup(self, oldName, newName) -> bool:
        """ Renames a subgroup of the current group.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    @staticmethod
    def Set(pConfig: 'ConfigBase') -> 'ConfigBase':
        """ Sets the config object as the current one, returns the pointer to the previous current object (both the parameter and returned value may be None).

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def SetExpandEnvVars(self, bDoIt: bool=True) -> None:
        """ Determine whether we wish to expand environment variables in key values.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def SetPath(self, strPath: str) -> None:
        """ Set current path: if the first character is â/â, it is the absolute path, otherwise it is a relative path.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def SetRecordDefaults(self, bDoIt: bool=True) -> None:
        """ Sets whether defaults are recorded to the config file whenever an attempt to read the value which is not present in it is done.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def Write(self, key, value) -> bool:
        """ Writes the String       value to the config file and returns True on success.

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def WriteBool(self, key, value) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def WriteFloat(self, key, value) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def WriteInt(self, key, value) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    def _cpp_ReadInt(self, key, defaultVal=0) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.ConfigBase.html
        """

    AppName: str  # See GetAppName
    FirstEntry: Any  # See GetFirstEntry
    FirstGroup: Any  # See GetFirstGroup
    NextEntry: Any  # See GetNextEntry
    NextGroup: Any  # See GetNextGroup
    NumberOfEntries: int  # See GetNumberOfEntries
    NumberOfGroups: int  # See GetNumberOfGroups
    Path: str  # See GetPath and SetPath
    VendorName: str  # See GetVendorName



class ConfigPathChanger:
    """ A handy little class which changes the current path in a Config
object and restores it in dtor.

        Source: https://docs.wxpython.org/wx.ConfigPathChanger.html
    """
    def __init__(self, pContainer, strEntry) -> None:
        """ Changes the path of the given   wx.ConfigBase  object so that the key strEntry  is accessible (for read or write).

            Source: https://docs.wxpython.org/wx.ConfigPathChanger.html
        """

    def Name(self) -> str:
        """ Returns the name of the key which was passed to the constructor.

            Source: https://docs.wxpython.org/wx.ConfigPathChanger.html
        """

    def UpdateIfDeleted(self) -> None:
        """ This method must be called if the original path inside the Config object (i.e.

            Source: https://docs.wxpython.org/wx.ConfigPathChanger.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ConfigPathChanger.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ConfigPathChanger.html
        """



class ContextHelp(Object):
    """ This class changes the cursor to a query and puts the application into
a âcontext-sensitive help modeâ.

        Source: https://docs.wxpython.org/wx.ContextHelp.html
    """
    def __init__(self, window=None, doNow=True) -> None:
        """ Constructs a context help object, calling BeginContextHelp   if doNow  is True (the default).

            Source: https://docs.wxpython.org/wx.ContextHelp.html
        """

    def BeginContextHelp(self, window: 'Window') -> bool:
        """ Puts the application into context-sensitive help mode.

            Source: https://docs.wxpython.org/wx.ContextHelp.html
        """

    def EndContextHelp(self) -> bool:
        """ Ends context-sensitive help mode.

            Source: https://docs.wxpython.org/wx.ContextHelp.html
        """



DIALOG_EX_CONTEXTHELP: int

class ContextHelpButton(BitmapButton):
    """ Instances of this class may be used to add a question mark button that
when pressed, puts the application into context-help mode.

        Source: https://docs.wxpython.org/wx.ContextHelpButton.html
    """
    def __init__(self, parent, id=ID_CONTEXT_HELP, pos=DefaultPosition, size=DefaultSize, style=0) -> None:
        """ Constructor, creating and showing a context help button.

            Source: https://docs.wxpython.org/wx.ContextHelpButton.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ContextHelpButton.html
        """



class ContextMenuEvent(CommandEvent):
    """ This class is used for context menu events, sent to give the
application a chance to show a context (popup) menu for a Window.

        Source: https://docs.wxpython.org/wx.ContextMenuEvent.html
    """
    def __init__(self, type=wxEVT_NULL, id=0, pos=DefaultPosition) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ContextMenuEvent.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the position in screen coordinates at which the menu should be shown.

            Source: https://docs.wxpython.org/wx.ContextMenuEvent.html
        """

    def SetPosition(self, point: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the position at which the menu should be shown.

            Source: https://docs.wxpython.org/wx.ContextMenuEvent.html
        """

    Position: Union[tuple[int, int], 'Point']  # See GetPosition and SetPosition



class Window(EvtHandler):
    """ Window is the base class for all windows and represents any visible
object on screen.

        Source: https://docs.wxpython.org/wx.Window.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def AcceptsFocus(self) -> bool:
        """ This method may be overridden in the derived classes to return False to indicate that this control doesnât accept input at all (i.e. behaves like e.g.   wx.StaticText) and so doesnât need focus.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def AcceptsFocusFromKeyboard(self) -> bool:
        """ This method may be overridden in the derived classes to return False to indicate that while this control can, in principle, have focus if the user clicks it with the mouse, it shouldnât be included in the TAB traversal chain when using the keyboard.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def AcceptsFocusRecursively(self) -> bool:
        """ Overridden to indicate whether this window or one of its children accepts focus.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def AddChild(self, child: 'WindowBase') -> None:
        """ Adds a child window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def AdjustForLayoutDirection(self, x, width, widthTotal) -> 'Coord':
        """ Mirror coordinates for RTL layout if this window uses it and if the mirroring is not done automatically like Win32.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def AlwaysShowScrollbars(self, hflag=True, vflag=True) -> None:
        """ Call this function to force one or both scrollbars to be always shown, even if the window is big enough to show its entire contents without scrolling.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def AssociateHandle(self, handle) -> None:
        """ Associate the window with a new native handle

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def BeginRepositioningChildren(self) -> bool:
        """ Prepare for changing positions of multiple child windows.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CacheBestSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the cached best size value.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CanAcceptFocus(self) -> bool:
        """ Can this window have focus right now?

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CanAcceptFocusFromKeyboard(self) -> bool:
        """ Can this window be assigned focus from keyboard right now?

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CanScroll(self, orient: int) -> bool:
        """ Returns True if this window can have a scroll bar in this orientation.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CanSetTransparent(self) -> bool:
        """ Returns True if the system supports transparent windows and calling SetTransparent   may succeed.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CaptureMouse(self) -> None:
        """ Directs all mouse input to this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Center(self, dir: int=BOTH) -> None:
        """ A synonym for wx.Centre     .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CenterOnParent(self, dir: int=BOTH) -> None:
        """ A synonym for CentreOnParent .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Centre(self, direction: int=BOTH) -> None:
        """ Centres the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def CentreOnParent(self, direction: int=BOTH) -> None:
        """ Centres the window on its parent.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ClearBackground(self) -> None:
        """ Clears the window by filling it with the current background colour.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ClientToScreen(self, *args, **kw) -> tuple:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ClientToWindowSize(self, size: Union[tuple[int, int], 'Size']) -> 'Size':
        """ Converts client area size size  to corresponding window size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Close(self, force: bool=False) -> bool:
        """ This function simply generates a   wx.CloseEvent  whose handler usually tries to close the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ConvertDialogToPixels(self, *args, **kw) -> 'Point':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ConvertPixelsToDialog(self, *args, **kw) -> 'Point':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name=PanelNameStr) -> bool:
        """ Construct the actual window object after creating the C++ object.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DLG_UNIT(self, dlg_unit) -> None:
        """ A convenience wrapper for ConvertDialogToPixels.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Destroy(self) -> Optional[bool]:
        """ Destroys the window safely.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DestroyChildren(self) -> bool:
        """ Destroys all children of a window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DestroyLater(self) -> None:
        """ Schedules the window to be destroyed in the near future.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Disable(self) -> bool:
        """ Disables the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DisableFocusFromKeyboard(self) -> None:
        """ Disable giving focus to this window using the keyboard navigation keys.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DissociateHandle(self) -> None:
        """ Dissociate the current native handle from the window

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DoGetBestClientSize(self) -> 'Size':
        """ Override this method to return the best size for a custom control.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DoGetBestSize(self) -> 'Size':
        """ Implementation of GetBestSize   that can be overridden.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DoUpdateWindowUI(self, event: 'UpdateUIEvent') -> None:
        """ Does the window-specific updating after processing the update event.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def DragAcceptFiles(self, accept: bool) -> None:
        """ Enables or disables eligibility for drop file events (OnDropFiles).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Enable(self, enable: bool=True) -> bool:
        """ Enable or disable the window for user input.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def EnableTouchEvents(self, eventsMask: int) -> bool:
        """ Request generation of touch events for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def EnableVisibleFocus(self, enable: bool) -> None:
        """ Enables or disables visible indication of keyboard focus.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def EndRepositioningChildren(self) -> None:
        """ Fix child window positions after setting all of them at once.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def FindFocus() -> 'Window':
        """ Finds the window or control which currently has the keyboard focus.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def FindWindow(self, *args, **kw) -> 'Window':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def FindWindowById(id, parent=None) -> 'Window':
        """ Find the first window with the given id.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def FindWindowByLabel(label, parent=None) -> 'Window':
        """ Find a window by its label.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def FindWindowByName(name, parent=None) -> 'Window':
        """ Find a window by its name (as given in a window constructor or Create   function call).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Fit(self) -> None:
        """ Sizes the window to fit its best size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def FitInside(self) -> None:
        """ Similar to Fit , but sizes the interior (virtual) size of a window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Freeze(self) -> None:
        """ Freezes the window or, in other words, prevents any updates from taking place on screen, the window is not redrawn at all.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def FromDIP(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def FromPhys(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetAcceleratorTable(self) -> 'AcceleratorTable':
        """ Gets the accelerator table for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetAccessible(self) -> 'Accessible':
        """ Returns the accessible object for this window, if any.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetAutoLayout(self) -> bool:
        """ Returns True if Layout   is called automatically when the window is resized.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetBackgroundColour(self) -> 'Colour':
        """ Returns the background colour of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetBackgroundStyle(self) -> 'BackgroundStyle':
        """ Returns the background style of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetBestHeight(self, width: int) -> int:
        """ Returns the best height needed by this window if it had the given width.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetBestSize(self) -> 'Size':
        """ This functions returns the best acceptable minimal size for the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetBestVirtualSize(self) -> 'Size':
        """ Return the largest of ClientSize and BestSize (as determined by a sizer, interior children, or other means)

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetBestWidth(self, height: int) -> int:
        """ Returns the best width needed by this window if it had the given height.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetBorder(self, *args, **kw) -> 'Border':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def GetCapture() -> 'Window':
        """ Returns the currently captured window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetCaret(self) -> 'Caret':
        """ Returns the caret() associated with the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetCharHeight(self) -> int:
        """ Returns the character height for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetCharWidth(self) -> int:
        """ Returns the average character width for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetChildren(self) -> WindowList:
        """ Returns a reference to the list of the windowâs children.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ Returns the default font and colours which are used by the control.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetClientAreaOrigin(self) -> 'Point':
        """ Get the origin of the client area of the window relative to the window top left corner (the client area may be shifted because of the borders, scrollbars, other decorationsâ¦)

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetClientRect(self) -> 'Rect':
        """ Get the client rectangle in window (i.e. client) coordinates.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetClientSize(self) -> None:
        """ Returns the size of the window âclient areaâ in pixels.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetConstraints(self) -> 'LayoutConstraints':
        """ Returns a pointer to the windowâs layout constraints, or None if there are none.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetContainingSizer(self) -> 'Sizer':
        """ Returns the sizer of which this window is a member, if any, otherwise None.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetContentScaleFactor(self) -> float:
        """ Returns the factor mapping logical pixels of this window to physical pixels.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetCursor(self) -> 'Cursor':
        """ Return the cursor associated with this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetDPI(self) -> 'Size':
        """ Return the DPI of the display used by this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetDPIScaleFactor(self) -> float:
        """ Returns the ratio of the DPI used by this window to the standard DPI.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetDefaultAttributes(self) -> 'VisualAttributes':
        """ Currently this is the same as calling Window.GetClassDefaultAttributes(wxWindow.GetWindowVariant()).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetDropTarget(self) -> 'DropTarget':
        """ Returns the associated drop target, which may be None.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetEffectiveMinSize(self) -> 'Size':
        """ Merges the windowâs best size into the min size and returns the result.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetEventHandler(self) -> 'EvtHandler':
        """ Returns the event handler for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetExtraStyle(self) -> int:
        """ Returns the extra style bits for the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetFont(self) -> 'Font':
        """ Returns the font for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetForegroundColour(self) -> 'Colour':
        """ Returns the foreground colour of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetGrandParent(self) -> 'Window':
        """ Returns the grandparent of a window, or None if there isnât one.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetGtkWidget(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetHandle(self) -> None:
        """ Returns the platform-specific handle of the physical window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetHelpText(self) -> str:
        """ Gets the help text to be used as context-sensitive help for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetHelpTextAtPoint(self, point, origin) -> str:
        """ Gets the help text to be used as context-sensitive help for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetId(self) -> int:
        """ Returns the identifier of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetLabel(self) -> str:
        """ Generic way of getting a label from any window, for identification purposes.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetLayoutDirection(self) -> int:
        """ Returns the layout direction for this window, Note that  Layout_Default   is returned if layout direction is not supported.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMaxClientSize(self) -> 'Size':
        """ Returns the maximum size of windowâs client area.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMaxHeight(self) -> int:
        """ Returns the vertical component of window maximal size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMaxSize(self) -> 'Size':
        """ Returns the maximum size of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMaxWidth(self) -> int:
        """ Returns the horizontal component of window maximal size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMinClientSize(self) -> 'Size':
        """ Returns the minimum size of windowâs client area, an indication to the sizer layout mechanism that this is the minimum required size of its client area.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMinHeight(self) -> int:
        """ Returns the vertical component of window minimal size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMinSize(self) -> 'Size':
        """ Returns the minimum size of the window, an indication to the sizer layout mechanism that this is the minimum required size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetMinWidth(self) -> int:
        """ Returns the horizontal component of window minimal size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetName(self) -> str:
        """ Returns the windowâs name.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetNextSibling(self) -> 'Window':
        """ Returns the next window after this one among the parentâs children or None if this window is the last child.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetParent(self) -> 'Window':
        """ Returns the parent of the window, or None if there is no parent.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetPopupMenuSelectionFromUser(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetPosition(self) -> 'Point':
        """ This gets the position of the window in pixels, relative to the parent window for the child windows or relative to the display origin for the top level windows.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetPrevSibling(self) -> 'Window':
        """ Returns the previous window before this one among the parentâs children or

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetRect(self) -> 'Rect':
        """ Returns the position and size of the window as a   wx.Rect  object.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetScreenPosition(self) -> 'Point':
        """ Returns the window position in screen coordinates, whether the window is a child window or a top level one.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetScreenRect(self) -> 'Rect':
        """ Returns the position and size of the window on the screen as a   wx.Rect  object.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetScrollPos(self, orientation: int) -> int:
        """ Returns the built-in scrollbar position.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetScrollRange(self, orientation: int) -> int:
        """ Returns the built-in scrollbar range.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetScrollThumb(self, orientation: int) -> int:
        """ Returns the built-in scrollbar thumb size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetSize(self) -> 'Size':
        """ Returns the size of the entire window in pixels, including title bar, border, scrollbars, etc.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetSizer(self) -> 'Sizer':
        """ Returns the sizer associated with the window by a previous call to SetSizer , or None.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetFullTextExtent(self, string, font=None) -> tuple:
        """ Gets the dimensions of the string as it would be drawn on the window with the currently selected font.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetTextExtent(self, string: str) -> 'Size':
        """ Gets the dimensions of the string as it would be drawn on the window with the currently selected font.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetThemeEnabled(self) -> bool:
        """ Returns True if the window uses the system theme for drawing its background.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetToolTip(self) -> 'ToolTip':
        """ Get the associated tooltip or None if none.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetToolTipText(self) -> str:
        """ Get the text of the associated tooltip or empty string if none.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetTopLevelParent(self) -> 'Window':
        """ Returns the first ancestor of this window which is a top-level window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetUpdateClientRect(self) -> 'Rect':
        """ Get the update rectangle bounding box in client coords.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetUpdateRegion(self) -> 'Region':
        """ Returns the region specifying which parts of the window have been damaged.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetValidator(self) -> 'Validator':
        """ Validator functions.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetVirtualSize(self) -> 'Size':
        """ This gets the virtual size of the window in pixels.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetWindowBorderSize(self) -> 'Size':
        """ Returns the size of the left/right and top/bottom borders of this window in x and y components of the result respectively.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetWindowStyle(self) -> int:
        """ See GetWindowStyleFlag   for more info.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetWindowStyleFlag(self) -> int:
        """ Gets the window style that was passed to the constructor or Create   method.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def GetWindowVariant(self) -> int:
        """ Returns the value previously passed to SetWindowVariant .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HandleAsNavigationKey(self, event: 'KeyEvent') -> bool:
        """ This function will generate the appropriate call to Navigate   if the key event is one normally used for keyboard navigation and return True in this case.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HandleWindowEvent(self, event: 'Event') -> bool:
        """ Shorthand for:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HasCapture(self) -> bool:
        """ Returns True if this window has the current mouse capture.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HasExtraStyle(self, exFlag: int) -> bool:
        """ Returns True if the window has the given exFlag  bit set in its extra styles.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HasFlag(self, flag: int) -> bool:
        """ Returns True if the window has the given flag  bit set.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HasFocus(self) -> bool:
        """ Returns True if the window (or in case of composite controls, its main child window) has focus.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HasMultiplePages(self) -> bool:
        """ This method should be overridden to return True if this window has multiple pages.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HasScrollbar(self, orient: int) -> bool:
        """ Returns True if this window currently has a scroll bar for this orientation.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HasTransparentBackground(self) -> bool:
        """ Returns True if this window background is transparent (as, for example, for   wx.StaticText) and should show the parent window background.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Hide(self) -> bool:
        """ Equivalent to calling wx.Window.Show (False).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HideWithEffect(self, effect, timeout=0) -> bool:
        """ This function hides a window, like Hide , but using a special visual effect if possible.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def HitTest(self, *args, **kw) -> 'HitTest':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def InformFirstDirection(self, direction, size, availableOtherDir) -> bool:
        """ wx.Sizer  and friends use this to give a chance to a component to recalc its min size once one of the final size components is known.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def InheritAttributes(self) -> None:
        """ This function is (or should be, in case of custom controls) called during window creation to intelligently set up the window visual attributes, that is the font and the foreground and background colours.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def InheritsBackgroundColour(self) -> bool:
        """ Return True if this window inherits the background colour from its parent.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def InheritsForegroundColour(self) -> bool:
        """ Return True if this window inherits the foreground colour from its parent.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def InitDialog(self) -> None:
        """ Sends an  wxEVT_INIT_DIALOG   event, whose handler usually transfers data to the dialog via validators.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def InvalidateBestSize(self) -> None:
        """ Resets the cached best size value so it will be recalculated the next time it is needed.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsBeingDeleted(self) -> bool:
        """ Returns True if this window is in process of being destroyed.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsDescendant(self, win: 'Window') -> bool:
        """ Check if the specified window is a descendant of this one.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsDoubleBuffered(self) -> bool:
        """ Returns True if the window contents is double-buffered by the system, i.e. if any drawing done on the window is really done on a temporary backing surface and transferred to the screen all at once later.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsEnabled(self) -> bool:
        """ Returns True if the window is enabled, i.e. if it accepts user input, False otherwise.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsExposed(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsFocusable(self) -> bool:
        """ Can this window itself have focus?

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsFrozen(self) -> bool:
        """ Returns True if the window is currently frozen by a call to Freeze .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsRetained(self) -> bool:
        """ Returns True if the window is retained, False otherwise.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsScrollbarAlwaysShown(self, orient: int) -> bool:
        """ Return whether a scrollbar is always shown.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsShown(self) -> bool:
        """ Returns True if the window is shown, False if it has been hidden.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsShownOnScreen(self) -> bool:
        """ Returns True if the window is physically visible on the screen, i.e. it is shown and all its parents up to the toplevel window are shown as well.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsThisEnabled(self) -> bool:
        """ Returns True if this window is intrinsically enabled, False otherwise, i.e. if Enable   Enable(false) had been called.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsTopLevel(self) -> bool:
        """ Returns True if the given window is a top-level one.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def IsTransparentBackgroundSupported(self, reason: Optional[str]=None) -> bool:
        """ Checks whether using transparent background might work.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Layout(self) -> bool:
        """ Lays out the children of this window using the associated sizer.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def LineDown(self) -> bool:
        """ Same as ScrollLines   (1).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def LineUp(self) -> bool:
        """ Same as ScrollLines   (-1).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Lower(self) -> None:
        """ Lowers the window to the bottom of the window hierarchy (Z-order).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def MacIsWindowScrollbar(self, sb) -> None:
        """ Is the given widget one of this windowâs built-in scrollbars?  Only applicable on Mac.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Move(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def MoveAfterInTabOrder(self, win: 'Window') -> None:
        """ Moves this window in the tab navigation order after the specified win.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def MoveBeforeInTabOrder(self, win: 'Window') -> None:
        """ Same as MoveAfterInTabOrder   except that it inserts this window just before win  instead of putting it right after it.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Navigate(self, flags: int=NavigationKeyEvent.IsForward) -> bool:
        """ Performs a keyboard navigation action starting from this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def NavigateIn(self, flags: int=NavigationKeyEvent.IsForward) -> bool:
        """ Performs a keyboard navigation action inside this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def NewControlId(count: int=1) -> int:
        """ Create a new ID or range of IDs that are not currently in use.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def OnInternalIdle(self) -> None:
        """ This virtual function is normally only used internally, but sometimes an application may need it to implement functionality that should not be disabled by an application defining an OnIdle handler in a derived class.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def PageDown(self) -> bool:
        """ Same as ScrollPages   (1).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def PageUp(self) -> bool:
        """ Same as ScrollPages   (-1).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def PopEventHandler(self, deleteHandler: bool=False) -> 'EvtHandler':
        """ Removes and returns the top-most event handler on the event handler stack.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def PopupMenu(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def PostSizeEvent(self) -> None:
        """ Posts a size event to the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def PostSizeEventToParent(self) -> None:
        """ Posts a size event to the parent of this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ProcessEvent(self, event: 'Event') -> bool:
        """ This function is public in   wx.EvtHandler  but protected in   wx.Window  because for Windows you should always call   wx.ProcessEvent  on the pointer returned by GetEventHandler   and not on the   wx.Window  object itself.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ProcessWindowEvent(self, event: 'Event') -> bool:
        """ Convenient wrapper for   wx.ProcessEvent.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ProcessWindowEventLocally(self, event: 'Event') -> bool:
        """ Wrapper for wx.EvtHandler.ProcessEventLocally .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def PushEventHandler(self, handler: 'EvtHandler') -> None:
        """ Pushes this event handler onto the event stack for the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Raise(self) -> None:
        """ Raises the window to the top of the window hierarchy (Z-order).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Refresh(self, eraseBackground=True, rect=None) -> None:
        """ Causes this window, and all of its children recursively, to be repainted.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def RefreshRect(self, rect, eraseBackground=True) -> None:
        """ Redraws the contents of the given rectangle: only the area inside it will be repainted.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def RegisterHotKey(self, hotkeyId, modifiers, virtualKeyCode) -> bool:
        """ Registers a system wide hotkey.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ReleaseMouse(self) -> None:
        """ Releases mouse input captured with CaptureMouse .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def RemoveChild(self, child: 'WindowBase') -> None:
        """ Removes a child window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def RemoveEventHandler(self, handler: 'EvtHandler') -> bool:
        """ Find the given handler  in the windows event handler stack and removes (but does not delete) it from the stack.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Reparent(self, newParent: 'Window') -> bool:
        """ Reparents the window, i.e. the window will be removed from its current parent window (e.g.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ScreenToClient(self, *args, **kw) -> tuple:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ScrollLines(self, lines: int) -> bool:
        """ Scrolls the window by the given number of lines down (if lines  is positive) or up.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ScrollPages(self, pages: int) -> bool:
        """ Scrolls the window by the given number of pages down (if pages  is positive) or up.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ScrollWindow(self, dx, dy, rect=None) -> None:
        """ Physically scrolls the pixels in the window and move child windows accordingly.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SendDestroyEvent(self) -> None:
        """ Generate   wx.WindowDestroyEvent  for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SendIdleEvents(self, event: 'IdleEvent') -> bool:
        """ Send idle event to window and all subwindows.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SendSizeEvent(self, flags: int=0) -> None:
        """ This function sends a dummy size event  to the window allowing it to re-layout its children positions.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SendSizeEventToParent(self, flags: int=0) -> None:
        """ Safe wrapper for GetParent . SendSizeEvent .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetAcceleratorTable(self, accel: 'AcceleratorTable') -> None:
        """ Sets the accelerator table for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetAccessible(self, accessible: 'Accessible') -> None:
        """ Sets the accessible for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetAutoLayout(self, autoLayout: bool) -> None:
        """ Determines whether the Layout   function will be called automatically when the window is resized.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetBackgroundColour(self, colour: Union[int, str, 'Colour']) -> bool:
        """ Sets the background colour of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetBackgroundStyle(self, style: BackgroundStyle) -> bool:
        """ Sets the background style of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetCanFocus(self, canFocus: bool) -> None:
        """ This method is only implemented by ports which have support for native TAB traversal (such as GTK+ 2.0).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetCaret(self, caret: 'Caret') -> None:
        """ Sets the caret() associated with the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetClientRect(self, rect) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetClientSize(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetConstraints(self, constraints: 'LayoutConstraints') -> None:
        """ Sets the window to have the given layout constraints.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetContainingSizer(self, sizer: 'Sizer') -> None:
        """ Used by   wx.Sizer  internally to notify the window about being managed by the given sizer.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetCursor(self, cursor: 'Cursor') -> bool:
        """ Sets the windowâs cursor.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetDimensions(self, x, y, width, height, sizeFlags=SIZE_AUTO) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetDoubleBuffered(self, on: bool) -> None:
        """ Turn on or off double buffering of the window if the system supports it.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetDropTarget(self, target: 'DropTarget') -> None:
        """ Associates a drop target with this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetEventHandler(self, handler: 'EvtHandler') -> None:
        """ Sets the event handler for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetExtraStyle(self, exStyle: int) -> None:
        """ Sets the extra style bits for the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetFocus(self) -> None:
        """ This sets the window to receive keyboard input.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetFocusFromKbd(self) -> None:
        """ This function is called by wxWidgets keyboard navigation code when the user gives the focus to this window from keyboard (e.g. using  TAB   key).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetFont(self, font: 'Font') -> bool:
        """ Sets the font for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetForegroundColour(self, colour: Union[int, str, 'Colour']) -> bool:
        """ Sets the foreground colour of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetHelpText(self, helpText: str) -> None:
        """ Sets the help text to be used as context-sensitive help for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetId(self, winid: int) -> None:
        """ Sets the identifier of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetInitialSize(self, size: Union[tuple[int, int], 'Size']=DefaultSize) -> None:
        """ A smart  SetSize that will fill in default size components with the windowâs best  size values.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetLabel(self, label: str) -> None:
        """ Sets the windowâs label.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetLayoutDirection(self, dir: int) -> None:
        """ Sets the layout direction for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetMaxClientSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the maximum client size of the window, to indicate to the sizer layout mechanism that this is the maximum possible size of its client area.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetMaxSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the maximum size of the window, to indicate to the sizer layout mechanism that this is the maximum possible size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetMinClientSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the minimum client size of the window, to indicate to the sizer layout mechanism that this is the minimum required size of windowâs client area.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetMinSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the minimum size of the window, to indicate to the sizer layout mechanism that this is the minimum required size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetName(self, name: str) -> None:
        """ Sets the windowâs name.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetNextHandler(self, handler: 'EvtHandler') -> None:
        """ Windows cannot be used to form event handler chains; this function thus will assert when called.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetOwnBackgroundColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the background colour of the window but prevents it from being inherited by the children of this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetOwnFont(self, font: 'Font') -> None:
        """ Sets the font of the window but prevents it from being inherited by the children of this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetOwnForegroundColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the foreground colour of the window but prevents it from being inherited by the children of this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetPalette(self, pal: 'Palette') -> None:
        """ pal (wx.Palette) â

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetPosition(self, pt: Union[tuple[int, int], 'Point']) -> None:
        """ Moves the window to the specified position.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetPreviousHandler(self, handler: 'EvtHandler') -> None:
        """ Windows cannot be used to form event handler chains; this function thus will assert when called.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetRect(self, rect) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetScrollPos(self, orientation, pos, refresh=True) -> None:
        """ Sets the position of one of the built-in scrollbars.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetScrollbar(self, orientation, position, thumbSize, range, refresh=True) -> None:
        """ Sets the scrollbar properties of a built-in scrollbar.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetSize(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetSizeHints(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetSizer(self, sizer, deleteOld=True) -> None:
        """ Sets the window to have the given layout sizer.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetSizerAndFit(self, sizer, deleteOld=True) -> None:
        """ Associate the sizer with the window and set the window size and minimal size accordingly.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetThemeEnabled(self, enable: bool) -> None:
        """ This function tells a window if it should use the systemâs âthemeâ code to draw the windowsâ background instead of its own background drawing code.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetToolTip(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetTransparent(self, alpha: 'Byte') -> bool:
        """ Set the transparency of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetValidator(self, validator: 'Validator') -> None:
        """ Deletes the current validator (if any) and sets the window validator, having called wx.Validator.Clone   to create a new validator of this type.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetVirtualSize(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetWindowStyle(self, style: int) -> None:
        """ See SetWindowStyleFlag   for more info.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetWindowStyleFlag(self, style: int) -> None:
        """ Sets the style of the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def SetWindowVariant(self, variant: int) -> None:
        """ Chooses a different variant of the window display to use.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ShouldInheritColours(self) -> bool:
        """ Return True from here to allow the colours of this window to be changed by InheritAttributes .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Show(self, show: bool=True) -> bool:
        """ Shows or hides the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ShowWithEffect(self, effect, timeout=0) -> bool:
        """ This function shows a window, like Show , but using a special visual effect if possible.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Thaw(self) -> None:
        """ Re-enables window updating after a previous call to Freeze .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ToDIP(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ToPhys(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def ToggleWindowStyle(self, flag: int) -> bool:
        """ Turns the given flag  on if itâs currently turned off and vice versa.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def TransferDataFromWindow(self) -> bool:
        """ Transfers values from child controls to data areas specified by their validators.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def TransferDataToWindow(self) -> bool:
        """ Transfers values to child controls from data areas specified by their validators.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def UnregisterHotKey(self, hotkeyId: int) -> bool:
        """ Unregisters a system wide hotkey.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    @staticmethod
    def UnreserveControlId(id, count=1) -> None:
        """ Unreserve an ID or range of IDs that was reserved by NewControlId .

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def UnsetToolTip(self) -> None:
        """ Unset any existing tooltip.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Update(self) -> None:
        """ Calling this method immediately repaints the invalidated area of the window and all of its children recursively (this normally only happens when the flow of control returns to the event loop).

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def UpdateWindowUI(self, flags: int=UPDATE_UI_NONE) -> None:
        """ This function sends one or more   wx.UpdateUIEvent  to the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def UseBackgroundColour(self) -> bool:
        """ Return True if a background colour has been set for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def UseBgCol(self) -> bool:
        """ Return True if a background colour has been set for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def UseForegroundColour(self) -> bool:
        """ Return True if a foreground colour has been set for this window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def Validate(self) -> bool:
        """ Validates the current values of the child controls using their validators.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def WarpPointer(self, x, y) -> None:
        """ Moves the pointer to the given position on the window.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def WindowToClientSize(self, size: Union[tuple[int, int], 'Size']) -> 'Size':
        """ Converts window size size  to corresponding client area size In other words, the returned value is what would GetClientSize   return if this window had given window size.

            Source: https://docs.wxpython.org/wx.Window.html
        """

    def __nonzero__(self) -> None:
        """ Can be used to test if the C++ part of the window still exists, with
code like this:

            Source: https://docs.wxpython.org/wx.Window.html
        """

    AcceleratorTable: 'AcceleratorTable'  # See GetAcceleratorTable and SetAcceleratorTable
    AutoLayout: bool  # See GetAutoLayout and SetAutoLayout
    BackgroundColour: Union[int, str, 'Colour']  # See GetBackgroundColour and SetBackgroundColour
    BackgroundStyle: BackgroundStyle  # See GetBackgroundStyle and SetBackgroundStyle
    BestSize: 'Size'  # See GetBestSize
    BestVirtualSize: 'Size'  # See GetBestVirtualSize
    Border: 'Border'  # See GetBorder
    Caret: 'Caret'  # See GetCaret and SetCaret
    CharHeight: int  # See GetCharHeight
    CharWidth: int  # See GetCharWidth
    Children: WindowList  # See GetChildren
    ClientAreaOrigin: 'Point'  # See GetClientAreaOrigin
    ClientRect: 'Rect'  # See GetClientRect and SetClientRect
    ClientSize: None  # See GetClientSize and SetClientSize
    Constraints: 'LayoutConstraints'  # See GetConstraints and SetConstraints
    ContainingSizer: 'Sizer'  # See GetContainingSizer and SetContainingSizer
    Cursor: 'Cursor'  # See GetCursor and SetCursor
    DefaultAttributes: 'VisualAttributes'  # See GetDefaultAttributes
    DropTarget: 'DropTarget'  # See GetDropTarget and SetDropTarget
    EffectiveMinSize: 'Size'  # See GetEffectiveMinSize
    Enabled: Any  # See IsEnabled and Enable
    EventHandler: 'EvtHandler'  # See GetEventHandler and SetEventHandler
    ExtraStyle: int  # See GetExtraStyle and SetExtraStyle
    Font: 'Font'  # See GetFont and SetFont
    ForegroundColour: Union[int, str, 'Colour']  # See GetForegroundColour and SetForegroundColour
    GrandParent: 'Window'  # See GetGrandParent
    Handle: None  # See GetHandle
    HelpText: str  # See GetHelpText and SetHelpText
    Id: int  # See GetId and SetId
    Label: str  # See GetLabel and SetLabel
    LayoutDirection: int  # See GetLayoutDirection and SetLayoutDirection
    MaxClientSize: Union[tuple[int, int], 'Size']  # See GetMaxClientSize and SetMaxClientSize
    MaxHeight: int  # See GetMaxHeight
    MaxSize: Union[tuple[int, int], 'Size']  # See GetMaxSize and SetMaxSize
    MaxWidth: int  # See GetMaxWidth
    MinClientSize: Union[tuple[int, int], 'Size']  # See GetMinClientSize and SetMinClientSize
    MinHeight: int  # See GetMinHeight
    MinSize: Union[tuple[int, int], 'Size']  # See GetMinSize and SetMinSize
    MinWidth: int  # See GetMinWidth
    Name: str  # See GetName and SetName
    Parent: 'Window'  # See GetParent
    Position: Union[tuple[int, int], 'Point']  # See GetPosition and SetPosition
    Rect: 'Rect'  # See GetRect and SetRect
    ScreenPosition: 'Point'  # See GetScreenPosition
    ScreenRect: 'Rect'  # See GetScreenRect
    Shown: Any  # See IsShown and Show
    Size: 'Size'  # See GetSize and SetSize
    Sizer: 'Sizer'  # See GetSizer and SetSizer
    ThemeEnabled: bool  # See GetThemeEnabled and SetThemeEnabled
    ToolTip: str  # See GetToolTip and SetToolTip
    TopLevel: Any  # See IsTopLevel
    TopLevelParent: 'Window'  # See GetTopLevelParent
    UpdateClientRect: 'Rect'  # See GetUpdateClientRect
    UpdateRegion: 'Region'  # See GetUpdateRegion
    Validator: 'Validator'  # See GetValidator and SetValidator
    VirtualSize: 'Size'  # See GetVirtualSize and SetVirtualSize
    WindowStyle: int  # See GetWindowStyle and SetWindowStyle
    WindowStyleFlag: int  # See GetWindowStyleFlag and SetWindowStyleFlag
    WindowVariant: int  # See GetWindowVariant and SetWindowVariant



BORDER_DEFAULT: int  # The window class will decide the kind of border to show, if any.

BORDER_SIMPLE: int  # Displays a thin border around the window. wx.SIMPLE_BORDER is the old name for this style.

BORDER_SUNKEN: int  # Displays a sunken border. wx.SUNKEN_BORDER is the old name for this style.

BORDER_RAISED: int  # Displays a raised border. wx.RAISED_BORDER is the old name for this style.

BORDER_STATIC: int  # Displays a border suitable for a static control. wx.STATIC_BORDER is the old name for this style. Windows only.

BORDER_THEME: int  # Displays a native border suitable for a control, on the current platform. On Windows, this will be a themed border; on most other platforms a sunken border will be used. For more information for themed borders on Windows, please see Themed borders on Windows.

BORDER_DOUBLE: int  # This style is obsolete and should not be used.

TRANSPARENT_WINDOW: int  # The window is transparent, that is, it will not receive paint events. Windows only.

WANTS_CHARS: int  # Use this to indicate that the window wants to get all char/key events for all keys - even for keys like TAB or ENTER which are usually used for dialog navigation and which wouldnât be generated without this style. If you need to use this style in order to get the arrows or etc., but would still like to have normal keyboard navigation take place, you should call Navigate in response to the key events for Tab and Shift-Tab.

NO_FULL_REPAINT_ON_RESIZE: int  # On Windows, this style used to disable repainting the window completely when its size is changed. Since this behaviour is now the default, the style is now obsolete and no longer has an effect.

VSCROLL: int  # Use this style to enable a vertical scrollbar. Notice that this style cannot be used with native controls which donât support scrollbars nor with top-level windows in most ports.

ALWAYS_SHOW_SB: int  # If a window has scrollbars, disable them instead of hiding them when they are not needed (i.e. when the size of the window is big enough to not require the scrollbars to navigate it). This style is currently implemented for wxMSW, wxGTK and wxUniversal and does nothing on the other platforms.

FULL_REPAINT_ON_RESIZE: int  # Use this style to force a complete redraw of the window whenever it is resized instead of redrawing just the part of the window affected by resizing. Note that this was the behaviour by default before 2.5.1 release and that if you experience redraw problems with code which previously used to work you may want to try this. Currently this style applies on GTK+ 2 and Windows only, and full repainting is always done on other platforms. ^^

EVT_HELP: int  # Process a  wxEVT_HELP   event. See    wx.HelpEvent.

EVT_HELP_RANGE: int  # Process a  wxEVT_HELP   event for a range of ids. See    wx.HelpEvent.

EVT_DROP_FILES: int  # Process a  wxEVT_DROP_FILES   event. See    wx.DropFilesEvent.

EVT_ERASE_BACKGROUND: int  # Process a  wxEVT_ERASE_BACKGROUND   event. See    wx.EraseEvent.

EVT_SET_FOCUS: int  # Process a  wxEVT_SET_FOCUS   event. See    wx.FocusEvent.

EVT_KILL_FOCUS: int  # Process a  wxEVT_KILL_FOCUS   event. See    wx.FocusEvent.

EVT_IDLE: int  # Process a  wxEVT_IDLE   event. See    wx.IdleEvent.

EVT_KEY_DOWN: int  # Process a  wxEVT_KEY_DOWN   event (any key has been pressed). See    wx.KeyEvent.

EVT_KEY_UP: int  # Process a  wxEVT_KEY_UP   event (any key has been released). See    wx.KeyEvent.

EVT_CHAR: int  # Process a  wxEVT_CHAR   event. See    wx.KeyEvent.

EVT_CHAR_HOOK: int  # Process a  wxEVT_CHAR_HOOK   event. See    wx.KeyEvent.

EVT_MOUSE_CAPTURE_LOST: int  # Process a  wxEVT_MOUSE_CAPTURE_LOST   event. See    wx.MouseCaptureLostEvent.

EVT_MOUSE_CAPTURE_CHANGED: int  # Process a  wxEVT_MOUSE_CAPTURE_CHANGED   event. See    wx.MouseCaptureChangedEvent.

EVT_PAINT: int  # Process a  wxEVT_PAINT   event. See    wx.PaintEvent.

EVT_SET_CURSOR: int  # Process a  wxEVT_SET_CURSOR   event. See    wx.SetCursorEvent.

EVT_SIZE: int  # Process a  wxEVT_SIZE   event. See    wx.SizeEvent.

EVT_SYS_COLOUR_CHANGED: int  # Process a  wxEVT_SYS_COLOUR_CHANGED   event. See    wx.SysColourChangedEvent. ^^

SIMPLE_BORDER: int

SUNKEN_BORDER: int

RAISED_BORDER: int

STATIC_BORDER: int

NO_BORDER: int

WS_EX_BLOCK_EVENTS: int

WS_EX_TRANSIENT: int

WS_EX_CONTEXTHELP: int

WS_EX_PROCESS_IDLE: int

WS_EX_PROCESS_UI_UPDATES: int

BORDER_MASK: int

TOUCH_NONE: int

TOUCH_ALL_GESTURES: int

MOD_SHIFT: int

MOD_CONTROL: int

MOD_ALT: int

MOD_WIN: int

UPDATE_UI_FROMIDLE: int

class Control(Window):
    """ This is the base class for a control or âwidgetâ.

        Source: https://docs.wxpython.org/wx.Control.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def Command(self, event: 'CommandEvent') -> None:
        """ Simulates the effect of the user issuing a command to the item.

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=ControlNameStr) -> bool:
        """ parent (wx.Window) â

            Source: https://docs.wxpython.org/wx.Control.html
        """

    @staticmethod
    def Ellipsize(label, dc, mode, maxWidth, flags=ELLIPSIZE_FLAGS_DEFAULT) -> str:
        """ Replaces parts of the label  string with ellipsis, if needed, so that it fits into maxWidth  pixels if possible.

            Source: https://docs.wxpython.org/wx.Control.html
        """

    @staticmethod
    def EscapeMnemonics(text: str) -> str:
        """ Escapes the special mnemonics characters (â&â) in the given string.

            Source: https://docs.wxpython.org/wx.Control.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def GetLabel(self) -> str:
        """ Returns the controlâs label, as it was passed to SetLabel .

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def GetLabelText(self, *args, **kw) -> str:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def GetSizeFromText(self, text: str) -> 'Size':
        """ Determine the minimum size needed by the control to display the given text.

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def GetSizeFromTextSize(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Control.html
        """

    @staticmethod
    def RemoveMnemonics(str: str) -> str:
        """ Returns the given str  string without mnemonics (â&â characters).

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def SetLabel(self, label: str) -> None:
        """ Sets the controlâs label.

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def SetLabelMarkup(self, markup: str) -> bool:
        """ Sets the controls label to a string using markup.

            Source: https://docs.wxpython.org/wx.Control.html
        """

    def SetLabelText(self, text: str) -> None:
        """ Sets the controlâs label to exactly the given string.

            Source: https://docs.wxpython.org/wx.Control.html
        """

    Label: str  # See GetLabel and SetLabel
    LabelText: str  # See GetLabelText and SetLabelText



class ControlWithItems(Control,ItemContainer):
    """ This is convenience class that derives from both Control and
ItemContainer.

        Source: https://docs.wxpython.org/wx.ControlWithItems.html
    """


class ItemContainer(ItemContainerImmutable):
    """ This class is an abstract base class for some wxWidgets controls which
contain several items such as ListBox, CheckListBox, ComboBox or
Choice.

        Source: https://docs.wxpython.org/wx.ItemContainer.html
    """
    def Append(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def AppendItems(self, items) -> Any:
        """ Alias for Append

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def Clear(self) -> None:
        """ Removes all items from the control.

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def Delete(self, n: int) -> None:
        """ Deletes an item from the control.

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def DetachClientObject(self, n: int) -> ClientData:
        """ Returns the client object associated with the given item and transfers its ownership to the caller.

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def GetClientData(self, n: int) -> ClientData:
        """ Returns a pointer to the client data associated with the given item (if any).

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def GetClientObject(self, n) -> Any:
        """ Alias for GetClientData

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def GetItems(self) -> Any:
        """ Alias for GetStrings

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def HasClientData(self) -> bool:
        """ Returns True, if either untyped data ( void* ) or object data (wxClientData) is associated with the items of the control.

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def HasClientObjectData(self) -> bool:
        """ Returns True, if object data is associated with the items of the control.

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def HasClientUntypedData(self) -> bool:
        """ Returns True, if untyped data ( void* ) is associated with the items of the control.

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def Insert(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def Set(self, items: list[str]) -> None:
        """ Replaces the current control contents with the given items.

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def SetClientData(self, n, data) -> None:
        """ Associates the given typed client data pointer with the given item: the data  object will be deleted when the item is deleted (either explicitly by using Delete   or implicitly when the control itself is destroyed).

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def SetClientObject(self, n, data) -> Any:
        """ Alias for SetClientData

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    def SetItems(self, items) -> Any:
        """ Alias for Set

            Source: https://docs.wxpython.org/wx.ItemContainer.html
        """

    Items: Any  # See GetItems and SetItems



class Cursor(GDIObject):
    """ A cursor is a small bitmap usually used for denoting where the mouse
pointer is, with a picture that might indicate the interpretation of a
mouse click.

        Source: https://docs.wxpython.org/wx.Cursor.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    def GetHandle(self) -> int:
        """ Get the handle for the Cursor.  Windows only.

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    def GetHotSpot(self) -> 'Point':
        """ Returns the coordinates of the cursor hot spot.

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    def IsOk(self) -> bool:
        """ Returns True if cursor data is present.

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    def SetHandle(self, handle) -> None:
        """ Set the handle to use for this Cursor.  Windows only.

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    def _copyFrom(self, other) -> None:
        """ For internal use only.

            Source: https://docs.wxpython.org/wx.Cursor.html
        """

    Handle: int  # See GetHandle and SetHandle
    HotSpot: 'Point'  # See GetHotSpot



class CustomDataObject(DataObjectSimple):
    """ CustomDataObject is a specialization of DataObjectSimple for some
application-specific data in arbitrary (either custom or one of the
standard ones).

        Source: https://docs.wxpython.org/wx.CustomDataObject.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.CustomDataObject.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.CustomDataObject.html
        """

    def GetData(self) -> Any:
        """ Returns a reference to the data buffer.

            Source: https://docs.wxpython.org/wx.CustomDataObject.html
        """

    def GetSize(self) -> int:
        """ Returns the data size in bytes.

            Source: https://docs.wxpython.org/wx.CustomDataObject.html
        """

    def SetData(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.CustomDataObject.html
        """

    AllFormats: None  # See GetAllFormats
    Data: Any  # See GetData and SetData
    Size: int  # See GetSize



class DataObjectSimple(DataObject):
    """ This is the simplest possible implementation of the DataObject
class.

        Source: https://docs.wxpython.org/wx.DataObjectSimple.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DataObjectSimple.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.DataObjectSimple.html
        """

    def GetDataHere(self, buf) -> bool:
        """ Copies this data objectâs data bytes to the given buffer

            Source: https://docs.wxpython.org/wx.DataObjectSimple.html
        """

    def GetDataSize(self) -> int:
        """ Gets the size of our data.

            Source: https://docs.wxpython.org/wx.DataObjectSimple.html
        """

    def GetFormat(self) -> 'DataFormat':
        """ Returns the (one and only one) format supported by this object.

            Source: https://docs.wxpython.org/wx.DataObjectSimple.html
        """

    def SetData(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DataObjectSimple.html
        """

    def SetFormat(self, format: 'DataFormat') -> None:
        """ Sets the supported format.

            Source: https://docs.wxpython.org/wx.DataObjectSimple.html
        """

    AllFormats: None  # See GetAllFormats
    DataHere: bool  # See GetDataHere
    DataSize: int  # See GetDataSize
    Format: 'DataFormat'  # See GetFormat and SetFormat



class DataFormat:
    """ A DataFormat is an encapsulation of a platform-specific format
handle which is used by the system for the clipboard and drag and drop
operations.

        Source: https://docs.wxpython.org/wx.DataFormat.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DataFormat.html
        """

    def GetId(self) -> str:
        """ Returns the name of a custom format (this function will fail for a standard format).

            Source: https://docs.wxpython.org/wx.DataFormat.html
        """

    def GetType(self) -> 'DataFormatId':
        """ Returns the platform-specific number identifying the format.

            Source: https://docs.wxpython.org/wx.DataFormat.html
        """

    def SetId(self, format: str) -> None:
        """ Sets the format to be the custom format identified by the given name.

            Source: https://docs.wxpython.org/wx.DataFormat.html
        """

    def SetType(self, type: DataFormatId) -> None:
        """ Sets the format to the given value, which should be one of DF_XXX constants.

            Source: https://docs.wxpython.org/wx.DataFormat.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Returns True if the formats are different.

            Source: https://docs.wxpython.org/wx.DataFormat.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Returns True if the formats are equal.

            Source: https://docs.wxpython.org/wx.DataFormat.html
        """

    Id: str  # See GetId and SetId
    Type: DataFormatId  # See GetType and SetType



DF_INVALID: int

DF_TEXT: int

DF_BITMAP: int

DF_METAFILE: int

DF_UNICODETEXT: int

DF_FILENAME: int

DF_HTML: int

DF_PNG: int

class DataObjectComposite(DataObject):
    """ DataObjectComposite is the simplest DataObject derivation which
may be used to support multiple formats.

        Source: https://docs.wxpython.org/wx.DataObjectComposite.html
    """
    def __init__(self) -> None:
        """ The default constructor.

            Source: https://docs.wxpython.org/wx.DataObjectComposite.html
        """

    def Add(self, dataObject, preferred=False) -> None:
        """ Adds the dataObject  to the list of supported objects and it becomes the preferred object if preferred  is True.

            Source: https://docs.wxpython.org/wx.DataObjectComposite.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.DataObjectComposite.html
        """

    def GetObject(self, format, dir=DataObject.Get) -> 'DataObjectSimple':
        """ Returns the pointer to the object which supports the passed format for the specified direction.

            Source: https://docs.wxpython.org/wx.DataObjectComposite.html
        """

    def GetReceivedFormat(self) -> 'DataFormat':
        """ Report the format passed to the SetData   method.

            Source: https://docs.wxpython.org/wx.DataObjectComposite.html
        """

    def SetData(self, format, buf) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.DataObjectComposite.html
        """

    AllFormats: None  # See GetAllFormats
    ReceivedFormat: 'DataFormat'  # See GetReceivedFormat



class DateSpan:
    """ This class is a âlogical time spanâ and is useful for implementing
program logic for such things as âadd one month to the dateâ which, in
general, doesnât mean to add 60x60x24x31 seconds to it, but to take
the same date the next month (to understand that this is indeed
different consider adding one month to Feb, 15  we want to get Mar,
15, of course).

        Source: https://docs.wxpython.org/wx.DateSpan.html
    """
    def __init__(self, years=0, months=0, weeks=0, days=0) -> None:
        """ Constructs the date span object for the given number of years, months, weeks and days.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def Add(self, other: 'DateSpan') -> 'DateSpan':
        """ Adds the given   wx.DateSpan  to this   wx.DateSpan  and returns a reference to itself.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Day() -> 'DateSpan':
        """ Returns a date span object corresponding to one day.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Days(days: int) -> 'DateSpan':
        """ Returns a date span object corresponding to the given number of days.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def GetDays(self) -> int:
        """ Returns the number of days (not counting the weeks component) in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def GetMonths(self) -> int:
        """ Returns the number of the months (not counting the years) in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def GetTotalDays(self) -> int:
        """ Returns the combined number of days in this date span, counting both weeks and days.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def GetTotalMonths(self) -> int:
        """ Returns the combined number of months in this date span, counting both years and months.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def GetWeeks(self) -> int:
        """ Returns the number of weeks in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def GetYears(self) -> int:
        """ Returns the number of years in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Month() -> 'DateSpan':
        """ Returns a date span object corresponding to one month.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Months(mon: int) -> 'DateSpan':
        """ Returns a date span object corresponding to the given number of months.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def Multiply(self, factor: int) -> 'DateSpan':
        """ Multiplies this date span by the specified factor.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def Neg(self) -> 'DateSpan':
        """ Changes the sign of this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def Negate(self) -> 'DateSpan':
        """ Returns a date span with the opposite sign.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def SetDays(self, n: int) -> 'DateSpan':
        """ Sets the number of days (without modifying any other components) in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def SetMonths(self, n: int) -> 'DateSpan':
        """ Sets the number of months (without modifying any other components) in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def SetWeeks(self, n: int) -> 'DateSpan':
        """ Sets the number of weeks (without modifying any other components) in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def SetYears(self, n: int) -> 'DateSpan':
        """ Sets the number of years (without modifying any other components) in this date span.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    def Subtract(self, other: 'DateSpan') -> 'DateSpan':
        """ Subtracts the given   wx.DateSpan  to this   wx.DateSpan  and returns a reference to itself.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Week() -> 'DateSpan':
        """ Returns a date span object corresponding to one week.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Weeks(weeks: int) -> 'DateSpan':
        """ Returns a date span object corresponding to the given number of weeks.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Year() -> 'DateSpan':
        """ Returns a date span object corresponding to one year.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """

    @staticmethod
    def Years(years: int) -> 'DateSpan':
        """ Returns a date span object corresponding to the given number of years.

            Source: https://docs.wxpython.org/wx.DateSpan.html
        """



class DateTime:
    """ DateTime class represents an absolute moment in time.

        Source: https://docs.wxpython.org/wx.DateTime.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def Add(self, *args, **kw) -> 'DateTime':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def ConvertYearToBC(year: int) -> int:
        """ Converts the year in absolute notation (i.e. a number which can be negative, positive or zero) to the year in BC/AD notation.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def DiffAsDateSpan(self, dt: 'DateTime') -> 'DateSpan':
        """ Returns the difference between this object and dt  as a   wx.DateSpan.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def Format(self, format=DefaultDateTimeFormat, tz=Local) -> str:
        """ This function does the same as the standard ANSI C  strftime(3)   function (http://www.cplusplus.com/reference/clibrary/ctime/strftime.html).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def FormatDate(self) -> str:
        """ Identical to calling Format   with  "%x"   argument (which means âpreferred date representation for the current localeâ).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def FormatISOCombined(self, sep: int='T') -> str:
        """ Returns the combined date-time representation in the ISO 8601 format  "YYYY-MM-DDTHH:MM:SS" .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def FormatISODate(self) -> str:
        """ This function returns the date representation in the ISO 8601 format  "YYYY-MM-DD" .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def FormatISOTime(self) -> str:
        """ This function returns the time representation in the ISO 8601 format  "HH:MM:SS" .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def FormatTime(self) -> str:
        """ Identical to calling Format   with  "%X"   argument (which means âpreferred time representation for the current localeâ).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def FromDMY(day, month, year=Inv_Year, hour=0, minute=0, second=0, millisecond=0) -> 'DateTime':
        """ Construct a DateTime using the supplied parameters.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def FromHMS(hour, minute=0, second=0, millisecond=0) -> 'DateTime':
        """ Construct a DateTime equal to Today () with the time set to the supplied parameters.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def FromJDN(jdn) -> 'DateTime':
        """ Construct a DateTime from a Julian Day Number.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def FromTimeT(timet) -> 'DateTime':
        """ Construct a DateTime from a C time_t value, the number of seconds since the epoch.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def FromTimezone(self, tz, noDST=False) -> 'DateTime':
        """ Transform the date from the given time zone to the local one.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetAmPmStrings() -> tuple:
        """ Returns the translations of the strings  AM   and   PM   used for time formatting for the current locale.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetAsDOS(self) -> int:
        """ Returns the date and time in DOS format.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetBeginDST(year=Inv_Year, country=Country_Default) -> 'DateTime':
        """ Get the beginning of DST for the given country in the given year (current one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetCentury(self, tz: 'DateTime.TimeZone'=Local) -> int:
        """ Returns the century of this date.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetCountry() -> 'DateTime.Country':
        """ Returns the current default country.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetCurrentMonth(cal: Calendar=Gregorian) -> 'DateTime.Month':
        """ Get the current month in given calendar (only Gregorian is currently supported).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetCurrentYear(cal: Calendar=Gregorian) -> int:
        """ Get the current year in given calendar (only Gregorian is currently supported).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetDateOnly(self) -> 'DateTime':
        """ Returns the object having the same date component as this one but time of 00:00:00.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetDay(self, tz: 'DateTime.TimeZone'=Local) -> intshort:
        """ Returns the day in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetDayOfYear(self, tz: 'DateTime.TimeZone'=Local) -> intshort:
        """ Returns the day of the year (in 1-366 range) in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetEndDST(year=Inv_Year, country=Country_Default) -> 'DateTime':
        """ Returns the end of DST for the given country in the given year (current one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetEnglishMonthName(month, flags=Name_Full) -> str:
        """ Return the standard English name of the given month.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetEnglishWeekDayName(weekday, flags=Name_Full) -> str:
        """ Return the standard English name of the given week day.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetFirstWeekDay(firstDay: WeekDay) -> bool:
        """ Acquires the first weekday of a week based on locale and/or OS settings.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetHour(self, tz: 'DateTime.TimeZone'=Local) -> intshort:
        """ Returns the hour in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetJDN(self) -> float:
        """ Synonym for GetJulianDayNumber .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetJulianDayNumber(self) -> float:
        """ Returns the JDN corresponding to this date.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetLastMonthDay(self, month=Inv_Month, year=Inv_Year) -> 'DateTime':
        """ Returns the copy of this object to which SetToLastMonthDay   was applied.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetLastWeekDay(self, weekday, month=Inv_Month, year=Inv_Year) -> 'DateTime':
        """ Returns the copy of this object to which SetToLastWeekDay   was applied.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetMJD(self) -> float:
        """ Synonym for GetModifiedJulianDayNumber .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetMillisecond(self, tz: 'DateTime.TimeZone'=Local) -> intshort:
        """ Returns the milliseconds in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetMinute(self, tz: 'DateTime.TimeZone'=Local) -> intshort:
        """ Returns the minute in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetModifiedJulianDayNumber(self) -> float:
        """ Returns the âModified Julian Day Numberâ  (MJD) which is, by definition, is equal to JDN - 2400000.5.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetMonth(self, tz: 'DateTime.TimeZone'=Local) -> 'DateTime.Month':
        """ Returns the month in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetMonthName(month, flags=Name_Full) -> str:
        """ Gets the full (default) or abbreviated name of the given month.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetNextWeekDay(self, weekday: DateTime.WeekDay) -> 'DateTime':
        """ Returns the copy of this object to which SetToNextWeekDay   was applied.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetNumberOfDays(month, year=Inv_Year, cal=Gregorian) -> intshort:
        """ Returns the number of days in the given month of the given year.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetPrevWeekDay(self, weekday: DateTime.WeekDay) -> 'DateTime':
        """ Returns the copy of this object to which SetToPrevWeekDay   was applied.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetRataDie(self) -> float:
        """ Return the Rata  Die number of this date.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetSecond(self, tz: 'DateTime.TimeZone'=Local) -> intshort:
        """ Returns the seconds in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetTicks(self) -> int:
        """ Returns the number of seconds since Jan 1, 1970 UTC.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetTimeNow() -> int:
        """ Returns the current time.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetTm(self, tz: 'DateTime.TimeZone'=Local) -> 'DateTime.Tm':
        """ Returns broken down representation of the date and time.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetValue(self) -> int:
        """ Returns the number of milliseconds since Jan 1, 1970 UTC.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetWeekBasedYear(self, tz: 'DateTime.TimeZone') -> int:
        """ Returns the year to which the week containing this date belongs.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetWeekDay(self, *args, **kw) -> 'DateTime.WeekDay':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetWeekDayInSameWeek(self, weekday, flags=Monday_First) -> 'DateTime':
        """ Returns the copy of this object to which SetToWeekDayInSameWeek   was applied.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def GetWeekDayName(weekday, flags=Name_Full) -> str:
        """ Gets the full (default) or abbreviated name of the given week day.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetWeekOfMonth(self, flags=Monday_First, tz=Local) -> intshort:
        """ Returns the ordinal number of the week in the month (in 1-5 range).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetWeekOfYear(self, flags=Monday_First, tz=Local) -> intshort:
        """ Returns the number of the week of the year this date is in.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetYear(self, tz: 'DateTime.TimeZone'=Local) -> int:
        """ Returns the year in the given timezone (local one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def GetYearDay(self, yday: int) -> 'DateTime':
        """ Returns the copy of this object to which SetToYearDay   was applied.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsBetween(self, t1, t2) -> bool:
        """ Returns True if IsStrictlyBetween   is True or if the date is equal to one of the limit values.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsDST(self, country: Country=Country_Default) -> int:
        """ Returns True if the DST is applied for this date in the given country.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def IsDSTApplicable(year=Inv_Year, country=Country_Default) -> bool:
        """ Returns True if DST was used in the given year (the current one by default) in the given country.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsEarlierThan(self, datetime: 'DateTime') -> bool:
        """ Returns True if this date precedes the given one.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsEqualTo(self, datetime: 'DateTime') -> bool:
        """ Returns True if the two dates are strictly identical.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsEqualUpTo(self, dt, ts) -> bool:
        """ Returns True if the date is equal to another one up to the given time interval, i.e. if the absolute difference between the two dates is less than this interval.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsLaterThan(self, datetime: 'DateTime') -> bool:
        """ Returns True if this date is later than the given one.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def IsLeapYear(year=Inv_Year, cal=Gregorian) -> bool:
        """ Returns True if the year  is a leap one in the specified calendar.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsSameDate(self, dt: 'DateTime') -> bool:
        """ Returns True if the date is the same without comparing the time parts.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsSameTime(self, dt: 'DateTime') -> bool:
        """ Returns True if the time is the same (although dates may differ).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsStrictlyBetween(self, t1, t2) -> bool:
        """ Returns True if this date lies strictly between the two given dates.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsValid(self) -> bool:
        """ Returns True if the object represents a valid time moment.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def IsWestEuropeanCountry(country: Country=Country_Default) -> bool:
        """ This function returns True if the specified (or default) country is one of Western European ones.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def IsWorkDay(self, country: Country=Country_Default) -> bool:
        """ Returns True is this day is not a holiday in the given country.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def MakeFromTimezone(self, tz, noDST=False) -> 'DateTime':
        """ Same as FromTimezone   but modifies the object in place.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def MakeTimezone(self, tz, noDST=False) -> 'DateTime':
        """ Modifies the object in place to represent the date in another time zone.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def MakeUTC(self, noDST: bool=False) -> 'DateTime':
        """ This is the same as calling MakeTimezone   with the argument  GMT0 .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def Now() -> 'DateTime':
        """ Returns the object corresponding to the current time in local time zone.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseDate(self, date: str) -> int:
        """ This function is like ParseDateTime , but it only allows the date to be specified.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseDateTime(self, datetime: str) -> int:
        """ Parses the string datetime  containing the date and time in free format.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseFormat(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseISOCombined(self, date, sep='T') -> bool:
        """ This function parses the string containing the date and time in ISO 8601 combined format  "YYYY-MM-DDTHH:MM:SS" .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseISODate(self, date: str) -> bool:
        """ This function parses the date in ISO 8601 format  "YYYY-MM-DD" .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseISOTime(self, date: str) -> bool:
        """ This function parses the time in ISO 8601 format  "HH:MM:SS" .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseRfc822Date(self, date: str) -> int:
        """ Parses the string date  looking for a date formatted according to the RFC 822 in it.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ParseTime(self, time: str) -> int:
        """ This functions is like ParseDateTime , but only allows the time to be specified in the input string.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ResetTime(self) -> 'DateTime':
        """ Reset time to midnight (00:00:00) without changing the date.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def Set(self, day, month, year=Inv_Year, hour=0, minute=0, second=0, millisec=0) -> 'DateTime':
        """ Sets the date and time from the parameters.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetHMS(self, hour, minute=0, second=0, millisec=0) -> 'DateTime':
        """ Sets the date to be equal to Today   and the time from supplied parameters.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetJDN(self, jdn: float) -> 'DateTime':
        """ Sets the date from the so-called Julian Day Number.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetTimeT(self, timet: int) -> 'DateTime':
        """ Constructs the object from timet  value holding the number of seconds since Jan 1, 1970 UTC.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetTm(self, tm: 'DateTime.Tm') -> 'DateTime':
        """ Sets the date and time from the broken down representation in the  ` wx.DateTime.Tm  `   structure.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def SetCountry(country: Country) -> None:
        """ Sets the country to use by default.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetDay(self, day: int) -> 'DateTime':
        """ Sets the day without changing other date components.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetFromDOS(self, ddt: int) -> 'DateTime':
        """ Sets the date from the date and time in DOS format.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetHour(self, hour: int) -> 'DateTime':
        """ Sets the hour without changing other date components.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetMillisecond(self, millisecond: int) -> 'DateTime':
        """ Sets the millisecond without changing other date components.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetMinute(self, minute: int) -> 'DateTime':
        """ Sets the minute without changing other date components.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetMonth(self, month: DateTime.Month) -> 'DateTime':
        """ Sets the month without changing other date components.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetSecond(self, second: int) -> 'DateTime':
        """ Sets the second without changing other date components.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToCurrent(self) -> 'DateTime':
        """ Sets the date and time of to the current values.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToLastMonthDay(self, month=Inv_Month, year=Inv_Year) -> 'DateTime':
        """ Sets the date to the last day in the specified month (the current one by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToLastWeekDay(self, weekday, month=Inv_Month, year=Inv_Year) -> bool:
        """ The effect of calling this function is the same as of calling  SetToWeekDay (-1, weekday, month, year).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToNextWeekDay(self, weekday: DateTime.WeekDay) -> 'DateTime':
        """ Sets the date so that it will be the first weekday  following the current date.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToPrevWeekDay(self, weekday: DateTime.WeekDay) -> 'DateTime':
        """ Sets the date so that it will be the last weekday  before the current date.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToWeekDay(self, weekday, n=1, month=Inv_Month, year=Inv_Year) -> bool:
        """ Sets the date to the n-th weekday  in the given month of the given year (the current month and year are used by default).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToWeekDayInSameWeek(self, weekday, flags=Monday_First) -> 'DateTime':
        """ Adjusts the date so that it will still lie in the same week as before, but its week day will be the given one.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def SetToWeekOfYear(year, numWeek, weekday=Mon) -> 'DateTime':
        """ Set the date to the given weekday  in the week number numWeek  of the given year  .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetToYearDay(self, yday: int) -> 'DateTime':
        """ Sets the date to the day number yday  in the same year (i.e. unlike the other functions, this one does not use the current year).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def SetYear(self, year: int) -> 'DateTime':
        """ Sets the year without changing other date components.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def Subtract(self, *args, **kw) -> 'DateTime':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ToTimezone(self, tz, noDST=False) -> 'DateTime':
        """ Transform the date to the given time zone.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def ToUTC(self, noDST: bool=False) -> 'DateTime':
        """ This is the same as calling ToTimezone   with the argument  GMT0 .

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def Today() -> 'DateTime':
        """ Returns the object corresponding to the midnight of the current day (i.e. the same as wx.Now     , but the time part is set to 0).

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    @staticmethod
    def UNow() -> 'DateTime':
        """ Returns the object corresponding to the current time including the milliseconds.

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DateTime.html
        """

    DayOfYear: intshort  # See GetDayOfYear
    JDN: float  # See GetJDN and SetJDN
    JulianDayNumber: float  # See GetJulianDayNumber
    LastMonthDay: 'DateTime'  # See GetLastMonthDay
    MJD: float  # See GetMJD
    ModifiedJulianDayNumber: float  # See GetModifiedJulianDayNumber
    RataDie: float  # See GetRataDie
    Ticks: int  # See GetTicks
    WeekOfMonth: intshort  # See GetWeekOfMonth
    WeekOfYear: intshort  # See GetWeekOfYear
    day: Any  # See GetDay and SetDay
    hour: Any  # See GetHour and SetHour
    millisecond: Any  # See GetMillisecond and SetMillisecond
    minute: Any  # See GetMinute and SetMinute
    month: Any  # See GetMonth and SetMonth
    second: Any  # See GetSecond and SetSecond
    year: Any  # See GetYear and SetYear



class DCBrushChanger:
    """ DCBrushChanger is a small helper class for setting a brush on a DC
and unsetting it automatically in the destructor, restoring the
previous one.

        Source: https://docs.wxpython.org/wx.DCBrushChanger.html
    """
    def __init__(self, dc, brush) -> None:
        """ Sets brush  on the given dc, storing the old one.

            Source: https://docs.wxpython.org/wx.DCBrushChanger.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCBrushChanger.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCBrushChanger.html
        """



class DCClipper:
    """ DCClipper is a helper class for setting a clipping region on a DC
during its lifetime.

        Source: https://docs.wxpython.org/wx.DCClipper.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Sets the clipping region to the specified region/coordinates.

            Source: https://docs.wxpython.org/wx.DCClipper.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCClipper.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCClipper.html
        """



class DCFontChanger:
    """ DCFontChanger is a small helper class for setting a font on a DC
and unsetting it automatically in the destructor, restoring the
previous one.

        Source: https://docs.wxpython.org/wx.DCFontChanger.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DCFontChanger.html
        """

    def Set(self, font: 'Font') -> None:
        """ Set the font to use.

            Source: https://docs.wxpython.org/wx.DCFontChanger.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCFontChanger.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCFontChanger.html
        """



class DCOverlay:
    """ Connects an overlay with a drawing DC.

        Source: https://docs.wxpython.org/wx.DCOverlay.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DCOverlay.html
        """

    def Clear(self) -> None:
        """ Clears the layer, restoring the state at the last init.

            Source: https://docs.wxpython.org/wx.DCOverlay.html
        """



class DCPenChanger:
    """ DCPenChanger is a small helper class for setting a pen on a DC and
unsetting it automatically in the destructor, restoring the previous
one.

        Source: https://docs.wxpython.org/wx.DCPenChanger.html
    """
    def __init__(self, dc, pen) -> None:
        """ Sets pen  on the given dc, storing the old one.

            Source: https://docs.wxpython.org/wx.DCPenChanger.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCPenChanger.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCPenChanger.html
        """



class DCTextBgColourChanger:
    """ DCTextBgColourChanger is a small helper class for setting a
background text colour on a DC and unsetting it automatically in the
destructor, restoring the previous one.

        Source: https://docs.wxpython.org/wx.DCTextBgColourChanger.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DCTextBgColourChanger.html
        """

    def Set(self, col: Union[int, str, 'Colour']) -> None:
        """ Set the background colour to use.

            Source: https://docs.wxpython.org/wx.DCTextBgColourChanger.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCTextBgColourChanger.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCTextBgColourChanger.html
        """



class DCTextBgModeChanger:
    """ DCTextBgModeChanger is a small helper class for setting a background
text mode on a DC and unsetting it automatically in the destructor,
restoring the previous one.

        Source: https://docs.wxpython.org/wx.DCTextBgModeChanger.html
    """
    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCTextBgModeChanger.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCTextBgModeChanger.html
        """



class DCTextColourChanger:
    """ DCTextColourChanger is a small helper class for setting a foreground
text colour on a DC and unsetting it automatically in the
destructor, restoring the previous one.

        Source: https://docs.wxpython.org/wx.DCTextColourChanger.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DCTextColourChanger.html
        """

    def Set(self, col: Union[int, str, 'Colour']) -> None:
        """ Set the colour to use.

            Source: https://docs.wxpython.org/wx.DCTextColourChanger.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCTextColourChanger.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DCTextColourChanger.html
        """



class DelegateRendererNative(RendererNative):
    """ DelegateRendererNative allows reuse of renderers code by forwarding
all the RendererNative methods to the given object and thus allowing
you to only modify some of its methods  without having to reimplement
all of them.

        Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawCheckBox(self, win, dc, rect, flags=0) -> None:
        """ Draw a check box.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawCheckMark(self, win, dc, rect, flags=0) -> None:
        """ Draw a check mark.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawComboBoxDropButton(self, win, dc, rect, flags=0) -> None:
        """ Draw a button like the one used by   wx.ComboBox  to show a drop down window.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawDropArrow(self, win, dc, rect, flags=0) -> None:
        """ Draw a drop down arrow that is suitable for use outside a combo box.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawFocusRect(self, win, dc, rect, flags=0) -> None:
        """ Draw a focus rectangle using the specified rectangle.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawHeaderButton(self, win, dc, rect, flags=0, sortArrow=HDR_SORT_ICON_NONE, params=None) -> int:
        """ Draw the header control button (used, for example, by   wx.ListCtrl).

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawHeaderButtonContents(self, win, dc, rect, flags=0, sortArrow=HDR_SORT_ICON_NONE, params=None) -> int:
        """ Draw the contents of a header control button (label, sort arrows, etc.).

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawItemSelectionRect(self, win, dc, rect, flags=0) -> None:
        """ Draw a selection rectangle underneath the text as used e.g.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawPushButton(self, win, dc, rect, flags=0) -> None:
        """ Draw a blank push button that looks very similar to   wx.Button.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawSplitterBorder(self, win, dc, rect, flags=0) -> None:
        """ Draw the border for sash window: this border must be such that the sash drawn by DrawSplitterSash   blends into it well.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawSplitterSash(self, win, dc, size, position, orient, flags=0) -> None:
        """ Draw a sash.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawTitleBarBitmap(self, win, dc, rect, button, flags=0) -> None:
        """ Draw a title bar button in the given state.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def DrawTreeItemButton(self, win, dc, rect, flags=0) -> None:
        """ Draw the expanded/collapsed icon for a tree control item.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def GetCheckBoxSize(self, win, flags=0) -> 'Size':
        """ Returns the size of a check box.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def GetCheckMarkSize(self, win: 'Window') -> 'Size':
        """ Returns the size of a check mark.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def GetExpanderSize(self, win: 'Window') -> 'Size':
        """ Returns the size of the expander used in tree-like controls.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def GetHeaderButtonHeight(self, win: 'Window') -> int:
        """ Returns the height of a header button, either a fixed platform height if available, or a generic height based on the win  windowâs font.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def GetHeaderButtonMargin(self, win: 'Window') -> int:
        """ Returns the horizontal margin on the left and right sides of header buttonâs label.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def GetSplitterParams(self, win: 'Window') -> 'SplitterRenderParams':
        """ Get the splitter parameters, see   wx.SplitterRenderParams.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    def GetVersion(self) -> 'RendererVersion':
        """ This function is used for version checking: Load   refuses to load any shared libraries implementing an older or incompatible version.

            Source: https://docs.wxpython.org/wx.DelegateRendererNative.html
        """

    Version: 'RendererVersion'  # See GetVersion



class RendererNative:
    """ First, a brief introduction to RendererNative and why it is needed.

        Source: https://docs.wxpython.org/wx.RendererNative.html
    """
    def DrawCheckBox(self, win, dc, rect, flags=0) -> None:
        """ Draw a check box.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawCheckMark(self, win, dc, rect, flags=0) -> None:
        """ Draw a check mark.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawChoice(self, win, dc, rect, flags=0) -> None:
        """ Draw a native   wx.Choice.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawCollapseButton(self, win, dc, rect, flags=0) -> None:
        """ Draw a collapse button.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawComboBox(self, win, dc, rect, flags=0) -> None:
        """ Draw a native   wx.ComboBox.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawComboBoxDropButton(self, win, dc, rect, flags=0) -> None:
        """ Draw a button like the one used by   wx.ComboBox  to show a drop down window.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawDropArrow(self, win, dc, rect, flags=0) -> None:
        """ Draw a drop down arrow that is suitable for use outside a combo box.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawFocusRect(self, win, dc, rect, flags=0) -> None:
        """ Draw a focus rectangle using the specified rectangle.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawGauge(self, win, dc, rect, value, max, flags=0) -> None:
        """ Draw a progress bar in the specified rectangle.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawHeaderButton(self, win, dc, rect, flags=0, sortArrow=HDR_SORT_ICON_NONE, params=None) -> int:
        """ Draw the header control button (used, for example, by   wx.ListCtrl).

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawHeaderButtonContents(self, win, dc, rect, flags=0, sortArrow=HDR_SORT_ICON_NONE, params=None) -> int:
        """ Draw the contents of a header control button (label, sort arrows, etc.).

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawItemSelectionRect(self, win, dc, rect, flags=0) -> None:
        """ Draw a selection rectangle underneath the text as used e.g.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawItemText(self, win, dc, text, rect, align=ALIGN_LEFT|ALIGN_TOP, flags=0, ellipsizeMode=ELLIPSIZE_END) -> None:
        """ Draw item text in the correct color based on selection status.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawPushButton(self, win, dc, rect, flags=0) -> None:
        """ Draw a blank push button that looks very similar to   wx.Button.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawRadioBitmap(self, win, dc, rect, flags=0) -> None:
        """ Draw a native   wx.RadioButton  bitmap.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawSplitterBorder(self, win, dc, rect, flags=0) -> None:
        """ Draw the border for sash window: this border must be such that the sash drawn by DrawSplitterSash   blends into it well.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawSplitterSash(self, win, dc, size, position, orient, flags=0) -> None:
        """ Draw a sash.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawTextCtrl(self, win, dc, rect, flags=0) -> None:
        """ Draw a native   wx.TextCtrl  frame.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawTitleBarBitmap(self, win, dc, rect, button, flags=0) -> None:
        """ Draw a title bar button in the given state.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def DrawTreeItemButton(self, win, dc, rect, flags=0) -> None:
        """ Draw the expanded/collapsed icon for a tree control item.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    @staticmethod
    def Get() -> 'RendererNative':
        """ Return the currently used renderer.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetCheckBoxSize(self, win, flags=0) -> 'Size':
        """ Returns the size of a check box.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetCheckMarkSize(self, win: 'Window') -> 'Size':
        """ Returns the size of a check mark.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetCollapseButtonSize(self, win, dc) -> 'Size':
        """ Returns the size of a collapse button.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    @staticmethod
    def GetDefault() -> 'RendererNative':
        """ Return the default (native) implementation for this platform â  this is also the one used by default but this may be changed by calling Set   in which case the return value of this method may be different from the return value of Get .

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetExpanderSize(self, win: 'Window') -> 'Size':
        """ Returns the size of the expander used in tree-like controls.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    @staticmethod
    def GetGeneric() -> 'RendererNative':
        """ Return the generic implementation of the renderer.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetHeaderButtonHeight(self, win: 'Window') -> int:
        """ Returns the height of a header button, either a fixed platform height if available, or a generic height based on the win  windowâs font.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetHeaderButtonMargin(self, win: 'Window') -> int:
        """ Returns the horizontal margin on the left and right sides of header buttonâs label.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetSplitterParams(self, win: 'Window') -> 'SplitterRenderParams':
        """ Get the splitter parameters, see   wx.SplitterRenderParams.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    def GetVersion(self) -> 'RendererVersion':
        """ This function is used for version checking: Load   refuses to load any shared libraries implementing an older or incompatible version.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    @staticmethod
    def Load(name: str) -> 'RendererNative':
        """ Load the renderer from the specified DLL, the returned pointer must be deleted by caller if not None when it is not used any more.

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    @staticmethod
    def Set(renderer: 'RendererNative') -> 'RendererNative':
        """ Set the renderer to use, passing None reverts to using the default renderer (the global renderer must always exist).

            Source: https://docs.wxpython.org/wx.RendererNative.html
        """

    Version: 'RendererVersion'  # See GetVersion



class Dialog(TopLevelWindow):
    """ A dialog box is a window with a title bar and sometimes a system menu,
which can be moved around the screen.

        Source: https://docs.wxpython.org/wx.Dialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def AddMainButtonId(self, id: int) -> None:
        """ Adds an identifier to be regarded as a main button for the non-scrolling area of a dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def CanDoLayoutAdaptation(self) -> bool:
        """ Returns True if this dialog can and should perform layout adaptation using DoLayoutAdaptation , usually if the dialog is too large to fit on the display.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def Centre(self, direction: int=BOTH) -> None:
        """ Centres the dialog box on the display.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def Create(self, parent, id=ID_ANY, title="", pos=DefaultPosition, size=DefaultSize, style=DEFAULT_DIALOG_STYLE, name=DialogNameStr) -> bool:
        """ Used for two-step dialog box construction.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def CreateButtonSizer(self, flags: int) -> 'Sizer':
        """ Creates a sizer with standard buttons.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def CreateSeparatedButtonSizer(self, flags: int) -> 'Sizer':
        """ Creates a sizer with standard buttons using CreateButtonSizer   separated from the rest of the dialog contents by a horizontal   wx.StaticLine.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def CreateSeparatedSizer(self, sizer: 'Sizer') -> 'Sizer':
        """ Returns the sizer containing the given one with a separating   wx.StaticLine  if necessarily.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def CreateStdDialogButtonSizer(self, flags: int) -> 'StdDialogButtonSizer':
        """ Creates a   wx.StdDialogButtonSizer  with standard buttons.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def CreateTextSizer(self, message, widthMax=-1) -> 'Sizer':
        """ Splits text up at newlines and places the lines into   wx.StaticText  objects with the specified maximum width in a vertical   wx.BoxSizer.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def DoLayoutAdaptation(self) -> bool:
        """ Performs layout adaptation, usually if the dialog is too large to fit on the display.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    @staticmethod
    def EnableLayoutAdaptation(enable: bool) -> None:
        """ A static function enabling or disabling layout adaptation for all dialogs.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def EndModal(self, retCode: int) -> None:
        """ Ends a modal dialog, passing a value to be returned from the ShowModal   invocation.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetAffirmativeId(self) -> int:
        """ Gets the identifier of the button which works like standard wx.OK button in this dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetContentWindow(self) -> 'Window':
        """ Override this to return a window containing the main content of the dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetEscapeId(self) -> int:
        """ Gets the identifier of the button to map presses of  ESC   button to.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetLayoutAdaptationDone(self) -> bool:
        """ Returns True if the dialog has been adapted, usually by making it scrollable to work with a small display.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetLayoutAdaptationLevel(self) -> int:
        """ Gets a value representing the aggressiveness of search for buttons and sizers to be in the non-scrolling part of a layout-adapted dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetLayoutAdaptationMode(self) -> 'DialogLayoutAdaptationMode':
        """ Gets the adaptation mode, overriding the global adaptation flag.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    @staticmethod
    def GetLayoutAdapter() -> 'DialogLayoutAdapter':
        """ A static function getting the current layout adapter object.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetMainButtonIds(self) -> list[int]:
        """ Returns an array of identifiers to be regarded as the main buttons for the non-scrolling area of a dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def GetReturnCode(self) -> int:
        """ Gets the return code for this window.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def Iconize(self, iconize: bool=True) -> None:
        """ Iconizes or restores the dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def IsIconized(self) -> bool:
        """ Returns True if the dialog box is iconized.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    @staticmethod
    def IsLayoutAdaptationEnabled() -> bool:
        """ A static function returning True if layout adaptation is enabled for all dialogs.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def IsMainButtonId(self, id: int) -> bool:
        """ Returns True if id  is in the array of identifiers to be regarded as the main buttons for the non-scrolling area of a dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def IsModal(self) -> bool:
        """ Returns True if the dialog box is modal, False otherwise.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetAffirmativeId(self, id: int) -> None:
        """ Sets the identifier to be used as wx.OK button.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetEscapeId(self, id: int) -> None:
        """ Sets the identifier of the button which should work like the standard âCancelâ button in this dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetIcon(self, icon: 'Icon') -> None:
        """ Sets the icon for this dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetIcons(self, icons: 'IconBundle') -> None:
        """ Sets the icons for this dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetLayoutAdaptationDone(self, done: bool) -> None:
        """ Marks the dialog as having been adapted, usually by making it scrollable to work with a small display.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetLayoutAdaptationLevel(self, level: int) -> None:
        """ Sets the aggressiveness of search for buttons and sizers to be in the non-scrolling part of a layout-adapted dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetLayoutAdaptationMode(self, mode: DialogLayoutAdaptationMode) -> None:
        """ Sets the adaptation mode, overriding the global adaptation flag.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    @staticmethod
    def SetLayoutAdapter(adapter: 'DialogLayoutAdapter') -> 'DialogLayoutAdapter':
        """ A static function for setting the current layout adapter object, returning the old adapter.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def SetReturnCode(self, retCode: int) -> None:
        """ Sets the return code for this window.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def Show(self, show: bool=True) -> bool:
        """ Hides or shows the dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def ShowModal(self) -> int:
        """ Shows an application-modal dialog.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def ShowWindowModal(self) -> None:
        """ Shows a dialog modal to the parent top level window only.

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Dialog.html
        """

    AffirmativeId: int  # See GetAffirmativeId and SetAffirmativeId
    ContentWindow: 'Window'  # See GetContentWindow
    EscapeId: int  # See GetEscapeId and SetEscapeId
    LayoutAdaptationDone: bool  # See GetLayoutAdaptationDone and SetLayoutAdaptationDone
    LayoutAdaptationLevel: int  # See GetLayoutAdaptationLevel and SetLayoutAdaptationLevel
    LayoutAdaptationMode: DialogLayoutAdaptationMode  # See GetLayoutAdaptationMode and SetLayoutAdaptationMode
    MainButtonIds: list[int]  # See GetMainButtonIds
    ReturnCode: int  # See GetReturnCode and SetReturnCode



CAPTION: int  # Puts a caption on the dialog box.

DEFAULT_DIALOG_STYLE: int  # Equivalent to a combination of wx.CAPTION, wx.CLOSE_BOX and wx.SYSTEM_MENU (the last one is not used under Unix).

RESIZE_BORDER: int  # Display a resizable frame around the window.

SYSTEM_MENU: int  # Display a system menu.

CLOSE_BOX: int  # Displays a close box on the frame.

MAXIMIZE_BOX: int  # Displays a maximize box on the dialog.

MINIMIZE_BOX: int  # Displays a minimize box on the dialog.

THICK_FRAME: int  # Display a thick frame around the window.

STAY_ON_TOP: int  # The dialog stays on top of all other windows.

NO_3D: int  # This style is obsolete and doesnât do anything any more, donât use it in any new code.

DIALOG_NO_PARENT: int  # By default, a dialog created with a None parent window will be given the applicationâs top level window  as parent. Use this style to prevent this from happening and create an orphan dialog. This is not recommended for modal dialogs.

DIALOG_EX_METAL: int  # On macOS, frames with this style will be shown with a metallic look. This is an extra style. ^^

EVT_INIT_DIALOG: int  # Process a  wxEVT_INIT_DIALOG   event. See    wx.InitDialogEvent. ^^

CANCEL: int

YES: int

NO: int

APPLY: int

CLOSE: int

HELP: int

NO_DEFAULT: int

class DialogLayoutAdapter:
    """ This abstract class is the base for classes that help wxWidgets
perform run-time layout adaptation of dialogs.

        Source: https://docs.wxpython.org/wx.DialogLayoutAdapter.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.DialogLayoutAdapter.html
        """

    def CanDoLayoutAdaptation(self, dialog: 'Dialog') -> bool:
        """ Override this to returns True if adaptation can and should be done.

            Source: https://docs.wxpython.org/wx.DialogLayoutAdapter.html
        """

    def DoLayoutAdaptation(self, dialog: 'Dialog') -> bool:
        """ Override this to perform layout adaptation, such as making parts of the dialog scroll and resizing the dialog to fit the display.

            Source: https://docs.wxpython.org/wx.DialogLayoutAdapter.html
        """



class DirDialog(Dialog):
    """ This class represents the directory chooser dialog.

        Source: https://docs.wxpython.org/wx.DirDialog.html
    """
    def __init__(self, parent, message=DirSelectorPromptStr, defaultPath="", style=DD_DEFAULT_STYLE, pos=DefaultPosition, size=DefaultSize, name=DirDialogNameStr) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    def GetMessage(self) -> str:
        """ Returns the message that will be displayed on the dialog.

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    def GetPath(self) -> str:
        """ Returns the default or user-selected path.

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    def GetPaths(self, paths: list[str]) -> None:
        """ Fills the array paths  with the full paths of the chosen directories.

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    def SetMessage(self, message: str) -> None:
        """ Sets the message that will be displayed on the dialog.

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    def SetPath(self, path: str) -> None:
        """ Sets the default path.

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning wx.ID_OK if the user pressed wx.OK, and wx.ID_CANCEL otherwise.

            Source: https://docs.wxpython.org/wx.DirDialog.html
        """

    Message: str  # See GetMessage and SetMessage
    Path: str  # See GetPath and SetPath



DD_DEFAULT_STYLE: int  # Equivalent to a combination of wx.DEFAULT_DIALOG_STYLE and wx.RESIZE_BORDER.

DD_DIR_MUST_EXIST: int  # The dialog will allow the user to choose only an existing folder. When this style is not given, a âCreate new directoryâ button is added to the dialog (on Windows) or some other way is provided to the user to type the name of a new folder.

DD_CHANGE_DIR: int  # Change the current working directory to the directory chosen by the user. This flag cannot be used with the  DD_MULTIPLE   style.

DD_MULTIPLE: int  # Allow the user to select multiple directories. This flag is only available since wxWidgets 3.1.4

DD_SHOW_HIDDEN: int  # Show hidden and system folders. This flag is only available since wxWidgets 3.1.4 ^^

class DirFilterListCtrl(Choice):
    """  Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.DirFilterListCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DirFilterListCtrl.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0) -> bool:
        """ parent (wx.GenericDirCtrl) â

            Source: https://docs.wxpython.org/wx.DirFilterListCtrl.html
        """

    def FillFilterList(self, filter, defaultFilter) -> None:
        """ filter (string) â

            Source: https://docs.wxpython.org/wx.DirFilterListCtrl.html
        """

    def Init(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DirFilterListCtrl.html
        """



class DirPickerCtrl(PickerBase):
    """ This control allows the user to select a directory.

        Source: https://docs.wxpython.org/wx.DirPickerCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DirPickerCtrl.html
        """

    def Create(self, parent, id=ID_ANY, path="", message=DirSelectorPromptStr, pos=DefaultPosition, size=DefaultSize, style=DIRP_DEFAULT_STYLE, validator=DefaultValidator, name=DirPickerCtrlNameStr) -> bool:
        """ Creates the widgets with the given parameters.

            Source: https://docs.wxpython.org/wx.DirPickerCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.DirPickerCtrl.html
        """

    def GetPath(self) -> str:
        """ Returns the absolute path of the currently selected directory.

            Source: https://docs.wxpython.org/wx.DirPickerCtrl.html
        """

    def SetInitialDirectory(self, dir: str) -> None:
        """ Set the directory to show when starting to browse for directories.

            Source: https://docs.wxpython.org/wx.DirPickerCtrl.html
        """

    def SetPath(self, dirname: str) -> None:
        """ Sets the absolute path of the currently selected directory.

            Source: https://docs.wxpython.org/wx.DirPickerCtrl.html
        """

    Path: str  # See GetPath and SetPath



DIRP_DEFAULT_STYLE: int  # The default style: includes wx.DIRP_DIR_MUST_EXIST and, under wxMSW only, wx.DIRP_USE_TEXTCTRL.

DIRP_USE_TEXTCTRL: int  # Creates a text control to the left of the picker button which is completely managed by the   wx.DirPickerCtrl  and which can be used by the user to specify a path (see SetPath). The text control is automatically synchronized with buttonâs value. Use functions defined in   wx.PickerBase  to modify the text control.

DIRP_DIR_MUST_EXIST: int  # Creates a picker which allows selecting only existing directories in the popup   wx.DirDialog. Notice that, as with  FLP_FILE_MUST_EXIST , it is still possible to enter a non-existent directory even when this file is specified if   DIRP_USE_TEXTCTRL   style is also used. Also note that if   DIRP_USE_TEXTCTRL   is not used, the native wxGTK implementation always uses this style as it doesnât support selecting non-existent directories.

DIRP_CHANGE_DIR: int  # Change current working directory on each user directory selection change.

DIRP_SMALL: int  # Use smaller version of the control with a small ââ¦â button instead of the normal âBrowseâ one. This flag is new since wxWidgets 2.9.3. ^^

EVT_DIRPICKER_CHANGED: int  # The user changed the directory selected in the control either using the button or using text control (see wx.DIRP_USE_TEXTCTRL; note that in this case the event is fired only if the userâs input is valid, e.g. an existing directory path). ^^

class Display:
    """ Determines the sizes and locations of displays connected to the
system.

        Source: https://docs.wxpython.org/wx.Display.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def ChangeMode(self, mode: 'VideoMode'=DefaultVideoMode) -> bool:
        """ Changes the video mode of this display to the mode specified in the mode parameter.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def GetClientArea(self) -> 'Rect':
        """ Returns the client area of the display.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    @staticmethod
    def GetCount() -> int:
        """ Returns the number of connected displays.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def GetCurrentMode(self) -> 'VideoMode':
        """ Returns the current video mode that this display is in.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    @staticmethod
    def GetFromPoint(pt: Union[tuple[int, int], 'Point']) -> int:
        """ Returns the index of the display on which the given point lies, or  NOT_FOUND   if the point is not on any connected display.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    @staticmethod
    def GetFromWindow(win: 'Window') -> int:
        """ Returns the index of the display on which the given window lies.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def GetGeometry(self) -> 'Rect':
        """ Returns the bounding rectangle of the display whose index was passed to the constructor.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def GetModes(self, mode: 'VideoMode'=DefaultVideoMode) -> ArrayVideoModes:
        """ Fills and returns an array with all the video modes that are supported by this display, or video modes that are supported by this display and match the mode parameter (if mode is not DefaultVideoMode).

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def GetName(self) -> str:
        """ Returns the displayâs name.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def GetPPI(self) -> 'Size':
        """ Returns display resolution in pixels per inch.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def GetScaleFactor(self) -> float:
        """ Returns scaling factor used by this display.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    @staticmethod
    def GetStdPPI() -> 'Size':
        """ Returns default display resolution for the current platform as   wx.Size.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    @staticmethod
    def GetStdPPIValue() -> int:
        """ Returns default display resolution for the current platform in pixels per inch.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    def IsPrimary(self) -> bool:
        """ Returns True if the display is the primary display.

            Source: https://docs.wxpython.org/wx.Display.html
        """

    ClientArea: 'Rect'  # See GetClientArea
    CurrentMode: 'VideoMode'  # See GetCurrentMode
    Geometry: 'Rect'  # See GetGeometry
    Name: str  # See GetName



class DisplayChangedEvent(Event):
    """ A display changed event is sent to top-level windows when the display
resolution has changed.

        Source: https://docs.wxpython.org/wx.DisplayChangedEvent.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.DisplayChangedEvent.html
        """



EVT_DISPLAY_CHANGED: int  # Process a  wxEVT_DISPLAY_CHANGED   event. ^^

class DPIChangedEvent(Event):
    """ Event sent when the display scale factor or pixel density (measured in
dots-per-inch, or DPI) of the monitor a window is on changes.

        Source: https://docs.wxpython.org/wx.DPIChangedEvent.html
    """
    def GetNewDPI(self) -> 'Size':
        """ Returns the new DPI.

            Source: https://docs.wxpython.org/wx.DPIChangedEvent.html
        """

    def GetOldDPI(self) -> 'Size':
        """ Returns the old DPI.

            Source: https://docs.wxpython.org/wx.DPIChangedEvent.html
        """

    def Scale(self, sz: Union[tuple[int, int], 'Size']) -> 'Size':
        """ Rescale a value in pixels to match the new DPI.

            Source: https://docs.wxpython.org/wx.DPIChangedEvent.html
        """

    def ScaleX(self, x: int) -> int:
        """ Rescale horizontal component to match the new DPI.

            Source: https://docs.wxpython.org/wx.DPIChangedEvent.html
        """

    def ScaleY(self, y: int) -> int:
        """ Rescale vertical component to match the new DPI.

            Source: https://docs.wxpython.org/wx.DPIChangedEvent.html
        """

    NewDPI: 'Size'  # See GetNewDPI
    OldDPI: 'Size'  # See GetOldDPI



EVT_DPI_CHANGED: int  # Process a  wxEVT_DPI_CHANGED   event. ^^

class DragImage(Object):
    """ This class is used when you wish to drag an object on the screen, and
a simple cursor is not enough.

        Source: https://docs.wxpython.org/wx.DragImage.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DragImage.html
        """

    def BeginDrag(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DragImage.html
        """

    def EndDrag(self) -> bool:
        """ Call this when the drag has finished.

            Source: https://docs.wxpython.org/wx.DragImage.html
        """

    def Hide(self) -> bool:
        """ Hides the image.

            Source: https://docs.wxpython.org/wx.DragImage.html
        """

    def Move(self, pt: Union[tuple[int, int], 'Point']) -> bool:
        """ Call this to move the image to a new position.

            Source: https://docs.wxpython.org/wx.DragImage.html
        """

    def Show(self) -> bool:
        """ Shows the image.

            Source: https://docs.wxpython.org/wx.DragImage.html
        """



class DropFilesEvent(Event):
    """ This class is used for drop files events, that is, when files have
been dropped onto the window.

        Source: https://docs.wxpython.org/wx.DropFilesEvent.html
    """
    def __init__(self, id=0, files=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.DropFilesEvent.html
        """

    def GetFiles(self) -> Any:
        """ Returns an array of filenames.

            Source: https://docs.wxpython.org/wx.DropFilesEvent.html
        """

    def GetNumberOfFiles(self) -> int:
        """ Returns the number of files dropped.

            Source: https://docs.wxpython.org/wx.DropFilesEvent.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the position at which the files were dropped.

            Source: https://docs.wxpython.org/wx.DropFilesEvent.html
        """

    Files: Any  # See GetFiles
    NumberOfFiles: int  # See GetNumberOfFiles
    Position: 'Point'  # See GetPosition



class DropSource:
    """ This class represents a source for a drag and drop operation.

        Source: https://docs.wxpython.org/wx.DropSource.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.DropSource.html
        """

    def DoDragDrop(self, flags: int=Drag_CopyOnly) -> 'DragResult':
        """ Starts the drag-and-drop operation which will terminate when the user releases the mouse.

            Source: https://docs.wxpython.org/wx.DropSource.html
        """

    def GetDataObject(self) -> 'DataObject':
        """ Returns the   wx.DataObject  object that has been assigned previously.

            Source: https://docs.wxpython.org/wx.DropSource.html
        """

    def GiveFeedback(self, effect: DragResult) -> bool:
        """ You may give some custom UI feedback during the drag and drop operation by overriding this function.

            Source: https://docs.wxpython.org/wx.DropSource.html
        """

    def SetCursor(self, res, cursor) -> None:
        """ Set the icon to use for a certain drag result.

            Source: https://docs.wxpython.org/wx.DropSource.html
        """

    def SetData(self, data: 'DataObject') -> None:
        """ Sets the data   wx.DataObject  associated with the drop source.

            Source: https://docs.wxpython.org/wx.DropSource.html
        """

    def SetIcon(self, res, icon) -> None:
        """ Set the icon to use for a certain drag result.

            Source: https://docs.wxpython.org/wx.DropSource.html
        """

    DataObject: 'DataObject'  # See GetDataObject



class DropTarget:
    """ This class represents a target for a drag and drop operation.

        Source: https://docs.wxpython.org/wx.DropTarget.html
    """
    def __init__(self, data: Optional['DataObject']=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def GetData(self) -> bool:
        """ This method may only be called from within OnData .

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def GetDataObject(self) -> 'DataObject':
        """ Returns the data   wx.DataObject  associated with the drop target.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def GetDefaultAction(self) -> 'DragResult':
        """ Returns default action for drag and drop or DragNone if this not specified.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def OnData(self, x, y, defResult) -> 'DragResult':
        """ Called after OnDrop   returns True.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def OnDragOver(self, x, y, defResult) -> 'DragResult':
        """ Called when the mouse is being dragged over the drop target.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def OnDrop(self, x, y) -> bool:
        """ Called when the user drops a data object on the target.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def OnEnter(self, x, y, defResult) -> 'DragResult':
        """ Called when the mouse enters the drop target.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def OnLeave(self) -> None:
        """ Called when the mouse leaves the drop target.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def SetDataObject(self, data: 'DataObject') -> None:
        """ Sets the data   wx.DataObject  associated with the drop target and deletes any previously associated data object.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    def SetDefaultAction(self, action: DragResult) -> None:
        """ Sets the default action for drag and drop.

            Source: https://docs.wxpython.org/wx.DropTarget.html
        """

    Data: bool  # See GetData
    DataObject: 'DataObject'  # See GetDataObject and SetDataObject
    DefaultAction: DragResult  # See GetDefaultAction and SetDefaultAction



class EraseEvent(Event):
    """ An erase event is sent when a windowâs background needs to be
repainted.

        Source: https://docs.wxpython.org/wx.EraseEvent.html
    """
    def __init__(self, id=0, dc=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.EraseEvent.html
        """

    def GetDC(self) -> 'DC':
        """ Returns the device context associated with the erase event to draw on.

            Source: https://docs.wxpython.org/wx.EraseEvent.html
        """

    DC: 'DC'  # See GetDC



class Event(Object):
    """ An event is a structure holding information about an event passed to a
callback or member function.

        Source: https://docs.wxpython.org/wx.Event.html
    """
    def __init__(self, id=0, eventType=wxEVT_NULL) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def Clone(self) -> 'Event':
        """ Returns a copy of the event.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def GetEventCategory(self) -> int:
        """ Returns a generic category for this event.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def GetEventObject(self) -> 'Window':
        """ Returns the object (usually a window) associated with the event, if any.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def GetEventType(self) -> int:
        """ Returns the identifier of the given event type, such as  wxEVT_BUTTON .

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def GetId(self) -> int:
        """ Returns the identifier associated with this event, such as a button command id.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def GetSkipped(self) -> bool:
        """ Returns True if the event handler should be skipped, False otherwise.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def GetTimestamp(self) -> int:
        """ Gets the timestamp for the event.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def IsCommandEvent(self) -> bool:
        """ Returns True if the event is or is derived from   wx.CommandEvent  else it returns False.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def ResumePropagation(self, propagationLevel: int) -> None:
        """ Sets the propagation level to the given value (for example returned from an earlier call to wx.Event.StopPropagation ).

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def SetEventObject(self, object: 'Object') -> None:
        """ Sets the originating object.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def SetEventType(self, type: int) -> None:
        """ Sets the event type.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def SetId(self, id: int) -> None:
        """ Sets the identifier associated with this event, such as a button command id.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def SetTimestamp(self, timeStamp: int=0) -> None:
        """ Sets the timestamp for the event.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def ShouldPropagate(self) -> bool:
        """ Test if this event should be propagated or not, i.e. if the propagation level is currently greater than 0.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def Skip(self, skip: bool=True) -> None:
        """ This method can be used inside an event handler to control whether further event handlers bound to this event will be called after the current one returns.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    def StopPropagation(self) -> int:
        """ Stop the event from propagating to its parent window.

            Source: https://docs.wxpython.org/wx.Event.html
        """

    EventObject: 'Object'  # See GetEventObject and SetEventObject
    EventType: int  # See GetEventType and SetEventType
    Id: int  # See GetId and SetId
    Skipped: bool  # See GetSkipped
    Timestamp: int  # See GetTimestamp and SetTimestamp



class EventBlocker(EvtHandler):
    """ This class is a special event handler which allows discarding any
event (or a set of event types) directed to a specific window.

        Source: https://docs.wxpython.org/wx.EventBlocker.html
    """
    def __init__(self, win, type=-1) -> None:
        """ Constructs the blocker for the given window and for the given event type.

            Source: https://docs.wxpython.org/wx.EventBlocker.html
        """

    def Block(self, eventType: int) -> None:
        """ Adds to the list of event types which should be blocked the given eventType.

            Source: https://docs.wxpython.org/wx.EventBlocker.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.EventBlocker.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.EventBlocker.html
        """



class EventFilter:
    """ A global event filter for pre-processing all the events generated in
the program.

        Source: https://docs.wxpython.org/wx.EventFilter.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.EventFilter.html
        """

    def FilterEvent(self, event: 'Event') -> int:
        """ Override this method to implement event pre-processing.

            Source: https://docs.wxpython.org/wx.EventFilter.html
        """



class EventLoopActivator:
    """ Makes an event loop temporarily active.

        Source: https://docs.wxpython.org/wx.EventLoopActivator.html
    """
    def __init__(self, loop: 'EventLoopBase') -> None:
        """ Makes the loop passed as the parameter currently active.

            Source: https://docs.wxpython.org/wx.EventLoopActivator.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.EventLoopActivator.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.EventLoopActivator.html
        """



class EventLoopBase:
    """ Base class for all event loop implementations.

        Source: https://docs.wxpython.org/wx.EventLoopBase.html
    """
    def Dispatch(self) -> bool:
        """ Dispatches the next event in the windowing system event queue.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def DispatchTimeout(self, timeout: int) -> int:
        """ Dispatch an event but not wait longer than the specified timeout for it.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def Exit(self, rc: int=0) -> None:
        """ Exit the currently running loop with the given exit code.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    @staticmethod
    def GetActive() -> 'EventLoopBase':
        """ Return the currently active (running) event loop.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def IsEventAllowedInsideYield(self, cat: int) -> bool:
        """ Returns True if the given event category is allowed inside a YieldFor   call (i.e.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def IsMain(self) -> bool:
        """ Returns True if this is the main loop executed by wx.App.OnRun .

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def IsOk(self) -> bool:
        """ Use this to check whether the event loop was successfully created before using it.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def IsRunning(self) -> bool:
        """ Return True if this event loop is currently running.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def IsYielding(self) -> bool:
        """ Returns True if called from inside wx.Yield       or from inside YieldFor .

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def OnExit(self) -> None:
        """ This function is called before the event loop terminates, whether this happens normally (because of wx.Exit       call) or abnormally (because of an exception thrown from inside the loop).

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def Pending(self) -> bool:
        """ Return True if any events are available.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def ProcessIdle(self) -> bool:
        """ This virtual function is called when the application becomes idle and normally just sends   wx.IdleEvent  to all interested parties.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def Run(self) -> int:
        """ Start the event loop, return the exit code when it is finished.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def ScheduleExit(self, rc: int=0) -> None:
        """ Schedule an exit from the loop with the given exit code.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    @staticmethod
    def SetActive(loop: 'EventLoopBase') -> None:
        """ Set currently active (running) event loop.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def WakeUp(self) -> None:
        """ Called by wxWidgets to wake up the event loop even if it is currently blocked inside Dispatch .

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def WakeUpIdle(self) -> None:
        """ Makes sure that idle events are sent again.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def Yield(self, onlyIfNeeded: bool=False) -> bool:
        """ Yields control to pending messages in the windowing system.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """

    def YieldFor(self, eventsToProcess: int) -> bool:
        """ Works like wx.Yield       with onlyIfNeeded  == True, except that it allows the caller to specify a mask of the   wx.EventCategory  values which indicates which events should be processed and which should instead be âdelayedâ (i.e.

            Source: https://docs.wxpython.org/wx.EventLoopBase.html
        """



class EvtHandler(Object,Trackable):
    """ A class that can handle events from the windowing system.

        Source: https://docs.wxpython.org/wx.EvtHandler.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    @staticmethod
    def AddFilter(filter: 'EventFilter') -> None:
        """ Add an event filter whose FilterEvent() method will be called for each and every event processed by wxWidgets.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def AddPendingEvent(self, event: 'Event') -> None:
        """ Post an event to be processed later.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def Bind(self, event, handler, source=None, id=wx.ID_ANY, id2=wx.ID_ANY) -> None:
        """ Bind an event to an event handler.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def Connect(self, id, lastId, eventType, func) -> None:
        """ Make an entry in the dynamic event table for an event binding.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def DeletePendingEvents(self) -> None:
        """ Deletes all events queued on this event handler using wx.QueueEvent       or AddPendingEvent .

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def Disconnect(self, id, lastId=-1, eventType=wxEVT_NULL, func=None) -> bool:
        """ Remove an event binding by removing its entry in the dynamic event table.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def GetEvtHandlerEnabled(self) -> bool:
        """ Returns True if the event handler is enabled, False otherwise.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def GetNextHandler(self) -> 'EvtHandler':
        """ Returns the pointer to the next handler in the chain.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def GetPreviousHandler(self) -> 'EvtHandler':
        """ Returns the pointer to the previous handler in the chain.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def IsUnlinked(self) -> bool:
        """ Returns True if the next and the previous handler pointers of this event handler instance are None.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def ProcessEvent(self, event: 'Event') -> bool:
        """ Processes an event, searching event tables and calling zero or more suitable event handler function(s).

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def ProcessEventLocally(self, event: 'Event') -> bool:
        """ Try to process the event in this handler and all those chained to it.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def ProcessPendingEvents(self) -> None:
        """ Processes the pending events previously queued using wx.QueueEvent       or AddPendingEvent ; you must call this function only if you are sure there are pending events for this handler, otherwise a  CHECK   will fail.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def QueueEvent(self, event: 'Event') -> None:
        """ Queue event for a later processing.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    @staticmethod
    def RemoveFilter(filter: 'EventFilter') -> None:
        """ Remove a filter previously installed with AddFilter .

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def SafelyProcessEvent(self, event: 'Event') -> bool:
        """ Processes an event by calling   wx.ProcessEvent  and handles any exceptions that occur in the process.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def SetEvtHandlerEnabled(self, enabled: bool) -> None:
        """ Enables or disables the event handler.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def SetNextHandler(self, handler: 'EvtHandler') -> None:
        """ Sets the pointer to the next handler.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def SetPreviousHandler(self, handler: 'EvtHandler') -> None:
        """ Sets the pointer to the previous handler.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def TryAfter(self, event: 'Event') -> bool:
        """ Method called by   wx.ProcessEvent  as last resort.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def TryBefore(self, event: 'Event') -> bool:
        """ Method called by   wx.ProcessEvent  before examining this object event tables.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def Unbind(self, event, source=None, id=wx.ID_ANY, id2=wx.ID_ANY, handler=None) -> None:
        """ Disconnects the event handler binding for event from self.
Returns True if successful.

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    def Unlink(self) -> None:
        """ Unlinks this event handler from the chain itâs part of (if any); then links the âpreviousâ event handler to the ânextâ one (so that the chain wonât be interrupted).

            Source: https://docs.wxpython.org/wx.EvtHandler.html
        """

    EvtHandlerEnabled: bool  # See GetEvtHandlerEnabled and SetEvtHandlerEnabled
    NextHandler: 'EvtHandler'  # See GetNextHandler and SetNextHandler
    PreviousHandler: 'EvtHandler'  # See GetPreviousHandler and SetPreviousHandler



class FileConfig(ConfigBase):
    """ FileConfig implements ConfigBase interface for storing and
retrieving configuration information using plain text files.

        Source: https://docs.wxpython.org/wx.FileConfig.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def DeleteAll(self) -> bool:
        """ Delete the whole underlying object (disk file, registry key, â¦).

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def DeleteEntry(self, key, bDeleteGroupIfEmpty=True) -> bool:
        """ Deletes the specified entry and the group it belongs to if it was the last key in it and the second parameter is True.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def DeleteGroup(self, key: str) -> bool:
        """ Delete the group (with all subgroups).

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def DisableAutoSave(self) -> None:
        """ Prevent this object from saving data to the disk file when it is destroyed.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def EnableAutoSave(self) -> None:
        """ Enables saving data to the disk file when this object is destroyed.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def Flush(self, bCurrentOnly: bool=False) -> bool:
        """ Permanently writes all changes (otherwise, theyâre only written from objectâs destructor).

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    @staticmethod
    def GetGlobalFileName(szFile: str) -> str:
        """ szFile (string) â

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    @staticmethod
    def GetLocalFileName(szFile, style=0) -> str:
        """ szFile (string) â

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def GetNumberOfEntries(self, bRecursive: bool=False) -> int:
        """ Get number of entries in the current group.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def GetNumberOfGroups(self, bRecursive: bool=False) -> int:
        """ Get number of entries/subgroups in the current group, with or without its subgroups.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def GetPath(self) -> str:
        """ Retrieve the current path (always as absolute path).

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def HasEntry(self, strName: str) -> bool:
        """ strName (string) â

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def HasGroup(self, strName: str) -> bool:
        """ strName (string) â

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def RenameEntry(self, oldName, newName) -> bool:
        """ Renames an entry in the current group.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def RenameGroup(self, oldName, newName) -> bool:
        """ Renames a subgroup of the current group.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def Save(self, os) -> bool:
        """ Saves all config data to the given stream, returns True if data was saved successfully or False on error.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def SetPath(self, strPath: str) -> None:
        """ Set current path: if the first character is â/â, it is the absolute path, otherwise it is a relative path.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    def SetUmask(self, mode: int) -> None:
        """ Allows setting the mode to be used for the config file creation.

            Source: https://docs.wxpython.org/wx.FileConfig.html
        """

    NumberOfEntries: int  # See GetNumberOfEntries
    NumberOfGroups: int  # See GetNumberOfGroups
    Path: str  # See GetPath and SetPath



class FileCtrl(Control):
    """ This control allows the user to select a file.

        Source: https://docs.wxpython.org/wx.FileCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def Create(self, parent, id=ID_ANY, defaultDirectory="", defaultFilename="", wildCard=FileSelectorDefaultWildcardStr, style=FC_DEFAULT_STYLE, pos=DefaultPosition, size=DefaultSize, name=FileCtrlNameStr) -> bool:
        """ Create function for two-step construction.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def GetDirectory(self) -> str:
        """ Returns the current directory of the file control (i.e. the directory shown by it).

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def GetFilename(self) -> str:
        """ Returns the currently selected filename.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def GetFilenames(self) -> list[str]:
        """ Returns a list of filenames selected in the control.  This function
should only be used with controls which have the wx.``wx.FC_MULTIPLE`` style,
use GetFilename for the others.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def GetFilterIndex(self) -> int:
        """ Returns the zero-based index of the currently selected filter.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def GetPath(self) -> str:
        """ Returns the full path (directory and filename) of the currently selected file.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def GetPaths(self) -> list[str]:
        """ Returns a list of the full paths (directory and filename) of the files
chosen. This function should only be used with controlss which have
the wx.``wx.FC_MULTIPLE`` style, use GetPath for the others.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def GetWildcard(self) -> str:
        """ Returns the current wildcard.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def SetDirectory(self, directory: str) -> bool:
        """ Sets(changes) the current directory displayed in the control.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def SetFilename(self, filename: str) -> bool:
        """ Selects a certain file.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def SetFilterIndex(self, filterIndex: int) -> None:
        """ Sets the current filter index, starting from zero.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def SetPath(self, path: str) -> bool:
        """ Changes to a certain directory and selects a certain file.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def SetWildcard(self, wildCard: str) -> None:
        """ Sets the wildcard, which can contain multiple file types, for example: âBMP files (.bmp)|.bmp|GIF files (.gif)|.gifâ.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    def ShowHidden(self, show: bool) -> None:
        """ Sets whether hidden files and folders are shown or not.

            Source: https://docs.wxpython.org/wx.FileCtrl.html
        """

    Directory: str  # See GetDirectory and SetDirectory
    Filename: str  # See GetFilename and SetFilename
    Filenames: list[str]  # See GetFilenames
    FilterIndex: int  # See GetFilterIndex and SetFilterIndex
    Path: str  # See GetPath and SetPath
    Paths: list[str]  # See GetPaths
    Wildcard: str  # See GetWildcard and SetWildcard



FC_DEFAULT_STYLE: int  # The default style: wx.FC_OPEN

FC_OPEN: int  # Creates an file control suitable for opening files. Cannot be combined with wx.FC_SAVE.

FC_SAVE: int  # Creates an file control suitable for saving files. Cannot be combined with wx.FC_OPEN.

FC_MULTIPLE: int  # For open control only, Allows selecting multiple files. Cannot be combined with wx.FC_SAVE

FC_NOSHOWHIDDEN: int  # Hides the âShow Hidden Filesâ checkbox (Generic only) ^^

EVT_FILECTRL_FILEACTIVATED: int  # The user activated a file(by double-clicking or pressing Enter)

EVT_FILECTRL_SELECTIONCHANGED: int  # The user changed the current selection(by selecting or deselecting a file)

EVT_FILECTRL_FOLDERCHANGED: int  # The current folder of the file control has been changed

EVT_FILECTRL_FILTERCHANGED: int  # The current file filter of the file control has been changed.

class FileCtrlEvent(CommandEvent):
    """ A file control event holds information about events associated with
FileCtrl objects.

        Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
    """
    def __init__(self, type, evtObject, id) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    def GetDirectory(self) -> str:
        """ Returns the current directory.

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    def GetFile(self) -> str:
        """ Returns the file selected (assuming it is only one file).

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    def GetFiles(self) -> list[str]:
        """ Returns the files selected.

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    def GetFilterIndex(self) -> int:
        """ Returns the current file filter index.

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    def SetDirectory(self, directory: str) -> None:
        """ Sets the directory of this event.

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    def SetFiles(self, files: list[str]) -> None:
        """ Sets the files changed by this event.

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    def SetFilterIndex(self, index: int) -> None:
        """ Sets the filter index changed by this event.

            Source: https://docs.wxpython.org/wx.FileCtrlEvent.html
        """

    Directory: str  # See GetDirectory and SetDirectory
    File: str  # See GetFile
    Files: list[str]  # See GetFiles and SetFiles
    FilterIndex: int  # See GetFilterIndex and SetFilterIndex



class FileDataObject(DataObjectSimple):
    """ FileDataObject is a specialization of DataObject for file names.

        Source: https://docs.wxpython.org/wx.FileDataObject.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FileDataObject.html
        """

    def AddFile(self, file: str) -> None:
        """ Adds a file to the file list represented by this data object (Windows only).

            Source: https://docs.wxpython.org/wx.FileDataObject.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.FileDataObject.html
        """

    def GetFilenames(self) -> list[str]:
        """ Returns the array of file names.

            Source: https://docs.wxpython.org/wx.FileDataObject.html
        """

    def SetData(self, format, buf) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.FileDataObject.html
        """

    AllFormats: None  # See GetAllFormats
    Filenames: list[str]  # See GetFilenames



class FileDialog(Dialog):
    """ This class represents the file chooser dialog.

        Source: https://docs.wxpython.org/wx.FileDialog.html
    """
    def __init__(self, parent, message=FileSelectorPromptStr, defaultDir="", defaultFile="", wildcard=FileSelectorDefaultWildcardStr, style=FD_DEFAULT_STYLE, pos=DefaultPosition, size=DefaultSize, name=FileDialogNameStr) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetCurrentlySelectedFilename(self) -> str:
        """ Returns the path of the file currently selected in dialog.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetCurrentlySelectedFilterIndex(self) -> int:
        """ Returns the file type filter index currently selected in dialog.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetDirectory(self) -> str:
        """ Returns the default directory.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetExtraControl(self) -> 'Window':
        """ If functions SetExtraControlCreator   and ShowModal   were called, returns the extra window.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetFilename(self) -> str:
        """ Returns the default filename.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetFilenames(self) -> list[str]:
        """ Returns a list of filenames chosen in the dialog.  This function
should only be used with the dialogs which have wx.``MULTIPLE`` style,
use GetFilename for the others.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetFilterIndex(self) -> int:
        """ Returns the index into the list of filters supplied, optionally, in the wildcard parameter.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetMessage(self) -> str:
        """ Returns the message that will be displayed on the dialog.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetPath(self) -> str:
        """ Returns the full path (directory and filename) of the selected file.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetPaths(self) -> list[str]:
        """ Returns a list of the full paths of the files chosen. This function
should only be used with the dialogs which have wx.``MULTIPLE`` style, use
GetPath for the others.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def GetWildcard(self) -> str:
        """ Returns the file dialog wildcard.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def SetCustomizeHook(self, customizeHook: 'FileDialogCustomizeHook') -> bool:
        """ Set the hook to be used for customizing the dialog contents.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def SetDirectory(self, directory: str) -> None:
        """ Sets the default directory.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def SetFilename(self, setfilename: str) -> None:
        """ Sets the default filename.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def SetFilterIndex(self, filterIndex: int) -> None:
        """ Sets the default filter index, starting from zero.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def SetMessage(self, message: str) -> None:
        """ Sets the message that will be displayed on the dialog.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def SetPath(self, path: str) -> None:
        """ Sets the path (the combined directory and filename that will be returned when the dialog is dismissed).

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def SetWildcard(self, wildCard: str) -> None:
        """ Sets the wildcard, which can contain multiple file types, for example: âBMP files (.bmp)|.bmp|GIF files (.gif)|.gifâ.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning  ID_OK   if the user pressed wx.OK, and   ID_CANCEL   otherwise.

            Source: https://docs.wxpython.org/wx.FileDialog.html
        """

    CurrentlySelectedFilename: str  # See GetCurrentlySelectedFilename
    CurrentlySelectedFilterIndex: int  # See GetCurrentlySelectedFilterIndex
    Directory: str  # See GetDirectory and SetDirectory
    ExtraControl: 'Window'  # See GetExtraControl
    Filename: str  # See GetFilename and SetFilename
    Filenames: list[str]  # See GetFilenames
    FilterIndex: int  # See GetFilterIndex and SetFilterIndex
    Message: str  # See GetMessage and SetMessage
    Path: str  # See GetPath and SetPath
    Paths: list[str]  # See GetPaths
    Wildcard: str  # See GetWildcard and SetWildcard



FD_DEFAULT_STYLE: int  # Equivalent to  FD_OPEN .

FD_NO_FOLLOW: int  # Directs the dialog to return the path and file name of the selected shortcut file, not its target as it does by default. Currently this flag is only implemented in wxMSW and wxOSX (where it prevents aliases from being resolved). The non-dereferenced link path is always returned, even without this flag, under Unix and so using it there doesnât do anything. This flag was added in wxWidgets 3.1.0.

FD_CHANGE_DIR: int  # Change the current working directory (when the dialog is dismissed) to the directory where the file(s) chosen by the user are.

FD_PREVIEW: int  # Show the preview of the selected files (currently only supported by wxGTK).

FD_SHOW_HIDDEN: int  # Show hidden files. This flag was added in wxWidgets 3.1.3 ^^

class FileDialogButton(FileDialogCustomControl):
    """ Represents a custom button inside FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogButton.html
    """


class FileDialogCheckBox(FileDialogCustomControl):
    """ Represents a custom checkbox inside FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogCheckBox.html
    """
    def GetValue(self) -> bool:
        """ Return True if the checkbox is checked.

            Source: https://docs.wxpython.org/wx.FileDialogCheckBox.html
        """

    def SetValue(self, value: bool) -> None:
        """ Check or uncheck the checkbox.

            Source: https://docs.wxpython.org/wx.FileDialogCheckBox.html
        """

    Value: bool  # See GetValue and SetValue



class FileDialogChoice(FileDialogCustomControl):
    """ Represents a custom read-only combobox inside FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogChoice.html
    """
    def GetSelection(self) -> int:
        """ Return the index of the selected item, possibly wx.NOT_FOUND.

            Source: https://docs.wxpython.org/wx.FileDialogChoice.html
        """

    def SetSelection(self, n: int) -> None:
        """ Set the selection to the item with the given index.

            Source: https://docs.wxpython.org/wx.FileDialogChoice.html
        """

    Selection: int  # See GetSelection and SetSelection



class FileDialogCustomControl(EvtHandler):
    """ The base class for all FileDialog custom controls.

        Source: https://docs.wxpython.org/wx.FileDialogCustomControl.html
    """
    def Disable(self) -> None:
        """ Disable this control.

            Source: https://docs.wxpython.org/wx.FileDialogCustomControl.html
        """

    def Enable(self, enable: bool=True) -> None:
        """ Enable or disable this control.

            Source: https://docs.wxpython.org/wx.FileDialogCustomControl.html
        """

    def Hide(self) -> None:
        """ Hide this control.

            Source: https://docs.wxpython.org/wx.FileDialogCustomControl.html
        """

    def Show(self, show: bool=True) -> None:
        """ Show or hide this control.

            Source: https://docs.wxpython.org/wx.FileDialogCustomControl.html
        """



class FileDialogCustomize:
    """ Used with FileDialogCustomizeHook to add custom controls to
FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogCustomize.html
    """
    def AddButton(self, label: str) -> 'FileDialogButton':
        """ Add a button with the specified label.

            Source: https://docs.wxpython.org/wx.FileDialogCustomize.html
        """

    def AddCheckBox(self, label: str) -> 'FileDialogCheckBox':
        """ Add a checkbox with the specified label.

            Source: https://docs.wxpython.org/wx.FileDialogCustomize.html
        """

    def AddChoice(self, strings: list[str]) -> 'FileDialogChoice':
        """ Add a read-only combobox with the specified contents.

            Source: https://docs.wxpython.org/wx.FileDialogCustomize.html
        """

    def AddRadioButton(self, label: str) -> 'FileDialogRadioButton':
        """ Add a radio button with the specified label.

            Source: https://docs.wxpython.org/wx.FileDialogCustomize.html
        """

    def AddStaticText(self, label: str) -> 'FileDialogStaticText':
        """ Add a static text with the given contents.

            Source: https://docs.wxpython.org/wx.FileDialogCustomize.html
        """

    def AddTextCtrl(self, label: str="") -> 'FileDialogTextCtrl':
        """ Add a text control with an optional label preceding it.

            Source: https://docs.wxpython.org/wx.FileDialogCustomize.html
        """



class FileDialogCustomizeHook:
    """ Base class for customization hooks used with FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogCustomizeHook.html
    """
    def AddCustomControls(self, customizer: 'FileDialogCustomize') -> None:
        """ Must be overridden to add custom controls to the dialog using the provided customizer object.

            Source: https://docs.wxpython.org/wx.FileDialogCustomizeHook.html
        """

    def TransferDataFromCustomControls(self) -> None:
        """ Should typically be overridden to save the values of the custom controls when the dialog is accepted.

            Source: https://docs.wxpython.org/wx.FileDialogCustomizeHook.html
        """

    def UpdateCustomControls(self) -> None:
        """ May be overridden to update the custom controls whenever something changes in the dialog.

            Source: https://docs.wxpython.org/wx.FileDialogCustomizeHook.html
        """



class FileDialogRadioButton(FileDialogCustomControl):
    """ Represents a custom radio button inside FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogRadioButton.html
    """
    def GetValue(self) -> bool:
        """ Return True if the radio button is selected.

            Source: https://docs.wxpython.org/wx.FileDialogRadioButton.html
        """

    def SetValue(self, value: bool) -> None:
        """ Select the value of the radio button.

            Source: https://docs.wxpython.org/wx.FileDialogRadioButton.html
        """

    Value: bool  # See GetValue and SetValue



class FileDialogStaticText(FileDialogCustomControl):
    """ Represents a custom static text inside FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogStaticText.html
    """
    def SetLabelText(self, text: str) -> None:
        """ Set the text shown in the label.

            Source: https://docs.wxpython.org/wx.FileDialogStaticText.html
        """



class FileDialogTextCtrl(FileDialogCustomControl):
    """ Represents a custom text control inside FileDialog.

        Source: https://docs.wxpython.org/wx.FileDialogTextCtrl.html
    """
    def GetValue(self) -> str:
        """ Get the current value entered into the control.

            Source: https://docs.wxpython.org/wx.FileDialogTextCtrl.html
        """

    def SetValue(self, text: str) -> None:
        """ Set the current control value.

            Source: https://docs.wxpython.org/wx.FileDialogTextCtrl.html
        """

    Value: str  # See GetValue and SetValue



class FileDirPickerEvent(CommandEvent):
    """ This event class is used for the events generated by FilePickerCtrl
and by DirPickerCtrl.

        Source: https://docs.wxpython.org/wx.FileDirPickerEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FileDirPickerEvent.html
        """

    def GetPath(self) -> str:
        """ Retrieve the absolute path of the file/directory the user has just selected.

            Source: https://docs.wxpython.org/wx.FileDirPickerEvent.html
        """

    def SetPath(self, path: str) -> None:
        """ Set the absolute path of the file/directory associated with the event.

            Source: https://docs.wxpython.org/wx.FileDirPickerEvent.html
        """

    Path: str  # See GetPath and SetPath



EVT_FILEPICKER_CHANGED: int  # Generated whenever the selected file changes.

class FilePickerCtrl(PickerBase):
    """ This control allows the user to select a file.

        Source: https://docs.wxpython.org/wx.FilePickerCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FilePickerCtrl.html
        """

    def Create(self, parent, id=ID_ANY, path="", message=FileSelectorPromptStr, wildcard=FileSelectorDefaultWildcardStr, pos=DefaultPosition, size=DefaultSize, style=FLP_DEFAULT_STYLE, validator=DefaultValidator, name=FilePickerCtrlNameStr) -> bool:
        """ Creates this widget with the given parameters.

            Source: https://docs.wxpython.org/wx.FilePickerCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.FilePickerCtrl.html
        """

    def GetPath(self) -> str:
        """ Returns the absolute path of the currently selected file.

            Source: https://docs.wxpython.org/wx.FilePickerCtrl.html
        """

    def SetInitialDirectory(self, dir: str) -> None:
        """ Set the directory to show when starting to browse for files.

            Source: https://docs.wxpython.org/wx.FilePickerCtrl.html
        """

    def SetPath(self, filename: str) -> None:
        """ Sets the absolute path of the currently selected file.

            Source: https://docs.wxpython.org/wx.FilePickerCtrl.html
        """

    Path: str  # See GetPath and SetPath



FLP_DEFAULT_STYLE: int  # The default style: includes wx.FLP_OPEN | wx.FLP_FILE_MUST_EXIST and, under wxMSW and wxOSX, wx.FLP_USE_TEXTCTRL.

FLP_USE_TEXTCTRL: int  # Creates a text control to the left of the picker button which is completely managed by the   wx.FilePickerCtrl  and which can be used by the user to specify a path (see SetPath). The text control is automatically synchronized with buttonâs value. Use functions defined in   wx.PickerBase  to modify the text control.

FLP_OPEN: int  # Creates a picker which allows the user to select a file to open.

FLP_SAVE: int  # Creates a picker which allows the user to select a file to save.

FLP_OVERWRITE_PROMPT: int  # Can be combined with wx.FLP_SAVE only: ask confirmation to the user before selecting a file.

FLP_FILE_MUST_EXIST: int  # Can be combined with wx.FLP_OPEN only: the file selected in the popup   wx.FileDialog  must be an existing file. Notice that it still remains possible for the user to enter a non-existent file name in the text control if  FLP_USE_TEXTCTRL   is also used, this flag is a hint for the user rather than a guarantee that the selected file does exist for the program.

FLP_CHANGE_DIR: int  # Change current working directory on each user file selection change.

FLP_SMALL: int  # Use smaller version of the control with a small ââ¦â button instead of the normal âBrowseâ one. This flag is new since wxWidgets 2.9.3. ^^

class FileDropTarget(DropTarget):
    """ This is a drop target which accepts files (dragged from File Manager
or Explorer).

        Source: https://docs.wxpython.org/wx.FileDropTarget.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FileDropTarget.html
        """

    def OnDrop(self, x, y) -> bool:
        """ See wx.DropTarget.OnDrop .

            Source: https://docs.wxpython.org/wx.FileDropTarget.html
        """

    def OnDropFiles(self, x, y, filenames) -> bool:
        """ Override this function to receive dropped files.

            Source: https://docs.wxpython.org/wx.FileDropTarget.html
        """



class FileHistory(Object):
    """ The FileHistory encapsulates a user interface convenience, the list
of most recently visited files as shown on a menu (usually the File
menu).

        Source: https://docs.wxpython.org/wx.FileHistory.html
    """
    def __init__(self, maxFiles=9, idBase=ID_FILE1) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def AddFileToHistory(self, filename: str) -> None:
        """ Adds a file to the file history list, if the object has a pointer to an appropriate file menu.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def AddFilesToMenu(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def GetBaseId(self) -> int:
        """ Returns the base identifier for the range used for appending items.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def GetCount(self) -> int:
        """ Returns the number of files currently stored in the file history.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def GetHistoryFile(self, index: int) -> str:
        """ Returns the file at this index (zero-based).

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def GetMaxFiles(self) -> int:
        """ Returns the maximum number of files that can be stored.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def GetMenuPathStyle(self) -> 'FileHistoryMenuPathStyle':
        """ Get the current style of the menu item labels.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def GetMenus(self) -> FileHistoryMenuList:
        """ Returns the list of menus that are managed by this file history object.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def Load(self, config: 'ConfigBase') -> None:
        """ Loads the file history from the given config object.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def RemoveFileFromHistory(self, i: int) -> None:
        """ Removes the specified file from the history.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def RemoveMenu(self, menu: 'Menu') -> None:
        """ Removes this menu from the list of those managed by this object.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def Save(self, config: 'ConfigBase') -> None:
        """ Saves the file history into the given config object.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def SetBaseId(self, baseId: int) -> None:
        """ Sets the base identifier for the range used for appending items.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def SetMenuPathStyle(self, style: FileHistoryMenuPathStyle) -> None:
        """ Set the style of the menu item labels.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    def UseMenu(self, menu: 'Menu') -> None:
        """ Adds this menu to the list of those menus that are managed by this file history object.

            Source: https://docs.wxpython.org/wx.FileHistory.html
        """

    BaseId: int  # See GetBaseId and SetBaseId
    Count: int  # See GetCount
    MaxFiles: int  # See GetMaxFiles
    MenuPathStyle: FileHistoryMenuPathStyle  # See GetMenuPathStyle and SetMenuPathStyle
    Menus: FileHistoryMenuList  # See GetMenus



class FileSystem(Object):
    """ This class provides an interface for opening files on different file
systems.

        Source: https://docs.wxpython.org/wx.FileSystem.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    @staticmethod
    def AddHandler(handler: 'FileSystemHandler') -> None:
        """ This static function adds new handler into the list of handlers (see   wx.FileSystemHandler) which provide access to virtual FS.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    def ChangePathTo(self, location, is_dir=False) -> None:
        """ Sets the current location.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    @staticmethod
    def FileNameToURL(filename: str) -> str:
        """ Converts a FileName       into an URL.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    def FindFileInPath(self, pStr, path, file) -> bool:
        """ Looks for the file with the given name file  in a colon or semi-colon (depending on the current platform) separated list of directories in path.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    def FindFirst(self, wildcard, flags=0) -> str:
        """ Works like FindFirstFile .

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    def FindNext(self) -> str:
        """ Returns the next filename that matches the parameters passed to FindFirst .

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    def GetPath(self) -> str:
        """ Returns the actual path (set by wx.FileSystem.ChangePathTo ).

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    @staticmethod
    def HasHandlerForPath(location: str) -> bool:
        """ This static function returns True if there is a registered handler which can open the given location.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    def OpenFile(self, location, flags=FS_READ) -> 'FSFile':
        """ Opens the file and returns a pointer to a   wx.FSFile  object or None if failed.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    @staticmethod
    def RemoveHandler(handler: 'FileSystemHandler') -> 'FileSystemHandler':
        """ Remove a filesystem handler from the list of handlers.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    @staticmethod
    def URLToFileName(url: str) -> str:
        """ Converts URL into a well-formed filename.

            Source: https://docs.wxpython.org/wx.FileSystem.html
        """

    Path: str  # See GetPath



FS_READ: int

FS_SEEKABLE: int

class FileSystemHandler(Object):
    """ Classes derived from FileSystemHandler are used to access virtual
file systems.

        Source: https://docs.wxpython.org/wx.FileSystemHandler.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    def CanOpen(self, location: str) -> bool:
        """ Returns True if the handler is able to open this file.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    def FindFirst(self, wildcard, flags=0) -> str:
        """ Works like FindFirstFile .

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    def FindNext(self) -> str:
        """ Returns next filename that matches parameters passed to wx.FileSystem.FindFirst .

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    @staticmethod
    def GetAnchor(location: str) -> str:
        """ Returns the anchor if present in the location.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    @staticmethod
    def GetLeftLocation(location: str) -> str:
        """ Returns the left location string extracted from location.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    @staticmethod
    def GetMimeTypeFromExt(location: str) -> str:
        """ Returns the MIME type based on extension  of location.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    @staticmethod
    def GetProtocol(location: str) -> str:
        """ Returns the protocol string extracted from location.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    @staticmethod
    def GetRightLocation(location: str) -> str:
        """ Returns the right location string extracted from location.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """

    def OpenFile(self, fs, location) -> 'FSFile':
        """ Opens the file and returns   wx.FSFile  pointer or None if failed.

            Source: https://docs.wxpython.org/wx.FileSystemHandler.html
        """



class FileSystemWatcher(EvtHandler):
    """ The FileSystemWatcher class allows receiving notifications of file
system changes.

        Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def Add(self, path, events=FSW_EVENT_ALL) -> bool:
        """ Adds path  to currently watched files.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def AddTree(self, path, events=FSW_EVENT_ALL, filter="") -> bool:
        """ This is the same as Add , but also recursively adds every file/directory in the tree rooted at path.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def GetWatchedPaths(self, paths: list[str]) -> int:
        """ Retrieves all watched paths and places them in paths.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def GetWatchedPathsCount(self) -> int:
        """ Returns the number of currently watched paths.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def Remove(self, path: str) -> bool:
        """ Removes path  from the list of watched paths.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def RemoveAll(self) -> bool:
        """ Clears the list of currently watched paths.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def RemoveTree(self, path: str) -> bool:
        """ This is the same as Remove , but also removes every file/directory belonging to the tree rooted at path.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    def SetOwner(self, handler: 'EvtHandler') -> None:
        """ Associates the file system watcher with the given handler  object.

            Source: https://docs.wxpython.org/wx.FileSystemWatcher.html
        """

    WatchedPathsCount: int  # See GetWatchedPathsCount



class FileSystemWatcherEvent(Event):
    """ A class of events sent when a file system event occurs.

        Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def Clone(self) -> 'Event':
        """ wx.Event

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def GetChangeType(self) -> int:
        """ Returns the type of file system change that occurred.

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def GetErrorDescription(self) -> str:
        """ Return a description of the warning or error if this is an error event.

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def GetNewPath(self) -> str:
        """ Returns the new path of the renamed file/directory if this is a rename event.

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def GetPath(self) -> str:
        """ Returns the path at which the event occurred.

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def GetWarningType(self) -> 'FSWWarningType':
        """ Return the type of the warning if this event is a warning one.

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def IsError(self) -> bool:
        """ Returns  true   if this error is an error event.

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    def ToString(self) -> str:
        """ Returns a String       describing an event, useful for logging, debugging or testing.

            Source: https://docs.wxpython.org/wx.FileSystemWatcherEvent.html
        """

    ChangeType: int  # See GetChangeType
    ErrorDescription: str  # See GetErrorDescription
    NewPath: str  # See GetNewPath
    Path: str  # See GetPath
    WarningType: 'FSWWarningType'  # See GetWarningType



class FileTranslationsLoader(TranslationsLoader):
    """ Standard TranslationsLoader implementation.

        Source: https://docs.wxpython.org/wx.FileTranslationsLoader.html
    """
    @staticmethod
    def AddCatalogLookupPathPrefix(prefix: str) -> None:
        """ Add a prefix to the catalog lookup path: the message catalog files will be looked up under prefix/lang/LC_MESSAGES and prefix/lang directories (in this order).

            Source: https://docs.wxpython.org/wx.FileTranslationsLoader.html
        """



class TranslationsLoader:
    """ Abstraction of translations discovery and loading.

        Source: https://docs.wxpython.org/wx.TranslationsLoader.html
    """
    def __init__(self) -> None:
        """ Trivial default constructor.

            Source: https://docs.wxpython.org/wx.TranslationsLoader.html
        """

    def GetAvailableTranslations(self, domain: str) -> list[str]:
        """ Implements wx.Translations.GetAvailableTranslations .

            Source: https://docs.wxpython.org/wx.TranslationsLoader.html
        """

    def LoadCatalog(self, domain, lang) -> MsgCatalog:
        """ Called to load requested catalog.

            Source: https://docs.wxpython.org/wx.TranslationsLoader.html
        """



class FileType:
    """ This class holds information about a given file type.

        Source: https://docs.wxpython.org/wx.FileType.html
    """
    def __init__(self, ftInfo: 'FileTypeInfo') -> None:
        """ Copy constructor.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    @staticmethod
    def ExpandCommand(command, params) -> str:
        """ This function is primarily intended for GetOpenCommand and GetPrintCommand usage but may be also used by the application directly if, for example, you want to use some non-default command to open the file.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetAllCommands(self, params: FileType.MessageParameters) -> tuple:
        """ Returns a tuple containing the verbs and commands arrays, corresponding for the registered information for this mime type.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetDescription(self) -> str:
        """ Returns a brief description for this file type: for example, âtext documentâ for
the âtext/plainâ MIME type.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetExpandedCommand(self, verb, params) -> str:
        """ The returned string is the command to be executed in order to open/print/edit the file of the given type.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetExtensions(self) -> list[str]:
        """ Returns all extensions associated with this file type: for
example, it may contain the following two elements for the MIME
type âtext/htmlâ (notice the absence of the leading dot): âhtmlâ
and âhtmâ.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetIcon(self) -> 'Icon':
        """ Return the icon associated with this mime type, if any.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetIconInfo(self) -> Any:
        """ Returns a tuple containing the Icon for this file type, the file where the
icon is found, and the index of the image in that file, if applicable.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetIconLocation(self) -> 'IconLocation':
        """ Returns a wx.IconLocation that can be used to fetch the icon for this mime type.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetMimeType(self) -> str:
        """ Returns full MIME type specification for this file type: for example, âtext/plainâ.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetMimeTypes(self) -> list[str]:
        """ Same as GetMimeType but returns a list of types.  This will usually contain
only one item, but sometimes, such as on Unix with KDE more than one type
if there are differences between KDE< mailcap and mime.types.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetOpenCommand(self, *args, **kw) -> str:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    def GetPrintCommand(self, params) -> str:
        """ Returns the command which must be executed (see Execute()) in order to
print the file of the given type. The name of the file is retrieved from
the MessageParameters class.

            Source: https://docs.wxpython.org/wx.FileType.html
        """

    Description: str  # See GetDescription
    Extensions: list[str]  # See GetExtensions
    Icon: 'Icon'  # See GetIcon
    IconInfo: Any  # See GetIconInfo
    IconLocation: 'IconLocation'  # See GetIconLocation
    MimeType: str  # See GetMimeType
    MimeTypes: list[str]  # See GetMimeTypes
    OpenCommand: str  # See GetOpenCommand
    PrintCommand: str  # See GetPrintCommand



class FileTypeInfo:
    """ Container of information about FileType.

        Source: https://docs.wxpython.org/wx.FileTypeInfo.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def AddExtension(self, ext: str) -> None:
        """ Add another extension associated with this file type.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetDescription(self) -> str:
        """ Get the long, user visible description.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetExtensions(self) -> list[str]:
        """ Get the array of all extensions.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetExtensionsCount(self) -> int:
        """ Get the number of extensions.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetIconFile(self) -> str:
        """ Get the icon filename.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetIconIndex(self) -> int:
        """ Get the index of the icon within the icon file.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetMimeType(self) -> str:
        """ Get the MIME type.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetOpenCommand(self) -> str:
        """ Get the open command.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetPrintCommand(self) -> str:
        """ Get the print command.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def GetShortDesc(self) -> str:
        """ Get the short description (only used under Win32 so far)

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def SetDescription(self, description: str) -> None:
        """ Set the file type description.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def SetIcon(self, iconFile, iconIndex=0) -> None:
        """ Set the icon information.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def SetOpenCommand(self, command: str) -> None:
        """ Set the command to be used for opening files of this type.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def SetPrintCommand(self, command: str) -> None:
        """ Set the command to be used for printing files of this type.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    def SetShortDesc(self, shortDesc: str) -> None:
        """ Set the short description for the files of this type.

            Source: https://docs.wxpython.org/wx.FileTypeInfo.html
        """

    Description: str  # See GetDescription and SetDescription
    Extensions: list[str]  # See GetExtensions
    ExtensionsCount: int  # See GetExtensionsCount
    IconFile: str  # See GetIconFile
    IconIndex: int  # See GetIconIndex
    MimeType: str  # See GetMimeType
    OpenCommand: str  # See GetOpenCommand and SetOpenCommand
    PrintCommand: str  # See GetPrintCommand and SetPrintCommand
    ShortDesc: str  # See GetShortDesc and SetShortDesc



class FilterFSHandler(FileSystemHandler):
    """ Filter file system handler.

        Source: https://docs.wxpython.org/wx.FilterFSHandler.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.FilterFSHandler.html
        """



class FindDialogEvent(CommandEvent):
    """ FindReplaceDialog events.

        Source: https://docs.wxpython.org/wx.FindDialogEvent.html
    """
    def __init__(self, commandType=wxEVT_NULL, id=0) -> None:
        """ Constructor used by wxWidgets only.

            Source: https://docs.wxpython.org/wx.FindDialogEvent.html
        """

    def GetDialog(self) -> 'FindReplaceDialog':
        """ Return the pointer to the dialog which generated this event.

            Source: https://docs.wxpython.org/wx.FindDialogEvent.html
        """

    def GetFindString(self) -> str:
        """ Return the string to find (never empty).

            Source: https://docs.wxpython.org/wx.FindDialogEvent.html
        """

    def GetFlags(self) -> int:
        """ Get the currently selected flags: this is the combination of the   wx.FindReplaceFlags  enumeration values.

            Source: https://docs.wxpython.org/wx.FindDialogEvent.html
        """

    def GetReplaceString(self) -> str:
        """ Return the string to replace the search string with (only for replace and replace all events).

            Source: https://docs.wxpython.org/wx.FindDialogEvent.html
        """

    Dialog: 'FindReplaceDialog'  # See GetDialog
    FindString: str  # See GetFindString
    Flags: int  # See GetFlags
    ReplaceString: str  # See GetReplaceString



EVT_FIND: int  # Find button was pressed in the dialog.

EVT_FIND_NEXT: int  # Find next button was pressed in the dialog.

EVT_FIND_REPLACE: int  # Replace button was pressed in the dialog.

EVT_FIND_REPLACE_ALL: int  # Replace all button was pressed in the dialog.

EVT_FIND_CLOSE: int  # The dialog is being destroyed, any pointers to it cannot be used any longer. ^^

class FindReplaceDialog(Dialog):
    """ FindReplaceDialog is a standard modeless dialog which is used to
allow the user to search for some text (and possibly replace it with
something else).

        Source: https://docs.wxpython.org/wx.FindReplaceDialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FindReplaceDialog.html
        """

    def Create(self, parent, data, title="", style=0) -> bool:
        """ Creates the dialog; use wx.Window.Show   to show it on screen.

            Source: https://docs.wxpython.org/wx.FindReplaceDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.FindReplaceDialog.html
        """

    def GetData(self) -> 'FindReplaceData':
        """ Get the   wx.FindReplaceData  object used by this dialog.

            Source: https://docs.wxpython.org/wx.FindReplaceDialog.html
        """

    Data: 'FindReplaceData'  # See GetData



class FindReplaceData(Object):
    """ FindReplaceData holds the data for FindReplaceDialog.

        Source: https://docs.wxpython.org/wx.FindReplaceData.html
    """
    def __init__(self, flags: 'int'=0) -> None:
        """ Constructor initializes the flags to default value (0).

            Source: https://docs.wxpython.org/wx.FindReplaceData.html
        """

    def GetFindString(self) -> str:
        """ Get the string to find.

            Source: https://docs.wxpython.org/wx.FindReplaceData.html
        """

    def GetFlags(self) -> int:
        """ Get the combination of  FindReplaceFlags   values.

            Source: https://docs.wxpython.org/wx.FindReplaceData.html
        """

    def GetReplaceString(self) -> str:
        """ Get the replacement string.

            Source: https://docs.wxpython.org/wx.FindReplaceData.html
        """

    def SetFindString(self, str: str) -> None:
        """ Set the string to find (used as initial value by the dialog).

            Source: https://docs.wxpython.org/wx.FindReplaceData.html
        """

    def SetFlags(self, flags: 'int') -> None:
        """ Set the flags to use to initialize the controls of the dialog.

            Source: https://docs.wxpython.org/wx.FindReplaceData.html
        """

    def SetReplaceString(self, str: str) -> None:
        """ Set the replacement string (used as initial value by the dialog).

            Source: https://docs.wxpython.org/wx.FindReplaceData.html
        """

    FindString: str  # See GetFindString and SetFindString
    Flags: 'int'  # See GetFlags and SetFlags
    ReplaceString: str  # See GetReplaceString and SetReplaceString



class FlexGridSizer(GridSizer):
    """ A flex grid sizer is a sizer which lays out its children in a two-
dimensional table with all table fields in one row having the same
height and all fields in one column having the same width, but all
rows or all columns are not necessarily the same height or width as in
the GridSizer.

        Source: https://docs.wxpython.org/wx.FlexGridSizer.html
    """
    def __init__(self, *args, **kw) -> None:
        """ wx.FlexGridSizer  constructors.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def AddGrowableCol(self, idx, proportion=0) -> None:
        """ Specifies that column idx  (starting from zero) should be grown if there is extra space available to the sizer.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def AddGrowableRow(self, idx, proportion=0) -> None:
        """ Specifies that row idx (starting from zero) should be grown if there is extra space available to the sizer.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def CalcMin(self) -> 'Size':
        """ This method is abstract and has to be overwritten by any derived class.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def GetColWidths(self) -> list[int]:
        """ Returns a read-only array containing the widths of the columns in the sizer.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def GetFlexibleDirection(self) -> int:
        """ Returns a   wx.Orientation  value that specifies whether the sizer flexibly resizes its columns, rows, or both (default).

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def GetNonFlexibleGrowMode(self) -> 'FlexSizerGrowMode':
        """ Returns the value that specifies how the sizer grows in the ânon-flexibleâ direction if there is one.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def GetRowHeights(self) -> list[int]:
        """ Returns a read-only array containing the heights of the rows in the sizer.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def IsColGrowable(self, idx: int) -> bool:
        """ Returns True if column idx  is growable.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def IsRowGrowable(self, idx: int) -> bool:
        """ Returns True if row idx  is growable.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def RemoveGrowableCol(self, idx: int) -> None:
        """ Specifies that the idx  column index is no longer growable.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def RemoveGrowableRow(self, idx: int) -> None:
        """ Specifies that the idx  row index is no longer growable.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Method which must be overridden in the derived sizer classes.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def SetFlexibleDirection(self, direction: int) -> None:
        """ Specifies whether the sizer should flexibly resize its columns, rows, or both.

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    def SetNonFlexibleGrowMode(self, mode: FlexSizerGrowMode) -> None:
        """ Specifies how the sizer should grow in the non-flexible direction if there is one (so SetFlexibleDirection   must have been called previously).

            Source: https://docs.wxpython.org/wx.FlexGridSizer.html
        """

    ColWidths: list[int]  # See GetColWidths
    FlexibleDirection: int  # See GetFlexibleDirection and SetFlexibleDirection
    NonFlexibleGrowMode: FlexSizerGrowMode  # See GetNonFlexibleGrowMode and SetNonFlexibleGrowMode
    RowHeights: list[int]  # See GetRowHeights



FLEX_GROWMODE_NONE: int

FLEX_GROWMODE_SPECIFIED: int

FLEX_GROWMODE_ALL: int

class GridSizer(Sizer):
    """ A grid sizer is a sizer which lays out its children in a two-
dimensional table with all table fields having the same size, i.e.

        Source: https://docs.wxpython.org/wx.GridSizer.html
    """
    def __init__(self, *args, **kw) -> None:
        """ wx.GridSizer  constructors.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def CalcMin(self) -> 'Size':
        """ This method is abstract and has to be overwritten by any derived class.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def CalcRowsCols(self) -> None:
        """ Calculates how many rows and columns will be in the sizer based
on the current number of items and also the rows, cols specified
in the constructor.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def GetCols(self) -> int:
        """ Returns the number of columns that has been specified for the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def GetEffectiveColsCount(self) -> int:
        """ Returns the number of columns currently used by the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def GetEffectiveRowsCount(self) -> int:
        """ Returns the number of rows currently used by the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def GetHGap(self) -> int:
        """ Returns the horizontal gap (in pixels) between cells in the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def GetRows(self) -> int:
        """ Returns the number of rows that has been specified for the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def GetVGap(self) -> int:
        """ Returns the vertical gap (in pixels) between the cells in the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Method which must be overridden in the derived sizer classes.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def SetCols(self, cols: int) -> None:
        """ Sets the number of columns in the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def SetHGap(self, gap: int) -> None:
        """ Sets the horizontal gap (in pixels) between cells in the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def SetRows(self, rows: int) -> None:
        """ Sets the number of rows in the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    def SetVGap(self, gap: int) -> None:
        """ Sets the vertical gap (in pixels) between the cells in the sizer.

            Source: https://docs.wxpython.org/wx.GridSizer.html
        """

    Cols: int  # See GetCols and SetCols
    EffectiveColsCount: int  # See GetEffectiveColsCount
    EffectiveRowsCount: int  # See GetEffectiveRowsCount
    HGap: int  # See GetHGap and SetHGap
    Rows: int  # See GetRows and SetRows
    VGap: int  # See GetVGap and SetVGap



class FocusEvent(Event):
    """ A focus event is sent when a windowâs focus changes.

        Source: https://docs.wxpython.org/wx.FocusEvent.html
    """
    def __init__(self, eventType=wxEVT_NULL, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FocusEvent.html
        """

    def GetWindow(self) -> 'Window':
        """ Returns the window associated with this event, that is the window which had the focus before for the  wxEVT_SET_FOCUS   event and the window which is going to receive focus for the   wxEVT_KILL_FOCUS   one.

            Source: https://docs.wxpython.org/wx.FocusEvent.html
        """

    def SetWindow(self, win: 'Window') -> None:
        """ win (wx.Window) â

            Source: https://docs.wxpython.org/wx.FocusEvent.html
        """

    Window: 'Window'  # See GetWindow and SetWindow



class Font(GDIObject):
    """ A font is an object which determines the appearance of text.

        Source: https://docs.wxpython.org/wx.Font.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Font.html
        """

    @staticmethod
    def AddPrivateFont(filename: str) -> bool:
        """ Specify the name of a file containing a TrueType font to be made available to the current application.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Bold(self) -> 'Font':
        """ Returns a bold version of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    @staticmethod
    def CanUsePrivateFont() -> bool:
        """ Returns True if this build of wxPython supports using AddPrivateFont.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetBaseFont(self) -> 'Font':
        """ Returns a font with the same face/size as the given one but with normal weight and style and not underlined nor stricken through.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    @staticmethod
    def GetDefaultEncoding() -> int:
        """ Returns the current applicationâs default encoding.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetEncoding(self) -> int:
        """ Returns the encoding of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetFaceName(self) -> str:
        """ Returns the face name associated with the font, or the empty string if there is no face information.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetFamily(self) -> int:
        """ Gets the font family if possible.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetFractionalPointSize(self) -> float:
        """ Gets the point size as a floating number.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetHFONT(self) -> None:
        """ Returns the fontâs native handle.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetNativeFontInfo(self) -> 'NativeFontInfo':
        """ Returns a font with the same face/size as the given one but with normal weight and style and not underlined nor stricken through.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetNativeFontInfoDesc(self) -> str:
        """ Returns the platform-dependent string completely describing this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetNativeFontInfoUserDesc(self) -> str:
        """ Returns a user-friendly string for this font object.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetNumericWeight(self) -> int:
        """ Gets the font weight as an integer value.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    @staticmethod
    def GetNumericWeightOf(weight: int) -> int:
        """ Get the raw weight value corresponding to the given symbolic constant.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetPangoFontDescription(self) -> None:
        """ Returns the fontâs native handle.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetPixelSize(self) -> 'Size':
        """ Gets the pixel size.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetPointSize(self) -> int:
        """ Gets the point size as an integer number.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetStrikethrough(self) -> bool:
        """ Returns True if the font is stricken-through, False otherwise.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetStyle(self) -> int:
        """ Gets the font style.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetUnderlined(self) -> bool:
        """ Returns True if the font is underlined, False otherwise.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def GetWeight(self) -> int:
        """ Gets the font weight.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def IsFixedWidth(self) -> bool:
        """ Returns True if the font is a fixed width (or monospaced) font, False if it is a proportional one or font is invalid.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def IsOk(self) -> bool:
        """ Returns True if this object is a valid font, False otherwise.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Italic(self) -> 'Font':
        """ Returns an italic version of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Larger(self) -> 'Font':
        """ Returns a larger version of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def MakeBold(self) -> 'Font':
        """ Changes this font to be bold.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def MakeItalic(self) -> 'Font':
        """ Changes this font to be italic.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def MakeLarger(self) -> 'Font':
        """ Changes this font to be larger.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def MakeSmaller(self) -> 'Font':
        """ Changes this font to be smaller.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def MakeStrikethrough(self) -> 'Font':
        """ Changes this font to be stricken-through.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def MakeUnderlined(self) -> 'Font':
        """ Changes this font to be underlined.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    @staticmethod
    def New(*args, **kw) -> 'Font':
        """ This function takes the same parameters as the relative Font constructor  and returns a new font object allocated on the heap.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def OSXGetCGFont(self) -> None:
        """ Returns the fontâs native handle.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Scale(self, x: float) -> 'Font':
        """ Changes the size of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Scaled(self, x: float) -> 'Font':
        """ Returns a scaled version of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    @staticmethod
    def SetDefaultEncoding(encoding: int) -> None:
        """ Sets the default font encoding.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetEncoding(self, encoding: int) -> None:
        """ Sets the encoding for this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetFaceName(self, faceName: str) -> bool:
        """ Sets the facename for the font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetFamily(self, family: int) -> None:
        """ Sets the font family.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetFractionalPointSize(self, pointSize: float) -> None:
        """ Sets the font size in points.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetNativeFontInfo(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetNativeFontInfoUserDesc(self, info: str) -> bool:
        """ Creates the font corresponding to the given native font description string and returns True if the creation was successful.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetNumericWeight(self, weight: int) -> None:
        """ Sets the font weight using an integer value.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetPixelSize(self, pixelSize: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the pixel size.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetPointSize(self, pointSize: int) -> None:
        """ Sets the font size in points to an integer value.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetStrikethrough(self, strikethrough: bool) -> None:
        """ Sets strike-through attribute of the font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetStyle(self, style: int) -> None:
        """ Sets the font style.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetSymbolicSize(self, size: FontSymbolicSize) -> None:
        """ Sets the font size using a predefined symbolic size name.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetSymbolicSizeRelativeTo(self, size, base) -> None:
        """ Sets the font size compared to the base font size.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetUnderlined(self, underlined: bool) -> None:
        """ Sets underlining.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def SetWeight(self, weight: int) -> None:
        """ Sets the font weight.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Smaller(self) -> 'Font':
        """ Returns a smaller version of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Strikethrough(self) -> 'Font':
        """ Returns stricken-through version of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def Underlined(self) -> 'Font':
        """ Returns underlined version of this font.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def _copyFrom(self, other) -> None:
        """ For internal use only.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Inequality operator.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Equality operator.

            Source: https://docs.wxpython.org/wx.Font.html
        """

    Encoding: int  # See GetEncoding and SetEncoding
    FaceName: str  # See GetFaceName and SetFaceName
    Family: int  # See GetFamily and SetFamily
    NativeFontInfoDesc: str  # See GetNativeFontInfoDesc and SetNativeFontInfo
    NativeFontInfoUserDesc: str  # See GetNativeFontInfoUserDesc and SetNativeFontInfoUserDesc
    PixelSize: Union[tuple[int, int], 'Size']  # See GetPixelSize and SetPixelSize
    PointSize: int  # See GetPointSize and SetPointSize
    Style: int  # See GetStyle and SetStyle
    Weight: int  # See GetWeight and SetWeight



class FontData(Object):
    """ This class holds a variety of information related to font dialogs.

        Source: https://docs.wxpython.org/wx.FontData.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def EnableEffects(self, enable: bool) -> None:
        """ Enables or disables âeffectsâ under Windows or generic only.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def GetAllowSymbols(self) -> bool:
        """ Under Windows, returns a flag determining whether symbol fonts can be selected.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def GetChosenFont(self) -> 'Font':
        """ Gets the font chosen by the user if the user pressed wx.OK ( wx.FontDialog.ShowModal   returned wx.ID_OK).

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def GetColour(self) -> 'Colour':
        """ Gets the colour associated with the font dialog.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def GetEnableEffects(self) -> bool:
        """ Determines whether âeffectsâ are enabled under Windows.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def GetInitialFont(self) -> 'Font':
        """ Gets the font that will be initially used by the font dialog.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def GetRestrictSelection(self) -> int:
        """ Returns the state of the flags restricting the selection.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def GetShowHelp(self) -> bool:
        """ Returns True if the Help button will be shown (Windows only).

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def RestrictSelection(self, flags: int) -> None:
        """ Restricts the selection to a subset of the available fonts.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def SetAllowSymbols(self, allowSymbols: bool) -> None:
        """ Under Windows, determines whether symbol fonts can be selected.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def SetChosenFont(self, font: 'Font') -> None:
        """ Sets the font that will be returned to the user (for internal use only).

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def SetColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the colour that will be used for the font foreground colour.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def SetInitialFont(self, font: 'Font') -> None:
        """ Sets the font that will be initially used by the font dialog.

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def SetRange(self, min, max) -> None:
        """ Sets the valid range for the font point size (Windows only).

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    def SetShowHelp(self, showHelp: bool) -> None:
        """ Determines whether the Help button will be displayed in the font dialog (Windows only).

            Source: https://docs.wxpython.org/wx.FontData.html
        """

    AllowSymbols: bool  # See GetAllowSymbols and SetAllowSymbols
    ChosenFont: 'Font'  # See GetChosenFont and SetChosenFont
    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour
    InitialFont: 'Font'  # See GetInitialFont and SetInitialFont
    ShowHelp: bool  # See GetShowHelp and SetShowHelp



class FontDialog(Dialog):
    """ This class represents the font chooser dialog.

        Source: https://docs.wxpython.org/wx.FontDialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FontDialog.html
        """

    def Create(self, *args, **kw) -> None:
        """ Creates the dialog if the   wx.FontDialog  object had been initialized using the default constructor.

            Source: https://docs.wxpython.org/wx.FontDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.FontDialog.html
        """

    def GetFontData(self) -> 'FontData':
        """ Returns the font data  associated with the font dialog.

            Source: https://docs.wxpython.org/wx.FontDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning  ID_OK   if the user pressed Ok, and   ID_CANCEL   otherwise.

            Source: https://docs.wxpython.org/wx.FontDialog.html
        """

    FontData: 'FontData'  # See GetFontData



class FontEnumerator:
    """ FontEnumerator enumerates either all available fonts on the system
or only the ones with given attributes - either only fixed-width
(suited for use in programs such as terminal emulators and the like)
or the fonts available in the given encoding).

        Source: https://docs.wxpython.org/wx.FontEnumerator.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    def EnumerateEncodings(self, font: str="") -> bool:
        """ Call OnFontEncoding   for each encoding supported by the given font - or for each encoding supported by at least some font if font  is not specified.

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    def EnumerateFacenames(self, encoding=FONTENCODING_SYSTEM, fixedWidthOnly=False) -> bool:
        """ Call OnFacename   for each font which supports given encoding (only if it is not  FONTENCODING_SYSTEM ) and is of fixed width (if  fixedWidthOnly  is True).

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    @staticmethod
    def GetEncodings(facename: str="") -> list[str]:
        """ Return array of strings containing all encodings found by EnumerateEncodings .

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    @staticmethod
    def GetFacenames(encoding=FONTENCODING_SYSTEM, fixedWidthOnly=False) -> list[str]:
        """ Return array of strings containing all facenames found by EnumerateFacenames .

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    @staticmethod
    def InvalidateCache() -> None:
        """ Invalidate cache used by some of the methods of this class internally.

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    @staticmethod
    def IsValidFacename(facename: str) -> bool:
        """ Returns True if the given string is valid face name, i.e.

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    def OnFacename(self, font: str) -> bool:
        """ Called by EnumerateFacenames   for each match.

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """

    def OnFontEncoding(self, font, encoding) -> bool:
        """ Called by EnumerateEncodings   for each match.

            Source: https://docs.wxpython.org/wx.FontEnumerator.html
        """



class FontInfo:
    """ This class is a helper used for Font creation using named parameter
idiom: it allows specifying various Font attributes using the
chained calls to its clearly named methods instead of passing them in
the fixed order to Font constructors.

        Source: https://docs.wxpython.org/wx.FontInfo.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def AllFlags(self, flags: int) -> 'FontInfo':
        """ Set all the font attributes at once.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def AntiAliased(self, antiAliased: bool=True) -> 'FontInfo':
        """ Set anti-aliasing flag.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Bold(self, bold: bool=True) -> 'FontInfo':
        """ Use a bold version of the font.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Encoding(self, encoding: int) -> 'FontInfo':
        """ Set the font encoding to use.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def FaceName(self, faceName: str) -> 'FontInfo':
        """ Set the font face name to use.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Family(self, family: int) -> 'FontInfo':
        """ Set the font family.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    @staticmethod
    def GetWeightClosestToNumericValue(numWeight: int) -> int:
        """ Get the symbolic weight closest to the given raw weight value.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Italic(self, italic: bool=True) -> 'FontInfo':
        """ Use an italic version of the font.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Light(self, light: bool=True) -> 'FontInfo':
        """ Use a lighter version of the font.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Slant(self, slant: bool=True) -> 'FontInfo':
        """ Use a slanted version of the font.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Strikethrough(self, strikethrough: bool=True) -> 'FontInfo':
        """ Use a strike-through version of the font.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Style(self, style: int) -> 'FontInfo':
        """ Specify the style of the font using one of FontStyle constants.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Underlined(self, underlined: bool=True) -> 'FontInfo':
        """ Use an underlined version of the font.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """

    def Weight(self, weight: int) -> 'FontInfo':
        """ Specify the weight of the font.

            Source: https://docs.wxpython.org/wx.FontInfo.html
        """



class FontList:
    """ A font list is a list containing all fonts which have been created.

        Source: https://docs.wxpython.org/wx.FontList.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FontList.html
        """

    def FindOrCreateFont(self, *args, **kw) -> 'Font':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FontList.html
        """



class FontMapper:
    """ FontMapper manages user-definable correspondence between logical
font names and the fonts present on the machine.

        Source: https://docs.wxpython.org/wx.FontMapper.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    def CharsetToEncoding(self, charset, interactive=True) -> int:
        """ Returns the encoding for the given charset (in the form of RFC 2046) or  FONTENCODING_SYSTEM   if couldnât decode it.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def Get() -> 'FontMapper':
        """ Get the current font mapper object.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def GetAllEncodingNames(encoding) -> list[str]:
        """ Returns the array of all possible names for the given encoding. If it
isnât empty, the first name in it is the canonical encoding name,
i.e. the same string as returned by GetEncodingName()

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    def GetAltForEncoding(self, encoding, facename="", interactive=True) -> tuple:
        """ Find an alternative for the given encoding (which is supposed to not be available on this system).

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def GetEncoding(n: int) -> int:
        """ Returns the n-th  supported encoding.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def GetEncodingDescription(encoding: int) -> str:
        """ Return user-readable string describing the given encoding.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def GetEncodingFromName(encoding: str) -> int:
        """ Return the encoding corresponding to the given internal name.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def GetEncodingName(encoding: int) -> str:
        """ Return internal string identifier for the encoding (see also wx.FontMapper.GetEncodingDescription ).

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def GetSupportedEncodingsCount() -> int:
        """ Returns the number of the font encodings supported by this class.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    def IsEncodingAvailable(self, encoding, facename="") -> bool:
        """ Check whether given encoding is available in given face or not.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    @staticmethod
    def Set(mapper: 'FontMapper') -> 'FontMapper':
        """ Set the current font mapper object and return previous one (may be None).

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    def SetConfigPath(self, prefix: str) -> None:
        """ Set the root config path to use (should be an absolute path).

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    def SetDialogParent(self, parent: 'Window') -> None:
        """ The parent window for modal dialogs.

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """

    def SetDialogTitle(self, title: str) -> None:
        """ The title for the dialogs (note that default is quite reasonable).

            Source: https://docs.wxpython.org/wx.FontMapper.html
        """



class FontMetrics:
    """ Simple collection of various font metrics.

        Source: https://docs.wxpython.org/wx.FontMetrics.html
    """
    def __init__(self) -> None:
        """ Constructor initializes all fields to 0.

            Source: https://docs.wxpython.org/wx.FontMetrics.html
        """

    ascent: Any  # A public C++ attribute of type int. Part of the height above the baseline.
    averageWidth: Any  # A public C++ attribute of type int. Average font width, a.k.a. âx-widthâ.
    descent: Any  # A public C++ attribute of type int. Part of the height below the baseline.
    externalLeading: Any  # A public C++ attribute of type int. Inter-line spacing.
    height: Any  # A public C++ attribute of type int. Total character height.
    internalLeading: Any  # A public C++ attribute of type int. Intra-line spacing.



class FontPickerCtrl(PickerBase):
    """ This control allows the user to select a font.

        Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def Create(self, parent, id=ID_ANY, font=NullFont, pos=DefaultPosition, size=DefaultSize, style=FNTP_DEFAULT_STYLE, validator=DefaultValidator, name=FontPickerCtrlNameStr) -> bool:
        """ Creates this widget with given parameters.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def GetMaxPointSize(self) -> int:
        """ Returns the maximum point size value allowed for the user-chosen font.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def GetMinPointSize(self) -> int:
        """ Returns the minimum point size value allowed for the user-chosen font.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def GetSelectedColour(self) -> 'Colour':
        """ Returns the currently selected colour.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def GetSelectedFont(self) -> 'Font':
        """ Returns the currently selected font.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def SetMaxPointSize(self, max: int) -> None:
        """ Sets the maximum point size value allowed for the user-chosen font.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def SetMinPointSize(self, min: int) -> None:
        """ Sets the minimum point size value allowed for the user-chosen font.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def SetSelectedColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the font colour.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    def SetSelectedFont(self, font: 'Font') -> None:
        """ Sets the currently selected font.

            Source: https://docs.wxpython.org/wx.FontPickerCtrl.html
        """

    MaxPointSize: int  # See GetMaxPointSize and SetMaxPointSize
    MinPointSize: int  # See GetMinPointSize and SetMinPointSize
    SelectedColour: Union[int, str, 'Colour']  # See GetSelectedColour and SetSelectedColour
    SelectedFont: 'Font'  # See GetSelectedFont and SetSelectedFont



FNTP_DEFAULT_STYLE: int  # The default style: wx.FNTP_FONTDESC_AS_LABEL | wx.FNTP_USEFONT_FOR_LABEL.

FNTP_USE_TEXTCTRL: int  # Creates a text control to the left of the picker button which is completely managed by the   wx.FontPickerCtrl  and which can be used by the user to specify a font (see SetSelectedFont). The text control is automatically synchronized with buttonâs value. Use functions defined in   wx.PickerBase  to modify the text control.

FNTP_FONTDESC_AS_LABEL: int  # Keeps the label of the button updated with the fontface name and the font size. E.g. choosing âTimes New Roman bold, italic withsize 10â from the fontdialog, will update the label (overwriting any previous label) with the âTimes New Roman, 10â text.

FNTP_USEFONT_FOR_LABEL: int  # Uses the currently selected font to draw the label of the button. ^^

EVT_FONTPICKER_CHANGED: int  # The user changed the font selected in the control either using the button or using text control (see wx.FNTP_USE_TEXTCTRL; note that in this case the event is fired only if the userâs input is valid, i.e. recognizable). ^^

class FontPickerEvent(CommandEvent):
    """ This event class is used for the events generated by FontPickerCtrl.

        Source: https://docs.wxpython.org/wx.FontPickerEvent.html
    """
    def __init__(self, generator, id, font) -> None:
        """ The constructor is not normally used by the user code.

            Source: https://docs.wxpython.org/wx.FontPickerEvent.html
        """

    def GetFont(self) -> 'Font':
        """ Retrieve the font the user has just selected.

            Source: https://docs.wxpython.org/wx.FontPickerEvent.html
        """

    def SetFont(self: 'Font', f) -> None:
        """ Set the font associated with the event.

            Source: https://docs.wxpython.org/wx.FontPickerEvent.html
        """

    Font: 'Font'  # See GetFont and SetFont



class Frame(TopLevelWindow):
    """ A frame is a window whose size and position can (usually) be changed
by the user.

        Source: https://docs.wxpython.org/wx.Frame.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def Centre(self, direction: int=BOTH) -> None:
        """ Centres the frame on the display.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def Create(self, parent, id=ID_ANY, title="", pos=DefaultPosition, size=DefaultSize, style=DEFAULT_FRAME_STYLE, name=FrameNameStr) -> bool:
        """ Used in two-step frame construction.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def CreateStatusBar(self, number=1, style=STB_DEFAULT_STYLE, id=0, name=StatusBarNameStr) -> 'StatusBar':
        """ Creates a status bar at the bottom of the frame.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def CreateToolBar(self, style=TB_DEFAULT_STYLE, id=ID_ANY, name=ToolBarNameStr) -> 'ToolBar':
        """ Creates a toolbar at the top or left of the frame.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def DoGiveHelp(self, text, show) -> None:
        """ Method used to show help string of the selected menu toolbar item.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def GetClientAreaOrigin(self) -> 'Point':
        """ Returns the origin of the frame client area (in client coordinates).

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def GetMenuBar(self) -> 'MenuBar':
        """ Returns a pointer to the menubar currently associated with the frame (if any).

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def GetStatusBar(self) -> 'StatusBar':
        """ Returns a pointer to the status bar currently associated with the frame (if any).

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def GetStatusBarPane(self) -> int:
        """ Returns the status bar pane used to display menu and toolbar help.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def GetToolBar(self) -> 'ToolBar':
        """ Returns a pointer to the toolbar currently associated with the frame (if any).

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def OnCreateStatusBar(self, number, style, id, name) -> 'StatusBar':
        """ Virtual function called when a status bar is requested by CreateStatusBar .

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def OnCreateToolBar(self, style, id, name) -> 'ToolBar':
        """ Virtual function called when a toolbar is requested by CreateToolBar .

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def PopStatusText(self, number: int=0) -> None:
        """ number (int) â

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def ProcessCommand(self, id: int) -> bool:
        """ Simulate a menu command.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def PushStatusText(self, text, number=0) -> None:
        """ text (string) â

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def SetMenuBar(self, menuBar: 'MenuBar') -> None:
        """ Tells the frame to show the given menu bar.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def SetStatusBar(self, statusBar: 'StatusBar') -> None:
        """ Associates a status bar with the frame.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def SetStatusBarPane(self, n: int) -> None:
        """ Set the status bar pane used to display menu and toolbar help.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def SetStatusText(self, text, number=0) -> None:
        """ Sets the status bar text and updates the status bar display.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def SetStatusWidths(self, widths: list[int]) -> None:
        """ Sets the widths of the fields in the status bar.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    def SetToolBar(self, toolBar: 'ToolBar') -> None:
        """ Associates a toolbar with the frame.

            Source: https://docs.wxpython.org/wx.Frame.html
        """

    MenuBar: 'MenuBar'  # See GetMenuBar and SetMenuBar
    StatusBar: 'StatusBar'  # See GetStatusBar and SetStatusBar
    StatusBarPane: int  # See GetStatusBarPane and SetStatusBarPane
    ToolBar: 'ToolBar'  # See GetToolBar and SetToolBar



DEFAULT_FRAME_STYLE: int  # Defined as wx.MINIMIZE_BOX | wx.MAXIMIZE_BOX | wx.RESIZE_BORDER | wx.SYSTEM_MENU | wx.CAPTION | wx.CLOSE_BOX | wx.CLIP_CHILDREN.

ICONIZE: int  # Display the frame iconized (minimized). Windows only.

MINIMIZE: int  # Identical to wx.ICONIZE. Windows only.

MAXIMIZE: int  # Displays the frame maximized. Windows and GTK+ only.

FRAME_TOOL_WINDOW: int  # Causes a frame with a small title bar to be created; the frame does not appear in the taskbar under Windows or GTK+.

FRAME_NO_TASKBAR: int  # Creates an otherwise normal frame but it does not appear in the taskbar under Windows or GTK+ (note that it will minimize to the desktop window under Windows which may seem strange to the users and thus it might be better to use this style only without wx.MINIMIZE_BOX style). In wxGTK, the flag is respected only if the window manager supports _NET_WM_STATE_SKIP_TASKBAR hint.

FRAME_FLOAT_ON_PARENT: int  # The frame will always be on top of its parent (unlike wx.STAY_ON_TOP). A frame created with this style must have a not None parent.

FRAME_SHAPED: int  # Windows with this style are allowed to have their shape changed with the SetShape  method. ^^

EVT_ICONIZE: int  # Process a  wxEVT_ICONIZE   event. See    wx.IconizeEvent.

EVT_MENU_OPEN: int  # A menu is about to be opened. See   wx.MenuEvent.

EVT_MENU_CLOSE: int  # A menu has been just closed. See   wx.MenuEvent.

EVT_MENU_HIGHLIGHT: int  # The menu item with the specified id has been highlighted: used to show help prompts in the status bar by   wx.Frame. See   wx.MenuEvent.

EVT_MENU_HIGHLIGHT_ALL: int  # A menu item has been highlighted, i.e. the currently selected menu item has changed. See   wx.MenuEvent. ^^

FRAME_EX_CONTEXTHELP: int

FRAME_EX_METAL: int

class FSFile(Object):
    """ This class represents a single file opened by FileSystem.

        Source: https://docs.wxpython.org/wx.FSFile.html
    """
    def __init__(self, stream, location, mimetype, anchor, modif) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FSFile.html
        """

    def DetachStream(self) -> 'InputStream':
        """ Detaches the stream from the   wx.FSFile  object.

            Source: https://docs.wxpython.org/wx.FSFile.html
        """

    def GetAnchor(self) -> str:
        """ Returns anchor (if present).

            Source: https://docs.wxpython.org/wx.FSFile.html
        """

    def GetLocation(self) -> str:
        """ Returns full location of the file, including path and protocol.

            Source: https://docs.wxpython.org/wx.FSFile.html
        """

    def GetMimeType(self) -> str:
        """ Returns the MIME type of the content of this file.

            Source: https://docs.wxpython.org/wx.FSFile.html
        """

    def GetModificationTime(self) -> 'DateTime':
        """ Returns time when this file was modified.

            Source: https://docs.wxpython.org/wx.FSFile.html
        """

    def GetStream(self) -> 'InputStream':
        """ Returns pointer to the stream.

            Source: https://docs.wxpython.org/wx.FSFile.html
        """

    Anchor: str  # See GetAnchor
    Location: str  # See GetLocation
    MimeType: str  # See GetMimeType
    ModificationTime: 'DateTime'  # See GetModificationTime
    Stream: 'InputStream'  # See GetStream



class FullScreenEvent(Event):
    """ An event being sent when the user enters or exits full screen mode.

        Source: https://docs.wxpython.org/wx.FullScreenEvent.html
    """
    def __init__(self, id=0, fullscreen=True) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.FullScreenEvent.html
        """

    def IsFullScreen(self) -> bool:
        """ Returns True if the frame entered full screen, False if exited full screen.

            Source: https://docs.wxpython.org/wx.FullScreenEvent.html
        """



EVT_FULLSCREEN: int  # Process a  wxEVT_FULLSCREEN   event. ^^

class Gauge(Control):
    """ A gauge is a horizontal or vertical bar which shows a quantity (often
time).

        Source: https://docs.wxpython.org/wx.Gauge.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    def Create(self, parent, id=ID_ANY, range=100, pos=DefaultPosition, size=DefaultSize, style=GA_HORIZONTAL, validator=DefaultValidator, name=GaugeNameStr) -> bool:
        """ Creates the gauge for two-step construction.

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    def GetRange(self) -> int:
        """ Returns the maximum position of the gauge.

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    def GetValue(self) -> int:
        """ Returns the current position of the gauge.

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    def IsVertical(self) -> bool:
        """ Returns True if the gauge is vertical (has  GA_VERTICAL   style) and False otherwise.

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    def Pulse(self) -> None:
        """ Switch the gauge to indeterminate mode (if required) and makes the gauge move a bit to indicate the user that some progress has been made.

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    def SetRange(self, range: int) -> None:
        """ Sets the range (maximum value) of the gauge.

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    def SetValue(self, pos: int) -> None:
        """ Sets the position of the gauge.

            Source: https://docs.wxpython.org/wx.Gauge.html
        """

    Range: int  # See GetRange and SetRange
    Value: int  # See GetValue and SetValue



GA_HORIZONTAL: int  # Creates a horizontal gauge.

GA_VERTICAL: int  # Creates a vertical gauge.

GA_SMOOTH: int  # Creates smooth progress bar with one pixel wide update step (not supported by all platforms).

GA_TEXT: int  # Display the current value in percents in the gauge itself. This style is only supported in Qt and ignored under the other platforms. This flag is only available in wxWidgets 3.1.0 and later.

GA_PROGRESS: int  # Reflect the value of gauge in the application taskbar button under Windows 7 and later and the dock icon under macOS, ignored under the other platforms. This flag is only available in wxWidgets 3.1.0 and later. ^^

class GBPosition:
    """ This class represents the position of an item in a virtual grid of
rows and columns managed by a GridBagSizer.

        Source: https://docs.wxpython.org/wx.GBPosition.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def Get(self) -> tuple:
        """ Return the row and col properties as a tuple.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def GetCol(self) -> int:
        """ Get the current column value.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.GBPosition object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def GetRow(self) -> int:
        """ Get the current row value.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def Set(self, row=0, col=0) -> None:
        """ Set both the row and column properties.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def SetCol(self, col: int) -> None:
        """ Set a new column value.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def SetRow(self, row: int) -> None:
        """ Set a new row value.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Compare inequality of two GBPositions.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Compare equality of two GBPositions.

            Source: https://docs.wxpython.org/wx.GBPosition.html
        """

    Col: int  # See GetCol and SetCol
    Row: int  # See GetRow and SetRow
    col: Any  # See GetCol and SetCol
    row: Any  # See GetRow and SetRow



class GridBagSizer(FlexGridSizer):
    """ A Sizer that can lay out items in a virtual grid like a
FlexGridSizer but in this case explicit positioning of the items is
allowed using GBPosition, and items can optionally span more than
one row and/or column using GBSpan.

        Source: https://docs.wxpython.org/wx.GridBagSizer.html
    """
    def __init__(self, vgap=0, hgap=0) -> None:
        """ Constructor, with optional parameters to specify the gap between the rows and columns.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def Add(self, *args, **kw) -> 'SizerItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def CalcMin(self) -> 'Size':
        """ Called when the managed size of the sizer is needed or when layout needs done.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def CheckForIntersection(self, *args, **kw) -> bool:
        """ Look at all items and see if any intersect (or would overlap) the given item.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def FindItem(self, *args, **kw) -> 'GBSizerItem':
        """ Find the sizer item for the given window or subsizer, returns None if not found.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def FindItemAtPoint(self, pt: Union[tuple[int, int], 'Point']) -> 'GBSizerItem':
        """ Return the sizer item located at the point given in pt, or None if there is no item at that point.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def FindItemAtPosition(self, pos: 'GBPosition') -> 'GBSizerItem':
        """ Return the sizer item for the given grid cell, or None if there is no item at that position.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def FindItemWithData(self, userData: 'Object') -> 'GBSizerItem':
        """ Return the sizer item that has a matching user data (it only compares pointer values) or None if not found.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def GetCellSize(self, row, col) -> 'Size':
        """ Get the size of the specified cell, including hgap and vgap.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def GetEmptyCellSize(self) -> 'Size':
        """ Get the size used for cells in the grid with no item.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def GetItemPosition(self, *args, **kw) -> 'GBPosition':
        """ Get the grid position of the specified item.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def GetItemSpan(self, *args, **kw) -> 'GBSpan':
        """ Get the row/col spanning of the specified item.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Called when the managed size of the sizer is needed or when layout needs done.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def SetEmptyCellSize(self, sz: Union[tuple[int, int], 'Size']) -> None:
        """ Set the size used for cells in the grid with no item.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def SetItemPosition(self, *args, **kw) -> bool:
        """ Set the grid position of the specified item.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    def SetItemSpan(self, *args, **kw) -> bool:
        """ Set the row/col spanning of the specified item.

            Source: https://docs.wxpython.org/wx.GridBagSizer.html
        """

    EmptyCellSize: Union[tuple[int, int], 'Size']  # See GetEmptyCellSize and SetEmptyCellSize



class GBSizerItem(SizerItem):
    """ The GBSizerItem class is used by the GridBagSizer for tracking the
items in the sizer.

        Source: https://docs.wxpython.org/wx.GBSizerItem.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def GetEndPos(self) -> tuple:
        """ Get the row and column of the endpoint of this item.

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def GetGBSizer(self) -> 'GridBagSizer':
        """ wx.GridBagSizer

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def GetPos(self) -> 'GBPosition':
        """ Get the grid position of the item.

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def GetSpan(self) -> 'GBSpan':
        """ Get the row and column spanning of the item.

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def Intersects(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def SetGBSizer(self, sizer: 'GridBagSizer') -> None:
        """ sizer (wx.GridBagSizer) â

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def SetPos(self, pos: 'GBPosition') -> bool:
        """ If the item is already a member of a sizer then first ensure that there is no other item that would intersect with this one at the new position, then set the new position.

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    def SetSpan(self, span: 'GBSpan') -> bool:
        """ If the item is already a member of a sizer then first ensure that there is no other item that would intersect with this one with its new spanning size, then set the new spanning.

            Source: https://docs.wxpython.org/wx.GBSizerItem.html
        """

    GBSizer: 'GridBagSizer'  # See GetGBSizer and SetGBSizer
    Pos: 'GBPosition'  # See GetPos and SetPos
    Span: 'GBSpan'  # See GetSpan and SetSpan



class GBSpan:
    """ This class is used to hold the row and column spanning attributes of
items in a GridBagSizer.

        Source: https://docs.wxpython.org/wx.GBSpan.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def Get(self) -> tuple:
        """ Return the rowspan and colspan properties as a tuple.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def GetColspan(self) -> int:
        """ Get the current colspan value.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.GBSpan object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def GetRowspan(self) -> int:
        """ Get the current rowspan value.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def Set(self, rowspan=0, colspan=0) -> None:
        """ Set both the rowspan and colspan properties.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def SetColspan(self, colspan: int) -> None:
        """ Set a new colspan value.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def SetRowspan(self, rowspan: int) -> None:
        """ Set a new rowspan value.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Compare inequality of two GBSpans.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Compare equality of two GBSpans.

            Source: https://docs.wxpython.org/wx.GBSpan.html
        """

    Colspan: int  # See GetColspan and SetColspan
    Rowspan: int  # See GetRowspan and SetRowspan
    colspan: Any  # See GetColspan and SetColspan
    rowspan: Any  # See GetRowspan and SetRowspan



class GCDC(DC):
    """ GCDC is a device context that draws on a GraphicsContext.

        Source: https://docs.wxpython.org/wx.GCDC.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GCDC.html
        """

    def GetGraphicsContext(self) -> 'GraphicsContext':
        """ Retrieves associated   wx.GraphicsContext.

            Source: https://docs.wxpython.org/wx.GCDC.html
        """

    def SetGraphicsContext(self, context: 'GraphicsContext') -> None:
        """ Set the graphics context to be used for this   wx.GCDC.

            Source: https://docs.wxpython.org/wx.GCDC.html
        """

    GraphicsContext: 'GraphicsContext'  # See GetGraphicsContext and SetGraphicsContext



class GraphicsContext(GraphicsObject):
    """ A GraphicsContext instance is the object that is drawn upon.

        Source: https://docs.wxpython.org/wx.GraphicsContext.html
    """
    def BeginLayer(self, opacity: 'Double') -> None:
        """ All rendering will be done into a fully transparent temporary context.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def Clip(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def ConcatTransform(self, matrix: 'GraphicsMatrix') -> None:
        """ Concatenates the passed in transform with the current transform of this context.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    @staticmethod
    def Create(*args, **kw) -> 'GraphicsContext':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateBitmap(self, bitmap: 'Bitmap') -> 'GraphicsBitmap':
        """ Creates   wx.GraphicsBitmap  from an existing   wx.Bitmap.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateBitmapFromImage(self, image: 'Image') -> 'GraphicsBitmap':
        """ Creates   wx.GraphicsBitmap  from an existing   wx.Image.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateBrush(self, brush: 'Brush') -> 'GraphicsBrush':
        """ Creates a native brush from a   wx.Brush.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateFont(self, *args, **kw) -> 'GraphicsFont':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    @staticmethod
    def CreateFromNative(context: Any) -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  from a native context.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    @staticmethod
    def CreateFromNativeWindow(window: Any) -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  from a native window.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    @staticmethod
    def CreateFromUnknownDC(dc: 'DC') -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  from a DC of unknown specific type.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateLinearGradientBrush(self, *args, **kw) -> 'GraphicsBrush':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateMatrix(self, *args, **kw) -> 'GraphicsMatrix':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreatePath(self) -> 'GraphicsPath':
        """ Creates a native graphics path which is initially empty.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreatePen(self, *args, **kw) -> 'GraphicsPen':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateRadialGradientBrush(self, *args, **kw) -> 'GraphicsBrush':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def CreateSubBitmap(self, bitmap, x, y, w, h) -> 'GraphicsBitmap':
        """ Extracts a sub-bitmap from an existing bitmap.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DisableOffset(self) -> None:
        """ Helper to determine if a 0.5 offset should be applied for the drawing operation.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawBitmap(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawEllipse(self, x, y, w, h) -> None:
        """ Draws an ellipse.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawIcon(self, icon, x, y, w, h) -> None:
        """ Draws the icon.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawLines(self, point2Ds, fillStyle=ODDEVEN_RULE) -> None:
        """ Draws a polygon.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawPath(self, path, fillStyle=ODDEVEN_RULE) -> None:
        """ Draws the path by first filling and then stroking.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawRectangle(self, x, y, w, h) -> None:
        """ Draws a rectangle.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawRoundedRectangle(self, x, y, w, h, radius) -> None:
        """ Draws a rounded rectangle.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def DrawText(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def EnableOffset(self, enable: bool=True) -> None:
        """ Indicates whether the context should try to offset for pixel boundaries.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def EndDoc(self) -> None:
        """ Done with that document (relevant only for printing / pdf etc.)

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def EndLayer(self) -> None:
        """ Composites back the drawings into the context with the opacity given at the BeginLayer   call.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def EndPage(self) -> None:
        """ Ends the current page (relevant only for printing / pdf etc.)

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def FillPath(self, path, fillStyle=ODDEVEN_RULE) -> None:
        """ Fills the path with the current brush.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def Flush(self) -> None:
        """ Make sure that the current content of this context is immediately visible.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def FromDIP(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetAntialiasMode(self) -> 'AntialiasMode':
        """ Returns the current shape antialiasing mode.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetClipBox(self, x, y, w, h) -> None:
        """ Returns bounding box of the current clipping region.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetCompositionMode(self) -> 'CompositionMode':
        """ Returns the current compositing operator.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetDPI(self) -> tuple:
        """ Returns the resolution of the graphics context in device points per inch.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetInterpolationQuality(self) -> 'InterpolationQuality':
        """ Returns the current interpolation quality.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetNativeContext(self) -> None:
        """ Returns the native context (CGContextRef for Core Graphics, Graphics pointer for GDIPlus and cairo_t pointer for cairo).

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetPartialTextExtents(self, text: str) -> list[float]:
        """ Fills the widths  array with the widths from the beginning of text  to the corresponding character of text.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetSize(self) -> tuple:
        """ Returns the size of the graphics context in device coordinates.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetFullTextExtent(self, *args, **kw) -> tuple:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetTransform(self) -> 'GraphicsMatrix':
        """ Gets the current transformation matrix of this context.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def GetWindow(self) -> 'Window':
        """ Returns the associated window if any.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def OffsetEnabled(self) -> bool:
        """ Helper to determine if a 0.5 offset should be applied for the drawing operation.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def PopState(self) -> None:
        """ Sets current state of the context to the state saved by a preceding call to PushState   and removes that state from the stack of saved states.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def PushState(self) -> None:
        """ Push the current state (like transformations, clipping region and quality settings) of the context on a stack.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def ResetClip(self) -> None:
        """ Resets the clipping to original shape.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def Rotate(self, angle: 'Double') -> None:
        """ Rotates the current transformation matrix (in radians).

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def Scale(self, xScale, yScale) -> None:
        """ Scales the current transformation matrix.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def SetAntialiasMode(self, antialias: AntialiasMode) -> bool:
        """ Sets the antialiasing mode, returns True if it supported.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def SetBrush(self, *args, **kw) -> None:
        """ Sets the brush for filling paths.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def SetCompositionMode(self, op: CompositionMode) -> bool:
        """ Sets the compositing operator, returns True if it supported.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def SetFont(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def SetInterpolationQuality(self, interpolation: InterpolationQuality) -> bool:
        """ Sets the interpolation quality, returns True if it is supported.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def SetPen(self, *args, **kw) -> None:
        """ Sets the pen used for stroking.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def SetTransform(self, matrix: 'GraphicsMatrix') -> None:
        """ Sets the current transformation matrix of this context.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def ShouldOffset(self) -> bool:
        """ Helper to determine if a 0.5 offset should be applied for the drawing operation.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def StartDoc(self, message: str) -> bool:
        """ Begin a new document (relevant only for printing / pdf etc.) If there is a progress dialog, message will be shown.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def StartPage(self, width=0, height=0) -> None:
        """ Opens a new page (relevant only for printing / pdf etc.) with the given size in points.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def StrokeLine(self, x1, y1, x2, y2) -> None:
        """ Strokes a single line.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def StrokeLineSegments(self, beginPoint2Ds, endPoint2Ds) -> None:
        """ Stroke disconnected lines from begin to end points.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def StrokeLines(self, point2Ds) -> None:
        """ Stroke lines connecting all the points.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def StrokePath(self, path: 'GraphicsPath') -> None:
        """ Strokes along a path with the current pen.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def ToDIP(self, *args, **kw) -> 'Size':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    def Translate(self, dx, dy) -> None:
        """ Translates the current transformation matrix.

            Source: https://docs.wxpython.org/wx.GraphicsContext.html
        """

    AntialiasMode: AntialiasMode  # See GetAntialiasMode and SetAntialiasMode
    CompositionMode: CompositionMode  # See GetCompositionMode and SetCompositionMode
    InterpolationQuality: InterpolationQuality  # See GetInterpolationQuality and SetInterpolationQuality
    NativeContext: None  # See GetNativeContext
    TextExtent: Any  # See GetTextExtent
    Transform: 'GraphicsMatrix'  # See GetTransform and SetTransform
    Window: 'Window'  # See GetWindow



class GDIObject(Object):
    """ This class allows platforms to implement functionality to optimise GDI
objects, such as Pen, Brush and Font.

        Source: https://docs.wxpython.org/wx.GDIObject.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.GDIObject.html
        """



class Pen(GDIObject):
    """ A pen is a drawing tool for drawing outlines.

        Source: https://docs.wxpython.org/wx.Pen.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetCap(self) -> 'PenCap':
        """ Returns the pen cap style, which may be one of  CAP_ROUND ,   CAP_PROJECTING   and   CAP_BUTT .

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetColour(self) -> 'Colour':
        """ Returns a reference to the pen colour.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetDashes(self) -> list[int]:
        """ Gets an array of dashes (defined as  char   in X,   DWORD   under Windows).

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetJoin(self) -> 'PenJoin':
        """ Returns the pen join style, which may be one of  JOIN_BEVEL ,   JOIN_ROUND   and   JOIN_MITER .

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetQuality(self) -> 'PenQuality':
        """ Returns the pen quality.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetStipple(self) -> 'Bitmap':
        """ Gets a pointer to the stipple bitmap.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetStyle(self) -> 'PenStyle':
        """ Returns the pen style.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def GetWidth(self) -> int:
        """ Returns the pen width.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def IsNonTransparent(self) -> bool:
        """ Returns True if the pen is a valid non-transparent pen.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the pen is initialised.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def IsTransparent(self) -> bool:
        """ Returns True if the pen is transparent.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetCap(self, capStyle: PenCap) -> None:
        """ Sets the pen cap style, which may be one of  CAP_ROUND ,   CAP_PROJECTING   and   CAP_BUTT .

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetColour(self, *args, **kw) -> None:
        """ The penâs colour is changed to the given colour.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetDashes(self, dashes: list[int]) -> None:
        """ Associates an array of dash values (defined as  char   in X,   DWORD   under Windows) with the pen.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetJoin(self, join_style: PenJoin) -> None:
        """ Sets the pen join style, which may be one of  JOIN_BEVEL ,   JOIN_ROUND   and   JOIN_MITER .

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetQuality(self, quality: PenQuality) -> None:
        """ Sets the pen quality.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetStipple(self, stipple: 'Bitmap') -> None:
        """ Sets the bitmap for stippling.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetStyle(self, style: PenStyle) -> None:
        """ Set the pen style.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def SetWidth(self, width: int) -> None:
        """ Sets the pen width.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def _copyFrom(self, other) -> None:
        """ For internal use only.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Inequality operator.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Equality operator.

            Source: https://docs.wxpython.org/wx.Pen.html
        """

    Cap: PenCap  # See GetCap and SetCap
    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour
    Dashes: list[int]  # See GetDashes and SetDashes
    Join: PenJoin  # See GetJoin and SetJoin
    Quality: PenQuality  # See GetQuality and SetQuality
    Stipple: 'Bitmap'  # See GetStipple and SetStipple
    Style: PenStyle  # See GetStyle and SetStyle
    Width: int  # See GetWidth and SetWidth



PENSTYLE_TRANSPARENT: int

class GenericDirCtrl(Control):
    """ This control can be used to place a directory listing (with optional
files) on an arbitrary window.

        Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def CollapsePath(self, path: str) -> bool:
        """ Collapse the given path.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def CollapseTree(self) -> None:
        """ Collapses the entire tree.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def Create(self, parent, id=ID_ANY, dir=DirDialogDefaultFolderStr, pos=DefaultPosition, size=DefaultSize, style=DIRCTRL_DEFAULT_STYLE, filter="", defaultFilter=0, name=TreeCtrlNameStr) -> bool:
        """ Create function for two-step construction.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def ExpandPath(self, path: str) -> bool:
        """ Tries to expand as much of the given path  as possible, so that the filename or directory is visible in the tree control.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetDefaultPath(self) -> str:
        """ Gets the default path.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetFilePath(self) -> str:
        """ Gets selected filename path only (else empty string).

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetFilePaths(self, paths: list[str]) -> None:
        """ Fills the array paths  with the currently selected filepaths.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetFilter(self) -> str:
        """ Returns the filter string.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetFilterIndex(self) -> int:
        """ Returns the current filter index (zero-based).

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetFilterListCtrl(self) -> 'DirFilterListCtrl':
        """ Returns a pointer to the filter list control (if present).

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetPath(self, *args, **kw) -> str:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetPaths(self) -> list:
        """ Returns a list of the currently selected paths.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetRootId(self) -> 'TreeItemId':
        """ Returns the root id for the tree control.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def GetTreeCtrl(self) -> 'TreeCtrl':
        """ Returns a pointer to the tree control.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def Init(self) -> None:
        """ Initializes variables.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def ReCreateTree(self) -> None:
        """ Collapse and expand the tree, thus re-creating it from scratch.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def SelectPath(self, path, select=True) -> None:
        """ Selects the given item.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def SelectPaths(self, paths: list[str]) -> None:
        """ Selects only the specified paths, clearing any previous selection.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def SetDefaultPath(self, path: str) -> None:
        """ Sets the default path.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def SetFilter(self, filter: str) -> None:
        """ Sets the filter string.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def SetFilterIndex(self, n: int) -> None:
        """ Sets the current filter index (zero-based).

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def SetPath(self, path: str) -> None:
        """ Sets the current path.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def ShowHidden(self, show: bool) -> None:
        """ show (bool) â If True, hidden folders and files will be displayed by the control. If False, they will not be displayed.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    def UnselectAll(self) -> None:
        """ Removes the selection from all currently selected items.

            Source: https://docs.wxpython.org/wx.GenericDirCtrl.html
        """

    DefaultPath: str  # See GetDefaultPath and SetDefaultPath
    FilePath: str  # See GetFilePath
    Filter: str  # See GetFilter and SetFilter
    FilterIndex: int  # See GetFilterIndex and SetFilterIndex
    FilterListCtrl: 'DirFilterListCtrl'  # See GetFilterListCtrl
    Path: str  # See GetPath and SetPath
    Paths: list  # See GetPaths
    RootId: 'TreeItemId'  # See GetRootId
    TreeCtrl: 'TreeCtrl'  # See GetTreeCtrl



DIRCTRL_DIR_ONLY: int  # Only show directories, and not files.

DIRCTRL_3D_INTERNAL: int  # Use 3D borders for internal controls. This is the default.

DIRCTRL_SELECT_FIRST: int  # When setting the default path, select the first file in the directory.

DIRCTRL_SHOW_FILTERS: int  # Show the drop-down filter list.

DIRCTRL_EDIT_LABELS: int  # Allow the folder and file labels to be editable.

DIRCTRL_MULTIPLE: int  # Allows multiple files and folders to be selected. ^^

EVT_DIRCTRL_SELECTIONCHANGED: int  # Selected directory has changed. Processes a  wxEVT_DIRCTRL_SELECTIONCHANGED   event type. Notice that this event is generated even for the changes done by the program itself and not only those done by the user. Available since wxWidgets 2.9.5.

EVT_DIRCTRL_FILEACTIVATED: int  # The user activated a file by double-clicking or pressing Enter. Available since wxWidgets 2.9.5. ^^

class GenericDragImage(Object):
    """ This class is used when you wish to drag an object on the screen, and
a simple cursor is not enough.

        Source: https://docs.wxpython.org/wx.GenericDragImage.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def BeginDrag(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def DoDrawImage(self, dc, pos) -> bool:
        """ Draws the image on the device context with top-left corner at the given position.

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def EndDrag(self) -> bool:
        """ Call this when the drag has finished.

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def GetImageRect(self, pos: Union[tuple[int, int], 'Point']) -> 'Rect':
        """ Returns the rectangle enclosing the image, assuming that the image is drawn with its top-left corner at the given point.

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def Hide(self) -> bool:
        """ Hides the image.

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def Move(self, pt: Union[tuple[int, int], 'Point']) -> bool:
        """ Call this to move the image to a new position.

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def Show(self) -> bool:
        """ Shows the image.

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """

    def UpdateBackingFromWindow(self, windowDC, destDC, sourceRect, destRect) -> bool:
        """ Override this if you wish to draw the window contents to the backing bitmap yourself.

            Source: https://docs.wxpython.org/wx.GenericDragImage.html
        """



class GenericMessageDialog(Dialog):
    """ This class represents a dialog that shows a single or multi-line
message, with a choice of wx.OK, Yes, No and Cancel buttons.

        Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
    """
    def __init__(self, parent, message, caption=MessageBoxCaptionStr, style=OK|CENTRE, pos=DefaultPosition) -> None:
        """ Constructor specifying the message box properties.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def AddMessageDialogCheckBox(self, sizer: 'Sizer') -> None:
        """ Can be overridden to provide more contents for the dialog

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def AddMessageDialogDetails(self, sizer: 'Sizer') -> None:
        """ Can be overridden to provide more contents for the dialog

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetCancelLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetCaption(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetEffectiveIcon(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetExtendedMessage(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetHelpLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetMessage(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetMessageDialogStyle(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetNoLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetOKLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def GetYesLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def HasCustomLabels(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def SetExtendedMessage(self, extendedMessage: str) -> None:
        """ Sets the extended message for the dialog: this message is usually an extension of the short message specified in the constructor or set with SetMessage .

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def SetHelpLabel(self, help: MessageDialogButtonLabel) -> bool:
        """ Sets the label for the Help button.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def SetMessage(self, message: str) -> None:
        """ Sets the message shown by the dialog.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def SetOKCancelLabels(self, ok, cancel) -> bool:
        """ Overrides the default labels of the wx.OK and Cancel buttons.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def SetOKLabel(self, ok: MessageDialogButtonLabel) -> bool:
        """ Overrides the default label of the wx.OK button.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def SetYesNoCancelLabels(self, yes, no, cancel) -> bool:
        """ Overrides the default labels of the Yes, No and Cancel buttons.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def SetYesNoLabels(self, yes, no) -> bool:
        """ Overrides the default labels of the Yes and No buttons.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning one of wx.ID_OK, wx.ID_CANCEL, wx.ID_YES, wx.ID_NO or wx.ID_HELP.

            Source: https://docs.wxpython.org/wx.GenericMessageDialog.html
        """

    CancelLabel: str  # See GetCancelLabel
    Caption: str  # See GetCaption
    EffectiveIcon: int  # See GetEffectiveIcon
    ExtendedMessage: str  # See GetExtendedMessage and SetExtendedMessage
    HelpLabel: MessageDialogButtonLabel  # See GetHelpLabel and SetHelpLabel
    Message: str  # See GetMessage and SetMessage
    MessageDialogStyle: int  # See GetMessageDialogStyle
    NoLabel: str  # See GetNoLabel
    OKLabel: MessageDialogButtonLabel  # See GetOKLabel and SetOKLabel
    YesLabel: str  # See GetYesLabel



YES_NO: int  # Puts Yes and No buttons in the message box. It is recommended to always use  CANCEL   with this style as otherwise the message box wonât have a close button under wxMSW and the user will be forced to answer it.

CANCEL_DEFAULT: int  # Makes the âCancelâ button default, can only be used with  CANCEL . This style is currently not supported (and ignored) in wxOSX.

YES_DEFAULT: int  # Makes the âYesâ button default, this is the default behaviour and this flag exists solely for symmetry with  NO_DEFAULT .

OK_DEFAULT: int  # Makes the âwx.OKâ button default, this is the default behaviour and this flag exists solely for symmetry with  CANCEL_DEFAULT .

ICON_NONE: int  # Displays no icon in the dialog if possible (an icon might still be displayed if the current platform mandates its use). This style may be used to prevent the dialog from using the default icon based on  YES_NO   presence as explained in   ICON_QUESTION   and   ICON_INFORMATION   documentation below.

ICON_ERROR: int  # Displays an error icon in the dialog.

ICON_WARNING: int  # Displays a warning icon in the dialog. This style should be used for informative warnings or, in combination with  YES_NO   or   CANCEL , for questions that have potentially serious consequences (caution icon is used on macOS in this case).

ICON_QUESTION: int  # Displays a question mark symbol. This icon is automatically used with  YES_NO   so itâs usually unnecessary to specify it explicitly. This style is not supported for message dialogs under wxMSW when a task dialog is used to implement them (i.e. when running under Windows Vista or later) because  Microsoft guidelines  indicate that no icon should be used for routine confirmations. If it is specified, no icon will be displayed.

ICON_INFORMATION: int  # Displays an information symbol. This icon is used by default if  YES_NO   is not given so it is usually unnecessary to specify it explicitly.

ICON_EXCLAMATION: int  # Alias for  ICON_WARNING .

ICON_HAND: int  # Alias for  ICON_ERROR .

ICON_AUTH_NEEDED: int  # Displays an authentication needed symbol. This style is only supported for message dialogs under wxMSW when a task dialog is used to implement them (i.e. when running under Windows Vista or later). In other cases the default icon selection logic will be used. Note this can be combined with other styles to provide a fallback. For instance, using wx.ICON_AUTH_NEEDED | wx.ICON_QUESTION will show a shield symbol on Windows Vista or above and a question symbol on other platforms. Available since wxWidgets 2.9.5

CENTRE: int  # Centre the message box on its parent or on the screen if parent is not specified. Setting this style under MSW makes no differences as the dialog is always centered on the parent. ^^

class GenericProgressDialog(Dialog):
    """ This class represents a dialog that shows a short message and a
progress bar.

        Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
    """
    def __init__(self, title, message, maximum=100, parent=None, style=PD_AUTO_HIDE|PD_APP_MODAL) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def GetMessage(self) -> str:
        """ Returns the last message passed to the Update   function; if you always passed ââ to Update   then the message set through the constructor is returned.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def GetRange(self) -> int:
        """ Returns the maximum value of the progress meter, as passed to the constructor or  NOT_FOUND   if the dialog has no progress bar.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def GetValue(self) -> int:
        """ Returns the last value passed to the Update   function or  NOT_FOUND   if the dialog has no progress bar.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def Pulse(self, newmsg: str="") -> tuple:
        """ Like Update   but makes the gauge control run in indeterminate mode.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def Resume(self) -> None:
        """ Can be used to continue with the dialog, after the user had clicked the âAbortâ button.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def SetRange(self, maximum: int) -> None:
        """ Changes the maximum value of the progress meter given in the constructor.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def Update(self, value, newmsg="") -> tuple:
        """ Updates the dialog, setting the progress bar to the new value and updating the message if new one is specified.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def WasCancelled(self) -> bool:
        """ Returns True if the âCancelâ button was pressed.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    def WasSkipped(self) -> bool:
        """ Returns True if the âSkipâ button was pressed.

            Source: https://docs.wxpython.org/wx.GenericProgressDialog.html
        """

    Message: str  # See GetMessage
    Range: int  # See GetRange and SetRange
    Value: int  # See GetValue



PD_APP_MODAL: int  # Make the progress dialog application-modal, i.e. disable all application windows while it is shown. If this flag is not given, it is only âlocallyâ modal â

PD_AUTO_HIDE: int  # Causes the progress dialog to disappear from screen as soon as the maximum value of the progress meter has been reached. If this style is not present, the dialog will become a modal dialog (see wx.Dialog.ShowModal ) once the maximum value has been reached and wait for the user to dismiss it.

PD_SMOOTH: int  # Causes smooth progress of the gauge control (uses a   wx.Gauge  with the  GA_SMOOTH   style).

PD_CAN_ABORT: int  # This flag tells the dialog that it should have a âCancelâ button which the user may press. If this happens, the next call to Update  will return False.

PD_CAN_SKIP: int  # This flag tells the dialog that it should have a âSkipâ button which the user may press. If this happens, the next call to Update  will return True in its skip parameter.

PD_ELAPSED_TIME: int  # This flag tells the dialog that it should show elapsed time (since creating the dialog).

PD_ESTIMATED_TIME: int  # This flag tells the dialog that it should show estimated time.

PD_REMAINING_TIME: int  # This flag tells the dialog that it should show remaining time. ^^

class GestureEvent(Event):
    """ This is the base class for all supported gesture events.

        Source: https://docs.wxpython.org/wx.GestureEvent.html
    """
    def __init__(self, winid=0, type=wxEVT_NULL) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.GestureEvent.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the position where the event took effect, in client coordinates: position of Pan event, center of zoom for Zoom event, center of rotation for Rotate event, center of box formed by 2 fingers for Two Finger Tap event and position of the pressed finger for Press and Tap Event.

            Source: https://docs.wxpython.org/wx.GestureEvent.html
        """

    def IsGestureEnd(self) -> bool:
        """ Returns True if the event was the last in a gesture sequence.

            Source: https://docs.wxpython.org/wx.GestureEvent.html
        """

    def IsGestureStart(self) -> bool:
        """ Returns True if the event was the first in a gesture sequence.

            Source: https://docs.wxpython.org/wx.GestureEvent.html
        """

    def SetGestureEnd(self, isEnd: bool=True) -> None:
        """ Sets the event to be the last in a gesture sequence.

            Source: https://docs.wxpython.org/wx.GestureEvent.html
        """

    def SetGestureStart(self, isStart: bool=True) -> None:
        """ Sets the event to be the first in a gesture sequence.

            Source: https://docs.wxpython.org/wx.GestureEvent.html
        """

    def SetPosition(self, pos: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the position where the event took effect, in client coordinates: position of Pan event, center of zoom for Zoom event, center of rotation for Rotate event.

            Source: https://docs.wxpython.org/wx.GestureEvent.html
        """

    Position: Union[tuple[int, int], 'Point']  # See GetPosition and SetPosition



class GIFHandler(ImageHandler):
    """ This is the image handler for the GIF format.

        Source: https://docs.wxpython.org/wx.GIFHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.GIFHandler.

            Source: https://docs.wxpython.org/wx.GIFHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.GIFHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.GIFHandler.html
        """

    def SaveAnimation(self, images, stream, verbose=True, delayMilliSecs=1000) -> bool:
        """ Save the animated gif.

            Source: https://docs.wxpython.org/wx.GIFHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.GIFHandler.html
        """



class GraphicsBitmap(GraphicsObject):
    """ Represents a bitmap.

        Source: https://docs.wxpython.org/wx.GraphicsBitmap.html
    """
    def __init__(self) -> None:
        """ Default constructor creates an invalid bitmap.

            Source: https://docs.wxpython.org/wx.GraphicsBitmap.html
        """

    def ConvertToImage(self) -> 'Image':
        """ Return the contents of this bitmap as   wx.Image.

            Source: https://docs.wxpython.org/wx.GraphicsBitmap.html
        """

    def GetNativeBitmap(self) -> None:
        """ Return the pointer to the native bitmap data.

            Source: https://docs.wxpython.org/wx.GraphicsBitmap.html
        """

    NativeBitmap: None  # See GetNativeBitmap



class GraphicsBrush(GraphicsObject):
    """ A GraphicsBrush is a native representation of a brush.

        Source: https://docs.wxpython.org/wx.GraphicsBrush.html
    """


class GraphicsFont(GraphicsObject):
    """ A GraphicsFont is a native representation of a font.

        Source: https://docs.wxpython.org/wx.GraphicsFont.html
    """


class GraphicsGradientStop:
    """ Represents a single gradient stop in a collection of gradient stops as
represented by GraphicsGradientStops.

        Source: https://docs.wxpython.org/wx.GraphicsGradientStop.html
    """
    def __init__(self, col=TransparentColour, pos=0.) -> None:
        """ Creates a stop with the given colour and position.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStop.html
        """

    def GetColour(self) -> 'Colour':
        """ Return the stop colour.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStop.html
        """

    def GetPosition(self) -> float:
        """ Return the stop position.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStop.html
        """

    def SetColour(self, col: Union[int, str, 'Colour']) -> None:
        """ Change the stop colour.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStop.html
        """

    def SetPosition(self, pos: float) -> None:
        """ Change the stop position.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStop.html
        """

    Colour: Union[int, str, 'Colour']  # See GetColour and SetColour
    Position: float  # See GetPosition and SetPosition



class GraphicsGradientStops:
    """ Represents a collection of GraphicGradientStop values for use with
CreateLinearGradientBrush and CreateRadialGradientBrush.

        Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
    """
    def __init__(self, startCol=TransparentColour, endCol=TransparentColour) -> None:
        """ Initializes the gradient stops with the given boundary colours.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def Add(self, *args, **kw) -> None:
        """ Add a new stop.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def GetCount(self) -> int:
        """ Returns the number of stops.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def GetEndColour(self) -> 'Colour':
        """ Returns the end colour.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def GetStartColour(self) -> 'Colour':
        """ Returns the start colour.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def Item(self, n: Any) -> 'GraphicsGradientStop':
        """ Returns the stop at the given index.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def SetEndColour(self, col: Union[int, str, 'Colour']) -> None:
        """ Set the end colour to col.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def SetStartColour(self, col: Union[int, str, 'Colour']) -> None:
        """ Set the start colour to col.

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def __getitem__(self, n) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    def __len__(self) -> SIP_SSIZE_T:
        """ SIP_SSIZE_T

            Source: https://docs.wxpython.org/wx.GraphicsGradientStops.html
        """

    Count: int  # See GetCount
    EndColour: Union[int, str, 'Colour']  # See GetEndColour and SetEndColour
    StartColour: Union[int, str, 'Colour']  # See GetStartColour and SetStartColour



class GraphicsMatrix(GraphicsObject):
    """ A GraphicsMatrix is a native representation of an affine matrix.

        Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
    """
    def Concat(self, t: 'GraphicsMatrix') -> None:
        """ Concatenates the matrix passed with the current matrix.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def Get(self) -> tuple:
        """ Returns the component values of the matrix via the argument pointers.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def GetNativeMatrix(self) -> None:
        """ Returns the native representation of the matrix.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def Invert(self) -> None:
        """ Inverts the matrix.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def IsEqual(self, t: 'GraphicsMatrix') -> bool:
        """ Returns True if the elements of the transformation matrix are equal.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def IsIdentity(self) -> bool:
        """ Return True if this is the identity matrix.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def Rotate(self, angle: 'Double') -> None:
        """ Rotates this matrix clockwise (in radians).

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def Scale(self, xScale, yScale) -> None:
        """ Scales this matrix.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def Set(self, a=1.0, b=0.0, c=0.0, d=1.0, tx=0.0, ty=0.0) -> None:
        """ Sets the matrix to the respective values (default values are the identity matrix).

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def TransformDistance(self, dx, dy) -> tuple:
        """ Applies this matrix to a distance (ie.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def TransformPoint(self, x, y) -> tuple:
        """ Applies this matrix to a point.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    def Translate(self, dx, dy) -> None:
        """ Translates this matrix.

            Source: https://docs.wxpython.org/wx.GraphicsMatrix.html
        """

    NativeMatrix: None  # See GetNativeMatrix



class GraphicsObject(Object):
    """ This class is the superclass of native graphics objects like pens etc.

        Source: https://docs.wxpython.org/wx.GraphicsObject.html
    """
    def GetRenderer(self) -> 'GraphicsRenderer':
        """ Returns the renderer that was used to create this instance, or None if it has not been initialized yet.

            Source: https://docs.wxpython.org/wx.GraphicsObject.html
        """

    def IsNull(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.GraphicsObject.html
        """

    def IsOk(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.GraphicsObject.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.GraphicsObject.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.GraphicsObject.html
        """

    Renderer: 'GraphicsRenderer'  # See GetRenderer



class GraphicsPath(GraphicsObject):
    """ A GraphicsPath is a native representation of a geometric path.

        Source: https://docs.wxpython.org/wx.GraphicsPath.html
    """
    def AddArc(self, *args, **kw) -> None:
        """ Adds an arc of a circle.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddArcToPoint(self, x1, y1, x2, y2, r) -> None:
        """ Adds an arc (of a circle with radius r) that is tangent to the line connecting current point and (x1, y1) and to the line connecting (x1, y1) and (x2, y2).

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddCircle(self, x, y, r) -> None:
        """ Appends a circle around (x,`y`) with radius r  as a new closed subpath.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddCurveToPoint(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddEllipse(self, x, y, w, h) -> None:
        """ Appends an ellipse fitting into the passed in rectangle as a new closed subpath.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddLineToPoint(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddPath(self, path: 'GraphicsPath') -> None:
        """ Adds another path onto the current path.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddQuadCurveToPoint(self, cx, cy, x, y) -> None:
        """ Adds a quadratic bezier curve from the current point, using a control point and an end point.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddRectangle(self, x, y, w, h) -> None:
        """ Appends a rectangle as a new closed subpath.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def AddRoundedRectangle(self, x, y, w, h, radius) -> None:
        """ Appends a rounded rectangle as a new closed subpath.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def CloseSubpath(self) -> None:
        """ Closes the current sub-path.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def Contains(self, *args, **kw) -> None:
        """ True if the point is within the path.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def GetBox(self) -> 'Rect2D':
        """ Gets the bounding box enclosing all points (possibly including control points).

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def GetCurrentPoint(self) -> 'Point2D':
        """ Gets the last point of the current path, (0,0) if not yet set.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def GetNativePath(self) -> None:
        """ Returns the native path (CGPathRef for Core Graphics, Path pointer for GDIPlus and a cairo_path_t pointer for cairo).

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def MoveToPoint(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def Transform(self, matrix: 'GraphicsMatrix') -> None:
        """ Transforms each point of this path by the matrix.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    def UnGetNativePath(self, p: Any) -> None:
        """ Gives back the native path returned by GetNativePath   because there might be some deallocations necessary (e.g.

            Source: https://docs.wxpython.org/wx.GraphicsPath.html
        """

    Box: 'Rect2D'  # See GetBox
    CurrentPoint: 'Point2D'  # See GetCurrentPoint
    NativePath: None  # See GetNativePath



class GraphicsPen(GraphicsObject):
    """ A GraphicsPen is a native representation of a pen.

        Source: https://docs.wxpython.org/wx.GraphicsPen.html
    """


class GraphicsPenInfo:
    """ This class is a helper used for GraphicsPen creation using named
parameter idiom: it allows specifying various GraphicsPen attributes
using the chained calls to its clearly named methods instead of
passing them in the fixed order to GraphicsPen constructors.

        Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
    """
    def __init__(*args, **kwargs) -> None:
        """ colour (wx.Colour) â

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def Cap(self, cap: PenCap) -> 'GraphicsPenInfo':
        """ cap (PenCap) â

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def Colour(self, col: Union[int, str, 'Colour']) -> 'GraphicsPenInfo':
        """ col (wx.Colour) â

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetCap(self) -> 'PenCap':
        """ wx.PenCap

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetColour(self) -> 'Colour':
        """ wx.Colour

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetEndX(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetEndY(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetGradientType(self) -> 'GradientType':
        """ wx.GradientType

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetJoin(self) -> 'PenJoin':
        """ wx.PenJoin

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetRadius(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetStartX(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetStartY(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetStipple(self) -> 'Bitmap':
        """ wx.Bitmap

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetStops(self) -> 'GraphicsGradientStops':
        """ wx.GraphicsGradientStops

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetStyle(self) -> 'PenStyle':
        """ wx.PenStyle

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetWidth(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetX1(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetX2(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetY1(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def GetY2(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def IsTransparent(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def Join(self, join: PenJoin) -> 'GraphicsPenInfo':
        """ join (PenJoin) â

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def LinearGradient(self, *args, **kw) -> 'GraphicsPenInfo':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def RadialGradient(self, *args, **kw) -> 'GraphicsPenInfo':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def Stipple(self, stipple: 'Bitmap') -> 'GraphicsPenInfo':
        """ stipple (wx.Bitmap) â

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def Style(self, style: PenStyle) -> 'GraphicsPenInfo':
        """ style (PenStyle) â

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    def Width(self, width: 'Double') -> 'GraphicsPenInfo':
        """ width (wx.Double) â

            Source: https://docs.wxpython.org/wx.GraphicsPenInfo.html
        """

    EndX: 'Double'  # See GetEndX
    EndY: 'Double'  # See GetEndY
    GradientType: 'GradientType'  # See GetGradientType
    Radius: 'Double'  # See GetRadius
    StartX: 'Double'  # See GetStartX
    StartY: 'Double'  # See GetStartY
    Stops: 'GraphicsGradientStops'  # See GetStops
    X1: 'Double'  # See GetX1
    X2: 'Double'  # See GetX2
    Y1: 'Double'  # See GetY1
    Y2: 'Double'  # See GetY2



class GraphicsRenderer(Object):
    """ A GraphicsRenderer is the instance corresponding to the rendering
engine used.

        Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
    """
    def CreateBitmap(self, bitmap: 'Bitmap') -> 'GraphicsBitmap':
        """ Creates   wx.GraphicsBitmap  from an existing   wx.Bitmap.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateBitmapFromImage(self, image: 'Image') -> 'GraphicsBitmap':
        """ Creates   wx.GraphicsBitmap  from an existing   wx.Image.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateBitmapFromNativeBitmap(self, bitmap: Any) -> 'GraphicsBitmap':
        """ Creates   wx.GraphicsBitmap  from a native bitmap handle.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateBrush(self, brush: 'Brush') -> 'GraphicsBrush':
        """ Creates a native brush from a   wx.Brush.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateContext(self, *args, **kw) -> 'GraphicsContext':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateContextFromImage(self, image: 'Image') -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  associated with a   wx.Image.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateContextFromNativeContext(self, context: Any) -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  from a native context.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateContextFromNativeWindow(self, window: Any) -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  from a native window.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateContextFromUnknownDC(self, dc: 'DC') -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  from a DC of unknown specific type.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateFont(self, *args, **kw) -> 'GraphicsFont':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateFontAtDPI(self, font, dpi, col=BLACK) -> 'GraphicsFont':
        """ Creates a native graphics font from a   wx.Font  and a text colour.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateImageFromBitmap(self, bmp: 'GraphicsBitmap') -> 'Image':
        """ Creates a   wx.Image  from a   wx.GraphicsBitmap.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateLinearGradientBrush(self, x1, y1, x2, y2, stops, matrix=NullGraphicsMatrix) -> 'GraphicsBrush':
        """ Creates a native brush with a linear gradient.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateMatrix(self, a=1.0, b=0.0, c=0.0, d=1.0, tx=0.0, ty=0.0) -> 'GraphicsMatrix':
        """ Creates a native affine transformation matrix from the passed in values.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateMeasuringContext(self) -> 'GraphicsContext':
        """ Creates a   wx.GraphicsContext  that can be used for measuring texts only.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreatePath(self) -> 'GraphicsPath':
        """ Creates a native graphics path which is initially empty.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreatePen(self, info: 'GraphicsPenInfo') -> 'GraphicsPen':
        """ Creates a native pen from its description.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateRadialGradientBrush(self, startX, startY, endX, endY, radius, stops, matrix=NullGraphicsMatrix) -> 'GraphicsBrush':
        """ Creates a native brush with a radial gradient.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def CreateSubBitmap(self, bitmap, x, y, w, h) -> 'GraphicsBitmap':
        """ Extracts a sub-bitmap from an existing bitmap.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    @staticmethod
    def GetCairoRenderer() -> 'GraphicsRenderer':
        """ Returns Cairo renderer.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    @staticmethod
    def GetDefaultRenderer() -> 'GraphicsRenderer':
        """ Returns the default renderer on this platform.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    @staticmethod
    def GetDirect2DRenderer() -> 'GraphicsRenderer':
        """ Returns Direct2D renderer (MSW and Python3 only).

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    @staticmethod
    def GetGDIPlusRenderer() -> 'GraphicsRenderer':
        """ Returns GDI+ renderer (MSW only).

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def GetName(self) -> str:
        """ Returns the name of the technology used by the renderer.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def GetType(self) -> None:
        """ Returns the name of the GraphicsRenderer class.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    def GetVersion(self, major, minor=None, micro=None) -> None:
        """ Returns the version major, minor and micro/build of the technology used by the renderer.

            Source: https://docs.wxpython.org/wx.GraphicsRenderer.html
        """

    Name: str  # See GetName
    Type: None  # See GetType



class Sizer(Object):
    """ Sizer is the abstract base class used for laying out subwindows in a
window.

        Source: https://docs.wxpython.org/wx.Sizer.html
    """
    def __init__(self) -> None:
        """ The constructor.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Add(self, *args, **kw) -> 'SizerItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def AddMany(self, items) -> None:
        """ AddMany is a convenience method for adding several items to a sizer
at one time. Simply pass it a list of tuples, where each tuple
consists of the parameters that you would normally pass to the Add
method.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def AddSpacer(self, size: int) -> 'SizerItem':
        """ This base function adds non-stretchable space to both the horizontal and vertical orientation of the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def AddStretchSpacer(self, prop: int=1) -> 'SizerItem':
        """ Adds stretchable space to the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def CalcMin(self) -> 'Size':
        """ This method is abstract and has to be overwritten by any derived class.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Clear(self, delete_windows: bool=False) -> None:
        """ Detaches all children from the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def ComputeFittingClientSize(self, window: 'Window') -> 'Size':
        """ Computes client area size for window  so that it matches the sizerâs minimal size.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def ComputeFittingWindowSize(self, window: 'Window') -> 'Size':
        """ Like ComputeFittingClientSize , but converts the result into window size.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Detach(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Fit(self, window: 'Window') -> 'Size':
        """ Tell the sizer to resize the window  so that its client area matches the sizerâs minimal size ( ComputeFittingClientSize   is called to determine it).

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def FitInside(self, window: 'Window') -> None:
        """ Tell the sizer to resize the virtual size of the window  to match the sizerâs minimal size.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetChildren(self) -> SizerItemList:
        """ Returns the list of the items in this sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetContainingWindow(self) -> 'Window':
        """ Returns the window this sizer is used in or None if none.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetItem(self, *args, **kw) -> 'SizerItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetItemById(self, id, recursive=False) -> 'SizerItem':
        """ Finds the item in the sizer which has the given id.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetItemCount(self) -> int:
        """ Returns the number of items in the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetMinSize(self) -> 'Size':
        """ Returns the minimal size of the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the current position of the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def GetSize(self) -> 'Size':
        """ Returns the current size of the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Hide(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def InformFirstDirection(self, direction, size, availableOtherDir) -> bool:
        """ Inform sizer about the first direction that has been decided (by parent item).

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Insert(self, *args, **kw) -> 'SizerItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def InsertSpacer(self, index, size) -> 'SizerItem':
        """ Inserts non-stretchable space to the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def InsertStretchSpacer(self, index, prop=1) -> 'SizerItem':
        """ Inserts stretchable space to the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def IsEmpty(self) -> bool:
        """ Return True if the sizer has no elements.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def IsShown(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Layout(self) -> None:
        """ Call this to force layout of the children anew, e.g. after having added a child to or removed a child (window, other sizer or space) from the sizer while keeping the current dimension.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Prepend(self, *args, **kw) -> 'SizerItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def PrependSpacer(self, size: int) -> 'SizerItem':
        """ Prepends non-stretchable space to the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def PrependStretchSpacer(self, prop: int=1) -> 'SizerItem':
        """ Prepends stretchable space to the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def RecalcSizes(self) -> None:
        """ This is a deprecated version of RepositionChildren()

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Remove(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Replace(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Method which must be overridden in the derived sizer classes.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def SetContainingWindow(self, window: 'Window') -> None:
        """ Set the window this sizer is used in.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def SetDimension(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def SetItemMinSize(self, *args, **kw) -> None:
        """ Set an itemâs minimum size by window, sizer, or position.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def SetMinSize(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def SetSizeHints(self, window: 'Window') -> None:
        """ This method first calls Fit   and then wx.TopLevelWindow.SetSizeHints   on the window  passed to it.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def Show(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def ShowItems(self, show: bool) -> None:
        """ Show or hide all items managed by the sizer.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def __iter__(self) -> None:
        """ A Python convenience method that allows Sizers to act as iterables that will yield their wx.SizerItems.

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    def __nonzero__(self) -> None:
        """ Can be used to test if the C++ part of the sizer still exists, with
code like this:

            Source: https://docs.wxpython.org/wx.Sizer.html
        """

    Children: SizerItemList  # See GetChildren
    ContainingWindow: 'Window'  # See GetContainingWindow and SetContainingWindow
    ItemCount: int  # See GetItemCount
    MinSize: Union[tuple[int, int], 'Size']  # See GetMinSize and SetMinSize
    Position: 'Point'  # See GetPosition
    Size: 'Size'  # See GetSize



ALL: int

EXPAND: int

SHAPED: int

FIXED_MINSIZE: int

RESERVE_SPACE_EVEN_IF_HIDDEN: int

ALIGN_CENTER: int

ALIGN_CENTRE: int

ALIGN_LEFT: int

ALIGN_TOP: int

ALIGN_BOTTOM: int

ALIGN_CENTER_VERTICAL: int

ALIGN_CENTRE_VERTICAL: int

ALIGN_CENTER_HORIZONTAL: int

ALIGN_CENTRE_HORIZONTAL: int

class GUIEventLoop(EventLoopBase):
    """ A generic implementation of the GUI event loop.

        Source: https://docs.wxpython.org/wx.GUIEventLoop.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.GUIEventLoop.html
        """



class HeaderButtonParams:
    """ This struct can optionally be used with
RendererNative.DrawHeaderButton() to specify custom values used to
draw the text or bitmap label.

        Source: https://docs.wxpython.org/wx.HeaderButtonParams.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.HeaderButtonParams.html
        """

    m_arrowColour: Any  # A public C++ attribute of type Colour     .
    m_labelAlignment: Any  # A public C++ attribute of type int.
    m_labelBitmap: Any  # A public C++ attribute of type Bitmap     .
    m_labelColour: Any  # A public C++ attribute of type Colour     .
    m_labelFont: Any  # A public C++ attribute of type Font     .
    m_labelText: Any  # A public C++ attribute of type string.
    m_selectionColour: Any  # A public C++ attribute of type Colour     .



class HeaderColumn:
    """ Represents a column header in controls displaying tabular data such as
DataViewCtrl or Grid.

        Source: https://docs.wxpython.org/wx.HeaderColumn.html
    """
    def GetAlignment(self) -> int:
        """ Returns the current column alignment.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def GetBitmap(self) -> 'Bitmap':
        """ This function exists only for backwards compatibility, itâs recommended to override GetBitmapBundle   in the new code and override this one to do nothing, as it will never be called if GetBitmapBundle   is overridden.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def GetBitmapBundle(self) -> 'BitmapBundle':
        """ Returns the bitmap in the header of the column, if any.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def GetFlags(self) -> int:
        """ Get the column flags.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def GetMinWidth(self) -> int:
        """ Return the minimal column width.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def GetTitle(self) -> str:
        """ Get the text shown in the column header.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def GetWidth(self) -> int:
        """ Returns the current width of the column.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def HasFlag(self, flag: int) -> bool:
        """ Return True if the specified flag is currently set for this column.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def IsHidden(self) -> bool:
        """ Returns True if the column is currently hidden.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def IsReorderable(self) -> bool:
        """ Returns True if the column can be dragged by user to change its order.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def IsResizeable(self) -> bool:
        """ Return True if the column can be resized by the user.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def IsShown(self) -> bool:
        """ Returns True if the column is currently shown.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def IsSortKey(self) -> bool:
        """ Returns True if the column is currently used for sorting.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def IsSortOrderAscending(self) -> bool:
        """ Returns True, if the sort order is ascending.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    def IsSortable(self) -> bool:
        """ Returns True if the column can be clicked by user to sort the control contents by the field in this column.

            Source: https://docs.wxpython.org/wx.HeaderColumn.html
        """

    Alignment: int  # See GetAlignment
    Bitmap: 'Bitmap'  # See GetBitmap
    BitmapBundle: 'BitmapBundle'  # See GetBitmapBundle
    Flags: int  # See GetFlags
    Hidden: Any  # See IsHidden
    MinWidth: int  # See GetMinWidth
    Reorderable: Any  # See IsReorderable
    Resizeable: Any  # See IsResizeable
    Shown: Any  # See IsShown
    SortKey: Any  # See IsSortKey
    SortOrderAscending: Any  # See IsSortOrderAscending
    Sortable: Any  # See IsSortable
    Title: str  # See GetTitle
    Width: int  # See GetWidth



COL_WIDTH_DEFAULT: int

COL_WIDTH_AUTOSIZE: int

COL_HIDDEN: int

COL_REORDERABLE: int

COL_SORTABLE: int

class HeaderColumnSimple(SettableHeaderColumn):
    """ Simple container for the information about the column.

        Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Constructor for a column header.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def GetAlignment(self) -> int:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def GetBitmap(self) -> 'Bitmap':
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def GetBitmapBundle(self) -> 'BitmapBundle':
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def GetFlags(self) -> int:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def GetMinWidth(self) -> int:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def GetTitle(self) -> str:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def GetWidth(self) -> int:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def IsSortKey(self) -> bool:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def IsSortOrderAscending(self) -> bool:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def SetAlignment(self, align: int) -> None:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def SetBitmap(self, bitmap: 'BitmapBundle') -> None:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def SetFlags(self, flags: int) -> None:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def SetMinWidth(self, minWidth: int) -> None:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def SetSortOrder(self, ascending: bool) -> None:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def SetTitle(self, title: str) -> None:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    def SetWidth(self, width: int) -> None:
        """ Trivial implementations of the base class pure virtual functions.

            Source: https://docs.wxpython.org/wx.HeaderColumnSimple.html
        """

    Alignment: int  # See GetAlignment and SetAlignment
    Bitmap: 'BitmapBundle'  # See GetBitmap and SetBitmap
    BitmapBundle: 'BitmapBundle'  # See GetBitmapBundle
    Flags: int  # See GetFlags and SetFlags
    MinWidth: int  # See GetMinWidth and SetMinWidth
    Title: str  # See GetTitle and SetTitle
    Width: int  # See GetWidth and SetWidth



class HeaderCtrl(Control):
    """ HeaderCtrl is the control containing the column headings which is
usually used for display of tabular data.

        Source: https://docs.wxpython.org/wx.HeaderCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def AddColumnsItems(self, menu, idColumnsBase=0) -> None:
        """ Helper function appending the checkable items corresponding to all the columns to the given menu.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def Create(self, parent, winid=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=HD_DEFAULT_STYLE, name=HeaderCtrlNameStr) -> bool:
        """ Create the header control window.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def GetColumn(self, idx: int) -> 'HeaderColumn':
        """ Method to be implemented by the derived classes to return the information for the given column.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def GetColumnAt(self, pos: int) -> int:
        """ Return the index of the column displayed at the given position.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def GetColumnCount(self) -> int:
        """ Return the number of columns in the control.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def GetColumnPos(self, idx: int) -> int:
        """ Get the position at which this column is currently displayed.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def GetColumnTitleWidth(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def GetColumnsOrder(self) -> list[int]:
        """ Return the array describing the columns display order.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def IsEmpty(self) -> bool:
        """ Return whether the control has any columns.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    @staticmethod
    def MoveColumnInOrderArray(order, idx, pos) -> None:
        """ Helper function to manipulate the array of column indices.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def OnColumnCountChanging(self, count: int) -> None:
        """ Can be overridden in the derived class to update internal data structures when the number of the columns in the control changes.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def ResetColumnsOrder(self) -> None:
        """ Reset the columns order to the natural one.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def SetColumnCount(self, count: int) -> None:
        """ Set the number of columns in the control.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def SetColumnsOrder(self, order: list[int]) -> None:
        """ Change the columns display order.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def ShowColumnsMenu(self, pt, title="") -> bool:
        """ Show the popup menu allowing the user to show or hide the columns.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def ShowCustomizeDialog(self) -> bool:
        """ Show the column customization dialog.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def UpdateColumn(self, idx: int) -> None:
        """ Update the column with the given index.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def UpdateColumnVisibility(self, idx, show) -> None:
        """ Method called when the column visibility is changed by the user.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def UpdateColumnWidthToFit(self, idx, widthTitle) -> bool:
        """ Method which may be implemented by the derived classes to allow double clicking the column separator to resize the column to fit its contents.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    def UpdateColumnsOrder(self, order: list[int]) -> None:
        """ Method called when the columns order is changed in the customization dialog.

            Source: https://docs.wxpython.org/wx.HeaderCtrl.html
        """

    ColumnCount: int  # See GetColumnCount and SetColumnCount
    ColumnsOrder: list[int]  # See GetColumnsOrder and SetColumnsOrder



HD_ALLOW_REORDER: int  # If this style is specified (it is by default), the user can reorder the control columns by dragging them.

HD_ALLOW_HIDE: int  # If this style is specified, the control shows a popup menu allowing the user to change the columns visibility on right mouse click. Notice that the program can always hide or show the columns, this style only affects the users capability to do it.

HD_BITMAP_ON_RIGHT: int  # The column image, if any, will be shown on the right side if this style is used. Note that this style is only implemented in wxMSW currently and doesnât do anything under the other platforms. It is available since wxWidgets 3.1.1.

HD_DEFAULT_STYLE: int  # Symbolic name for the default control style, currently equal to  HD_ALLOW_REORDER . ^^

EVT_HEADER_CLICK: int  # A column heading was clicked.

EVT_HEADER_RIGHT_CLICK: int  # A column heading was right clicked.

EVT_HEADER_MIDDLE_CLICK: int  # A column heading was clicked with the middle mouse button.

EVT_HEADER_DCLICK: int  # A column heading was double clicked.

EVT_HEADER_RIGHT_DCLICK: int  # A column heading was right double clicked.

EVT_HEADER_MIDDLE_DCLICK: int  # A column heading was double clicked with the middle mouse button.

EVT_HEADER_SEPARATOR_DCLICK: int  # Separator to the right of the specified column was double clicked (this action is commonly used to resize the column to fit its contents width and the control provides UpdateColumnWidthToFit  method to make implementing this easier).

EVT_HEADER_BEGIN_RESIZE: int  # The user started to drag the separator to the right of the column with the specified index (this can only happen for the columns for which wx.HeaderColumn.IsResizeable   returns True). The event can be vetoed to prevent the column from being resized. If it isnât, the resizing and end resize (or dragging cancelled) events will be generated later.

EVT_HEADER_RESIZING: int  # The user is dragging the column with the specified index resizing it and its current width is wx.HeaderCtrlEvent.GetWidth . The event can be vetoed to stop the dragging operation completely at any time.

EVT_HEADER_END_RESIZE: int  # The user stopped dragging the column by releasing the mouse. The column should normally be resized to the value of wx.HeaderCtrlEvent.GetWidth .

EVT_HEADER_BEGIN_REORDER: int  # The user started to drag the column with the specified index (this can only happen for the controls with wx.HD_ALLOW_REORDER style). This event can be vetoed to prevent the column from being reordered, otherwise the end reorder message will be generated later.

EVT_HEADER_END_REORDER: int  # The user dropped the column in its new location. The event can be vetoed to prevent the column from being placed at the new position or handled to update the display of the data in the associated control to match the new column location (available from wx.HeaderCtrlEvent.GetNewOrder ).

EVT_HEADER_DRAGGING_CANCELLED: int  # The resizing or reordering operation currently in progress was cancelled. This can happen if the user pressed Esc key while dragging the mouse or the mouse capture was lost for some other reason. You only need to handle this event if your application entered into some modal mode when resizing or reordering began, in which case it should handle this event in addition to the matching end resizing or reordering ones. ^^

class HeaderCtrlEvent(NotifyEvent):
    """ Event class representing the events generated by HeaderCtrl.

        Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
        """

    def GetColumn(self) -> int:
        """ Return the index of the column affected by this event.

            Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
        """

    def GetNewOrder(self) -> int:
        """ Return the new order of the column.

            Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
        """

    def GetWidth(self) -> int:
        """ Return the current width of the column.

            Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
        """

    def SetColumn(self, col: int) -> None:
        """ col (int) â

            Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
        """

    def SetNewOrder(self, order: int) -> None:
        """ order (int) â

            Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
        """

    def SetWidth(self, width: int) -> None:
        """ width (int) â

            Source: https://docs.wxpython.org/wx.HeaderCtrlEvent.html
        """

    Column: int  # See GetColumn and SetColumn
    NewOrder: int  # See GetNewOrder and SetNewOrder
    Width: int  # See GetWidth and SetWidth



class HeaderCtrlSimple(HeaderCtrl):
    """ HeaderCtrlSimple is a concrete header control which can be used
directly, without inheriting from it as you need to do when using
HeaderCtrl itself.

        Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def AppendColumn(self, col: 'HeaderColumnSimple') -> None:
        """ Append the column to the end of the control.

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def DeleteColumn(self, idx: int) -> None:
        """ Delete the column at the given position.

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def GetBestFittingWidth(self, idx: int) -> int:
        """ This function can be overridden in the classes deriving from this control instead of overriding UpdateColumnWidthToFit .

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def HideColumn(self, idx: int) -> None:
        """ Hide the column with the given index.

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def InsertColumn(self, col, idx) -> None:
        """ Insert the column at the given position.

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def RemoveSortIndicator(self) -> None:
        """ Remove the sort indicator from the column being used as sort key.

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def ShowColumn(self, idx, show=True) -> None:
        """ Show or hide the column.

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """

    def ShowSortIndicator(self, idx, sortOrder=True) -> None:
        """ Update the column sort indicator.

            Source: https://docs.wxpython.org/wx.HeaderCtrlSimple.html
        """



class HelpControllerBase(Object):
    """ This is the abstract base class a family of classes by which
applications may invoke a help viewer to provide on-line help.

        Source: https://docs.wxpython.org/wx.HelpControllerBase.html
    """
    def __init__(self, parentWindow: Optional['Window']=None) -> None:
        """ Constructs a help instance object, but does not invoke the help viewer.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def DisplayBlock(self, blockNo: int) -> bool:
        """ If the help viewer is not running, runs it and displays the file at the given block number.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def DisplayContents(self) -> bool:
        """ If the help viewer is not running, runs it and displays the contents.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def DisplayContextPopup(self, contextId: int) -> bool:
        """ Displays the section as a popup window using a context id.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def DisplaySection(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def DisplayTextPopup(self, text, pos) -> bool:
        """ Displays the text in a popup window, if possible.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def GetFrameParameters(self) -> tuple:
        """ For   wx.html.HtmlHelpController, returns the latest frame size and position settings and whether a new frame is drawn with each invocation.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def GetParentWindow(self) -> 'Window':
        """ Returns the window to be used as the parent for the help window.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def Initialize(self, file: str) -> bool:
        """ Initializes the help instance with a help filename.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def KeywordSearch(self, keyWord, mode=HELP_SEARCH_ALL) -> bool:
        """ If the help viewer is not running, runs it, and searches for sections matching the given keyword.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def LoadFile(self, file: str="") -> bool:
        """ If the help viewer is not running, runs it and loads the given file.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def OnQuit(self) -> None:
        """ Overridable member called when this applicationâs viewer is quit by the user.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def Quit(self) -> bool:
        """ If the viewer is running, quits it by disconnecting.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def SetFrameParameters(self, titleFormat, size, pos=DefaultPosition, newFrameEachTime=False) -> None:
        """ Set the parameters of the frame window.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def SetParentWindow(self, parentWindow: 'Window') -> None:
        """ Sets the window to be used as the parent for the help window.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    def SetViewer(self, viewer, flags=HELP_NETSCAPE) -> None:
        """ Sets detailed viewer information.

            Source: https://docs.wxpython.org/wx.HelpControllerBase.html
        """

    FrameParameters: tuple  # See GetFrameParameters and SetFrameParameters
    ParentWindow: 'Window'  # See GetParentWindow and SetParentWindow



HELP_NETSCAPE: int

class HelpControllerHelpProvider(SimpleHelpProvider):
    """ HelpControllerHelpProvider is an implementation of HelpProvider
which supports both context identifiers and plain text help strings.

        Source: https://docs.wxpython.org/wx.HelpControllerHelpProvider.html
    """
    def __init__(self, hc: Optional['HelpControllerBase']=None) -> None:
        """ Note that the instance doesnât own the help controller.

            Source: https://docs.wxpython.org/wx.HelpControllerHelpProvider.html
        """

    def GetHelpController(self) -> 'HelpControllerBase':
        """ Returns the help controller associated with this help provider.

            Source: https://docs.wxpython.org/wx.HelpControllerHelpProvider.html
        """

    def SetHelpController(self, hc: 'HelpControllerBase') -> None:
        """ Sets the help controller associated with this help provider.

            Source: https://docs.wxpython.org/wx.HelpControllerHelpProvider.html
        """

    HelpController: 'HelpControllerBase'  # See GetHelpController and SetHelpController



class HelpProvider:
    """ HelpProvider is an abstract class used by a program implementing
context-sensitive help to show the help text for the given window.

        Source: https://docs.wxpython.org/wx.HelpProvider.html
    """
    def AddHelp(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HelpProvider.html
        """

    @staticmethod
    def Get() -> 'HelpProvider':
        """ Returns pointer to help provider instance.

            Source: https://docs.wxpython.org/wx.HelpProvider.html
        """

    def GetHelp(self, window: 'Window') -> str:
        """ This version associates the given text with all windows with this id.

            Source: https://docs.wxpython.org/wx.HelpProvider.html
        """

    def RemoveHelp(self, window: 'WindowBase') -> None:
        """ Removes the association between the window pointer and the help text.

            Source: https://docs.wxpython.org/wx.HelpProvider.html
        """

    @staticmethod
    def Set(helpProvider: 'HelpProvider') -> 'HelpProvider':
        """ Set the current, application-wide help provider.

            Source: https://docs.wxpython.org/wx.HelpProvider.html
        """

    def ShowHelp(self, window: 'WindowBase') -> bool:
        """ Shows help for the given window.

            Source: https://docs.wxpython.org/wx.HelpProvider.html
        """

    def ShowHelpAtPoint(self, window, point, origin) -> bool:
        """ This function may be overridden to show help for the window when it should depend on the position inside the window, By default this method forwards to ShowHelp , so it is enough to only implement the latter if the help doesnât depend on the position.

            Source: https://docs.wxpython.org/wx.HelpProvider.html
        """



class HelpEvent(CommandEvent):
    """ A help event is sent when the user has requested context-sensitive
help.

        Source: https://docs.wxpython.org/wx.HelpEvent.html
    """
    def __init__(self, type=wxEVT_NULL, winid=0, pt=DefaultPosition, origin=Origin_Unknown) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.HelpEvent.html
        """

    def GetOrigin(self) -> 'HelpEvent.Origin':
        """ Returns the origin of the help event which is one of the   wx.HelpEvent.Origin   values.

            Source: https://docs.wxpython.org/wx.HelpEvent.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the left-click position of the mouse, in screen coordinates.

            Source: https://docs.wxpython.org/wx.HelpEvent.html
        """

    def SetOrigin(self, origin: HelpEvent.Origin) -> None:
        """ Set the help event origin, only used internally by wxWidgets normally.

            Source: https://docs.wxpython.org/wx.HelpEvent.html
        """

    def SetPosition(self, pt: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the left-click position of the mouse, in screen coordinates.

            Source: https://docs.wxpython.org/wx.HelpEvent.html
        """

    Position: Union[tuple[int, int], 'Point']  # See GetPosition and SetPosition



class HScrolledWindow(Panel,VarHScrollHelper):
    """ In the name of this class, âHâ stands for âhorizontalâ because it can
be used for scrolling columns of variable widths.

        Source: https://docs.wxpython.org/wx.HScrolledWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HScrolledWindow.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name=PanelNameStr) -> bool:
        """ Same as the non-default constructor, but returns a status code: True if ok, False if the window couldnât be created.

            Source: https://docs.wxpython.org/wx.HScrolledWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.HScrolledWindow.html
        """



class HTMLDataObject(DataObjectSimple):
    """ HTMLDataObject is used for working with HTML-formatted text.

        Source: https://docs.wxpython.org/wx.HTMLDataObject.html
    """
    def __init__(self, html: str="") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.HTMLDataObject.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.HTMLDataObject.html
        """

    def GetHTML(self) -> str:
        """ Returns the HTML string.

            Source: https://docs.wxpython.org/wx.HTMLDataObject.html
        """

    def SetData(self, format, buf) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.HTMLDataObject.html
        """

    def SetHTML(self, html: str) -> None:
        """ Sets the HTML string.

            Source: https://docs.wxpython.org/wx.HTMLDataObject.html
        """

    AllFormats: None  # See GetAllFormats
    HTML: str  # See GetHTML and SetHTML



class HVScrolledWindow(Panel,VarHVScrollHelper):
    """ This window inherits all functionality of both vertical and
horizontal, variable scrolled windows.

        Source: https://docs.wxpython.org/wx.HVScrolledWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.HVScrolledWindow.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name=PanelNameStr) -> bool:
        """ Same as the non-default constructor, but returns a status code: True if ok, False if the window couldnât be created.

            Source: https://docs.wxpython.org/wx.HVScrolledWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.HVScrolledWindow.html
        """



class Icon(GDIObject):
    """ An icon is a small rectangular bitmap usually used for denoting a
minimized application.

        Source: https://docs.wxpython.org/wx.Icon.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def CopyFromBitmap(self, bmp: 'Bitmap') -> None:
        """ Copies bmp  bitmap to this icon.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def CreateFromHICON(self, hicon) -> bool:
        """ MSW-only method to create a wx.Icon from a native icon handle.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetDepth(self) -> int:
        """ Gets the colour depth of the icon.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetHandle(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetHeight(self) -> int:
        """ Gets the height of the icon in physical pixels.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetLogicalHeight(self) -> float:
        """ Gets the height of the icon in logical pixels.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetLogicalSize(self) -> 'Size':
        """ Gets the size of the icon in logical pixels.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetLogicalWidth(self) -> float:
        """ Gets the width of the icon in logical pixels.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetScaleFactor(self) -> float:
        """ Gets the scale factor of this icon.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetSize(self) -> 'Size':
        """ Gets the size of the icon in physical pixels.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def GetWidth(self) -> int:
        """ Gets the width of the icon in physical pixels.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def IsOk(self) -> bool:
        """ Returns True if icon data is present.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def LoadFile(self, name, type=BITMAP_TYPE_ANY, desiredWidth=-1, desiredHeight=-1) -> bool:
        """ Loads an icon from a file or resource.

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def SetDepth(self, depth: int) -> None:
        """ Sets the depth member (does not affect the icon data).

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def SetHandle(self, handle) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def SetHeight(self, height: int) -> None:
        """ Sets the height member (does not affect the icon data).

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def SetWidth(self, width: int) -> None:
        """ Sets the width member (does not affect the icon data).

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Icon.html
        """

    Depth: int  # See GetDepth and SetDepth
    Handle: int  # See GetHandle and SetHandle
    Height: int  # See GetHeight and SetHeight
    LogicalHeight: float  # See GetLogicalHeight
    LogicalSize: 'Size'  # See GetLogicalSize
    LogicalWidth: float  # See GetLogicalWidth
    ScaleFactor: float  # See GetScaleFactor
    Size: 'Size'  # See GetSize
    Width: int  # See GetWidth and SetWidth



class IconBundle(GDIObject):
    """ This class contains multiple copies of an icon in different sizes.

        Source: https://docs.wxpython.org/wx.IconBundle.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.IconBundle.html
        """

    def AddIcon(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.IconBundle.html
        """

    def GetIcon(self, *args, **kw) -> 'Icon':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.IconBundle.html
        """

    def GetIconByIndex(self, n: int) -> 'Icon':
        """ return the icon at index (must be < GetIconCount )

            Source: https://docs.wxpython.org/wx.IconBundle.html
        """

    def GetIconCount(self) -> int:
        """ return the number of available icons

            Source: https://docs.wxpython.org/wx.IconBundle.html
        """

    def GetIconOfExactSize(self, size: Union[tuple[int, int], 'Size']) -> 'Icon':
        """ Returns the icon with exactly the given size or wx.NullIcon       if this size is not available.

            Source: https://docs.wxpython.org/wx.IconBundle.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if the bundle doesnât contain any icons, False otherwise (in which case a call to GetIcon   with default parameter should return a valid icon).

            Source: https://docs.wxpython.org/wx.IconBundle.html
        """

    Icon: 'Icon'  # See GetIcon
    IconCount: int  # See GetIconCount



class IconizeEvent(Event):
    """ An event being sent when the frame is iconized (minimized) or
restored.

        Source: https://docs.wxpython.org/wx.IconizeEvent.html
    """
    def __init__(self, id=0, iconized=True) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.IconizeEvent.html
        """

    def IsIconized(self) -> bool:
        """ Returns True if the frame has been iconized, False if it has been restored.

            Source: https://docs.wxpython.org/wx.IconizeEvent.html
        """



class IconLocation:
    """ IconLocation is a tiny class describing the location of an
(external, i.e.

        Source: https://docs.wxpython.org/wx.IconLocation.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    def GetFileName(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    def GetIndex(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the object is valid, i.e. was properly initialized, and False otherwise.

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    def SetFileName(self, filename: str) -> None:
        """ filename (string) â

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    def SetIndex(self, num) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.IconLocation.html
        """

    FileName: str  # See GetFileName and SetFileName
    Index: int  # See GetIndex and SetIndex



class IdleEvent(Event):
    """ This class is used for idle events, which are generated when the
system becomes idle.

        Source: https://docs.wxpython.org/wx.IdleEvent.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.IdleEvent.html
        """

    @staticmethod
    def GetMode() -> 'IdleMode':
        """ Static function returning a value specifying how wxWidgets will send idle events: to all windows, or only to those which specify that they will process the events.

            Source: https://docs.wxpython.org/wx.IdleEvent.html
        """

    def MoreRequested(self) -> bool:
        """ Returns True if the OnIdle function processing this event requested more processing time.

            Source: https://docs.wxpython.org/wx.IdleEvent.html
        """

    def RequestMore(self, needMore: bool=True) -> None:
        """ Tells wxWidgets that more processing is required.

            Source: https://docs.wxpython.org/wx.IdleEvent.html
        """

    @staticmethod
    def SetMode(mode: IdleMode) -> None:
        """ Static function for specifying how wxWidgets will send idle events: to all windows, or only to those which specify that they will process the events.

            Source: https://docs.wxpython.org/wx.IdleEvent.html
        """



IDLE_PROCESS_SPECIFIED: int

IDLE_PROCESS_ALL: int

class IdManager:
    """ IdManager is responsible for allocating and releasing window IDs.

        Source: https://docs.wxpython.org/wx.IdManager.html
    """
    @staticmethod
    def ReserveId(count: int=1) -> int:
        """ Called directly by wx.Window.NewControlId , this function will create a new ID or range of IDs.

            Source: https://docs.wxpython.org/wx.IdManager.html
        """

    @staticmethod
    def UnreserveId(id, count=1) -> None:
        """ Called directly by wx.Window.UnreserveControlId , this function will unreserve an ID or range of IDs that is currently reserved.

            Source: https://docs.wxpython.org/wx.IdManager.html
        """



class IFFHandler(ImageHandler):
    """ This is the image handler for the IFF format.

        Source: https://docs.wxpython.org/wx.IFFHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.IFFHandler.

            Source: https://docs.wxpython.org/wx.IFFHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.IFFHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.IFFHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.IFFHandler.html
        """



class Image(Object):
    """ This class encapsulates a platform-independent image.

        Source: https://docs.wxpython.org/wx.Image.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def AddHandler(handler: 'ImageHandler') -> None:
        """ Register an image handler.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def AdjustChannels(self, factor_red, factor_green, factor_blue, factor_alpha=1.0) -> 'Image':
        """ This function muliplies all 4 channels (red, green, blue, alpha) with
a factor (around 1.0). Useful for gamma correction, colour correction
and to add a certain amount of transparency to a image (fade in fade
out effects). If factor_alpha is given but the original image has no
alpha channel then a alpha channel will be added.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Blur(self, blurRadius: int) -> 'Image':
        """ Blurs the image in both horizontal and vertical directions by the specified pixel blurRadius.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def BlurHorizontal(self, blurRadius: int) -> 'Image':
        """ Blurs the image in the horizontal direction only.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def BlurVertical(self, blurRadius: int) -> 'Image':
        """ Blurs the image in the vertical direction only.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def CanRead(*args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ChangeBrightness(self, factor: float) -> None:
        """ Changes the brightness (value) of each pixel in the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ChangeHSV(self, angleH, factorS, factorV) -> None:
        """ Changes the hue, the saturation and the brightness (value) of each pixel in the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ChangeLightness(self, alpha: int) -> 'Image':
        """ Returns a changed version of the image based on the given lightness.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ChangeSaturation(self, factor: float) -> None:
        """ Changes the saturation of each pixel in the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def CleanUpHandlers() -> None:
        """ Deletes all image handlers.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Clear(self, value: int=0) -> None:
        """ Initialize the image data with zeroes (the default) or with the byte value given as value.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ClearAlpha(self) -> None:
        """ Removes the alpha channel from the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ComputeHistogram(self, histogram: 'ImageHistogram') -> int:
        """ Computes the histogram of the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ConvertAlphaToMask(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ConvertToBitmap(self, depth=-1) -> None:
        """ Convert the image to a wx.Bitmap.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ConvertToDisabled(self, brightness: int=255) -> 'Image':
        """ Returns disabled (dimmed) version of the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ConvertToGreyscale(self, *args, **kw) -> 'Image':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ConvertToMono(self, r, g, b) -> 'Image':
        """ Returns monochromatic version of the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ConvertToMonoBitmap(self, red, green, blue) -> None:
        """ Creates a monochrome version of the image and returns it as a wx.Bitmap.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def ConvertToRegion(self, R=-1, G=-1, B=-1, tolerance=0) -> 'Region':
        """ Create a wx.Region where the transparent areas match the given RGB values.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Copy(self) -> 'Image':
        """ Returns an identical copy of this image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Create(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Destroy(self) -> None:
        """ Destroys the image data.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def FindFirstUnusedColour(self, startR=1, startG=0, startB=0) -> tuple:
        """ Finds the first colour that is never used in the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def FindHandler(*args, **kw) -> 'ImageHandler':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def FindHandlerMime(mimetype: str) -> 'ImageHandler':
        """ Finds the handler associated with the given MIME type.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetAlpha(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetAlphaBuffer(self) -> Any:
        """ Returns a writable Python buffer object that is pointing at the Alpha
data buffer inside the Image. You need to ensure that you do
not use this buffer object after the image has been destroyed.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetBlue(self, x, y) -> int:
        """ Returns the blue intensity at the given coordinate.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetData(self) -> Any:
        """ Returns a copy of the RGB bytes of the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetDataBuffer(self) -> Any:
        """ Returns a writable Python buffer object that is pointing at the RGB
image data buffer inside the Image. You need to ensure that you do
not use this buffer object after the image has been destroyed.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def GetDefaultLoadFlags() -> int:
        """ Returns the currently used default file load flags.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetGreen(self, x, y) -> int:
        """ Returns the green intensity at the given coordinate.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetHeight(self) -> int:
        """ Gets the height of the image in pixels.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def GetImageCount(*args, **kw) -> None:
        """ If the image file contains more than one image and the image handler is capable of retrieving these individually, this function will return the number of available images.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def GetImageExtWildcard() -> str:
        """ Iterates all registered   wx.ImageHandler  objects, and returns a string containing file extension masks suitable for passing to file open/save dialog boxes.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetLoadFlags(self) -> int:
        """ Returns the file load flags used for this object.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetMaskBlue(self) -> int:
        """ Gets the blue value of the mask colour.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetMaskGreen(self) -> int:
        """ Gets the green value of the mask colour.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetMaskRed(self) -> int:
        """ Gets the red value of the mask colour.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetOption(self, name: str) -> str:
        """ Gets a user-defined string-valued option.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetOptionInt(self, name: str) -> int:
        """ Gets a user-defined integer-valued option.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetOrFindMaskColour(self) -> tuple:
        """ Get the current mask colour or find a suitable unused colour that could be used as a mask colour.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetPalette(self) -> 'Palette':
        """ Returns the palette associated with the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetRed(self, x, y) -> int:
        """ Returns the red intensity at the given coordinate.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetSize(self) -> 'Size':
        """ Returns the size of the image in pixels.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetSubImage(self, rect: 'Rect') -> 'Image':
        """ Returns a sub image of the current one as long as the rect belongs entirely to the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetType(self) -> 'BitmapType':
        """ Gets the type of image found by LoadFile   or specified with SaveFile .

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def GetWidth(self) -> int:
        """ Gets the width of the image in pixels.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def HSVtoRGB(hsv: HSVValue) -> RGBValue:
        """ Converts a color in HSV color space to RGB color space.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def HasAlpha(self) -> bool:
        """ Returns True if this image has alpha channel, False otherwise.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def HasMask(self) -> bool:
        """ Returns True if there is a mask active, False otherwise.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def HasOption(self, name: str) -> bool:
        """ Returns True if the given option is present.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def InitAlpha(self) -> None:
        """ Initializes the image alpha channel data.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def InitStandardHandlers() -> None:
        """ Internal use only.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def InsertHandler(handler: 'ImageHandler') -> None:
        """ Adds a handler at the start of the static list of format handlers.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def IsOk(self) -> bool:
        """ Returns True if image data is present.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def IsTransparent(self, x, y, threshold=IMAGE_ALPHA_THRESHOLD) -> bool:
        """ Returns True if the given pixel is transparent, i.e. either has the mask colour if this image has a mask or if this image has alpha channel and alpha value of this pixel is strictly less than threshold.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def LoadFile(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Mirror(self, horizontally: bool=True) -> 'Image':
        """ Returns a mirrored copy of the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Paste(self, image, x, y, alphaBlend=IMAGE_ALPHA_BLEND_OVER) -> None:
        """ Copy the data of the given image  to the specified position in this image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def RGBtoHSV(rgb: RGBValue) -> HSVValue:
        """ Converts a color in RGB color space to HSV color space.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def RemoveHandler(name: str) -> bool:
        """ Finds the handler with the given name, and removes it.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Replace(self, r1, g1, b1, r2, g2, b2) -> None:
        """ Replaces the colour specified by r1,g1,b1 by the colour r2,g2,b2.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Rescale(self, width, height, quality=IMAGE_QUALITY_NORMAL) -> 'Image':
        """ Changes the size of the image in-place by scaling it: after a call to this function,the image will have the given width and height.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Resize(self, size, pos, red=-1, green=-1, blue=-1) -> 'Image':
        """ Changes the size of the image in-place without scaling it by adding either a border with the given colour or cropping as necessary.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Rotate(self, angle, rotationCentre, interpolating=True, offsetAfterRotation=None) -> 'Image':
        """ Rotates the image about the given point, by angle  radians.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Rotate180(self) -> 'Image':
        """ Returns a copy of the image rotated by 180 degrees.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Rotate90(self, clockwise: bool=True) -> 'Image':
        """ Returns a copy of the image rotated 90 degrees in the direction indicated by clockwise.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def RotateHue(self, angle: float) -> None:
        """ Rotates the hue of each pixel in the image by angle, which is a float in the range [-1.0..+1.0], where -1.0 corresponds to -360 degrees and +1.0 corresponds to +360 degrees.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SaveFile(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Scale(self, width, height, quality=IMAGE_QUALITY_NORMAL) -> 'Image':
        """ Returns a scaled version of the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetAlpha(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetAlphaBuffer(self, alpha) -> None:
        """ Sets the internal image alpha pointer to point at a Python buffer
object.  This can save making an extra copy of the data but you must
ensure that the buffer object lives lives at least as long as the
Image does.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetData(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetDataBuffer(self, *args, **kw) -> None:
        """ Sets the internal image data pointer to point at a Python buffer
object.  This can save making an extra copy of the data but you must
ensure that the buffer object lives lives at least as long as the
Image does.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    @staticmethod
    def SetDefaultLoadFlags(flags: int) -> None:
        """ Sets the default value for the flags used for loading image files.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetLoadFlags(self, flags: int) -> None:
        """ Sets the flags used for loading image files by this object.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetMask(self, hasMask: bool=True) -> None:
        """ Specifies whether there is a mask or not.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetMaskColour(self, red, green, blue) -> None:
        """ Sets the mask colour for this image (and tells the image to use the mask).

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetMaskFromImage(self, mask, mr, mg, mb) -> bool:
        """ Sets imageâs mask so that the pixels that have RGB value of mr,mg,mb in mask will be masked in the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetOption(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetPalette(self, palette: 'Palette') -> None:
        """ Associates a palette with the image.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetRGB(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def SetType(self, type: BitmapType) -> None:
        """ Set the type of image returned by GetType .

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def Size(self, size, pos, red=-1, green=-1, blue=-1) -> 'Image':
        """ Returns a resized version of this image without scaling it by adding either a border with the given colour or cropping as necessary.

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Image.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Image.html
        """

    Height: int  # See GetHeight
    MaskBlue: int  # See GetMaskBlue
    MaskGreen: int  # See GetMaskGreen
    MaskRed: int  # See GetMaskRed
    Type: BitmapType  # See GetType and SetType
    Width: int  # See GetWidth



BITMAP_TYPE_BMP: int

BITMAP_TYPE_GIF: int

BITMAP_TYPE_JPEG: int

BITMAP_TYPE_PNG: int

BITMAP_TYPE_PCX: int

BITMAP_TYPE_PNM: int

BITMAP_TYPE_TIFF: int

BITMAP_TYPE_TGA: int

BITMAP_TYPE_XPM: int

BITMAP_TYPE_ICO: int

BITMAP_TYPE_CUR: int

BITMAP_TYPE_ANI: int

BITMAP_TYPE_ANY: int

class ImageDataObject(CustomDataObject):
    """ ImageDataObject is a specialization of DataObject for image data.

        Source: https://docs.wxpython.org/wx.ImageDataObject.html
    """
    def __init__(self, image: 'Image'=NullImage) -> None:
        """ Constructor, optionally passing an image (otherwise use SetImage   later).

            Source: https://docs.wxpython.org/wx.ImageDataObject.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.ImageDataObject.html
        """

    def GetImage(self) -> 'Image':
        """ Returns the image associated with the data object.

            Source: https://docs.wxpython.org/wx.ImageDataObject.html
        """

    def SetData(self, format, buf) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ImageDataObject.html
        """

    def SetImage(self, image: 'Image') -> None:
        """ Sets the image stored by the data object.

            Source: https://docs.wxpython.org/wx.ImageDataObject.html
        """

    AllFormats: None  # See GetAllFormats
    Image: 'Image'  # See GetImage and SetImage



class ImageHandler(Object):
    """ This is the base class for implementing image file loading/saving, and
image creation from data.

        Source: https://docs.wxpython.org/wx.ImageHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def CanRead(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def DoGetImageCount(self, stream: 'InputStream') -> int:
        """ Called to get the number of images available in a multi-image file type, if supported.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def GetAltExtensions(self) -> list[str]:
        """ Returns the other file extensions associated with this handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def GetExtension(self) -> str:
        """ Gets the preferred file extension associated with this handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def GetImageCount(self, stream: 'InputStream') -> int:
        """ If the image file contains more than one image and the image handler is capable of retrieving these individually, this function will return the number of available images.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def GetMimeType(self) -> str:
        """ Gets the MIME type associated with this handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def GetName(self) -> str:
        """ Gets the name of this handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def GetType(self) -> 'BitmapType':
        """ Gets the image type associated with this handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def SetAltExtensions(self, extensions: list[str]) -> None:
        """ Sets the alternative file extensions associated with this handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def SetExtension(self, extension: str) -> None:
        """ Sets the preferred file extension associated with this handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def SetMimeType(self, mimetype: str) -> None:
        """ Sets the handler MIME type.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def SetName(self, name: str) -> None:
        """ Sets the handler name.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    def SetType(self, type: BitmapType) -> None:
        """ Sets the bitmap type for the handler.

            Source: https://docs.wxpython.org/wx.ImageHandler.html
        """

    AltExtensions: list[str]  # See GetAltExtensions and SetAltExtensions
    Extension: str  # See GetExtension and SetExtension
    MimeType: str  # See GetMimeType and SetMimeType
    Name: str  # See GetName and SetName
    Type: BitmapType  # See GetType and SetType



class ImageHistogram:
    """ startR (int) â 

        Source: https://docs.wxpython.org/wx.ImageHistogram.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ImageHistogram.html
        """

    def FindFirstUnusedColour(self, startR=1, startG=0, startB=0) -> tuple:
        """ startR (int) â

            Source: https://docs.wxpython.org/wx.ImageHistogram.html
        """

    @staticmethod
    def MakeKey(r, g, b) -> int:
        """ r (int) â

            Source: https://docs.wxpython.org/wx.ImageHistogram.html
        """



class ImageList(Object):
    """ A ImageList contains a list of images, which are stored in an
unspecified form.

        Source: https://docs.wxpython.org/wx.ImageList.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def Add(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def Create(self, width, height, mask=True, initialCount=1) -> bool:
        """ Initializes the list.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def Destroy(self) -> None:
        """ Destroys the current list.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def Draw(self, index, dc, x, y, flags=IMAGELIST_DRAW_NORMAL, solidBackground=False) -> bool:
        """ Draws a specified image onto a device context.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def GetBitmap(self, index: int) -> 'Bitmap':
        """ Returns the bitmap corresponding to the given index.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def GetIcon(self, index: int) -> 'Icon':
        """ Returns the icon corresponding to the given index.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def GetImageCount(self) -> int:
        """ Returns the number of images in the list.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def GetSize(self, *args, **kw) -> tuple:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def Remove(self, index: int) -> bool:
        """ Removes the image at the given position.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def RemoveAll(self) -> bool:
        """ Removes all the images in the list.

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    def Replace(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ImageList.html
        """

    ImageCount: int  # See GetImageCount
    Size: tuple  # See GetSize



IMAGELIST_DRAW_NORMAL: int

IMAGELIST_DRAW_TRANSPARENT: int

IMAGELIST_DRAW_SELECTED: int

IMAGELIST_DRAW_FOCUSED: int

class IndividualLayoutConstraint(Object):
    """ sibling (wx.Window) â 

        Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def Above(self, sibling, margin=LAYOUT_DEFAULT_MARGIN) -> None:
        """ sibling (wx.Window) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def Absolute(self, val: int) -> None:
        """ val (int) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def AsIs(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def Below(self, sibling, margin=LAYOUT_DEFAULT_MARGIN) -> None:
        """ sibling (wx.Window) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetDone(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetEdge(self, which, thisWin, other) -> int:
        """ which (Edge) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetMargin(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetMyEdge(self) -> 'Edge':
        """ wx.Edge

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetOtherEdge(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetOtherWindow(self) -> 'Window':
        """ wx.Window

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetPercent(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetRelationship(self) -> 'Relationship':
        """ wx.Relationship

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def GetValue(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def LeftOf(self, sibling, margin=LAYOUT_DEFAULT_MARGIN) -> None:
        """ sibling (wx.Window) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def PercentOf(self, otherW, wh, per) -> None:
        """ otherW (wx.Window) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def ResetIfWin(self, otherW: 'Window') -> bool:
        """ otherW (wx.Window) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def RightOf(self, sibling, margin=LAYOUT_DEFAULT_MARGIN) -> None:
        """ sibling (wx.Window) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def SameAs(self, otherW, edge, margin=LAYOUT_DEFAULT_MARGIN) -> None:
        """ otherW (wx.Window) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def SatisfyConstraint(self, constraints, win) -> bool:
        """ constraints (wx.LayoutConstraints) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def Set(self, rel, otherW, otherE, val=0, margin=LAYOUT_DEFAULT_MARGIN) -> None:
        """ rel (Relationship) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def SetDone(self, d: bool) -> None:
        """ d (bool) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def SetEdge(self, which: Edge) -> None:
        """ which (Edge) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def SetMargin(self, m: int) -> None:
        """ m (int) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def SetRelationship(self, r: Relationship) -> None:
        """ r (Relationship) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def SetValue(self, v: int) -> None:
        """ v (int) â

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    def Unconstrained(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.IndividualLayoutConstraint.html
        """

    Done: bool  # See GetDone and SetDone
    Margin: int  # See GetMargin and SetMargin
    MyEdge: 'Edge'  # See GetMyEdge
    OtherEdge: int  # See GetOtherEdge
    OtherWindow: 'Window'  # See GetOtherWindow
    Percent: int  # See GetPercent
    Relationship: Relationship  # See GetRelationship and SetRelationship
    Value: int  # See GetValue and SetValue



class InfoBar(Control):
    """ An info bar is a transient window shown at top or bottom of its parent
window to display non-critical information to the user.

        Source: https://docs.wxpython.org/wx.InfoBar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def AddButton(self, btnid, label="") -> None:
        """ Add a button to be shown in the info bar.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def Create(self, parent, winid=ID_ANY) -> bool:
        """ Create the info bar window.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def Dismiss(self) -> None:
        """ Hide the info bar window.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def GetButtonCount(self) -> int:
        """ Returns the number of currently shown buttons.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def GetButtonId(self, idx: int) -> int:
        """ Returns the ID of the button at the given position.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def GetEffectDuration(self) -> int:
        """ Return the effect animation duration currently used.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def GetHideEffect(self) -> 'ShowEffect':
        """ Return the effect currently used for hiding the bar.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def GetShowEffect(self) -> 'ShowEffect':
        """ Return the effect currently used for showing the bar.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def HasButtonId(self, btnid: int) -> bool:
        """ Returns whether a button with the given ID is currently shown.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def RemoveButton(self, btnid: int) -> None:
        """ Remove a button previously added by AddButton .

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def SetEffectDuration(self, duration: int) -> None:
        """ Set the duration of the animation used when showing or hiding the bar.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def SetFont(self, font: 'Font') -> bool:
        """ Overridden base class methods changes the font of the text message.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def SetShowHideEffects(self, showEffect, hideEffect) -> None:
        """ Set the effects to use when showing and hiding the bar.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    def ShowMessage(self, msg, flags=ICON_INFORMATION) -> None:
        """ Show a message in the bar.

            Source: https://docs.wxpython.org/wx.InfoBar.html
        """

    ButtonCount: int  # See GetButtonCount
    EffectDuration: int  # See GetEffectDuration and SetEffectDuration
    HideEffect: 'ShowEffect'  # See GetHideEffect
    ShowEffect: 'ShowEffect'  # See GetShowEffect



SHOW_EFFECT_NONE: int

SHOW_EFFECT_SLIDE_TO_BOTTOM: int

SHOW_EFFECT_SLIDE_TO_TOP: int

class InitDialogEvent(Event):
    """ A InitDialogEvent is sent as a dialog or panel is being initialised.

        Source: https://docs.wxpython.org/wx.InitDialogEvent.html
    """
    def __init__(self, id: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.InitDialogEvent.html
        """



class InputStream(StreamBase):
    """ InputStream is an abstract base class which may not be used
directly.

        Source: https://docs.wxpython.org/wx.InputStream.html
    """
    def __init__(self) -> None:
        """ Creates a dummy input stream.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def CanRead(self) -> bool:
        """ Returns True if some data is available in the stream right now, so that calling Read   wouldnât block.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def Eof(self) -> bool:
        """ Returns True after an attempt has been made to read past the end of the stream.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def GetC(self) -> int:
        """ Returns the first character in the input queue and removes it, blocking until it appears if necessary.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def LastRead(self) -> int:
        """ Returns the last number of bytes read.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def Peek(self) -> int:
        """ Returns the first character in the input queue without removing it.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def Read(self, *args, **kw) -> 'InputStream':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def ReadAll(self, buffer, size) -> bool:
        """ Reads exactly the specified number of bytes into the buffer.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def SeekI(self, pos, mode=FromStart) -> 'FileOffset':
        """ Changes the stream current position.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def TellI(self) -> 'FileOffset':
        """ Returns the current stream position or InvalidOffset   if itâs not available (e.g.

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def Ungetch(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def close(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def eof(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def flush(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def read(self, *args, **kw) -> Any:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def readline(self, *args, **kw) -> Any:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def readlines(self, *args, **kw) -> Any:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def seek(self, offset, whence=0) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    def tell(self) -> 'FileOffset':
        """ wx.FileOffset

            Source: https://docs.wxpython.org/wx.InputStream.html
        """

    C: int  # See GetC



class InternetFSHandler(FileSystemHandler):
    """ A file system handler for accessing files from internet servers.

        Source: https://docs.wxpython.org/wx.InternetFSHandler.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.InternetFSHandler.html
        """



class ItemAttr:
    """ Represents the attributes (colour, font, â¦) of an item of a control
with multiple items such as e.g.

        Source: https://docs.wxpython.org/wx.ItemAttr.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def GetBackgroundColour(self) -> 'Colour':
        """ Returns the currently set background colour.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def GetFont(self) -> 'Font':
        """ Returns the currently set font.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def GetTextColour(self) -> 'Colour':
        """ Returns the currently set text colour.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def HasBackgroundColour(self) -> bool:
        """ Returns True if the currently set background colour is valid.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def HasColours(self) -> bool:
        """ Returns True if either text or background colour is set.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def HasFont(self) -> bool:
        """ Returns True if the currently set font is valid.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def HasTextColour(self) -> bool:
        """ Returns True if the currently set text colour is valid.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def IsDefault(self) -> bool:
        """ Returns True if this object has no custom attributes set.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def SetBackgroundColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets a new background colour.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def SetFont(self, font: 'Font') -> None:
        """ Sets a new font.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def SetTextColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets a new text colour.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Compare two item attributes for inequality.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Compare two item attributes for equality.

            Source: https://docs.wxpython.org/wx.ItemAttr.html
        """

    BackgroundColour: Union[int, str, 'Colour']  # See GetBackgroundColour and SetBackgroundColour
    Font: 'Font'  # See GetFont and SetFont
    TextColour: Union[int, str, 'Colour']  # See GetTextColour and SetTextColour



class ItemContainerImmutable:
    """ ItemContainer defines an interface which is implemented by all
controls which have string subitems each of which may be selected.

        Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def FindString(self, string, caseSensitive=False) -> int:
        """ Finds an item whose label matches the given string.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def GetCount(self) -> int:
        """ Returns the number of items in the control.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def GetSelection(self) -> int:
        """ Returns the index of the selected item or  NOT_FOUND   if no item is selected.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def GetString(self, n: int) -> str:
        """ Returns the label of the item with the given index.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def GetStringSelection(self) -> str:
        """ Returns the label of the selected item or an empty string if no item is selected.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def GetStrings(self) -> list[str]:
        """ Returns the array of the labels of all items in the control.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if the control is empty or False if it has some items.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def Select(self, n: int) -> None:
        """ This is the same as SetSelection   and exists only because it is slightly more natural for controls which support multiple selection.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def SetSelection(self, n: int) -> None:
        """ Sets the selection to the given item n  or removes the selection entirely if n  ==  NOT_FOUND .

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def SetString(self, n, string) -> None:
        """ Sets the label for the given item.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    def SetStringSelection(self, string: str) -> bool:
        """ Selects the item with the specified string in the control.

            Source: https://docs.wxpython.org/wx.ItemContainerImmutable.html
        """

    Count: int  # See GetCount
    Selection: int  # See GetSelection and SetSelection
    StringSelection: str  # See GetStringSelection and SetStringSelection
    Strings: list[str]  # See GetStrings



class JoystickEvent(Event):
    """ This event class contains information about joystick events,
particularly events received by windows.

        Source: https://docs.wxpython.org/wx.JoystickEvent.html
    """
    def __init__(self, eventType=wxEVT_NULL, state=0, joystick=JOYSTICK1, change=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def ButtonDown(self, button: int=JOY_BUTTON_ANY) -> bool:
        """ Returns True if the event was a down event from the specified button (or any button).

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def ButtonIsDown(self, button: int=JOY_BUTTON_ANY) -> bool:
        """ Returns True if the specified button (or any button) was in a down state.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def ButtonUp(self, button: int=JOY_BUTTON_ANY) -> bool:
        """ Returns True if the event was an up event from the specified button (or any button).

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def GetButtonChange(self) -> int:
        """ Returns the identifier of the button changing state.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def GetButtonOrdinal(self) -> int:
        """ Returns the 0-indexed ordinal of the button changing state.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def GetButtonState(self) -> int:
        """ Returns the down state of the buttons.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def GetJoystick(self) -> int:
        """ Returns the identifier of the joystick generating the event - one of wx.JOYSTICK1 and wx.JOYSTICK2.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the x, y position of the joystick event.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def GetZPosition(self) -> int:
        """ Returns the z position of the joystick event.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def IsButton(self) -> bool:
        """ Returns True if this was a button up or down event (not  âis any button down?â).

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def IsMove(self) -> bool:
        """ Returns True if this was an x, y move event.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    def IsZMove(self) -> bool:
        """ Returns True if this was a z move event.

            Source: https://docs.wxpython.org/wx.JoystickEvent.html
        """

    ButtonChange: int  # See GetButtonChange
    ButtonOrdinal: int  # See GetButtonOrdinal
    ButtonState: int  # See GetButtonState
    Joystick: int  # See GetJoystick
    Position: 'Point'  # See GetPosition
    ZPosition: int  # See GetZPosition



EVT_JOY_BUTTON_DOWN: int  # Process a  wxEVT_JOY_BUTTON_DOWN   event.

EVT_JOY_BUTTON_UP: int  # Process a  wxEVT_JOY_BUTTON_UP   event.

EVT_JOY_MOVE: int  # Process a  wxEVT_JOY_MOVE   event.

EVT_JOY_ZMOVE: int  # Process a  wxEVT_JOY_ZMOVE   event.

EVT_JOYSTICK_EVENTS: int  # Processes all joystick events. ^^

JOYSTICK1: int

JOYSTICK2: int

class JPEGHandler(ImageHandler):
    """ This is the image handler for the JPEG format.

        Source: https://docs.wxpython.org/wx.JPEGHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.JPEGHandler.

            Source: https://docs.wxpython.org/wx.JPEGHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.JPEGHandler.html
        """

    @staticmethod
    def GetLibraryVersionInfo() -> 'VersionInfo':
        """ Retrieve the version information about the JPEG library used by this handler.

            Source: https://docs.wxpython.org/wx.JPEGHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.JPEGHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.JPEGHandler.html
        """



class KeyboardState:
    """ Provides methods for testing the state of the keyboard modifier keys.

        Source: https://docs.wxpython.org/wx.KeyboardState.html
    """
    def __init__(self, controlDown=False, shiftDown=False, altDown=False, metaDown=False) -> None:
        """ Constructor initializes the modifier key settings.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def AltDown(self) -> bool:
        """ Returns True if the Alt key is pressed.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def CmdDown(self) -> bool:
        """ Returns True if the key used for command accelerators is pressed.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def ControlDown(self) -> bool:
        """ Returns True if the Control key or Apple/Command key under macOS is pressed.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def GetModifiers(self) -> int:
        """ Return the bit mask of all pressed modifier keys.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def HasAnyModifiers(self) -> bool:
        """ Returns True if any modifiers at all are pressed.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def HasModifiers(self) -> bool:
        """ Returns True if Control or Alt are pressed.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def MetaDown(self) -> bool:
        """ Returns True if the Meta/Windows/Apple key is pressed.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def RawControlDown(self) -> bool:
        """ Returns True if the Control key (also under macOS).

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def SetAltDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def SetControlDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def SetMetaDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def SetRawControlDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def SetShiftDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    def ShiftDown(self) -> bool:
        """ Returns True if the Shift key is pressed.

            Source: https://docs.wxpython.org/wx.KeyboardState.html
        """

    altDown: Any  # See AltDown and SetAltDown
    cmdDown: Any  # See CmdDown
    controlDown: Any  # See ControlDown and SetControlDown
    metaDown: Any  # See MetaDown and SetMetaDown
    rawControlDown: Any  # See RawControlDown and SetRawControlDown
    shiftDown: Any  # See ShiftDown and SetShiftDown



class KeyEvent(Event,KeyboardState):
    """ This event class contains information about key press and release
events.

        Source: https://docs.wxpython.org/wx.KeyEvent.html
    """
    def __init__(self, keyEventType: int=wxEVT_NULL) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def DoAllowNextEvent(self) -> None:
        """ Allow normal key events generation.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def GetKeyCode(self) -> int:
        """ Returns the key code of the key that generated this event.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def GetPosition(self) -> 'Point':
        """ Obtains the position (in client coordinates) at which the key was pressed.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def GetRawKeyCode(self) -> 'int':
        """ Returns the raw key code for this event.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def GetRawKeyFlags(self) -> 'int':
        """ Returns the low level key flags for this event.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def GetUnicodeKey(self) -> int:
        """ Returns the Unicode character corresponding to this key event.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def GetX(self) -> 'Coord':
        """ Returns the X position (in client coordinates) of the event.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def GetY(self) -> 'Coord':
        """ Returns the Y position (in client coordinates) of the event.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def IsAutoRepeat(self) -> bool:
        """ Returns True if this event is an auto-repeat of the key, False if this is the initial key press.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def IsKeyInCategory(self, category: int) -> bool:
        """ Returns True if the key is in the given key category.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def IsNextEventAllowed(self) -> bool:
        """ Returns True if DoAllowNextEvent   had been called, False by default.

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def SetKeyCode(self, keyCode) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def SetRawKeyCode(self, rawKeyCode) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def SetRawKeyFlags(self, rawFlags) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    def SetUnicodeKey(self, uniChar) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.KeyEvent.html
        """

    KeyCode: int  # See GetKeyCode and SetKeyCode
    Position: 'Point'  # See GetPosition
    RawKeyCode: 'int'  # See GetRawKeyCode and SetRawKeyCode
    RawKeyFlags: 'int'  # See GetRawKeyFlags and SetRawKeyFlags
    UnicodeKey: int  # See GetUnicodeKey and SetUnicodeKey
    X: 'Coord'  # See GetX
    Y: 'Coord'  # See GetY



class LanguageInfo:
    """ Encapsulates a Language identifier together with OS-specific
information related to that language.

        Source: https://docs.wxpython.org/wx.LanguageInfo.html
    """
    def GetCanonicalWithRegion(self) -> str:
        """ Return the canonical locale name including the region, if known.

            Source: https://docs.wxpython.org/wx.LanguageInfo.html
        """

    def GetLocaleName(self) -> str:
        """ Return the locale name corresponding to this language usable with  setlocale()   on the current system.

            Source: https://docs.wxpython.org/wx.LanguageInfo.html
        """

    CanonicalName: Any  # A public C++ attribute of type string. Canonical name of the language, e.g.  fr_FR .
    CanonicalRef: Any  # A public C++ attribute of type string. Canonical reference including region.
    CanonicalWithRegion: str  # See GetCanonicalWithRegion
    Description: Any  # A public C++ attribute of type string. Human-readable name of the language in English.
    DescriptionNative: Any  # A public C++ attribute of type string. Human-readable name of the language in this language itself.
    Language: Any  # A public C++ attribute of type int.   wx.Language  id.
    LayoutDirection: Any  # A public C++ attribute of type LayoutDirection     . The layout direction used for this language.
    LocaleName: str  # See GetLocaleName
    LocaleTag: Any  # A public C++ attribute of type string. Tag for locale in BCP 47-like notation.



LANGUAGE_DEFAULT: int

LANGUAGE_UNKNOWN: int

LANGUAGE_ABKHAZIAN: int

LANGUAGE_AFAR: int

LANGUAGE_AFAR_DJIBOUTI: int

LANGUAGE_AFAR_ERITREA: int

LANGUAGE_AFAR_ETHIOPIA: int

LANGUAGE_AFRIKAANS: int

LANGUAGE_AFRIKAANS_NAMIBIA: int

LANGUAGE_AFRIKAANS_SOUTH_AFRICA: int

LANGUAGE_AGHEM: int

LANGUAGE_AGHEM_CAMEROON: int

LANGUAGE_AKAN: int

LANGUAGE_AKAN_GHANA: int

LANGUAGE_ALBANIAN: int

LANGUAGE_ALBANIAN_ALBANIA: int

LANGUAGE_ALBANIAN_KOSOVO: int

LANGUAGE_ALBANIAN_NORTH_MACEDONIA: int

LANGUAGE_ALSATIAN_FRANCE: int

LANGUAGE_AMHARIC: int

LANGUAGE_AMHARIC_ETHIOPIA: int

LANGUAGE_ARABIC: int

LANGUAGE_ARABIC_ALGERIA: int

LANGUAGE_ARABIC_BAHRAIN: int

LANGUAGE_ARABIC_CHAD: int

LANGUAGE_ARABIC_COMOROS: int

LANGUAGE_ARABIC_DJIBOUTI: int

LANGUAGE_ARABIC_EGYPT: int

LANGUAGE_ARABIC_ERITREA: int

LANGUAGE_ARABIC_IRAQ: int

LANGUAGE_ARABIC_ISRAEL: int

LANGUAGE_ARABIC_JORDAN: int

LANGUAGE_ARABIC_KUWAIT: int

LANGUAGE_ARABIC_LEBANON: int

LANGUAGE_ARABIC_LIBYA: int

LANGUAGE_ARABIC_MAURITANIA: int

LANGUAGE_ARABIC_MOROCCO: int

LANGUAGE_ARABIC_OMAN: int

LANGUAGE_ARABIC_PALESTINIAN_AUTHORITY: int

LANGUAGE_ARABIC_QATAR: int

LANGUAGE_ARABIC_SAUDI_ARABIA: int

LANGUAGE_ARABIC_SOMALIA: int

LANGUAGE_ARABIC_SOUTH_SUDAN: int

LANGUAGE_ARABIC_SUDAN: int

LANGUAGE_ARABIC_SYRIA: int

LANGUAGE_ARABIC_TUNISIA: int

LANGUAGE_ARABIC_UAE: int

LANGUAGE_ARABIC_WORLD: int

LANGUAGE_ARABIC_YEMEN: int

LANGUAGE_ARMENIAN: int

LANGUAGE_ARMENIAN_ARMENIA: int

LANGUAGE_ASSAMESE: int

LANGUAGE_ASSAMESE_INDIA: int

LANGUAGE_ASTURIAN: int

LANGUAGE_ASTURIAN_SPAIN: int

LANGUAGE_ASU: int

LANGUAGE_ASU_TANZANIA: int

LANGUAGE_AYMARA: int

LANGUAGE_AZERBAIJANI: int

LANGUAGE_AZERBAIJANI_CYRILLIC: int

LANGUAGE_AZERBAIJANI_CYRILLIC_AZERBAIJAN: int

LANGUAGE_AZERBAIJANI_LATIN: int

LANGUAGE_AZERBAIJANI_LATIN_AZERBAIJAN: int

LANGUAGE_BAFIA: int

LANGUAGE_BAFIA_CAMEROON: int

LANGUAGE_BAMANANKAN: int

LANGUAGE_BAMANANKAN_LATIN: int

LANGUAGE_BAMANANKAN_LATIN_MALI: int

LANGUAGE_BANGLA: int

LANGUAGE_BANGLA_BANGLADESH: int

LANGUAGE_BANGLA_INDIA: int

LANGUAGE_BASAA: int

LANGUAGE_BASAA_CAMEROON: int

LANGUAGE_BASHKIR: int

LANGUAGE_BASHKIR_RUSSIA: int

LANGUAGE_BASQUE: int

LANGUAGE_BASQUE_SPAIN: int

LANGUAGE_BELARUSIAN: int

LANGUAGE_BELARUSIAN_BELARUS: int

LANGUAGE_BEMBA: int

LANGUAGE_BEMBA_ZAMBIA: int

LANGUAGE_BENA: int

LANGUAGE_BENA_TANZANIA: int

LANGUAGE_BIHARI: int

LANGUAGE_BISLAMA: int

LANGUAGE_BLIN: int

LANGUAGE_BLIN_ERITREA: int

LANGUAGE_BODO: int

LANGUAGE_BODO_INDIA: int

LANGUAGE_BOSNIAN: int

LANGUAGE_BOSNIAN_CYRILLIC: int

LANGUAGE_BOSNIAN_CYRILLIC_BOSNIA_AND_HERZEGOVINA: int

LANGUAGE_BOSNIAN_LATIN: int

LANGUAGE_BOSNIAN_LATIN_BOSNIA_AND_HERZEGOVINA: int

LANGUAGE_BRETON: int

LANGUAGE_BRETON_FRANCE: int

LANGUAGE_BULGARIAN: int

LANGUAGE_BULGARIAN_BULGARIA: int

LANGUAGE_BURMESE: int

LANGUAGE_BURMESE_MYANMAR: int

LANGUAGE_CATALAN: int

LANGUAGE_CATALAN_ANDORRA: int

LANGUAGE_CATALAN_FRANCE: int

LANGUAGE_CATALAN_ITALY: int

LANGUAGE_CATALAN_SPAIN: int

LANGUAGE_CEBUANO: int

LANGUAGE_CEBUANO_LATIN: int

LANGUAGE_CEBUANO_LATIN_PHILIPPINES: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT_ARABIC: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT_ARABIC_MOROCCO: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT_LATIN: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT_LATIN_ALGERIA: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT_LATIN_MOROCCO: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT_TIFINAGH: int

LANGUAGE_CENTRAL_ATLAS_TAMAZIGHT_TIFINAGH_MOROCCO: int

LANGUAGE_CENTRAL_KURDISH: int

LANGUAGE_CENTRAL_KURDISH_IRAQ: int

LANGUAGE_CHAKMA: int

LANGUAGE_CHAKMA_CHAKMA: int

LANGUAGE_CHAKMA_CHAKMA_BANGLADESH: int

LANGUAGE_CHAKMA_CHAKMA_INDIA: int

LANGUAGE_CHECHEN: int

LANGUAGE_CHECHEN_RUSSIA: int

LANGUAGE_CHEROKEE: int

LANGUAGE_CHEROKEE_CHEROKEE: int

LANGUAGE_CHEROKEE_US: int

LANGUAGE_CHIGA: int

LANGUAGE_CHIGA_UGANDA: int

LANGUAGE_CHINESE: int

LANGUAGE_CHINESE_CHINA: int

LANGUAGE_CHINESE_HONGKONG: int

LANGUAGE_CHINESE_MACAO: int

LANGUAGE_CHINESE_SIMPLIFIED_EXPLICIT: int

LANGUAGE_CHINESE_SIMPLIFIED_HONGKONG: int

LANGUAGE_CHINESE_SIMPLIFIED_MACAO: int

LANGUAGE_CHINESE_SINGAPORE: int

LANGUAGE_CHINESE_TAIWAN: int

LANGUAGE_CHINESE_TRADITIONAL_EXPLICIT: int

LANGUAGE_CHURCH_SLAVIC: int

LANGUAGE_CHURCH_SLAVIC_RUSSIA: int

LANGUAGE_COLOGNIAN: int

LANGUAGE_COLOGNIAN_GERMANY: int

LANGUAGE_CORNISH: int

LANGUAGE_CORNISH_UK: int

LANGUAGE_CORSICAN: int

LANGUAGE_CORSICAN_FRANCE: int

LANGUAGE_CROATIAN: int

LANGUAGE_CROATIAN_BOSNIA_AND_HERZEGOVINA: int

LANGUAGE_CROATIAN_CROATIA: int

LANGUAGE_CZECH: int

LANGUAGE_CZECH_CZECHIA: int

LANGUAGE_DANISH: int

LANGUAGE_DANISH_DENMARK: int

LANGUAGE_DANISH_GREENLAND: int

LANGUAGE_DARI: int

LANGUAGE_DARI_AFGHANISTAN: int

LANGUAGE_DIVEHI: int

LANGUAGE_DIVEHI_MALDIVES: int

LANGUAGE_DUALA: int

LANGUAGE_DUALA_CAMEROON: int

LANGUAGE_DUTCH: int

LANGUAGE_DUTCH_ARUBA: int

LANGUAGE_DUTCH_BELGIAN: int

LANGUAGE_DUTCH_BONAIRE_SINT_EUSTATIUS_AND_SABA: int

LANGUAGE_DUTCH_CURACAO: int

LANGUAGE_DUTCH_NETHERLANDS: int

LANGUAGE_DUTCH_SINT_MAARTEN: int

LANGUAGE_DUTCH_SURINAME: int

LANGUAGE_DZONGKHA: int

LANGUAGE_DZONGKHA_BHUTAN: int

LANGUAGE_EDO: int

LANGUAGE_EDO_NIGERIA: int

LANGUAGE_EMBU: int

LANGUAGE_EMBU_KENYA: int

LANGUAGE_ENGLISH: int

LANGUAGE_ENGLISH_AMERICAN_SAMOA: int

LANGUAGE_ENGLISH_ANGUILLA: int

LANGUAGE_ENGLISH_ANTIGUA_AND_BARBUDA: int

LANGUAGE_ENGLISH_AUSTRALIA: int

LANGUAGE_ENGLISH_AUSTRIA: int

LANGUAGE_ENGLISH_BAHAMAS: int

LANGUAGE_ENGLISH_BARBADOS: int

LANGUAGE_ENGLISH_BELGIUM: int

LANGUAGE_ENGLISH_BELIZE: int

LANGUAGE_ENGLISH_BERMUDA: int

LANGUAGE_ENGLISH_BOTSWANA: int

LANGUAGE_ENGLISH_BRITISH_INDIAN_OCEAN_TERRITORY: int

LANGUAGE_ENGLISH_BRITISH_VIRGIN_ISLANDS: int

LANGUAGE_ENGLISH_BURUNDI: int

LANGUAGE_ENGLISH_CAMEROON: int

LANGUAGE_ENGLISH_CANADA: int

LANGUAGE_ENGLISH_CARIBBEAN: int

LANGUAGE_ENGLISH_CARIBBEAN_CB: int

LANGUAGE_ENGLISH_CAYMAN_ISLANDS: int

LANGUAGE_ENGLISH_CHRISTMAS_ISLAND: int

LANGUAGE_ENGLISH_COCOS_KEELING_ISLANDS: int

LANGUAGE_ENGLISH_COOK_ISLANDS: int

LANGUAGE_ENGLISH_CYPRUS: int

LANGUAGE_ENGLISH_DENMARK: int

LANGUAGE_ENGLISH_DOMINICA: int

LANGUAGE_ENGLISH_EIRE: int

LANGUAGE_ENGLISH_ERITREA: int

LANGUAGE_ENGLISH_ESWATINI: int

LANGUAGE_ENGLISH_EUROPE: int

LANGUAGE_ENGLISH_FALKLAND_ISLANDS: int

LANGUAGE_ENGLISH_FIJI: int

LANGUAGE_ENGLISH_FINLAND: int

LANGUAGE_ENGLISH_GAMBIA: int

LANGUAGE_ENGLISH_GERMANY: int

LANGUAGE_ENGLISH_GHANA: int

LANGUAGE_ENGLISH_GIBRALTAR: int

LANGUAGE_ENGLISH_GRENADA: int

LANGUAGE_ENGLISH_GUAM: int

LANGUAGE_ENGLISH_GUERNSEY: int

LANGUAGE_ENGLISH_GUYANA: int

LANGUAGE_ENGLISH_HONG_KONG_SAR: int

LANGUAGE_ENGLISH_INDIA: int

LANGUAGE_ENGLISH_INDONESIA: int

LANGUAGE_ENGLISH_ISLE_OF_MAN: int

LANGUAGE_ENGLISH_ISRAEL: int

LANGUAGE_ENGLISH_JAMAICA: int

LANGUAGE_ENGLISH_JERSEY: int

LANGUAGE_ENGLISH_KENYA: int

LANGUAGE_ENGLISH_KIRIBATI: int

LANGUAGE_ENGLISH_LESOTHO: int

LANGUAGE_ENGLISH_LIBERIA: int

LANGUAGE_ENGLISH_MACAO_SAR: int

LANGUAGE_ENGLISH_MADAGASCAR: int

LANGUAGE_ENGLISH_MALAWI: int

LANGUAGE_ENGLISH_MALAYSIA: int

LANGUAGE_ENGLISH_MALTA: int

LANGUAGE_ENGLISH_MARSHALL_ISLANDS: int

LANGUAGE_ENGLISH_MAURITIUS: int

LANGUAGE_ENGLISH_MICRONESIA: int

LANGUAGE_ENGLISH_MONTSERRAT: int

LANGUAGE_ENGLISH_NAMIBIA: int

LANGUAGE_ENGLISH_NAURU: int

LANGUAGE_ENGLISH_NETHERLANDS: int

LANGUAGE_ENGLISH_NEW_ZEALAND: int

LANGUAGE_ENGLISH_NIGERIA: int

LANGUAGE_ENGLISH_NIUE: int

LANGUAGE_ENGLISH_NORFOLK_ISLAND: int

LANGUAGE_ENGLISH_NORTHERN_MARIANA_ISLANDS: int

LANGUAGE_ENGLISH_PAKISTAN: int

LANGUAGE_ENGLISH_PALAU: int

LANGUAGE_ENGLISH_PAPUA_NEW_GUINEA: int

LANGUAGE_ENGLISH_PHILIPPINES: int

LANGUAGE_ENGLISH_PITCAIRN_ISLANDS: int

LANGUAGE_ENGLISH_PUERTO_RICO: int

LANGUAGE_ENGLISH_RWANDA: int

LANGUAGE_ENGLISH_SAMOA: int

LANGUAGE_ENGLISH_SEYCHELLES: int

LANGUAGE_ENGLISH_SIERRA_LEONE: int

LANGUAGE_ENGLISH_SINGAPORE: int

LANGUAGE_ENGLISH_SINT_MAARTEN: int

LANGUAGE_ENGLISH_SLOVENIA: int

LANGUAGE_ENGLISH_SOLOMON_ISLANDS: int

LANGUAGE_ENGLISH_SOUTH_AFRICA: int

LANGUAGE_ENGLISH_SOUTH_SUDAN: int

LANGUAGE_ENGLISH_ST_HELENA_ASCENSION_TRISTAN_DA_CUNHA: int

LANGUAGE_ENGLISH_ST_KITTS_AND_NEVIS: int

LANGUAGE_ENGLISH_ST_LUCIA: int

LANGUAGE_ENGLISH_ST_VINCENT_AND_GRENADINES: int

LANGUAGE_ENGLISH_SUDAN: int

LANGUAGE_ENGLISH_SWEDEN: int

LANGUAGE_ENGLISH_SWITZERLAND: int

LANGUAGE_ENGLISH_TANZANIA: int

LANGUAGE_ENGLISH_TOKELAU: int

LANGUAGE_ENGLISH_TONGA: int

LANGUAGE_ENGLISH_TRINIDAD: int

LANGUAGE_ENGLISH_TURKS_AND_CAICOS_ISLANDS: int

LANGUAGE_ENGLISH_TUVALU: int

LANGUAGE_ENGLISH_UGANDA: int

LANGUAGE_ENGLISH_UK: int

LANGUAGE_ENGLISH_UNITED_ARAB_EMIRATES: int

LANGUAGE_ENGLISH_US: int

LANGUAGE_ENGLISH_US_OUTLYING_ISLANDS: int

LANGUAGE_ENGLISH_US_VIRGIN_ISLANDS: int

LANGUAGE_ENGLISH_VANUATU: int

LANGUAGE_ENGLISH_WORLD: int

LANGUAGE_ENGLISH_ZAMBIA: int

LANGUAGE_ENGLISH_ZIMBABWE: int

LANGUAGE_ESPERANTO: int

LANGUAGE_ESPERANTO_WORLD: int

LANGUAGE_ESTONIAN: int

LANGUAGE_ESTONIAN_ESTONIA: int

LANGUAGE_EWE: int

LANGUAGE_EWE_GHANA: int

LANGUAGE_EWE_TOGO: int

LANGUAGE_EWONDO: int

LANGUAGE_EWONDO_CAMEROON: int

LANGUAGE_FAEROESE: int

LANGUAGE_FAEROESE_DENMARK: int

LANGUAGE_FAEROESE_FAROE_ISLANDS: int

LANGUAGE_FARSI: int

LANGUAGE_FIJI: int

LANGUAGE_FILIPINO: int

LANGUAGE_FILIPINO_PHILIPPINES: int

LANGUAGE_FINNISH: int

LANGUAGE_FINNISH_FINLAND: int

LANGUAGE_FRENCH: int

LANGUAGE_FRENCH_ALGERIA: int

LANGUAGE_FRENCH_BELGIAN: int

LANGUAGE_FRENCH_BENIN: int

LANGUAGE_FRENCH_BURKINA_FASO: int

LANGUAGE_FRENCH_BURUNDI: int

LANGUAGE_FRENCH_CAMEROON: int

LANGUAGE_FRENCH_CANADIAN: int

LANGUAGE_FRENCH_CARIBBEAN: int

LANGUAGE_FRENCH_CENTRAL_AFRICAN_REPUBLIC: int

LANGUAGE_FRENCH_CHAD: int

LANGUAGE_FRENCH_COMOROS: int

LANGUAGE_FRENCH_CONGO: int

LANGUAGE_FRENCH_CONGO_DRC: int

LANGUAGE_FRENCH_COTE_DIVOIRE: int

LANGUAGE_FRENCH_DJIBOUTI: int

LANGUAGE_FRENCH_EQUATORIAL_GUINEA: int

LANGUAGE_FRENCH_FRANCE: int

LANGUAGE_FRENCH_FRENCH_GUIANA: int

LANGUAGE_FRENCH_FRENCH_POLYNESIA: int

LANGUAGE_FRENCH_GABON: int

LANGUAGE_FRENCH_GUADELOUPE: int

LANGUAGE_FRENCH_GUINEA: int

LANGUAGE_FRENCH_HAITI: int

LANGUAGE_FRENCH_LUXEMBOURG: int

LANGUAGE_FRENCH_MADAGASCAR: int

LANGUAGE_FRENCH_MALI: int

LANGUAGE_FRENCH_MARTINIQUE: int

LANGUAGE_FRENCH_MAURITANIA: int

LANGUAGE_FRENCH_MAURITIUS: int

LANGUAGE_FRENCH_MAYOTTE: int

LANGUAGE_FRENCH_MONACO: int

LANGUAGE_FRENCH_MOROCCO: int

LANGUAGE_FRENCH_NEW_CALEDONIA: int

LANGUAGE_FRENCH_NIGER: int

LANGUAGE_FRENCH_REUNION: int

LANGUAGE_FRENCH_RWANDA: int

LANGUAGE_FRENCH_SENEGAL: int

LANGUAGE_FRENCH_SEYCHELLES: int

LANGUAGE_FRENCH_ST_BARTHELEMY: int

LANGUAGE_FRENCH_ST_MARTIN: int

LANGUAGE_FRENCH_ST_PIERRE_AND_MIQUELON: int

LANGUAGE_FRENCH_SWISS: int

LANGUAGE_FRENCH_SYRIA: int

LANGUAGE_FRENCH_TOGO: int

LANGUAGE_FRENCH_TUNISIA: int

LANGUAGE_FRENCH_VANUATU: int

LANGUAGE_FRENCH_WALLIS_AND_FUTUNA: int

LANGUAGE_FRISIAN: int

LANGUAGE_FRISIAN_NETHERLANDS: int

LANGUAGE_FRIULIAN: int

LANGUAGE_FRIULIAN_ITALY: int

LANGUAGE_FULAH: int

LANGUAGE_FULAH_LATIN: int

LANGUAGE_FULAH_LATIN_BURKINA_FASO: int

LANGUAGE_FULAH_LATIN_CAMEROON: int

LANGUAGE_FULAH_LATIN_GAMBIA: int

LANGUAGE_FULAH_LATIN_GHANA: int

LANGUAGE_FULAH_LATIN_GUINEA: int

LANGUAGE_FULAH_LATIN_GUINEA_BISSAU: int

LANGUAGE_FULAH_LATIN_LIBERIA: int

LANGUAGE_FULAH_LATIN_MAURITANIA: int

LANGUAGE_FULAH_LATIN_NIGER: int

LANGUAGE_FULAH_LATIN_NIGERIA: int

LANGUAGE_FULAH_LATIN_SENEGAL: int

LANGUAGE_FULAH_LATIN_SIERRA_LEONE: int

LANGUAGE_GALICIAN: int

LANGUAGE_GALICIAN_SPAIN: int

LANGUAGE_GANDA: int

LANGUAGE_GANDA_UGANDA: int

LANGUAGE_GEORGIAN: int

LANGUAGE_GEORGIAN_GEORGIA: int

LANGUAGE_GERMAN: int

LANGUAGE_GERMAN_AUSTRIAN: int

LANGUAGE_GERMAN_BELGIUM: int

LANGUAGE_GERMAN_GERMANY: int

LANGUAGE_GERMAN_ITALY: int

LANGUAGE_GERMAN_LIECHTENSTEIN: int

LANGUAGE_GERMAN_LUXEMBOURG: int

LANGUAGE_GERMAN_SWISS: int

LANGUAGE_GREEK: int

LANGUAGE_GREEK_CYPRUS: int

LANGUAGE_GREEK_GREECE: int

LANGUAGE_GREENLANDIC: int

LANGUAGE_GUARANI: int

LANGUAGE_GUARANI_PARAGUAY: int

LANGUAGE_GUJARATI: int

LANGUAGE_GUJARATI_INDIA: int

LANGUAGE_GUSII: int

LANGUAGE_GUSII_KENYA: int

LANGUAGE_HAUSA: int

LANGUAGE_HAUSA_LATIN: int

LANGUAGE_HAUSA_LATIN_GHANA: int

LANGUAGE_HAUSA_LATIN_NIGER: int

LANGUAGE_HAUSA_LATIN_NIGERIA: int

LANGUAGE_HAWAIIAN: int

LANGUAGE_HAWAIIAN_US: int

LANGUAGE_HEBREW: int

LANGUAGE_HEBREW_ISRAEL: int

LANGUAGE_HINDI: int

LANGUAGE_HINDI_INDIA: int

LANGUAGE_HUNGARIAN: int

LANGUAGE_HUNGARIAN_HUNGARY: int

LANGUAGE_IBIBIO: int

LANGUAGE_IBIBIO_NIGERIA: int

LANGUAGE_ICELANDIC: int

LANGUAGE_ICELANDIC_ICELAND: int

LANGUAGE_IGBO: int

LANGUAGE_IGBO_NIGERIA: int

LANGUAGE_INDONESIAN: int

LANGUAGE_INDONESIAN_INDONESIA: int

LANGUAGE_INTERLINGUA: int

LANGUAGE_INTERLINGUA_WORLD: int

LANGUAGE_INTERLINGUE: int

LANGUAGE_INUKTITUT: int

LANGUAGE_INUKTITUT_LATIN: int

LANGUAGE_INUKTITUT_LATIN_CANADA: int

LANGUAGE_INUKTITUT_SYLLABICS: int

LANGUAGE_INUKTITUT_SYLLABICS_CANADA: int

LANGUAGE_INUPIAK: int

LANGUAGE_IRISH: int

LANGUAGE_IRISH_IRELAND: int

LANGUAGE_ITALIAN: int

LANGUAGE_ITALIAN_ITALY: int

LANGUAGE_ITALIAN_SAN_MARINO: int

LANGUAGE_ITALIAN_SWISS: int

LANGUAGE_ITALIAN_VATICAN_CITY: int

LANGUAGE_JAPANESE: int

LANGUAGE_JAPANESE_JAPAN: int

LANGUAGE_JAVANESE: int

LANGUAGE_JAVANESE_INDONESIA: int

LANGUAGE_JAVANESE_JAVANESE: int

LANGUAGE_JAVANESE_JAVANESE_INDONESIA: int

LANGUAGE_JOLA_FONYI: int

LANGUAGE_JOLA_FONYI_SENEGAL: int

LANGUAGE_KABUVERDIANU: int

LANGUAGE_KABUVERDIANU_CABO_VERDE: int

LANGUAGE_KABYLE: int

LANGUAGE_KABYLE_ALGERIA: int

LANGUAGE_KAKO: int

LANGUAGE_KAKO_CAMEROON: int

LANGUAGE_KALAALLISUT: int

LANGUAGE_KALENJIN: int

LANGUAGE_KALENJIN_KENYA: int

LANGUAGE_KAMBA: int

LANGUAGE_KAMBA_KENYA: int

LANGUAGE_KANNADA: int

LANGUAGE_KANNADA_INDIA: int

LANGUAGE_KANURI: int

LANGUAGE_KANURI_LATIN: int

LANGUAGE_KANURI_NIGERIA: int

LANGUAGE_KASHMIRI: int

LANGUAGE_KASHMIRI_DEVANAGARI: int

LANGUAGE_KASHMIRI_DEVANAGARI_INDIA: int

LANGUAGE_KASHMIRI_INDIA: int

LANGUAGE_KASHMIRI_PERSO_ARABIC: int

LANGUAGE_KASHMIRI_PERSO_ARABIC_INDIA: int

LANGUAGE_KAZAKH: int

LANGUAGE_KAZAKH_KAZAKHSTAN: int

LANGUAGE_KHMER: int

LANGUAGE_KHMER_CAMBODIA: int

LANGUAGE_KICHE: int

LANGUAGE_KICHE_GUATEMALA: int

LANGUAGE_KICHE_LATIN: int

LANGUAGE_KIKUYU: int

LANGUAGE_KIKUYU_KENYA: int

LANGUAGE_KINYARWANDA: int

LANGUAGE_KINYARWANDA_RWANDA: int

LANGUAGE_KIRGHIZ: int

LANGUAGE_KIRGHIZ_KYRGYZSTAN: int

LANGUAGE_KIRUNDI: int

LANGUAGE_KIRUNDI_BURUNDI: int

LANGUAGE_KONKANI: int

LANGUAGE_KONKANI_INDIA: int

LANGUAGE_KOREAN: int

LANGUAGE_KOREAN_KOREA: int

LANGUAGE_KOREAN_NORTH_KOREA: int

LANGUAGE_KOYRABORO_SENNI: int

LANGUAGE_KOYRABORO_SENNI_MALI: int

LANGUAGE_KOYRA_CHIINI: int

LANGUAGE_KOYRA_CHIINI_MALI: int

LANGUAGE_KURDISH: int

LANGUAGE_KURDISH_PERSO_ARABIC_IRAN: int

LANGUAGE_KWASIO: int

LANGUAGE_KWASIO_CAMEROON: int

LANGUAGE_LAKOTA: int

LANGUAGE_LAKOTA_US: int

LANGUAGE_LANGI: int

LANGUAGE_LANGI_TANZANIA: int

LANGUAGE_LAOTHIAN: int

LANGUAGE_LAOTHIAN_LAOS: int

LANGUAGE_LATIN: int

LANGUAGE_LATIN_WORLD: int

LANGUAGE_LATVIAN: int

LANGUAGE_LATVIAN_LATVIA: int

LANGUAGE_LINGALA: int

LANGUAGE_LINGALA_ANGOLA: int

LANGUAGE_LINGALA_CENTRAL_AFRICAN_REPUBLIC: int

LANGUAGE_LINGALA_CONGO: int

LANGUAGE_LINGALA_CONGO_DRC: int

LANGUAGE_LITHUANIAN: int

LANGUAGE_LITHUANIAN_LITHUANIA: int

LANGUAGE_LOWER_SORBIAN: int

LANGUAGE_LOWER_SORBIAN_GERMANY: int

LANGUAGE_LOW_GERMAN: int

LANGUAGE_LOW_GERMAN_GERMANY: int

LANGUAGE_LOW_GERMAN_NETHERLANDS: int

LANGUAGE_LUBA_KATANGA: int

LANGUAGE_LUBA_KATANGA_CONGO_DRC: int

LANGUAGE_LUO: int

LANGUAGE_LUO_KENYA: int

LANGUAGE_LUXEMBOURGISH: int

LANGUAGE_LUXEMBOURGISH_LUXEMBOURG: int

LANGUAGE_LUYIA: int

LANGUAGE_LUYIA_KENYA: int

LANGUAGE_MACEDONIAN: int

LANGUAGE_MACEDONIAN_NORTH_MACEDONIA: int

LANGUAGE_MACHAME: int

LANGUAGE_MACHAME_TANZANIA: int

LANGUAGE_MAKHUWA_MEETTO: int

LANGUAGE_MAKHUWA_MEETTO_MOZAMBIQUE: int

LANGUAGE_MAKONDE: int

LANGUAGE_MAKONDE_TANZANIA: int

LANGUAGE_MALAGASY: int

LANGUAGE_MALAGASY_MADAGASCAR: int

LANGUAGE_MALAY: int

LANGUAGE_MALAYALAM: int

LANGUAGE_MALAYALAM_INDIA: int

LANGUAGE_MALAY_BRUNEI: int

LANGUAGE_MALAY_MALAYSIA: int

LANGUAGE_MALAY_SINGAPORE: int

LANGUAGE_MALTESE: int

LANGUAGE_MALTESE_MALTA: int

LANGUAGE_MANIPURI: int

LANGUAGE_MANIPURI_INDIA: int

LANGUAGE_MANX: int

LANGUAGE_MANX_ISLE_OF_MAN: int

LANGUAGE_MAORI: int

LANGUAGE_MAORI_NEW_ZEALAND: int

LANGUAGE_MAPUCHE: int

LANGUAGE_MAPUCHE_CHILE: int

LANGUAGE_MARATHI: int

LANGUAGE_MARATHI_INDIA: int

LANGUAGE_MASAI: int

LANGUAGE_MASAI_KENYA: int

LANGUAGE_MASAI_TANZANIA: int

LANGUAGE_MAZANDERANI: int

LANGUAGE_MAZANDERANI_IRAN: int

LANGUAGE_MERU: int

LANGUAGE_MERU_KENYA: int

LANGUAGE_META: int

LANGUAGE_META_CAMEROON: int

LANGUAGE_MOHAWK: int

LANGUAGE_MOHAWK_CANADA: int

LANGUAGE_MOLDAVIAN: int

LANGUAGE_MONGOLIAN: int

LANGUAGE_MONGOLIAN_CYRILLIC: int

LANGUAGE_MONGOLIAN_MONGOLIA: int

LANGUAGE_MONGOLIAN_TRADITIONAL: int

LANGUAGE_MONGOLIAN_TRADITIONAL_CHINA: int

LANGUAGE_MONGOLIAN_TRADITIONAL_MONGOLIA: int

LANGUAGE_MORISYEN: int

LANGUAGE_MORISYEN_MAURITIUS: int

LANGUAGE_MUNDANG: int

LANGUAGE_MUNDANG_CAMEROON: int

LANGUAGE_NAMA: int

LANGUAGE_NAMA_NAMIBIA: int

LANGUAGE_NAURU: int

LANGUAGE_NEPALI: int

LANGUAGE_NEPALI_INDIA: int

LANGUAGE_NEPALI_NEPAL: int

LANGUAGE_NGIEMBOON: int

LANGUAGE_NGIEMBOON_CAMEROON: int

LANGUAGE_NGOMBA: int

LANGUAGE_NGOMBA_CAMEROON: int

LANGUAGE_NKO: int

LANGUAGE_NKO_GUINEA: int

LANGUAGE_NORTHERN_LURI: int

LANGUAGE_NORTHERN_LURI_IRAN: int

LANGUAGE_NORTHERN_LURI_IRAQ: int

LANGUAGE_NORTH_NDEBELE: int

LANGUAGE_NORTH_NDEBELE_ZIMBABWE: int

LANGUAGE_NORWEGIAN: int

LANGUAGE_NORWEGIAN_BOKMAL: int

LANGUAGE_NORWEGIAN_BOKMAL_NORWAY: int

LANGUAGE_NORWEGIAN_BOKMAL_SVALBARD_AND_JAN_MAYEN: int

LANGUAGE_NORWEGIAN_NYNORSK: int

LANGUAGE_NORWEGIAN_NYNORSK_NORWAY: int

LANGUAGE_NUER: int

LANGUAGE_NUER_SOUTH_SUDAN: int

LANGUAGE_NYANKOLE: int

LANGUAGE_NYANKOLE_UGANDA: int

LANGUAGE_OCCITAN: int

LANGUAGE_OCCITAN_FRANCE: int

LANGUAGE_ODIA: int

LANGUAGE_ODIA_INDIA: int

LANGUAGE_OROMO: int

LANGUAGE_OROMO_ETHIOPIA: int

LANGUAGE_OROMO_KENYA: int

LANGUAGE_OSSETIC: int

LANGUAGE_OSSETIC_GEORGIA: int

LANGUAGE_OSSETIC_RUSSIA: int

LANGUAGE_PAPIAMENTO: int

LANGUAGE_PAPIAMENTO_CARIBBEAN: int

LANGUAGE_PASHTO: int

LANGUAGE_PASHTO_AFGHANISTAN: int

LANGUAGE_PASHTO_PAKISTAN: int

LANGUAGE_PERSIAN_IRAN: int

LANGUAGE_POLISH: int

LANGUAGE_POLISH_POLAND: int

LANGUAGE_PORTUGUESE: int

LANGUAGE_PORTUGUESE_ANGOLA: int

LANGUAGE_PORTUGUESE_BRAZILIAN: int

LANGUAGE_PORTUGUESE_CABO_VERDE: int

LANGUAGE_PORTUGUESE_EQUATORIAL_GUINEA: int

LANGUAGE_PORTUGUESE_GUINEA_BISSAU: int

LANGUAGE_PORTUGUESE_LUXEMBOURG: int

LANGUAGE_PORTUGUESE_MACAO_SAR: int

LANGUAGE_PORTUGUESE_MOZAMBIQUE: int

LANGUAGE_PORTUGUESE_PORTUGAL: int

LANGUAGE_PORTUGUESE_SAO_TOME_AND_PRINCIPE: int

LANGUAGE_PORTUGUESE_SWITZERLAND: int

LANGUAGE_PORTUGUESE_TIMOR_LESTE: int

LANGUAGE_PRUSSIAN: int

LANGUAGE_PRUSSIAN_WORLD: int

LANGUAGE_PUNJABI: int

LANGUAGE_PUNJABI_ARABIC: int

LANGUAGE_PUNJABI_GURMUKHI: int

LANGUAGE_PUNJABI_INDIA: int

LANGUAGE_PUNJABI_PAKISTAN: int

LANGUAGE_QUECHUA: int

LANGUAGE_QUECHUA_BOLIVIA: int

LANGUAGE_QUECHUA_ECUADOR: int

LANGUAGE_QUECHUA_MACRO: int

LANGUAGE_QUECHUA_PERU: int

LANGUAGE_RHAETO_ROMANCE: int

LANGUAGE_RHAETO_ROMANCE_SWITZERLAND: int

LANGUAGE_ROMANIAN: int

LANGUAGE_ROMANIAN_MOLDOVA: int

LANGUAGE_ROMANIAN_ROMANIA: int

LANGUAGE_ROMBO: int

LANGUAGE_ROMBO_TANZANIA: int

LANGUAGE_RUSSIAN: int

LANGUAGE_RUSSIAN_BELARUS: int

LANGUAGE_RUSSIAN_KAZAKHSTAN: int

LANGUAGE_RUSSIAN_KYRGYZSTAN: int

LANGUAGE_RUSSIAN_MOLDOVA: int

LANGUAGE_RUSSIAN_RUSSIA: int

LANGUAGE_RUSSIAN_UKRAINE: int

LANGUAGE_RWA: int

LANGUAGE_RWA_TANZANIA: int

LANGUAGE_SAHO: int

LANGUAGE_SAHO_ERITREA: int

LANGUAGE_SAKHA: int

LANGUAGE_SAKHA_RUSSIA: int

LANGUAGE_SAMBURU: int

LANGUAGE_SAMBURU_KENYA: int

LANGUAGE_SAMI: int

LANGUAGE_SAMI_FINLAND: int

LANGUAGE_SAMI_INARI: int

LANGUAGE_SAMI_INARI_FINLAND: int

LANGUAGE_SAMI_LULE: int

LANGUAGE_SAMI_LULE_NORWAY: int

LANGUAGE_SAMI_LULE_SWEDEN: int

LANGUAGE_SAMI_NORWAY: int

LANGUAGE_SAMI_SKOLT: int

LANGUAGE_SAMI_SKOLT_FINLAND: int

LANGUAGE_SAMI_SOUTHERN: int

LANGUAGE_SAMI_SOUTHERN_NORWAY: int

LANGUAGE_SAMI_SOUTHERN_SWEDEN: int

LANGUAGE_SAMI_SWEDEN: int

LANGUAGE_SAMOAN: int

LANGUAGE_SANGHO: int

LANGUAGE_SANGHO_CENTRAL_AFRICAN_REPUBLIC: int

LANGUAGE_SANGU: int

LANGUAGE_SANGU_TANZANIA: int

LANGUAGE_SANSKRIT: int

LANGUAGE_SANSKRIT_INDIA: int

LANGUAGE_SCOTS_GAELIC: int

LANGUAGE_SCOTS_GAELIC_UK: int

LANGUAGE_SENA: int

LANGUAGE_SENA_MOZAMBIQUE: int

LANGUAGE_SERBIAN: int

LANGUAGE_SERBIAN_CYRILLIC: int

LANGUAGE_SERBIAN_CYRILLIC_BOSNIA_AND_HERZEGOVINA: int

LANGUAGE_SERBIAN_CYRILLIC_KOSOVO: int

LANGUAGE_SERBIAN_CYRILLIC_MONTENEGRO: int

LANGUAGE_SERBIAN_CYRILLIC_SERBIA: int

LANGUAGE_SERBIAN_CYRILLIC_YU: int

LANGUAGE_SERBIAN_LATIN: int

LANGUAGE_SERBIAN_LATIN_BOSNIA_AND_HERZEGOVINA: int

LANGUAGE_SERBIAN_LATIN_KOSOVO: int

LANGUAGE_SERBIAN_LATIN_MONTENEGRO: int

LANGUAGE_SERBIAN_LATIN_SERBIA: int

LANGUAGE_SERBIAN_LATIN_YU: int

LANGUAGE_SERBIAN_SERBIA: int

LANGUAGE_SERBIAN_YU: int

LANGUAGE_SERBO_CROATIAN: int

LANGUAGE_SESOTHO: int

LANGUAGE_SESOTHO_LESOTHO: int

LANGUAGE_SESOTHO_SA_LEBOA: int

LANGUAGE_SESOTHO_SA_LEBOA_SOUTH_AFRICA: int

LANGUAGE_SESOTHO_SOUTH_AFRICA: int

LANGUAGE_SETSWANA: int

LANGUAGE_SETSWANA_BOTSWANA: int

LANGUAGE_SETSWANA_SOUTH_AFRICA: int

LANGUAGE_SHAMBALA: int

LANGUAGE_SHAMBALA_TANZANIA: int

LANGUAGE_SHONA: int

LANGUAGE_SHONA_LATIN: int

LANGUAGE_SHONA_LATIN_ZIMBABWE: int

LANGUAGE_SINDHI: int

LANGUAGE_SINDHI_ARABIC: int

LANGUAGE_SINDHI_DEVANAGARI: int

LANGUAGE_SINDHI_DEVANAGARI_INDIA: int

LANGUAGE_SINDHI_PAKISTAN: int

LANGUAGE_SINHALESE: int

LANGUAGE_SINHALESE_SRI_LANKA: int

LANGUAGE_SISWATI: int

LANGUAGE_SISWATI_ESWATINI: int

LANGUAGE_SISWATI_SOUTH_AFRICA: int

LANGUAGE_SLOVAK: int

LANGUAGE_SLOVAK_SLOVAKIA: int

LANGUAGE_SLOVENIAN: int

LANGUAGE_SLOVENIAN_SLOVENIA: int

LANGUAGE_SOGA: int

LANGUAGE_SOGA_UGANDA: int

LANGUAGE_SOMALI: int

LANGUAGE_SOMALI_DJIBOUTI: int

LANGUAGE_SOMALI_ETHIOPIA: int

LANGUAGE_SOMALI_KENYA: int

LANGUAGE_SOMALI_SOMALIA: int

LANGUAGE_SOUTH_NDEBELE: int

LANGUAGE_SOUTH_NDEBELE_SOUTH_AFRICA: int

LANGUAGE_SPANISH: int

LANGUAGE_SPANISH_ARGENTINA: int

LANGUAGE_SPANISH_BELIZE: int

LANGUAGE_SPANISH_BOLIVIA: int

LANGUAGE_SPANISH_BRAZIL: int

LANGUAGE_SPANISH_CHILE: int

LANGUAGE_SPANISH_COLOMBIA: int

LANGUAGE_SPANISH_COSTA_RICA: int

LANGUAGE_SPANISH_CUBA: int

LANGUAGE_SPANISH_DOMINICAN_REPUBLIC: int

LANGUAGE_SPANISH_ECUADOR: int

LANGUAGE_SPANISH_EL_SALVADOR: int

LANGUAGE_SPANISH_EQUATORIAL_GUINEA: int

LANGUAGE_SPANISH_GUATEMALA: int

LANGUAGE_SPANISH_HONDURAS: int

LANGUAGE_SPANISH_LATIN_AMERICA: int

LANGUAGE_SPANISH_MEXICAN: int

LANGUAGE_SPANISH_NICARAGUA: int

LANGUAGE_SPANISH_PANAMA: int

LANGUAGE_SPANISH_PARAGUAY: int

LANGUAGE_SPANISH_PERU: int

LANGUAGE_SPANISH_PHILIPPINES: int

LANGUAGE_SPANISH_PUERTO_RICO: int

LANGUAGE_SPANISH_SPAIN: int

LANGUAGE_SPANISH_URUGUAY: int

LANGUAGE_SPANISH_US: int

LANGUAGE_SPANISH_VENEZUELA: int

LANGUAGE_STANDARD_MOROCCAN_TAMAZIGHT: int

LANGUAGE_STANDARD_MOROCCAN_TAMAZIGHT_TIFINAGH: int

LANGUAGE_STANDARD_MOROCCAN_TAMAZIGHT_TIFINAGH_MOROCCO: int

LANGUAGE_SUNDANESE: int

LANGUAGE_SWAHILI: int

LANGUAGE_SWAHILI_CONGO_DRC: int

LANGUAGE_SWAHILI_KENYA: int

LANGUAGE_SWAHILI_TANZANIA: int

LANGUAGE_SWAHILI_UGANDA: int

LANGUAGE_SWEDISH: int

LANGUAGE_SWEDISH_ALAND_ISLANDS: int

LANGUAGE_SWEDISH_FINLAND: int

LANGUAGE_SWEDISH_SWEDEN: int

LANGUAGE_SWISS_GERMAN: int

LANGUAGE_SWISS_GERMAN_LIECHTENSTEIN: int

LANGUAGE_SWISS_GERMAN_SWITZERLAND: int

LANGUAGE_SYRIAC: int

LANGUAGE_SYRIAC_SYRIA: int

LANGUAGE_TACHELHIT: int

LANGUAGE_TACHELHIT_LATIN: int

LANGUAGE_TACHELHIT_LATIN_MOROCCO: int

LANGUAGE_TACHELHIT_TIFINAGH: int

LANGUAGE_TACHELHIT_TIFINAGH_MOROCCO: int

LANGUAGE_TAGALOG: int

LANGUAGE_TAITA: int

LANGUAGE_TAITA_KENYA: int

LANGUAGE_TAJIK: int

LANGUAGE_TAJIK_CYRILLIC: int

LANGUAGE_TAJIK_CYRILLIC_TAJIKISTAN: int

LANGUAGE_TAMIL: int

LANGUAGE_TAMIL_INDIA: int

LANGUAGE_TAMIL_MALAYSIA: int

LANGUAGE_TAMIL_SINGAPORE: int

LANGUAGE_TAMIL_SRI_LANKA: int

LANGUAGE_TASAWAQ: int

LANGUAGE_TASAWAQ_NIGER: int

LANGUAGE_TATAR: int

LANGUAGE_TATAR_RUSSIA: int

LANGUAGE_TELUGU: int

LANGUAGE_TELUGU_INDIA: int

LANGUAGE_TESO: int

LANGUAGE_TESO_KENYA: int

LANGUAGE_TESO_UGANDA: int

LANGUAGE_THAI: int

LANGUAGE_THAI_THAILAND: int

LANGUAGE_TIBETAN: int

LANGUAGE_TIBETAN_CHINA: int

LANGUAGE_TIBETAN_INDIA: int

LANGUAGE_TIGRE: int

LANGUAGE_TIGRE_ERITREA: int

LANGUAGE_TIGRINYA: int

LANGUAGE_TIGRINYA_ERITREA: int

LANGUAGE_TIGRINYA_ETHIOPIA: int

LANGUAGE_TONGA: int

LANGUAGE_TONGA_TONGA: int

LANGUAGE_TSONGA: int

LANGUAGE_TSONGA_SOUTH_AFRICA: int

LANGUAGE_TURKISH: int

LANGUAGE_TURKISH_CYPRUS: int

LANGUAGE_TURKISH_TURKEY: int

LANGUAGE_TURKMEN: int

LANGUAGE_TURKMEN_TURKMENISTAN: int

LANGUAGE_TWI: int

LANGUAGE_UIGHUR: int

LANGUAGE_UIGHUR_CHINA: int

LANGUAGE_UKRAINIAN: int

LANGUAGE_UKRAINIAN_UKRAINE: int

LANGUAGE_UPPER_SORBIAN: int

LANGUAGE_UPPER_SORBIAN_GERMANY: int

LANGUAGE_URDU: int

LANGUAGE_URDU_INDIA: int

LANGUAGE_URDU_PAKISTAN: int

LANGUAGE_UZBEK: int

LANGUAGE_UZBEK_CYRILLIC: int

LANGUAGE_UZBEK_CYRILLIC_UZBEKISTAN: int

LANGUAGE_UZBEK_LATIN: int

LANGUAGE_UZBEK_LATIN_UZBEKISTAN: int

LANGUAGE_UZBEK_PERSO_ARABIC: int

LANGUAGE_UZBEK_PERSO_ARABIC_AFGHANISTAN: int

LANGUAGE_VAI: int

LANGUAGE_VAI_LATIN: int

LANGUAGE_VAI_LATIN_LIBERIA: int

LANGUAGE_VAI_VAI: int

LANGUAGE_VAI_VAI_LIBERIA: int

LANGUAGE_VALENCIAN: int

LANGUAGE_VENDA: int

LANGUAGE_VENDA_SOUTH_AFRICA: int

LANGUAGE_VIETNAMESE: int

LANGUAGE_VIETNAMESE_VIETNAM: int

LANGUAGE_VOLAPUK: int

LANGUAGE_VOLAPUK_WORLD: int

LANGUAGE_VUNJO: int

LANGUAGE_VUNJO_TANZANIA: int

LANGUAGE_WALSER: int

LANGUAGE_WALSER_SWITZERLAND: int

LANGUAGE_WELSH: int

LANGUAGE_WELSH_UK: int

LANGUAGE_WOLAYTTA: int

LANGUAGE_WOLAYTTA_ETHIOPIA: int

LANGUAGE_WOLOF: int

LANGUAGE_WOLOF_SENEGAL: int

LANGUAGE_XHOSA: int

LANGUAGE_XHOSA_SOUTH_AFRICA: int

LANGUAGE_YANGBEN: int

LANGUAGE_YANGBEN_CAMEROON: int

LANGUAGE_YI: int

LANGUAGE_YIDDISH: int

LANGUAGE_YIDDISH_WORLD: int

LANGUAGE_YI_CHINA: int

LANGUAGE_YORUBA: int

LANGUAGE_YORUBA_BENIN: int

LANGUAGE_YORUBA_NIGERIA: int

LANGUAGE_ZARMA: int

LANGUAGE_ZARMA_NIGER: int

LANGUAGE_ZHUANG: int

LANGUAGE_ZULU: int

LANGUAGE_ZULU_SOUTH_AFRICA: int

LANGUAGE_USER_DEFINED: int

LANGUAGE_AZERI: int

LANGUAGE_AZERI_CYRILLIC: int

LANGUAGE_AZERI_LATIN: int

LANGUAGE_BENGALI: int

LANGUAGE_BENGALI_BANGLADESH: int

LANGUAGE_BENGALI_INDIA: int

LANGUAGE_BHUTANI: int

LANGUAGE_CHINESE_SIMPLIFIED: int

LANGUAGE_CHINESE_TRADITIONAL: int

LANGUAGE_CHINESE_MACAU: int

LANGUAGE_KERNEWEK: int

LANGUAGE_MALAY_BRUNEI_DARUSSALAM: int

LANGUAGE_ORIYA: int

LANGUAGE_ORIYA_INDIA: int

LANGUAGE_SPANISH_MODERN: int

LANGUAGE_CAMBODIAN: int

class LayoutConstraints(Object):
    """ bool

        Source: https://docs.wxpython.org/wx.LayoutConstraints.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.LayoutConstraints.html
        """

    def AreSatisfied(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.LayoutConstraints.html
        """

    def SatisfyConstraints(self, win, noChanges) -> bool:
        """ win (wx.Window) â

            Source: https://docs.wxpython.org/wx.LayoutConstraints.html
        """

    bottom: Any  # A public C++ attribute of type IndividualLayoutConstraint     .
    centreX: Any  # A public C++ attribute of type IndividualLayoutConstraint     .
    centreY: Any  # A public C++ attribute of type IndividualLayoutConstraint     .
    height: Any  # A public C++ attribute of type IndividualLayoutConstraint     .
    left: Any  # A public C++ attribute of type IndividualLayoutConstraint     .
    right: Any  # A public C++ attribute of type IndividualLayoutConstraint     .
    top: Any  # A public C++ attribute of type IndividualLayoutConstraint     .
    width: Any  # A public C++ attribute of type IndividualLayoutConstraint     .



class LinuxDistributionInfo:
    """ A structure containing information about a Linux distribution as
returned by the lsb_release utility.

        Source: https://docs.wxpython.org/wx.LinuxDistributionInfo.html
    """
    def __ne__(self, item: Any) -> bool:
        """ ldi (wx.LinuxDistributionInfo) â

            Source: https://docs.wxpython.org/wx.LinuxDistributionInfo.html
        """

    def __eq__(self, item: Any) -> bool:
        """ ldi (wx.LinuxDistributionInfo) â

            Source: https://docs.wxpython.org/wx.LinuxDistributionInfo.html
        """

    CodeName: Any  # A public C++ attribute of type string. The code name of the distribution; e.g. âjauntyâ.
    Description: Any  # A public C++ attribute of type string. The description of the distribution; e.g. âUbuntu 9.04â.
    Id: Any  # A public C++ attribute of type string. The id of the distribution; e.g. âUbuntuâ.
    Release: Any  # A public C++ attribute of type string. The version of the distribution; e.g. â9.04â.



class ListCtrl(Control):
    """ A list control presents lists in a number of formats: list view,
report view, icon view and small icon view.

        Source: https://docs.wxpython.org/wx.ListCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def Append(self, entry) -> None:
        """ Append an item to the list control.  The entry parameter should be a
sequence with an item for each column

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def AppendColumn(self, heading, format=LIST_FORMAT_LEFT, width=-1) -> int:
        """ Adds a new column to the list control in report view mode.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def Arrange(self, flag: int=LIST_ALIGN_DEFAULT) -> bool:
        """ Arranges the items in icon or small icon view.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def AssignImageList(self, imageList, which) -> None:
        """ Sets the image list associated with the control and takes ownership of it.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def CheckItem(self, item, check=True) -> None:
        """ Check or uncheck a   wx.ListItem  in a control using checkboxes.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def ClearAll(self) -> None:
        """ Deletes all items and all columns.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def ClearColumnImage(self, col) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=LC_ICON, validator=DefaultValidator, name=ListCtrlNameStr) -> bool:
        """ Creates the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def DeleteAllColumns(self) -> bool:
        """ Delete all columns in the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def DeleteAllItems(self) -> bool:
        """ Deletes all items in the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def DeleteColumn(self, col: int) -> bool:
        """ Deletes a column.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def DeleteItem(self, item: int) -> bool:
        """ Deletes the specified item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def EditLabel(self, item: int) -> 'TextCtrl':
        """ Starts editing the label of the given item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def EnableAlternateRowColours(self, enable: bool=True) -> None:
        """ Enable alternating row background colours (also called zebra striping).

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def EnableBellOnNoMatch(self, on: bool=True) -> None:
        """ Enable or disable a beep if there is no match for the currently entered text when searching for the item from keyboard.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def EnableCheckBoxes(self, enable: bool=True) -> bool:
        """ Enable or disable checkboxes for list items.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def EnableSystemTheme(self, enable: bool=True) -> None:
        """ Can be used to disable the system theme of controls using it by default.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def EnsureVisible(self, item: int) -> bool:
        """ Ensures this item is visible.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def ExtendRulesAndAlternateColour(self, extend: bool=True) -> None:
        """ Extend rules and alternate rows background to the entire client area.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def FindItem(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def Focus(self, idx) -> None:
        """ Focus and show the given item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetAlternateRowColour(self) -> 'Colour':
        """ Get the alternative row background colour.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetColumn(self, col) -> 'ListItem':
        """ Gets information about this column. See SetItem() for more information.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetColumnCount(self) -> int:
        """ Returns the number of columns.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetColumnIndexFromOrder(self, pos: int) -> int:
        """ Gets the column index from its position in visual order.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetColumnOrder(self, col: int) -> int:
        """ Gets the column visual order position.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetColumnWidth(self, col: int) -> int:
        """ Gets the column width (report view only).

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetColumnsOrder(self) -> list[int]:
        """ Returns the array containing the orders of all columns.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetCountPerPage(self) -> int:
        """ Gets the number of items that can fit vertically in the visible area of the list control (list or report view) or the total number of items in the list control (icon or small icon view).

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetEditControl(self) -> 'TextCtrl':
        """ Returns the edit control being currently used to edit a label.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetFirstSelected(self, *args) -> int:
        """ Returns the first selected item, or -1 when none is selected.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetFocusedItem(self) -> int:
        """ Gets the currently focused item or -1 if none is focused.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetImageList(self, which: int) -> 'ImageList':
        """ Returns the specified image list.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItem(self, itemIdx, col=0) -> 'ListItem':
        """ Gets information about the item. See SetItem() for more information.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemBackgroundColour(self, item: int) -> 'Colour':
        """ Returns the colour for this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemCount(self) -> int:
        """ Returns the number of items in the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemData(self, item: int) -> int:
        """ Gets the application-defined data associated with this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemFont(self, item: int) -> 'Font':
        """ Returns the itemâs font.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemPosition(self, item) -> 'Point':
        """ Returns the position of the item, in icon or small icon view.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemRect(self, item, code=LIST_RECT_BOUNDS) -> 'Rect':
        """ Returns the rectangle representing the itemâs size and position, in physical coordinates.
code is one of wx.``wx.LIST_RECT_BOUNDS``, wx.``wx.LIST_RECT_ICON``, wx.``wx.LIST_RECT_LABEL``.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemSpacing(self) -> 'Size':
        """ Retrieves the spacing between icons in pixels: horizontal spacing is returned as  x   component of the    wx.Size  object and the vertical spacing as its  y   component.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemState(self, item, stateMask) -> int:
        """ Gets the item state.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemText(self, item, col=0) -> str:
        """ Gets the item text for this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetItemTextColour(self, item: int) -> 'Colour':
        """ Returns the colour for this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetMainWindow(self) -> 'Window':
        """ wx.Window

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetNextItem(self, item, geometry=LIST_NEXT_ALL, state=LIST_STATE_DONTCARE) -> int:
        """ Searches for an item with the given geometry or state, starting from item  but excluding the item  itself.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetNextSelected(self, item) -> None:
        """ Returns subsequent selected items, or -1 when no more are selected.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetSelectedItemCount(self) -> int:
        """ Returns the number of selected items in the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetSortIndicator(self) -> int:
        """ Returns the column that shows the sort indicator.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetSubItemRect(self, item, subItem, rect, code=LIST_RECT_BOUNDS) -> bool:
        """ Returns the rectangle representing the size and position, in physical coordinates, of the given subitem, i.e.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetTextColour(self) -> 'Colour':
        """ Gets the text colour of the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetTopItem(self) -> int:
        """ Gets the index of the topmost visible item when in list or report view.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetUpdatedAscendingSortIndicator(self, col: int) -> bool:
        """ Returns the new value to use for sort indicator after clicking a column.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def GetViewRect(self) -> 'Rect':
        """ Returns the rectangle taken by all items in the control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def HasCheckBoxes(self) -> bool:
        """ Returns True if checkboxes are enabled for list items.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def HasColumnOrderSupport(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def HitTest(self, point) -> None:
        """ Determines which item (if any) is at the specified point, giving details in flags.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def HitTestSubItem(*args, **kwargs) -> tuple:
        """ Determines which item (if any) is at the specified point, giving details in flags.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def InReportView(self) -> bool:
        """ Returns True if the control is currently using LC_REPORT  style.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def InsertColumn(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def InsertItem(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def IsAscendingSortIndicator(self) -> bool:
        """ Returns True if the sort indicator direction is ascending, False when the direction is descending.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if the control doesnât currently contain any items.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def IsItemChecked(self, item: int) -> bool:
        """ Return True if the checkbox for the given   wx.ListItem  is checked.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def IsSelected(self, idx) -> None:
        """ Returns True if the item is selected.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def IsVirtual(self) -> bool:
        """ Returns True if the control is currently in virtual report view.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def IsVisible(self, item: int) -> bool:
        """ Check if the item is visible.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def OnGetItemAttr(self, item: int) -> Optional['ItemAttr']:
        """ This function may be overridden in the derived class for a control with  LC_VIRTUAL   style.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def OnGetItemColumnImage(self, item, column) -> int:
        """ Override this function in the derived class for a control with  LC_VIRTUAL   and   LC_REPORT   styles in order to specify the image index for the given line and column.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def OnGetItemImage(self, item: int) -> int:
        """ This function must be overridden in the derived class for a control with  LC_VIRTUAL   style using images.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def OnGetItemIsChecked(self, item: int) -> bool:
        """ This function must  be overridden in the derived class for a control with  LC_VIRTUAL   style that uses checkboxes.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def OnGetItemText(self, item, column) -> str:
        """ This function must  be overridden in the derived class for a control with  LC_VIRTUAL   style.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def RefreshItem(self, item: int) -> None:
        """ Redraws the given item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def RefreshItems(self, itemFrom, itemTo) -> None:
        """ Redraws the items between itemFrom  and itemTo.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def RemoveSortIndicator(self) -> None:
        """ Remove the sort indicator from the column being used as sort key.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def ScrollList(self, dx, dy) -> bool:
        """ Scrolls the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def Select(self, idx, on=1) -> None:
        """ Selects/deselects an item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetAlternateRowColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Set the alternative row background colour to a specific colour.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetBackgroundColour(self, col: Union[int, str, 'Colour']) -> bool:
        """ Sets the background colour.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetColumn(self, col, item) -> bool:
        """ Sets information about this column.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetColumnImage(self, col, image) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetColumnWidth(self, col, width) -> bool:
        """ Sets the column width.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetColumnsOrder(self, orders: list[int]) -> bool:
        """ Changes the order in which the columns are shown.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetHeaderAttr(self, attr: 'ItemAttr') -> bool:
        """ Change the font and the colours used for the list control header.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetImageList(self, imageList, which) -> None:
        """ Sets the image list associated with the control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItem(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemBackgroundColour(self, item, col) -> None:
        """ Sets the background colour for this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemColumnImage(self, item, column, image) -> bool:
        """ Sets the image associated with the item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemCount(self, count: int) -> None:
        """ This method can only be used with virtual list controls.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemData(self, item, data) -> bool:
        """ Associates application-defined data with this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemFont(self, item, font) -> None:
        """ Sets the itemâs font.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemImage(self, item, image, selImage=-1) -> bool:
        """ Sets the unselected and selected images associated with the item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemPosition(self, item, pos) -> bool:
        """ Sets the position of the item, in icon or small icon view.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemState(self, item, state, stateMask) -> bool:
        """ Sets the item state.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemText(self, item, text) -> None:
        """ Sets the item text for this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetItemTextColour(self, item, col) -> None:
        """ Sets the colour for this item.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetNormalImages(self, images: Vector) -> None:
        """ Sets the images to use when showing large, normal icons in this control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetSingleStyle(self, style, add=True) -> None:
        """ Adds or removes a single window style.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetSmallImages(self, images: Vector) -> None:
        """ Sets the images to use when showing small icons in this control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetTextColour(self, col: Union[int, str, 'Colour']) -> None:
        """ Sets the text colour of the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SetWindowStyleFlag(self, style: int) -> None:
        """ Sets the whole window style, deleting all items.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def ShowSortIndicator(self, col, ascending=True) -> None:
        """ Show the sort indicator of a specific column in a specific direction.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    def SortItems(self, fnSortCallBack) -> None:
        """ Call this function to sort the items in the list control.

            Source: https://docs.wxpython.org/wx.ListCtrl.html
        """

    AlternateRowColour: Union[int, str, 'Colour']  # See GetAlternateRowColour and SetAlternateRowColour
    Column: 'ListItem'  # See GetColumn and SetColumn
    ColumnCount: int  # See GetColumnCount
    ColumnsOrder: list[int]  # See GetColumnsOrder and SetColumnsOrder
    CountPerPage: int  # See GetCountPerPage
    EditControl: 'TextCtrl'  # See GetEditControl
    FocusedItem: None  # See GetFocusedItem
    Item: 'ListItem'  # See GetItem and SetItem
    ItemCount: int  # See GetItemCount and SetItemCount
    ItemPosition: 'Point'  # See GetItemPosition and SetItemPosition
    ItemRect: 'Rect'  # See GetItemRect
    ItemSpacing: 'Size'  # See GetItemSpacing
    MainWindow: 'Window'  # See GetMainWindow
    SelectedItemCount: int  # See GetSelectedItemCount
    SortIndicator: int  # See GetSortIndicator
    TextColour: Union[int, str, 'Colour']  # See GetTextColour and SetTextColour
    TopItem: int  # See GetTopItem
    ViewRect: 'Rect'  # See GetViewRect



LC_LIST: int  # Multicolumn list view, with optional small icons. Columns are computed automatically, i.e. you donât set columns as in  LC_REPORT . In other words, the list wraps, unlike a    wx.ListBox.

LC_REPORT: int  # Single or multicolumn report view, with optional header.

LC_VIRTUAL: int  # The application provides items text on demand. May only be used with  LC_REPORT .

LC_ICON: int  # Large icon view, with optional labels.

LC_SMALL_ICON: int  # Small icon view, with optional labels.

LC_ALIGN_TOP: int  # Icons align to the top. Win32 default, Win32 only.

LC_ALIGN_LEFT: int  # Icons align to the left.

LC_AUTOARRANGE: int  # Icons arrange themselves. Win32 only.

LC_EDIT_LABELS: int  # Labels are editable: the application will be notified when editing starts.

LC_NO_HEADER: int  # No header in report mode.

LC_SINGLE_SEL: int  # Single selection (default is multiple).

LC_SORT_ASCENDING: int  # Sort in ascending order. (You must still supply a comparison callback in wx.ListCtrl.SortItems .)

LC_SORT_DESCENDING: int  # Sort in descending order. (You must still supply a comparison callback in wx.ListCtrl.SortItems .)

LC_HRULES: int  # Draws light horizontal rules between rows in report mode.

LC_VRULES: int  # Draws light vertical rules between columns in report mode. ^^

EVT_LIST_BEGIN_DRAG: int  # Begin dragging with the left mouse button. Processes a  wxEVT_LIST_BEGIN_DRAG   event type.

EVT_LIST_BEGIN_RDRAG: int  # Begin dragging with the right mouse button. Processes a  wxEVT_LIST_BEGIN_RDRAG   event type.

EVT_LIST_BEGIN_LABEL_EDIT: int  # Begin editing a label. This can be prevented by calling Veto(). Processes a  wxEVT_LIST_BEGIN_LABEL_EDIT   event type.

EVT_LIST_END_LABEL_EDIT: int  # Finish editing a label. This can be prevented by calling Veto(). Processes a  wxEVT_LIST_END_LABEL_EDIT   event type.

EVT_LIST_DELETE_ITEM: int  # An item was deleted. Processes a  wxEVT_LIST_DELETE_ITEM   event type.

EVT_LIST_DELETE_ALL_ITEMS: int  # All items were deleted. Processes a  wxEVT_LIST_DELETE_ALL_ITEMS   event type.

EVT_LIST_ITEM_SELECTED: int  # The item has been selected. Notice that the mouse is captured by the control itself when this event is generated, see event handling overview. Processes a  wxEVT_LIST_ITEM_SELECTED   event type.

EVT_LIST_ITEM_DESELECTED: int  # The item has been deselected. Processes a  wxEVT_LIST_ITEM_DESELECTED   event type.

EVT_LIST_ITEM_ACTIVATED: int  # The item has been activated (ENTER or double click). Processes a  wxEVT_LIST_ITEM_ACTIVATED   event type.

EVT_LIST_ITEM_FOCUSED: int  # The currently focused item has changed. Processes a  wxEVT_LIST_ITEM_FOCUSED   event type.

EVT_LIST_ITEM_MIDDLE_CLICK: int  # The middle mouse button has been clicked on an item. This is only supported by the generic control. Processes a  wxEVT_LIST_ITEM_MIDDLE_CLICK   event type.

EVT_LIST_ITEM_RIGHT_CLICK: int  # The right mouse button has been clicked on an item. Processes a  wxEVT_LIST_ITEM_RIGHT_CLICK   event type.

EVT_LIST_KEY_DOWN: int  # A key has been pressed. Processes a  wxEVT_LIST_KEY_DOWN   event type.

EVT_LIST_INSERT_ITEM: int  # An item has been inserted. Processes a  wxEVT_LIST_INSERT_ITEM   event type.

EVT_LIST_COL_CLICK: int  # A column (m_col) has been left-clicked. Processes a  wxEVT_LIST_COL_CLICK   event type.

EVT_LIST_COL_RIGHT_CLICK: int  # A column (m_col) has been right-clicked. Processes a  wxEVT_LIST_COL_RIGHT_CLICK   event type.

EVT_LIST_COL_BEGIN_DRAG: int  # The user started resizing a column - can be vetoed. Processes a  wxEVT_LIST_COL_BEGIN_DRAG   event type.

EVT_LIST_COL_DRAGGING: int  # The divider between columns is being dragged. Processes a  wxEVT_LIST_COL_DRAGGING   event type.

EVT_LIST_COL_END_DRAG: int  # A column has been resized by the user. Processes a  wxEVT_LIST_COL_END_DRAG   event type.

EVT_LIST_CACHE_HINT: int  # Prepare cache for a virtual list control. Processes a  wxEVT_LIST_CACHE_HINT   event type.

EVT_LIST_ITEM_CHECKED: int  # The item has been checked. Processes a  wxEVT_LIST_ITEM_CHECKED   event type (new since wxWidgets 3.1.0).

EVT_LIST_ITEM_UNCHECKED: int  # The item has been unchecked. Processes a  wxEVT_LIST_ITEM_UNCHECKED   event type (new since wxWidgets 3.1.0). ^^

LIST_ALIGN_DEFAULT: int

LIST_ALIGN_LEFT: int

LIST_ALIGN_TOP: int

LIST_ALIGN_SNAP_TO_GRID: int

IMAGE_LIST_NORMAL: int

IMAGE_LIST_SMALL: int

IMAGE_LIST_STATE: int

LIST_NEXT_ABOVE: int

LIST_NEXT_ALL: int

LIST_NEXT_BELOW: int

LIST_NEXT_LEFT: int

LIST_NEXT_RIGHT: int

LIST_STATE_DONTCARE: int

LIST_STATE_DROPHILITED: int

LIST_STATE_FOCUSED: int

LIST_STATE_SELECTED: int

LIST_STATE_CUT: int

LIST_HITTEST_ABOVE: int

LIST_HITTEST_BELOW: int

LIST_HITTEST_TOLEFT: int

LIST_HITTEST_TORIGHT: int

LIST_HITTEST_NOWHERE: int

LIST_HITTEST_ONITEMICON: int

LIST_HITTEST_ONITEMLABEL: int

LIST_HITTEST_ONITEMSTATEICON: int

LIST_HITTEST_ONITEM: int

class ListEvent(NotifyEvent):
    """ A list event holds information about events associated with ListCtrl
objects.

        Source: https://docs.wxpython.org/wx.ListEvent.html
    """
    def __init__(self, commandType=wxEVT_NULL, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetCacheFrom(self) -> int:
        """ For  EVT_LIST_CACHE_HINT   event only: return the first item which the list control advises us to cache.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetCacheTo(self) -> int:
        """ For  EVT_LIST_CACHE_HINT   event only: return the last item (inclusive) which the list control advises us to cache.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetColumn(self) -> int:
        """ The column position: it is only used with  COL   events.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetData(self) -> 'UIntPtr':
        """ The data.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetImage(self) -> int:
        """ The image.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetIndex(self) -> int:
        """ The item index.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetItem(self) -> 'ListItem':
        """ An item object, used by some events.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetKeyCode(self) -> int:
        """ Key code if the event is a keypress event.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetLabel(self) -> str:
        """ The (new) item label for  EVT_LIST_END_LABEL_EDIT   event.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetMask(self) -> int:
        """ The mask.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetPoint(self) -> 'Point':
        """ The position of the mouse pointer if the event is a drag event.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def GetText(self) -> str:
        """ The text.

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def IsEditCancelled(self) -> bool:
        """ This method only makes sense for  EVT_LIST_END_LABEL_EDIT   message and returns True if it the label editing has been cancelled by the user ( GetLabel   returns an empty string in this case but it doesnât allow the application to distinguish between really cancelling the edit and the admittedly rare case when the user wants to rename it to an empty string).

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def SetCacheFrom(self, cacheFrom: int) -> None:
        """ cacheFrom (long) â

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def SetCacheTo(self, cacheTo: int) -> None:
        """ cacheTo (long) â

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def SetColumn(self, col: int) -> None:
        """ col (int) â

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def SetIndex(self, index: int) -> None:
        """ index (long) â

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def SetItem(self, item: 'ListItem') -> None:
        """ item (wx.ListItem) â

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def SetKeyCode(self, code: int) -> None:
        """ code (int) â

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    def SetPoint(self, point: Union[tuple[int, int], 'Point']) -> None:
        """ point (wx.Point) â

            Source: https://docs.wxpython.org/wx.ListEvent.html
        """

    CacheFrom: int  # See GetCacheFrom and SetCacheFrom
    CacheTo: int  # See GetCacheTo and SetCacheTo
    Column: int  # See GetColumn and SetColumn
    Data: 'UIntPtr'  # See GetData
    Image: int  # See GetImage
    Index: int  # See GetIndex and SetIndex
    Item: 'ListItem'  # See GetItem and SetItem
    KeyCode: int  # See GetKeyCode and SetKeyCode
    Label: str  # See GetLabel
    Mask: int  # See GetMask
    Point: Union[tuple[int, int], 'Point']  # See GetPoint and SetPoint
    Text: str  # See GetText



class ListItem(Object):
    """ This class stores information about a ListCtrl item or column.

        Source: https://docs.wxpython.org/wx.ListItem.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def Clear(self) -> None:
        """ Resets the item state to the default.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetAlign(self) -> 'ListColumnFormat':
        """ Returns the alignment for this item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetBackgroundColour(self) -> 'Colour':
        """ Returns the background colour for this item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetColumn(self) -> int:
        """ Returns the zero-based column; meaningful only in report mode.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetData(self) -> int:
        """ Returns client data associated with the control.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetFont(self) -> 'Font':
        """ Returns the font used to display the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetId(self) -> int:
        """ Returns the zero-based item position.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetImage(self) -> int:
        """ Returns the zero-based index of the image associated with the item into the image list.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetMask(self) -> int:
        """ Returns a bit mask indicating which fields of the structure are valid.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetState(self) -> int:
        """ Returns a bit field representing the state of the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetText(self) -> str:
        """ Returns the label/header text.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetTextColour(self) -> 'Colour':
        """ Returns the text colour.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def GetWidth(self) -> int:
        """ Meaningful only for column headers in report mode.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetAlign(self, align: ListColumnFormat) -> None:
        """ Sets the alignment for the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetBackgroundColour(self, colBack: Union[int, str, 'Colour']) -> None:
        """ Sets the background colour for the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetColumn(self, col: int) -> None:
        """ Sets the zero-based column.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetData(self, data: int) -> None:
        """ Sets client data for the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetFont(self, font: 'Font') -> None:
        """ Sets the font for the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetId(self, id: int) -> None:
        """ Sets the zero-based item position.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetImage(self, image: int) -> None:
        """ Sets the zero-based index of the image associated with the item into the image list.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetMask(self, mask: int) -> None:
        """ Sets the mask of valid fields.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetState(self, state: int) -> None:
        """ Sets the item state flags (note that the valid state flags are influenced by the value of the state mask, see wx.ListItem.SetStateMask ).

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetStateMask(self, stateMask: int) -> None:
        """ Sets the bitmask that is used to determine which of the state flags are to be set.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetText(self, text: str) -> None:
        """ Sets the text label for the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetTextColour(self, colText: Union[int, str, 'Colour']) -> None:
        """ Sets the text colour for the item.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    def SetWidth(self, width: int) -> None:
        """ Meaningful only for column headers in report mode.

            Source: https://docs.wxpython.org/wx.ListItem.html
        """

    Align: ListColumnFormat  # See GetAlign and SetAlign
    BackgroundColour: Union[int, str, 'Colour']  # See GetBackgroundColour and SetBackgroundColour
    Column: int  # See GetColumn and SetColumn
    Data: int  # See GetData and SetData
    Font: 'Font'  # See GetFont and SetFont
    Id: int  # See GetId and SetId
    Image: int  # See GetImage and SetImage
    Mask: int  # See GetMask and SetMask
    State: int  # See GetState and SetState
    Text: str  # See GetText and SetText
    TextColour: Union[int, str, 'Colour']  # See GetTextColour and SetTextColour
    Width: int  # See GetWidth and SetWidth



LIST_MASK_STATE: int

LIST_MASK_TEXT: int

LIST_MASK_IMAGE: int

LIST_MASK_DATA: int

LIST_MASK_WIDTH: int

LIST_MASK_FORMAT: int

class ListView(ListCtrl):
    """ This class currently simply presents a simpler to use interface for
the ListCtrl  it can be thought of as a faÃ§ade for that complicated
class.

        Source: https://docs.wxpython.org/wx.ListView.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def ClearColumnImage(self, col: int) -> None:
        """ Resets the column image â  after calling this function, no image will be shown.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def Focus(self, index: int) -> None:
        """ Sets focus to the item with the given index.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def GetFirstSelected(self) -> int:
        """ Returns the first selected item in a (presumably) multiple selection control.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def GetFocusedItem(self) -> int:
        """ Returns the currently focused item or -1 if none.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def GetNextSelected(self, item: int) -> int:
        """ Used together with GetFirstSelected   to iterate over all selected items in the control.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def IsSelected(self, index: int) -> bool:
        """ Returns True if the item with the given index  is selected, False otherwise.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def Select(self, n, on=True) -> None:
        """ Selects or unselects the given item.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    def SetColumnImage(self, col, image) -> None:
        """ Sets the column image for the specified column.

            Source: https://docs.wxpython.org/wx.ListView.html
        """

    FirstSelected: int  # See GetFirstSelected
    FocusedItem: int  # See GetFocusedItem



class Locale:
    """ Locale class encapsulates all language-dependent settings and is a
generalization of the C locale concept.

        Source: https://docs.wxpython.org/wx.Locale.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def AddCatalog(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def AddCatalogLookupPathPrefix(prefix: str) -> None:
        """ Calls wx.FileTranslationsLoader.AddCatalogLookupPathPrefix .

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def AddLanguage(info: 'LanguageInfo') -> None:
        """ Adds custom, user-defined language to the database of known languages.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def FindLanguageInfo(locale: str) -> 'LanguageInfo':
        """ This function may be used to find the language description structure for the given locale, specified either as a two letter ISO language code (for example, âptâ), a language code followed by the country code (âpt_BRâ) or a full, human readable, language description (âPortuguese_Brazilâ).

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def GetCanonicalName(self) -> str:
        """ Returns the canonical form of current locale name.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def GetHeaderValue(self, header, domain="") -> str:
        """ Calls wx.Translations.GetHeaderValue .

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetInfo(index, cat=LOCALE_CAT_DEFAULT) -> str:
        """ Get the values of the given locale-dependent datum.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def GetLanguage(self) -> int:
        """ Returns the   wx.Language  constant of current language.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetLanguageCanonicalName(lang: int) -> str:
        """ Returns canonical name (see GetCanonicalName ) of the given language or empty string if this language is unknown.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetLanguageInfo(lang: int) -> 'LanguageInfo':
        """ Returns a pointer to   wx.LanguageInfo  structure containing information about the given language or None if this language is unknown.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetLanguageName(lang: int) -> str:
        """ Returns English name of the given language or empty string if this language is unknown.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def GetLocale(self) -> str:
        """ Returns the locale name as passed to the constructor or Init .

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def GetName(self) -> str:
        """ Returns the current short name for the locale (as given to the constructor or the Init   function).

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetOSInfo(index, cat=LOCALE_CAT_DEFAULT) -> str:
        """ Get the values of a locale datum in the OS locale.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def GetString(self, *args, **kw) -> str:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def GetSysName(self) -> str:
        """ Returns current platform-specific locale name as passed to setlocale().

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetSystemEncoding() -> int:
        """ Tries to detect the userâs default font encoding.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetSystemEncodingName() -> str:
        """ Tries to detect the name of the userâs default font encoding.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def GetSystemLanguage() -> int:
        """ Tries to detect the userâs default locale setting.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def Init(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    @staticmethod
    def IsAvailable(lang: int) -> bool:
        """ Check whether the operating system and/or C run time environment supports this locale.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def IsLoaded(self, domain: str) -> bool:
        """ Calls wx.Translations.IsLoaded .

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the locale could be set successfully.

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.Locale.html
        """

    CanonicalName: str  # See GetCanonicalName
    Language: int  # See GetLanguage
    Locale: str  # See GetLocale
    Name: str  # See GetName
    SysName: str  # See GetSysName



LOCALE_CAT_DEFAULT: int

LOCALE_LOAD_DEFAULT: int

LOCALE_DONT_LOAD_DEFAULT: int

class Log:
    """ Log class defines the interface for the log targets used by
wxWidgets logging functions as explained in the Logging Overview.

        Source: https://docs.wxpython.org/wx.Log.html
    """
    @staticmethod
    def AddTraceMask(mask: str) -> None:
        """ Add the mask  to the list of allowed masks for wx.LogTrace     .

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def ClearTraceMasks() -> None:
        """ Removes all trace masks previously set with AddTraceMask .

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def DisableTimestamp() -> None:
        """ Disables time stamping of the log messages.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    def DoLogRecord(self, level, msg, info) -> None:
        """ Called to log a new record.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    def DoLogText(self, msg: str) -> None:
        """ Called to log the specified string.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    def DoLogTextAtLevel(self, level, msg) -> None:
        """ Called to log the specified string at given level.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def DontCreateOnDemand() -> None:
        """ Instructs   wx.Log  to not create new log targets on the fly if there is none currently (see GetActiveTarget ).

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def EnableLogging(enable: bool=True) -> bool:
        """ Globally enable or disable logging.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    def Flush(self) -> None:
        """ Show all pending output and clear the buffer.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def FlushActive() -> None:
        """ Flushes the current log target if any, does nothing if there is none.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def GetActiveTarget() -> 'Log':
        """ Returns the pointer to the active log target (may be None).

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def GetLogLevel() -> 'LogLevel':
        """ Returns the current log level limit.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def GetRepetitionCounting() -> bool:
        """ Returns whether the repetition counting mode is enabled.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def GetTimestamp() -> str:
        """ Returns the current timestamp format string.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def GetTraceMasks() -> list[str]:
        """ Returns the currently allowed list of string trace masks.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def GetVerbose() -> bool:
        """ Returns whether the verbose mode is currently active.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def IsAllowedTraceMask(mask: str) -> bool:
        """ Returns True if the mask  is one of allowed masks for wx.LogTrace     .

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def IsEnabled() -> bool:
        """ Returns True if logging is enabled at all now.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def IsLevelEnabled(level, component) -> bool:
        """ Returns True if logging at this level is enabled for the current thread.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    def LogRecord(self, level, msg, info) -> None:
        """ Log the given record.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def RemoveTraceMask(mask: str) -> None:
        """ Remove the mask  from the list of allowed masks for wx.LogTrace     .

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def Resume() -> None:
        """ Resumes logging previously suspended by a call to Suspend .

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def SetActiveTarget(logtarget: 'Log') -> 'Log':
        """ Sets the specified log target as the active one.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def SetComponentLevel(component, level) -> None:
        """ Sets the log level for the given component.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    def SetFormatter(self, formatter: 'LogFormatter') -> 'LogFormatter':
        """ Sets the specified formatter as the active one.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def SetLogLevel(logLevel: 'LogLevel') -> None:
        """ Specifies that log messages with level greater (numerically) than logLevel  should be ignored and not sent to the active log target.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def SetRepetitionCounting(repetCounting: bool=True) -> None:
        """ Enables logging mode in which a log message is logged once, and in case exactly the same message successively repeats one or more times, only the number of repetitions is logged.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def SetThreadActiveTarget(logger: 'Log') -> 'Log':
        """ Sets a thread-specific log target.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def SetTimestamp(format: str) -> None:
        """ Sets the timestamp format prepended by the default log targets to all messages.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def SetVerbose(verbose: bool=True) -> None:
        """ Activates or deactivates verbose mode in which the verbose messages are logged as the normal ones instead of being silently dropped.

            Source: https://docs.wxpython.org/wx.Log.html
        """

    @staticmethod
    def Suspend() -> None:
        """ Suspends the logging until Resume   is called.

            Source: https://docs.wxpython.org/wx.Log.html
        """



LOG_Warning: int

LOG_COMPONENT: int

class LogBuffer(Log):
    """ LogBuffer is a very simple implementation of log sink which simply
collects all the logged messages in a string (except the debug
messages which are output in the usual way immediately as weâre
presumably not interested in collecting them for later).

        Source: https://docs.wxpython.org/wx.LogBuffer.html
    """
    def __init__(self) -> None:
        """ The default constructor does nothing.

            Source: https://docs.wxpython.org/wx.LogBuffer.html
        """

    def Flush(self) -> None:
        """ Shows all the messages collected so far to the user (using a message box in the GUI applications or by printing them out to the console in text mode) and clears the internal buffer.

            Source: https://docs.wxpython.org/wx.LogBuffer.html
        """

    def GetBuffer(self) -> str:
        """ Returns the current buffer contains.

            Source: https://docs.wxpython.org/wx.LogBuffer.html
        """

    Buffer: str  # See GetBuffer



class LogChain(Log):
    """ This simple class allows you to chain log sinks, that is to install a
new sink but keep passing log messages to the old one instead of
replacing it completely as Log.SetActiveTarget does.

        Source: https://docs.wxpython.org/wx.LogChain.html
    """
    def __init__(self, logger: 'Log') -> None:
        """ Sets the specified  logger   (which may be None) as the default log target but the log messages are also passed to the previous log target if any.

            Source: https://docs.wxpython.org/wx.LogChain.html
        """

    def DetachOldLog(self) -> None:
        """ Detaches the old log target so it wonât be destroyed when the   wx.LogChain  object is destroyed.

            Source: https://docs.wxpython.org/wx.LogChain.html
        """

    def GetOldLog(self) -> 'Log':
        """ Returns the pointer to the previously active log target (which may be None).

            Source: https://docs.wxpython.org/wx.LogChain.html
        """

    def IsPassingMessages(self) -> bool:
        """ Returns True if the messages are passed to the previously active log target (default) or False if PassMessages   had been called.

            Source: https://docs.wxpython.org/wx.LogChain.html
        """

    def PassMessages(self, passMessages: bool) -> None:
        """ By default, the log messages are passed to the previously active log target.

            Source: https://docs.wxpython.org/wx.LogChain.html
        """

    def SetLog(self, logger: 'Log') -> None:
        """ Sets another log target to use (may be None).

            Source: https://docs.wxpython.org/wx.LogChain.html
        """

    OldLog: 'Log'  # See GetOldLog



class LogFormatter:
    """ LogFormatter class is used to format the log messages.

        Source: https://docs.wxpython.org/wx.LogFormatter.html
    """
    def __init__(self) -> None:
        """ The default constructor does nothing.

            Source: https://docs.wxpython.org/wx.LogFormatter.html
        """

    def Format(self, level, msg, info) -> str:
        """ This function creates the full log message string.

            Source: https://docs.wxpython.org/wx.LogFormatter.html
        """

    def FormatTime(self, time: int) -> str:
        """ This function formats the time stamp part of the log message.

            Source: https://docs.wxpython.org/wx.LogFormatter.html
        """



class LogGui(Log):
    """ This is the default log target for the GUI wxWidgets applications.

        Source: https://docs.wxpython.org/wx.LogGui.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.LogGui.html
        """

    def Flush(self) -> None:
        """ Presents the accumulated log messages, if any, to the user.

            Source: https://docs.wxpython.org/wx.LogGui.html
        """



class LogInterposer(LogChain):
    """ A special version of LogChain which uses itself as the new log
target.

        Source: https://docs.wxpython.org/wx.LogInterposer.html
    """
    def __init__(self) -> None:
        """ The default constructor installs this object as the current active log target.

            Source: https://docs.wxpython.org/wx.LogInterposer.html
        """



class LogInterposerTemp(LogChain):
    """ A special version of LogChain which uses itself as the new log
target.

        Source: https://docs.wxpython.org/wx.LogInterposerTemp.html
    """
    def __init__(self) -> None:
        """ The default constructor installs this object as the current active log target.

            Source: https://docs.wxpython.org/wx.LogInterposerTemp.html
        """



class LogNull:
    """ This class allows you to temporarily suspend logging.

        Source: https://docs.wxpython.org/wx.LogNull.html
    """
    def __init__(self) -> None:
        """ Suspends logging.

            Source: https://docs.wxpython.org/wx.LogNull.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.LogNull.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.LogNull.html
        """



class LogRecordInfo:
    """ Information about a log record (unit of the log output).

        Source: https://docs.wxpython.org/wx.LogRecordInfo.html
    """
    filename: Any  # A public C++ attribute of type int. The name of the file where this log message was generated.
    func: Any  # A public C++ attribute of type int. The name of the function where the log record was generated.
    line: Any  # A public C++ attribute of type int. The line number at which this log message was generated.
    timestamp: Any  # A public C++ attribute of type int. Time when the log message was generated.
    timestampMS: Any  # A public C++ attribute of type LongLong_t. Time in milliseconds since Epoch when the log message was generated.



class LogStderr(Log):
    """ This class can be used to redirect the log messages to a C file stream
(not to be confused with C++ streams).

        Source: https://docs.wxpython.org/wx.LogStderr.html
    """
    def __init__(self) -> None:
        """ Constructs a log target which sends all the log messages to the given  FILE .

            Source: https://docs.wxpython.org/wx.LogStderr.html
        """



class LogTextCtrl(Log):
    """ Using these target all the log messages can be redirected to a text
control.

        Source: https://docs.wxpython.org/wx.LogTextCtrl.html
    """
    def __init__(self, pTextCtrl: 'TextCtrl') -> None:
        """ Constructs a log target which sends all the log messages to the given text control.

            Source: https://docs.wxpython.org/wx.LogTextCtrl.html
        """



class LogWindow(LogInterposer):
    """ This class represents a background log window: to be precise, it
collects all log messages in the log frame which it manages but also
passes them on to the log target which was active at the moment of its
creation.

        Source: https://docs.wxpython.org/wx.LogWindow.html
    """
    def __init__(self, pParent, szTitle, show=True, passToOld=True) -> None:
        """ Creates the log frame window and starts collecting the messages in it.

            Source: https://docs.wxpython.org/wx.LogWindow.html
        """

    def GetFrame(self) -> 'Frame':
        """ Returns the associated log frame window.

            Source: https://docs.wxpython.org/wx.LogWindow.html
        """

    def OnFrameClose(self, frame: 'Frame') -> bool:
        """ Called if the user closes the window interactively, will not be called if it is destroyed for another reason (such as when program exits).

            Source: https://docs.wxpython.org/wx.LogWindow.html
        """

    def OnFrameDelete(self, frame: 'Frame') -> None:
        """ Called right before the log frame is going to be deleted: will always be called unlike OnFrameClose .

            Source: https://docs.wxpython.org/wx.LogWindow.html
        """

    def Show(self, show: bool=True) -> None:
        """ Shows or hides the frame.

            Source: https://docs.wxpython.org/wx.LogWindow.html
        """

    Frame: 'Frame'  # See GetFrame



class LongPressEvent(GestureEvent):
    """ This event is generated when one finger touches the surface and
remains stationary.

        Source: https://docs.wxpython.org/wx.LongPressEvent.html
    """
    def __init__(self, windid: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.LongPressEvent.html
        """



EVT_LONG_PRESS: int  # Process a  wxEVT_LONG_PRESS . ^^

class Mask(Object):
    """ This class encapsulates a monochrome mask bitmap, where the masked
area is black and the unmasked area is white.

        Source: https://docs.wxpython.org/wx.Mask.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Mask.html
        """

    def GetBitmap(self) -> 'Bitmap':
        """ Returns the mask as a monochrome bitmap.

            Source: https://docs.wxpython.org/wx.Mask.html
        """

    Bitmap: 'Bitmap'  # See GetBitmap



class Matrix2D:
    """ A simple container for 2x2 matrix.

        Source: https://docs.wxpython.org/wx.Matrix2D.html
    """
    def __init__(self, v11=1, v12=0, v21=0, v22=1) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.Matrix2D.html
        """

    m_11: Any  # A public C++ attribute of type Double     . The matrix elements in the usual mathematical notation.
    m_12: Any  # A public C++ attribute of type Double     .
    m_21: Any  # A public C++ attribute of type Double     .
    m_22: Any  # A public C++ attribute of type Double     .



class MaximizeEvent(Event):
    """ An event being sent when a top level window is maximized.

        Source: https://docs.wxpython.org/wx.MaximizeEvent.html
    """
    def __init__(self, id: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MaximizeEvent.html
        """



EVT_MAXIMIZE: int  # Process a  wxEVT_MAXIMIZE   event. ^^

class MDIChildFrame(Frame):
    """ An MDI child frame is a frame that can only exist inside a
MDIClientWindow, which is itself a child of MDIParentFrame.

        Source: https://docs.wxpython.org/wx.MDIChildFrame.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    def Activate(self) -> None:
        """ Activates this MDI child frame.

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    def Create(self, parent, id=ID_ANY, title="", pos=DefaultPosition, size=DefaultSize, style=DEFAULT_FRAME_STYLE, name=FrameNameStr) -> bool:
        """ Used in two-step frame construction.

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    def GetMDIParent(self) -> 'MDIParentFrame':
        """ Returns the MDI parent frame containing this child.

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    def IsAlwaysMaximized(self) -> bool:
        """ Returns True for MDI children in TDI implementations.

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    def Maximize(self, maximize: bool=True) -> None:
        """ Maximizes this MDI child frame.

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    def Restore(self) -> None:
        """ Restores this MDI child frame (unmaximizes).

            Source: https://docs.wxpython.org/wx.MDIChildFrame.html
        """

    MDIParent: 'MDIParentFrame'  # See GetMDIParent



class MDIClientWindow(Window):
    """ An MDI client window is a child of MDIParentFrame, and manages zero
or more MDIChildFrame objects.

        Source: https://docs.wxpython.org/wx.MDIClientWindow.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.MDIClientWindow.html
        """

    def CreateClient(self, parent, style=0) -> bool:
        """ Called by   wx.MDIParentFrame  immediately after creating the client window.

            Source: https://docs.wxpython.org/wx.MDIClientWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.MDIClientWindow.html
        """



class MDIParentFrame(Frame):
    """ An MDI (Multiple Document Interface) parent frame is a window which
can contain MDI child frames in its client area which emulates the
full desktop.

        Source: https://docs.wxpython.org/wx.MDIParentFrame.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def ActivateNext(self) -> None:
        """ Activates the MDI child following the currently active one.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def ActivatePrevious(self) -> None:
        """ Activates the MDI child preceding the currently active one.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def ArrangeIcons(self) -> None:
        """ Arranges any iconized (minimized) MDI child windows.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def Cascade(self) -> None:
        """ Arranges the MDI child windows in a cascade.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def Create(self, parent, id=ID_ANY, title="", pos=DefaultPosition, size=DefaultSize, style=DEFAULT_FRAME_STYLE|VSCROLL|HSCROLL, name=FrameNameStr) -> bool:
        """ Used in two-step frame construction.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def GetActiveChild(self) -> 'MDIChildFrame':
        """ Returns a pointer to the active MDI child, if there is one.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def GetClientWindow(self) -> 'MDIClientWindow':
        """ Returns a pointer to the client window.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def GetWindowMenu(self) -> 'Menu':
        """ Returns the current MDI Window menu.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    @staticmethod
    def IsTDI() -> bool:
        """ Returns whether the MDI implementation is tab-based.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def OnCreateClient(self) -> 'MDIClientWindow':
        """ Override this to return a different kind of client window.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def SetWindowMenu(self, menu: 'Menu') -> None:
        """ Replace the current MDI Window menu.

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    def Tile(self, orient: Orientation=HORIZONTAL) -> None:
        """ Tiles the MDI child windows either horizontally or vertically depending on whether orient  is  HORIZONTAL   or   VERTICAL .

            Source: https://docs.wxpython.org/wx.MDIParentFrame.html
        """

    ActiveChild: 'MDIChildFrame'  # See GetActiveChild
    ClientWindow: 'MDIClientWindow'  # See GetClientWindow
    WindowMenu: 'Menu'  # See GetWindowMenu and SetWindowMenu



FRAME_NO_WINDOW_MENU: int

class MemoryDC(DC):
    """ A memory device context provides a means to draw graphics onto a
bitmap.

        Source: https://docs.wxpython.org/wx.MemoryDC.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MemoryDC.html
        """

    def GetSelectedBitmap(self) -> 'Bitmap':
        """ wx.Bitmap

            Source: https://docs.wxpython.org/wx.MemoryDC.html
        """

    def SelectObject(self, bitmap: 'Bitmap') -> None:
        """ Allow using this device context object to modify the given bitmap contents.

            Source: https://docs.wxpython.org/wx.MemoryDC.html
        """

    def SelectObjectAsSource(self, bitmap: 'Bitmap') -> None:
        """ Selects the given bitmap into the device context, to use as the memory bitmap.

            Source: https://docs.wxpython.org/wx.MemoryDC.html
        """

    SelectedBitmap: 'Bitmap'  # See GetSelectedBitmap



class MemoryFSHandler(FileSystemHandler):
    """ This FileSystem handler can store arbitrary data in memory stream
and make them accessible via an URL.

        Source: https://docs.wxpython.org/wx.MemoryFSHandler.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MemoryFSHandler.html
        """

    @staticmethod
    def AddFile(*args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MemoryFSHandler.html
        """

    @staticmethod
    def AddFileWithMimeType(*args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MemoryFSHandler.html
        """

    @staticmethod
    def RemoveFile(filename: str) -> None:
        """ Removes a file from memory FS and frees the occupied memory.

            Source: https://docs.wxpython.org/wx.MemoryFSHandler.html
        """



class Menu(EvtHandler):
    """ A menu is a popup (or pull down) list of items, one of which may be
selected before the menu goes away (clicking elsewhere dismisses the
menu).

        Source: https://docs.wxpython.org/wx.Menu.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Append(self, *args, **kw) -> 'MenuItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def AppendCheckItem(self, id, item, help="") -> 'MenuItem':
        """ Adds a checkable item to the end of the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def AppendRadioItem(self, id, item, help="") -> 'MenuItem':
        """ Adds a radio item to the end of the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def AppendSeparator(self) -> 'MenuItem':
        """ Adds a separator to the end of the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def AppendSubMenu(self, submenu, text, help="") -> 'MenuItem':
        """ Adds the given submenu  to this menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Attach(self, menubar: 'MenuBar') -> None:
        """ menubar (wx.MenuBar) â

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Break(self) -> None:
        """ Inserts a break in a menu, causing the next appended item to appear in a new column.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Check(self, id, check) -> None:
        """ Checks or unchecks the menu item.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Delete(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def DestroyItem(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Detach(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Enable(self, id, enable) -> None:
        """ Enables or disables (greys out) a menu item.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def FindChildItem(self, id: int) -> tuple:
        """ Finds the menu item object associated with the given menu item identifier and, optionally, the position of the item in the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def FindItem(self, *args, **kw) -> int:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def FindItemById(self, id) -> 'MenuItem':
        """ FindItemById(id) . MenuItem

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def FindItemByPosition(self, position: int) -> 'MenuItem':
        """ Returns the   wx.MenuItem  given a position in the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetHelpString(self, id: int) -> str:
        """ Returns the help string associated with a menu item.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetInvokingWindow(self) -> 'Window':
        """ wx.Window

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetLabel(self, id: int) -> str:
        """ Returns a menu item label.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetLabelText(self, id: int) -> str:
        """ Returns a menu item label, without any of the original mnemonics and accelerators.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetMenuItemCount(self) -> int:
        """ Returns the number of items in the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetMenuItems(self) -> MenuItemList:
        """ Returns the list of items in the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetParent(self) -> 'Menu':
        """ wx.Menu

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetStyle(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetTitle(self) -> str:
        """ Returns the title of the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def GetWindow(self) -> 'Window':
        """ wx.Window

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Insert(self, *args, **kw) -> 'MenuItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def InsertCheckItem(self, pos, id, item, helpString="") -> 'MenuItem':
        """ Inserts a checkable item at the given position.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def InsertRadioItem(self, pos, id, item, helpString="") -> 'MenuItem':
        """ Inserts a radio item at the given position.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def InsertSeparator(self, pos: int) -> 'MenuItem':
        """ Inserts a separator at the given position.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def IsAttached(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def IsChecked(self, id: int) -> bool:
        """ Determines whether a menu item is checked.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def IsEnabled(self, id: int) -> bool:
        """ Determines whether a menu item is enabled.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Prepend(self, *args, **kw) -> 'MenuItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def PrependCheckItem(self, id, item, helpString="") -> 'MenuItem':
        """ Inserts a checkable item at position 0.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def PrependRadioItem(self, id, item, helpString="") -> 'MenuItem':
        """ Inserts a radio item at position 0.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def PrependSeparator(self) -> 'MenuItem':
        """ Inserts a separator at position 0.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def Remove(self, *args, **kw) -> 'MenuItem':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def SetHelpString(self, id, helpString) -> None:
        """ Sets an itemâs help string.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def SetInvokingWindow(self, win: 'Window') -> None:
        """ win (wx.Window) â

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def SetLabel(self, id, label) -> None:
        """ Sets the label of a menu item.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def SetParent(self, parent: 'Menu') -> None:
        """ parent (wx.Menu) â

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def SetTitle(self, title: str) -> None:
        """ Sets the title of the menu.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    def UpdateUI(self, source: Optional['EvtHandler']=None) -> None:
        """ Update the state of all menu items, recursively, by generating  wxEVT_UPDATE_UI   events for them.

            Source: https://docs.wxpython.org/wx.Menu.html
        """

    InvokingWindow: 'Window'  # See GetInvokingWindow and SetInvokingWindow
    MenuItemCount: int  # See GetMenuItemCount
    MenuItems: MenuItemList  # See GetMenuItems
    Parent: 'Menu'  # See GetParent and SetParent
    Style: int  # See GetStyle
    Title: str  # See GetTitle and SetTitle
    Window: 'Window'  # See GetWindow



MENU_TEAROFF: int

class MenuBar(Window):
    """ A menu bar is a series of menus accessible from the top of a frame.

        Source: https://docs.wxpython.org/wx.MenuBar.html
    """
    def __init__(self, style: int=0) -> None:
        """ Construct an empty menu bar.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Append(self, menu, title) -> bool:
        """ Adds the item to the end of the menu bar.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Attach(self, frame: 'Frame') -> None:
        """ frame (wx.Frame) â

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Check(self, id, check) -> None:
        """ Checks or unchecks a menu item.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Detach(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Enable(self, id, enable) -> None:
        """ Enables or disables (greys out) a menu item.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def EnableTop(self, pos, enable) -> None:
        """ Enables or disables a whole menu.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def FindItem(self, id: int) -> tuple:
        """ Finds the menu item object associated with the given menu item identifier.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def FindItemById(self, id) -> 'MenuItem':
        """ FindItemById(id) . MenuItem

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def FindMenu(self, title: str) -> int:
        """ Returns the index of the menu with the given title  or  NOT_FOUND   if no such menu exists in this menubar.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def FindMenuItem(self, menuString, itemString) -> int:
        """ Finds the menu item id for a menu name/menu item string pair.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetFrame(self) -> 'Frame':
        """ wx.Frame

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetHelpString(self, id: int) -> str:
        """ Gets the help string associated with the menu item identifier.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetLabel(self, id: int) -> str:
        """ Gets the label associated with a menu item.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetMenu(self, menuIndex: int) -> 'Menu':
        """ Returns the menu at menuIndex  (zero-based).

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetMenuCount(self) -> int:
        """ Returns the number of menus in this menubar.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetMenuLabel(self, pos: int) -> str:
        """ Returns the label of a top-level menu.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetMenuLabelText(self, pos: int) -> str:
        """ Returns the label of a top-level menu.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def GetMenus(self) -> None:
        """ Return a list of (menu, label) items for the menus in the MenuBar.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Insert(self, pos, menu, title) -> bool:
        """ Inserts the menu at the given position into the menu bar.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def IsAttached(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def IsChecked(self, id: int) -> bool:
        """ Determines whether an item is checked.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def IsEnabled(self, id: int) -> bool:
        """ Determines whether an item is enabled.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def IsEnabledTop(self, pos: int) -> bool:
        """ Returns True if the menu with the given index is enabled.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    @staticmethod
    def MacGetCommonMenuBar() -> 'MenuBar':
        """ Enables you to get the global menubar on Mac, that is, the menubar displayed when the app is running without any frames open.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    @staticmethod
    def MacSetCommonMenuBar(menubar: 'MenuBar') -> None:
        """ Enables you to set the global menubar on Mac, that is, the menubar displayed when the app is running without any frames open.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def OSXGetAppleMenu(self) -> 'Menu':
        """ Returns the Apple menu.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Refresh(self, eraseBackground=True, rect=None) -> None:
        """ Redraw the menu bar.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Remove(self, pos: int) -> 'Menu':
        """ Removes the menu from the menu bar and returns the menu object - the caller is responsible for deleting it.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def Replace(self, pos, menu, title) -> 'Menu':
        """ Replaces the menu at the given position with another one.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def SetHelpString(self, id, helpString) -> None:
        """ Sets the help string associated with a menu item.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def SetLabel(self, id, label) -> None:
        """ Sets the label of a menu item.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def SetMenuLabel(self, pos, label) -> None:
        """ Sets the label of a top-level menu.

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    def SetMenus(self, items) -> None:
        """ SetMenus()

            Source: https://docs.wxpython.org/wx.MenuBar.html
        """

    Menus: None  # See GetMenus and SetMenus



MB_DOCKABLE: int

class MenuEvent(Event):
    """ This class is used for a variety of menu-related events.

        Source: https://docs.wxpython.org/wx.MenuEvent.html
    """
    def __init__(self, type=wxEVT_NULL, id=0, menu=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MenuEvent.html
        """

    def GetMenu(self) -> 'Menu':
        """ Returns the menu which is being opened or closed, or the menu containing the highlighted item.

            Source: https://docs.wxpython.org/wx.MenuEvent.html
        """

    def GetMenuId(self) -> int:
        """ Returns the menu identifier associated with the event.

            Source: https://docs.wxpython.org/wx.MenuEvent.html
        """

    def IsPopup(self) -> bool:
        """ Returns True if the menu which is being opened or closed is a popup menu, False if it is a normal one.

            Source: https://docs.wxpython.org/wx.MenuEvent.html
        """

    Menu: 'Menu'  # See GetMenu
    MenuId: int  # See GetMenuId



class MenuItem(Object):
    """ A menu item represents an item in a menu.

        Source: https://docs.wxpython.org/wx.MenuItem.html
    """
    def __init__(self, parentMenu=None, id=ID_SEPARATOR, text="", helpString="", kind=ITEM_NORMAL, subMenu=None) -> None:
        """ Constructs a   wx.MenuItem  object.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def AddExtraAccel(self, accel: AcceleratorEntry) -> None:
        """ Add an extra accelerator for this menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def Check(self, check: bool=True) -> None:
        """ Checks or unchecks the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def ClearExtraAccels(self) -> None:
        """ Clear the extra accelerators list.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def Enable(self, enable: bool=True) -> None:
        """ Enables or disables the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetAccel(self) -> 'AcceleratorEntry':
        """ Get our accelerator or None (caller must delete the pointer)

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetBackgroundColour(self) -> 'Colour':
        """ Returns the background colour associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetBitmap(self, *args, **kw) -> 'Bitmap':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetBitmapBundle(self) -> 'BitmapBundle':
        """ Returns the bitmap bundle containing the bitmap used for this item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetDisabledBitmap(self) -> 'Bitmap':
        """ Returns the bitmap used for disabled items.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetFont(self) -> 'Font':
        """ Returns the font associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetHelp(self) -> str:
        """ Returns the help string associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetId(self) -> int:
        """ Returns the menu item identifier.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetItemLabel(self) -> str:
        """ Returns the text associated with the menu item including any accelerator characters that were passed to the constructor or SetItemLabel .

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetItemLabelText(self) -> str:
        """ Returns the text associated with the menu item, without any accelerator characters.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetKind(self) -> 'ItemKind':
        """ Returns the item kind, one of  ITEM_SEPARATOR ,   ITEM_NORMAL ,   ITEM_CHECK   or   ITEM_RADIO .

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    @staticmethod
    def GetLabelText(text: str) -> str:
        """ Strips all accelerator characters and mnemonics from the given text.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetMarginWidth(self) -> int:
        """ Gets the width of the menu item checkmark bitmap.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetMenu(self) -> 'Menu':
        """ Returns the menu this menu item is in, or None if this menu item is not attached.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetSubMenu(self) -> 'Menu':
        """ Returns the submenu associated with the menu item, or None if there isnât one.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def GetTextColour(self) -> 'Colour':
        """ Returns the text colour associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def IsCheck(self) -> bool:
        """ Returns True if the item is a check item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def IsCheckable(self) -> bool:
        """ Returns True if the item is checkable.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def IsChecked(self) -> bool:
        """ Returns True if the item is checked.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def IsEnabled(self) -> bool:
        """ Returns True if the item is enabled.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def IsRadio(self) -> bool:
        """ Returns True if the item is a radio button.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def IsSeparator(self) -> bool:
        """ Returns True if the item is a separator.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def IsSubMenu(self) -> bool:
        """ Returns True if the item is a submenu.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetAccel(self, accel: 'AcceleratorEntry') -> None:
        """ Set the accel for this item - this may also be done indirectly with SetText

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetBackgroundColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the background colour associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetBitmap(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetBitmaps(self, checked, unchecked=NullBitmap) -> None:
        """ Sets the checked/unchecked bitmaps for the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetDisabledBitmap(self, disabled: 'BitmapBundle') -> None:
        """ Sets the to be used for disabled menu items.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetFont(self, font: 'Font') -> None:
        """ Sets the font associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetHelp(self, helpString: str) -> None:
        """ Sets the help string.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetItemLabel(self, label: str) -> None:
        """ Sets the label associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetMarginWidth(self, width: int) -> None:
        """ Sets the width of the menu item checkmark bitmap.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetMenu(self, menu: 'Menu') -> None:
        """ Sets the parent menu which will contain this menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetSubMenu(self, menu: 'Menu') -> None:
        """ Sets the submenu of this menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    def SetTextColour(self, colour: Union[int, str, 'Colour']) -> None:
        """ Sets the text colour associated with the menu item.

            Source: https://docs.wxpython.org/wx.MenuItem.html
        """

    Accel: 'AcceleratorEntry'  # See GetAccel and SetAccel
    BackgroundColour: Union[int, str, 'Colour']  # See GetBackgroundColour and SetBackgroundColour
    Bitmap: 'BitmapBundle'  # See GetBitmap and SetBitmap
    BitmapBundle: 'BitmapBundle'  # See GetBitmapBundle
    DisabledBitmap: 'BitmapBundle'  # See GetDisabledBitmap and SetDisabledBitmap
    Enabled: Any  # See IsEnabled and Enable
    Font: 'Font'  # See GetFont and SetFont
    Help: str  # See GetHelp and SetHelp
    Id: int  # See GetId
    ItemLabel: str  # See GetItemLabel and SetItemLabel
    ItemLabelText: str  # See GetItemLabelText
    Kind: 'ItemKind'  # See GetKind
    MarginWidth: int  # See GetMarginWidth and SetMarginWidth
    Menu: 'Menu'  # See GetMenu and SetMenu
    SubMenu: 'Menu'  # See GetSubMenu and SetSubMenu
    TextColour: Union[int, str, 'Colour']  # See GetTextColour and SetTextColour



WXK_DELETE: int

WXK_BACK: int

WXK_INSERT: int

WXK_RETURN: int

WXK_PAGEUP: int

WXK_PAGEDOWN: int

WXK_LEFT: int

WXK_RIGHT: int

WXK_UP: int

WXK_DOWN: int

WXK_HOME: int

WXK_END: int

WXK_SPACE: int

WXK_TAB: int

WXK_ESCAPE: int

WXK_CANCEL: int

WXK_CLEAR: int

WXK_MENU: int

WXK_PAUSE: int

WXK_CAPITAL: int

WXK_SELECT: int

WXK_PRINT: int

WXK_EXECUTE: int

WXK_SNAPSHOT: int

WXK_HELP: int

WXK_ADD: int

WXK_SEPARATOR: int

WXK_SUBTRACT: int

WXK_DECIMAL: int

WXK_DIVIDE: int

WXK_NUMLOCK: int

WXK_SCROLL: int

WXK_NUMPAD_SPACE: int

WXK_NUMPAD_TAB: int

WXK_NUMPAD_ENTER: int

WXK_NUMPAD_HOME: int

WXK_NUMPAD_LEFT: int

WXK_NUMPAD_UP: int

WXK_NUMPAD_RIGHT: int

WXK_NUMPAD_DOWN: int

WXK_NUMPAD_PAGEUP: int

WXK_NUMPAD_PAGEDOWN: int

WXK_NUMPAD_END: int

WXK_NUMPAD_BEGIN: int

WXK_NUMPAD_INSERT: int

WXK_NUMPAD_DELETE: int

WXK_NUMPAD_EQUAL: int

WXK_NUMPAD_MULTIPLY: int

WXK_NUMPAD_ADD: int

WXK_NUMPAD_SEPARATOR: int

WXK_NUMPAD_SUBTRACT: int

WXK_NUMPAD_DECIMAL: int

WXK_NUMPAD_DIVIDE: int

WXK_WINDOWS_LEFT: int

WXK_WINDOWS_RIGHT: int

WXK_WINDOWS_MENU: int

WXK_COMMAND: int

WXK_SHIFT: int

WXK_ALT: int

class MessageDialog(Dialog):
    """ This class represents a dialog that shows a single or multi-line
message, with a choice of wx.OK, Yes, No and Cancel buttons.

        Source: https://docs.wxpython.org/wx.MessageDialog.html
    """
    def __init__(self, parent, message, caption=MessageBoxCaptionStr, style=OK|CENTRE, pos=DefaultPosition) -> None:
        """ Constructor specifying the message box properties.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetCancelLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetCaption(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetEffectiveIcon(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetExtendedMessage(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetHelpLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetMessage(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetMessageDialogStyle(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetNoLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetOKLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def GetYesLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def HasCustomLabels(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def SetExtendedMessage(self, extendedMessage: str) -> None:
        """ Sets the extended message for the dialog: this message is usually an extension of the short message specified in the constructor or set with SetMessage .

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def SetHelpLabel(self, help: MessageDialogButtonLabel) -> bool:
        """ Sets the label for the Help button.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def SetMessage(self, message: str) -> None:
        """ Sets the message shown by the dialog.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def SetOKCancelLabels(self, ok, cancel) -> bool:
        """ Overrides the default labels of the wx.OK and Cancel buttons.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def SetOKLabel(self, ok: MessageDialogButtonLabel) -> bool:
        """ Overrides the default label of the wx.OK button.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def SetYesNoCancelLabels(self, yes, no, cancel) -> bool:
        """ Overrides the default labels of the Yes, No and Cancel buttons.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def SetYesNoLabels(self, yes, no) -> bool:
        """ Overrides the default labels of the Yes and No buttons.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning one of wx.ID_OK, wx.ID_CANCEL, wx.ID_YES, wx.ID_NO or wx.ID_HELP.

            Source: https://docs.wxpython.org/wx.MessageDialog.html
        """

    CancelLabel: str  # See GetCancelLabel
    Caption: str  # See GetCaption
    EffectiveIcon: int  # See GetEffectiveIcon
    ExtendedMessage: str  # See GetExtendedMessage and SetExtendedMessage
    HelpLabel: MessageDialogButtonLabel  # See GetHelpLabel and SetHelpLabel
    Message: str  # See GetMessage and SetMessage
    MessageDialogStyle: int  # See GetMessageDialogStyle
    NoLabel: str  # See GetNoLabel
    OKLabel: MessageDialogButtonLabel  # See GetOKLabel and SetOKLabel
    YesLabel: str  # See GetYesLabel



class Metafile(Object):
    """ A Metafile represents the MS Windows metafile object, so metafile
operations have no effect in X.

        Source: https://docs.wxpython.org/wx.Metafile.html
    """
    def __init__(self, filename: str="") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.Metafile.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the metafile is valid.

            Source: https://docs.wxpython.org/wx.Metafile.html
        """

    def Play(self, dc: 'DC') -> bool:
        """ Plays the metafile into the given device context, returning True if successful.

            Source: https://docs.wxpython.org/wx.Metafile.html
        """

    def SetClipboard(self, width=0, height=0) -> bool:
        """ Passes the metafile data to the clipboard.

            Source: https://docs.wxpython.org/wx.Metafile.html
        """



class MimeTypesManager:
    """ This class allows the application to retrieve information about all
known MIME types from a system-specific location and the filename
extensions to the MIME types and vice versa.

        Source: https://docs.wxpython.org/wx.MimeTypesManager.html
    """
    def __init__(self) -> None:
        """ Constructor puts the object in the âworkingâ state.

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """

    def AddFallbacks(self, fallbacks: 'FileTypeInfo') -> None:
        """ This function may be used to provide hard-wired fallbacks for the MIME types and extensions that might not be present in the system MIME database.

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """

    def Associate(self, ftInfo: 'FileTypeInfo') -> 'FileType':
        """ Create a new association using the fields of   wx.FileTypeInfo  (at least the MIME type and the extension should be set).

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """

    def EnumAllFileTypes(self) -> list[str]:
        """ Returns a list of all known file types.

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """

    def GetFileTypeFromExtension(self, extension: str) -> 'FileType':
        """ Gather information about the files with given extension and return the corresponding   wx.FileType  object or None if the extension is unknown.

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """

    def GetFileTypeFromMimeType(self, mimeType: str) -> 'FileType':
        """ Gather information about the files with given MIME type and return the corresponding   wx.FileType  object or None if the MIME type is unknown.

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """

    @staticmethod
    def IsOfType(mimeType, wildcard) -> bool:
        """ This function returns True if either the given mimeType  is exactly the same as wildcard  or if it has the same category and the subtype of wildcard  is ââ.

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """

    def Unassociate(self, ft: 'FileType') -> bool:
        """ Undo Associate .

            Source: https://docs.wxpython.org/wx.MimeTypesManager.html
        """



class MiniFrame(Frame):
    """ A miniframe is a frame with a small title bar.

        Source: https://docs.wxpython.org/wx.MiniFrame.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MiniFrame.html
        """

    def Create(self, parent, id=ID_ANY, title="", pos=DefaultPosition, size=DefaultSize, style=CAPTION|RESIZE_BORDER, name=FrameNameStr) -> bool:
        """ Used in two-step frame construction.

            Source: https://docs.wxpython.org/wx.MiniFrame.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.MiniFrame.html
        """



class MirrorDC(DC):
    """ MirrorDC is a simple wrapper class which is always associated with a
real DC object and either forwards all of its operations to it
without changes (no mirroring takes place) or exchanges x and y
coordinates which makes it possible to reuse the same code to draw a
figure and its mirror  i.e.

        Source: https://docs.wxpython.org/wx.MirrorDC.html
    """
    def __init__(self, dc, mirror) -> None:
        """ Creates a (maybe) mirrored DC associated with the real dc.

            Source: https://docs.wxpython.org/wx.MirrorDC.html
        """



class ModalDialogHook:
    """ Allows intercepting all modal dialog calls.

        Source: https://docs.wxpython.org/wx.ModalDialogHook.html
    """
    def __init__(self) -> None:
        """ Default and trivial constructor.

            Source: https://docs.wxpython.org/wx.ModalDialogHook.html
        """

    def Enter(self, dialog: 'Dialog') -> int:
        """ Called by wxWidgets before showing any modal dialogs.

            Source: https://docs.wxpython.org/wx.ModalDialogHook.html
        """

    def Exit(self, dialog: 'Dialog') -> None:
        """ Called by wxWidgets after dismissing the modal dialog.

            Source: https://docs.wxpython.org/wx.ModalDialogHook.html
        """

    def Register(self) -> None:
        """ Register this hook as being active.

            Source: https://docs.wxpython.org/wx.ModalDialogHook.html
        """

    def Unregister(self) -> None:
        """ Unregister this hook.

            Source: https://docs.wxpython.org/wx.ModalDialogHook.html
        """



class MouseCaptureChangedEvent(Event):
    """ A mouse capture changed event is sent to a window that loses its mouse
capture.

        Source: https://docs.wxpython.org/wx.MouseCaptureChangedEvent.html
    """
    def __init__(self, windowId=0, gainedCapture=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MouseCaptureChangedEvent.html
        """

    def GetCapturedWindow(self) -> 'Window':
        """ Returns the window that gained the capture, or None if it was a non-wxWidgets window.

            Source: https://docs.wxpython.org/wx.MouseCaptureChangedEvent.html
        """

    CapturedWindow: 'Window'  # See GetCapturedWindow



class MouseCaptureLostEvent(Event):
    """ A mouse capture lost event is sent to a window that had obtained mouse
capture, which was subsequently lost due to an âexternalâ event (for
example, when a dialog box is shown or if another application captures
the mouse).

        Source: https://docs.wxpython.org/wx.MouseCaptureLostEvent.html
    """
    def __init__(self, windowId: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MouseCaptureLostEvent.html
        """



class MouseEvent(Event,MouseState):
    """ This event class contains information about the events generated by
the mouse: they include mouse buttons press and release events and
mouse move events.

        Source: https://docs.wxpython.org/wx.MouseEvent.html
    """
    def __init__(self, mouseEventType: int=wxEVT_NULL) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Aux1DClick(self) -> bool:
        """ Returns True if the event was a first extra button double click.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Aux1Down(self) -> bool:
        """ Returns True if the first extra button mouse button changed to down.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Aux1Up(self) -> bool:
        """ Returns True if the first extra button mouse button changed to up.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Aux2DClick(self) -> bool:
        """ Returns True if the event was a second extra button double click.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Aux2Down(self) -> bool:
        """ Returns True if the second extra button mouse button changed to down.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Aux2Up(self) -> bool:
        """ Returns True if the second extra button mouse button changed to up.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Button(self, but: MouseButton) -> bool:
        """ Returns True if the event was generated by the specified button.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def ButtonDClick(self, but: MouseButton=MOUSE_BTN_ANY) -> bool:
        """ If the argument is omitted, this returns True if the event was a mouse double click event.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def ButtonDown(self, but: MouseButton=MOUSE_BTN_ANY) -> bool:
        """ If the argument is omitted, this returns True if the event was a mouse button down event.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def ButtonUp(self, but: MouseButton=MOUSE_BTN_ANY) -> bool:
        """ If the argument is omitted, this returns True if the event was a mouse button up event.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Dragging(self) -> bool:
        """ Returns True if this was a dragging event (motion while a button is depressed).

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Entering(self) -> bool:
        """ Returns True if the mouse was entering the window.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetButton(self) -> int:
        """ Returns the mouse button which generated this event or  MOUSE_BTN_NONE   if no button is involved (for mouse move, enter or leave event, for example).

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetClickCount(self) -> int:
        """ Returns the number of mouse clicks for this event: 1 for a simple click, 2 for a double-click, 3 for a triple-click and so on.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetColumnsPerAction(self) -> int:
        """ Returns the configured number of columns (or whatever) to be scrolled per wheel action.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetLinesPerAction(self) -> int:
        """ Returns the configured number of lines (or whatever) to be scrolled per wheel action.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetLogicalPosition(self, dc: 'DC') -> 'Point':
        """ Returns the logical mouse position in pixels (i.e. translated according to the translation set for the DC, which usually indicates that the window has been scrolled).

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetMagnification(self) -> float:
        """ For magnify (pinch to zoom) events: returns the change in magnification.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetWheelAxis(self) -> 'MouseWheelAxis':
        """ Gets the axis the wheel operation concerns.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetWheelDelta(self) -> int:
        """ Get wheel delta, normally 120.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def GetWheelRotation(self) -> int:
        """ Get wheel rotation, positive or negative indicates direction of rotation.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def IsButton(self) -> bool:
        """ Returns True if the event was a mouse button event (not necessarily a button down event - that may be tested using ButtonDown ).

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def IsPageScroll(self) -> bool:
        """ Returns True if the system has been setup to do page scrolling with the mouse wheel instead of line scrolling.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def IsWheelInverted(self) -> bool:
        """ On Mac, has the user selected âNaturalâ scrolling in their System Preferences? Currently False on all other OSâs.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Leaving(self) -> bool:
        """ Returns True if the mouse was leaving the window.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def LeftDClick(self) -> bool:
        """ Returns True if the event was a left double click.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def LeftDown(self) -> bool:
        """ Returns True if the left mouse button changed to down.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def LeftUp(self) -> bool:
        """ Returns True if the left mouse button changed to up.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Magnify(self) -> bool:
        """ Returns True if the event is a magnify (i.e. pinch to zoom) event.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def MetaDown(self) -> bool:
        """ Returns True if the Meta key was down at the time of the event.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def MiddleDClick(self) -> bool:
        """ Returns True if the event was a middle double click.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def MiddleDown(self) -> bool:
        """ Returns True if the middle mouse button changed to down.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def MiddleUp(self) -> bool:
        """ Returns True if the middle mouse button changed to up.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def Moving(self) -> bool:
        """ Returns True if this was a motion event and no mouse buttons were pressed.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def RightDClick(self) -> bool:
        """ Returns True if the event was a right double click.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def RightDown(self) -> bool:
        """ Returns True if the right mouse button changed to down.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def RightUp(self) -> bool:
        """ Returns True if the right mouse button changed to up.

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def SetColumnsPerAction(self, columnsPerAction) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def SetLinesPerAction(self, linesPerAction) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def SetWheelAxis(self, wheelAxis) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def SetWheelDelta(self, wheelDelta) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    def SetWheelRotation(self, wheelRotation) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.MouseEvent.html
        """

    ColumnsPerAction: int  # See GetColumnsPerAction and SetColumnsPerAction
    LinesPerAction: int  # See GetLinesPerAction and SetLinesPerAction
    WheelAxis: 'MouseWheelAxis'  # See GetWheelAxis and SetWheelAxis
    WheelDelta: int  # See GetWheelDelta and SetWheelDelta
    WheelRotation: int  # See GetWheelRotation and SetWheelRotation



EVT_LEFT_DOWN: int  # Process a  wxEVT_LEFT_DOWN   event. The handler of this event should normally call event.Skip() to allow the default processing to take place as otherwise the window under mouse wouldnât get the focus.

EVT_LEFT_UP: int  # Process a  wxEVT_LEFT_UP   event.

EVT_LEFT_DCLICK: int  # Process a  wxEVT_LEFT_DCLICK   event.

EVT_MIDDLE_DOWN: int  # Process a  wxEVT_MIDDLE_DOWN   event.

EVT_MIDDLE_UP: int  # Process a  wxEVT_MIDDLE_UP   event.

EVT_MIDDLE_DCLICK: int  # Process a  wxEVT_MIDDLE_DCLICK   event.

EVT_RIGHT_DOWN: int  # Process a  wxEVT_RIGHT_DOWN   event.

EVT_RIGHT_UP: int  # Process a  wxEVT_RIGHT_UP   event.

EVT_RIGHT_DCLICK: int  # Process a  wxEVT_RIGHT_DCLICK   event.

EVT_MOUSE_AUX1_DOWN: int  # Process a  wxEVT_AUX1_DOWN   event.

EVT_MOUSE_AUX1_UP: int  # Process a  wxEVT_AUX1_UP   event.

EVT_MOUSE_AUX1_DCLICK: int  # Process a  wxEVT_AUX1_DCLICK   event.

EVT_MOUSE_AUX2_DOWN: int  # Process a  wxEVT_AUX2_DOWN   event.

EVT_MOUSE_AUX2_UP: int  # Process a  wxEVT_AUX2_UP   event.

EVT_MOUSE_AUX2_DCLICK: int  # Process a  wxEVT_AUX2_DCLICK   event.

EVT_MOTION: int  # Process a  wxEVT_MOTION   event.

EVT_ENTER_WINDOW: int  # Process a  wxEVT_ENTER_WINDOW   event.

EVT_LEAVE_WINDOW: int  # Process a  wxEVT_LEAVE_WINDOW   event.

EVT_MOUSEWHEEL: int  # Process a  wxEVT_MOUSEWHEEL   event.

EVT_MOUSE_EVENTS: int  # Process all mouse events.

EVT_MAGNIFY: int  # Process a  wxEVT_MAGNIFY   event (new since wxWidgets 3.1.0). ^^

class MouseEventsManager(EvtHandler):
    """ Helper for handling mouse input events in windows containing multiple
items.

        Source: https://docs.wxpython.org/wx.MouseEventsManager.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def Create(self, win: 'Window') -> bool:
        """ Finishes initialization of the object created using default constructor.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseClickBegin(self, item: int) -> None:
        """ May be overridden to update the state of an item when it is pressed.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseClickCancelled(self, item: int) -> None:
        """ Must be overridden to reset the item appearance changed by MouseClickBegin .

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseClicked(self, item: int) -> bool:
        """ Must be overridden to react to mouse clicks.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseDragBegin(self, item, pos) -> bool:
        """ Must be overridden to allow or deny dragging of the item.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseDragCancelled(self, item: int) -> None:
        """ Must be overridden to handle cancellation of mouse dragging.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseDragEnd(self, item, pos) -> None:
        """ Must be overridden to handle item drop.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseDragging(self, item, pos) -> None:
        """ Must be overridden to provide feed back while an item is being dragged.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """

    def MouseHitTest(self, pos: Union[tuple[int, int], 'Point']) -> int:
        """ Must be overridden to return the item at the given position.

            Source: https://docs.wxpython.org/wx.MouseEventsManager.html
        """



class MouseState(KeyboardState):
    """ Represents the mouse state.

        Source: https://docs.wxpython.org/wx.MouseState.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def Aux1IsDown(self) -> bool:
        """ Returns True if the first extra button mouse button is currently down.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def Aux2IsDown(self) -> bool:
        """ Returns True if the second extra button mouse button is currently down.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the physical mouse position.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def GetX(self) -> 'Coord':
        """ Returns X coordinate of the physical mouse event position.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def GetY(self) -> 'Coord':
        """ Returns Y coordinate of the physical mouse event position.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def LeftIsDown(self) -> bool:
        """ Returns True if the left mouse button is currently down.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def MiddleIsDown(self) -> bool:
        """ Returns True if the middle mouse button is currently down.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def RightIsDown(self) -> bool:
        """ Returns True if the right mouse button is currently down.

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetAux1Down(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetAux2Down(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetLeftDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetMiddleDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetPosition(self, pos: Union[tuple[int, int], 'Point']) -> None:
        """ pos (wx.Point) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetRightDown(self, down: bool) -> None:
        """ down (bool) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetState(self, state: 'MouseState') -> None:
        """ state (wx.MouseState) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetX(self, x: int) -> None:
        """ x (int) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    def SetY(self, y: int) -> None:
        """ y (int) â

            Source: https://docs.wxpython.org/wx.MouseState.html
        """

    Position: Union[tuple[int, int], 'Point']  # See GetPosition and SetPosition
    X: int  # See GetX and SetX
    Y: int  # See GetY and SetY
    aux1IsDown: Any  # See Aux1IsDown and SetAux1Down
    aux2IsDown: Any  # See Aux2IsDown and SetAux2Down
    leftIsDown: Any  # See LeftIsDown and SetLeftDown
    middleIsDown: Any  # See MiddleIsDown and SetMiddleDown
    rightIsDown: Any  # See RightIsDown and SetRightDown
    x: Any  # See GetX and SetX
    y: Any  # See GetY and SetY



class MoveEvent(Event):
    """ A move event holds information about window position change.

        Source: https://docs.wxpython.org/wx.MoveEvent.html
    """
    def __init__(self, pt, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.MoveEvent.html
        """

    def GetPosition(self) -> 'Point':
        """ Returns the position of the window generating the move change event.

            Source: https://docs.wxpython.org/wx.MoveEvent.html
        """

    def GetRect(self) -> 'Rect':
        """ wx.Rect

            Source: https://docs.wxpython.org/wx.MoveEvent.html
        """

    def SetPosition(self, pos: Union[tuple[int, int], 'Point']) -> None:
        """ pos (wx.Point) â

            Source: https://docs.wxpython.org/wx.MoveEvent.html
        """

    def SetRect(self, rect: 'Rect') -> None:
        """ rect (wx.Rect) â

            Source: https://docs.wxpython.org/wx.MoveEvent.html
        """

    Position: Union[tuple[int, int], 'Point']  # See GetPosition and SetPosition
    Rect: 'Rect'  # See GetRect and SetRect



EVT_MOVE: int  # Process a  wxEVT_MOVE   event, which is generated when a window is moved.

EVT_MOVE_START: int  # Process a  wxEVT_MOVE_START   event, which is generated when the user starts to move or size a window. wxMSW only.

EVT_MOVING: int  # Process a  wxEVT_MOVING   event, which is generated while the user is moving the window. wxMSW only.

EVT_MOVE_END: int  # Process a  wxEVT_MOVE_END   event, which is generated when the user stops moving or sizing a window. wxMSW only. ^^

class MultiChoiceDialog(Dialog):
    """ This class represents a dialog that shows a list of strings, and
allows the user to select one or more.

        Source: https://docs.wxpython.org/wx.MultiChoiceDialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.MultiChoiceDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.MultiChoiceDialog.html
        """

    def GetSelections(self) -> list[int]:
        """ Returns array with indexes of selected items.

            Source: https://docs.wxpython.org/wx.MultiChoiceDialog.html
        """

    def SetSelections(self, selections: list[int]) -> None:
        """ Sets selected items from the array of selected itemsâ indexes.

            Source: https://docs.wxpython.org/wx.MultiChoiceDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning either wx.ID_OK or wx.ID_CANCEL.

            Source: https://docs.wxpython.org/wx.MultiChoiceDialog.html
        """

    Selections: list[int]  # See GetSelections and SetSelections



class NativeFontInfo:
    """ NativeFontInfo is platform-specific font representation: this class
should be considered as an opaque font description only used by the
native functions, the user code can only get the objects of this type
from somewhere and pass it somewhere else (possibly save them
somewhere using ToString() and restore them using FromString())

        Source: https://docs.wxpython.org/wx.NativeFontInfo.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def FromString(self, s: str) -> bool:
        """ s (string) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def FromUserString(self, s: str) -> bool:
        """ s (string) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetEncoding(self) -> int:
        """ wx.FontEncoding

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetFaceName(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetFamily(self) -> int:
        """ wx.FontFamily

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetFractionalPointSize(self) -> float:
        """ float

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetNumericWeight(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetPointSize(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetStyle(self) -> int:
        """ wx.FontStyle

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetUnderlined(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def GetWeight(self) -> int:
        """ wx.FontWeight

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def Init(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def InitFromFont(self, font: 'Font') -> None:
        """ font (wx.Font) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetEncoding(self, encoding: int) -> None:
        """ encoding (FontEncoding) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetFaceName(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetFamily(self, family: int) -> None:
        """ family (FontFamily) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetFractionalPointSize(self, pointsize: float) -> None:
        """ pointsize (float) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetNumericWeight(self, weight: int) -> None:
        """ weight (int) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetPointSize(self, pointsize: int) -> None:
        """ pointsize (int) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetStyle(self, style: int) -> None:
        """ style (FontStyle) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetUnderlined(self, underlined: bool) -> None:
        """ underlined (bool) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def SetWeight(self, weight: int) -> None:
        """ weight (FontWeight) â

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def ToString(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def ToUserString(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    def __str__(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.NativeFontInfo.html
        """

    Encoding: int  # See GetEncoding and SetEncoding
    FaceName: str  # See GetFaceName and SetFaceName
    Family: int  # See GetFamily and SetFamily
    FractionalPointSize: float  # See GetFractionalPointSize and SetFractionalPointSize
    NumericWeight: int  # See GetNumericWeight and SetNumericWeight
    PointSize: int  # See GetPointSize and SetPointSize
    Style: int  # See GetStyle and SetStyle
    Underlined: bool  # See GetUnderlined and SetUnderlined
    Weight: int  # See GetWeight and SetWeight



class NativePixelData:
    """ A class providing direct access to a wx.Bitmapâs
internal data without alpha channel (RGB).

        Source: https://docs.wxpython.org/wx.NativePixelData.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.NativePixelData.html
        """

    def GetPixels(self) -> 'NativePixelData_Accessor':
        """ wx.NativePixelData_Accessor

            Source: https://docs.wxpython.org/wx.NativePixelData.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.NativePixelData.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.NativePixelData.html
        """

    Pixels: 'NativePixelData_Accessor'  # See GetPixels



class NativePixelData_Accessor:
    """  Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def Get(self) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def IsOk(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def MoveTo(self, data, x, y) -> None:
        """ data (NativePixelData) â

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def Offset(self, data, x, y) -> None:
        """ data (NativePixelData) â

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def OffsetX(self, data, x) -> None:
        """ data (NativePixelData) â

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def OffsetY(self, data, y) -> None:
        """ data (NativePixelData) â

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def Reset(self, data: NativePixelData) -> None:
        """ data (NativePixelData) â

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def Set(self, red, green, blue) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """

    def nextPixel(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.NativePixelData_Accessor.html
        """



class NavigationKeyEvent(Event):
    """ This event class contains information about navigation events,
generated by navigation keys such as tab and page down.

        Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def GetCurrentFocus(self) -> 'Window':
        """ Returns the child that has the focus, or None.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def GetDirection(self) -> bool:
        """ Returns True if the navigation was in the forward direction.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def IsFromTab(self) -> bool:
        """ Returns True if the navigation event was from a tab key.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def IsWindowChange(self) -> bool:
        """ Returns True if the navigation event represents a window change (for example, from Ctrl-Page Down in a notebook).

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def SetCurrentFocus(self, currentFocus: 'Window') -> None:
        """ Sets the current focus window member.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def SetDirection(self, direction: bool) -> None:
        """ Sets the direction to forward if direction  is True, or backward if False.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def SetFlags(self, flags: int) -> None:
        """ Sets the flags for this event.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def SetFromTab(self, fromTab: bool) -> None:
        """ Marks the navigation event as from a tab key.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    def SetWindowChange(self, windowChange: bool) -> None:
        """ Marks the event as a window change event.

            Source: https://docs.wxpython.org/wx.NavigationKeyEvent.html
        """

    CurrentFocus: 'Window'  # See GetCurrentFocus and SetCurrentFocus
    Direction: bool  # See GetDirection and SetDirection



class NonOwnedWindow(Window):
    """ Common base class for all non-child windows.

        Source: https://docs.wxpython.org/wx.NonOwnedWindow.html
    """
    def SetShape(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.NonOwnedWindow.html
        """



class NotifyEvent(CommandEvent):
    """ This class is not used by the event handlers by itself, but is a base
class for other event classes (such as BookCtrlEvent).

        Source: https://docs.wxpython.org/wx.NotifyEvent.html
    """
    def __init__(self, eventType=wxEVT_NULL, id=0) -> None:
        """ Constructor (used internally by wxWidgets only).

            Source: https://docs.wxpython.org/wx.NotifyEvent.html
        """

    def Allow(self) -> None:
        """ This is the opposite of Veto : it explicitly allows the event to be processed.

            Source: https://docs.wxpython.org/wx.NotifyEvent.html
        """

    def IsAllowed(self) -> bool:
        """ Returns True if the change is allowed ( Veto   hasnât been called) or False otherwise (if it was).

            Source: https://docs.wxpython.org/wx.NotifyEvent.html
        """

    def Veto(self) -> None:
        """ Prevents the change announced by this event from happening.

            Source: https://docs.wxpython.org/wx.NotifyEvent.html
        """



class NumberEntryDialog(Dialog):
    """ This class represents a dialog that requests a numeric input from the
user.

        Source: https://docs.wxpython.org/wx.NumberEntryDialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.NumberEntryDialog.html
        """

    def Create(self, parent, message, prompt, caption, value, min, max, pos=DefaultPosition) -> bool:
        """ parent (wx.Window) â Parent window.

            Source: https://docs.wxpython.org/wx.NumberEntryDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.NumberEntryDialog.html
        """

    def GetValue(self) -> int:
        """ Returns the value that the user has entered if the user has pressed wx.OK, or the original value if the user has pressed Cancel.

            Source: https://docs.wxpython.org/wx.NumberEntryDialog.html
        """

    Value: int  # See GetValue



class Object:
    """ This is the root class of many of the wxWidgets classes.

        Source: https://docs.wxpython.org/wx.Object.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def Destroy(self) -> Optional[bool]:
        """ Deletes the C++ object this Python object is a proxy for.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def GetClassInfo(self) -> 'ClassInfo':
        """ This virtual function is redefined for every class that requires run-time type information, when using the DECLARE_CLASS  macro (or similar).

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def GetClassName(self) -> 'Char':
        """ Returns the class name of the C++ class using RTTI.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def GetRefData(self) -> 'ObjectRefData':
        """ Returns the Object.m_refData  pointer, i.e. the data referenced by this object.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def IsSameAs(self, obj: 'Object') -> bool:
        """ Returns True if this object has the same data pointer as obj.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def Ref(self, clone: 'Object') -> None:
        """ Makes this object refer to the data in clone.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def SetRefData(self, data: 'ObjectRefData') -> None:
        """ Sets the Object.m_refData  pointer.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def UnRef(self) -> None:
        """ Decrements the reference count in the associated data, and if it is zero, deletes the data.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    def UnShare(self) -> None:
        """ This is the same of AllocExclusive   but this method is public.

            Source: https://docs.wxpython.org/wx.Object.html
        """

    ClassInfo: 'ClassInfo'  # See GetClassInfo
    ClassName: 'Char'  # See GetClassName
    RefData: 'ObjectRefData'  # See GetRefData and SetRefData



class OutputStream(StreamBase):
    """ OutputStream is an abstract base class which may not be used
directly.

        Source: https://docs.wxpython.org/wx.OutputStream.html
    """
    def __init__(self) -> None:
        """ Creates a dummy   wx.OutputStream  object.

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def Close(self) -> bool:
        """ Closes the stream, returning False if an error occurs.

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def LastWrite(self) -> int:
        """ Returns the number of bytes written during the last Write .

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def PutC(self, c: int) -> None:
        """ Puts the specified character in the output queue and increments the stream position.

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def SeekO(self, pos, mode=FromStart) -> 'FileOffset':
        """ Changes the stream current position.

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def TellO(self) -> 'FileOffset':
        """ Returns the current stream position.

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def Write(self, *args, **kw) -> 'OutputStream':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def WriteAll(self, buffer, size) -> bool:
        """ Writes exactly the specified number of bytes from the buffer.

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def close(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def eof(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def flush(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def seek(self, offset, whence=0) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def tell(self) -> 'FileOffset':
        """ wx.FileOffset

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """

    def write(self, data) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.OutputStream.html
        """



class Overlay:
    """ Creates an overlay over an existing window, allowing for manipulations
like rubberbanding, etc.

        Source: https://docs.wxpython.org/wx.Overlay.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Overlay.html
        """

    def Reset(self) -> None:
        """ Clears the overlay without restoring the former state.

            Source: https://docs.wxpython.org/wx.Overlay.html
        """



class PageSetupDialog(Object):
    """ This class represents the page setup common dialog.

        Source: https://docs.wxpython.org/wx.PageSetupDialog.html
    """
    def __init__(self, parent, data=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PageSetupDialog.html
        """

    def GetPageSetupData(self) -> 'PageSetupDialogData':
        """ Returns the   wx.PageSetupDialogData  object associated with the dialog.

            Source: https://docs.wxpython.org/wx.PageSetupDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning  ID_OK   if the user pressed wx.OK, and   ID_CANCEL   otherwise.

            Source: https://docs.wxpython.org/wx.PageSetupDialog.html
        """

    PageSetupData: 'PageSetupDialogData'  # See GetPageSetupData



class PageSetupDialogData(Object):
    """ This class holds a variety of information related to
PageSetupDialog.

        Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def EnableHelp(self, flag: bool) -> None:
        """ Enables or disables the âHelpâ button (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def EnableMargins(self, flag: bool) -> None:
        """ Enables or disables the margin controls (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def EnableOrientation(self, flag: bool) -> None:
        """ Enables or disables the orientation control (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def EnablePaper(self, flag: bool) -> None:
        """ Enables or disables the paper size control (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def EnablePrinter(self, flag: bool) -> None:
        """ Enables or disables the âPrinterâ button, which invokes a printer setup dialog.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetDefaultInfo(self) -> bool:
        """ Returns True if the dialog will simply return default printer information (such as orientation) instead of showing a dialog (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetDefaultMinMargins(self) -> bool:
        """ Returns True if the page setup dialog will take its minimum margin values from the currently selected printer properties (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetEnableHelp(self) -> bool:
        """ Returns True if the printer setup button is enabled.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetEnableMargins(self) -> bool:
        """ Returns True if the margin controls are enabled (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetEnableOrientation(self) -> bool:
        """ Returns True if the orientation control is enabled (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetEnablePaper(self) -> bool:
        """ Returns True if the paper size control is enabled (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetEnablePrinter(self) -> bool:
        """ Returns True if the printer setup button is enabled.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetMarginBottomRight(self) -> 'Point':
        """ Returns the right (x) and bottom (y) margins in millimetres.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetMarginTopLeft(self) -> 'Point':
        """ Returns the left (x) and top (y) margins in millimetres.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetMinMarginBottomRight(self) -> 'Point':
        """ Returns the right (x) and bottom (y) minimum margins the user can enter (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetMinMarginTopLeft(self) -> 'Point':
        """ Returns the left (x) and top (y) minimum margins the user can enter (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetPaperId(self) -> 'PaperSize':
        """ Returns the paper id (stored in the internal   wx.PrintData  object).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetPaperSize(self) -> 'Size':
        """ Returns the paper size in millimetres.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def GetPrintData(self) -> 'PrintData':
        """ Returns a reference to the print data associated with this object.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the print data associated with the dialog data is valid.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetDefaultInfo(self, flag: bool) -> None:
        """ Pass True if the dialog will simply return default printer information (such as orientation) instead of showing a dialog (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetDefaultMinMargins(self, flag: bool) -> None:
        """ Pass True if the page setup dialog will take its minimum margin values from the currently selected printer properties (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetMarginBottomRight(self, pt: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the right (x) and bottom (y) margins in millimetres.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetMarginTopLeft(self, pt: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the left (x) and top (y) margins in millimetres.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetMinMarginBottomRight(self, pt: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the right (x) and bottom (y) minimum margins the user can enter (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetMinMarginTopLeft(self, pt: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the left (x) and top (y) minimum margins the user can enter (Windows only).

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetPaperId(self, id: PaperSize) -> None:
        """ Sets the paper size id.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetPaperSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the paper size in millimetres.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def SetPrintData(self, printData: 'PrintData') -> None:
        """ Sets the print data associated with this object.

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PageSetupDialogData.html
        """

    MarginBottomRight: Union[tuple[int, int], 'Point']  # See GetMarginBottomRight and SetMarginBottomRight
    MarginTopLeft: Union[tuple[int, int], 'Point']  # See GetMarginTopLeft and SetMarginTopLeft
    MinMarginBottomRight: Union[tuple[int, int], 'Point']  # See GetMinMarginBottomRight and SetMinMarginBottomRight
    MinMarginTopLeft: Union[tuple[int, int], 'Point']  # See GetMinMarginTopLeft and SetMinMarginTopLeft
    PaperId: PaperSize  # See GetPaperId and SetPaperId
    PaperSize: Union[tuple[int, int], 'Size']  # See GetPaperSize and SetPaperSize
    PrintData: 'PrintData'  # See GetPrintData and SetPrintData



class PaintEvent(Event):
    """ A paint event is sent when a windowâs contents needs to be repainted.

        Source: https://docs.wxpython.org/wx.PaintEvent.html
    """
    def __init__(self, window: 'Window') -> None:
        """ Constructor for exclusive use of wxWidgets itself.

            Source: https://docs.wxpython.org/wx.PaintEvent.html
        """



class Palette(GDIObject):
    """ A palette is a table that maps pixel values to RGB colours.

        Source: https://docs.wxpython.org/wx.Palette.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Palette.html
        """

    def Create(self, red, green, blue) -> None:
        """ Creates a palette from 3 sequences of integers, one for each red, blue or green component.

            Source: https://docs.wxpython.org/wx.Palette.html
        """

    def GetColoursCount(self) -> int:
        """ Returns number of entries in palette.

            Source: https://docs.wxpython.org/wx.Palette.html
        """

    def GetPixel(self, red, green, blue) -> int:
        """ Returns a pixel value (index into the palette) for the given RGB values.

            Source: https://docs.wxpython.org/wx.Palette.html
        """

    def GetRGB(self, pixel) -> tuple:
        """ Returns RGB values for a given palette index.

            Source: https://docs.wxpython.org/wx.Palette.html
        """

    def IsOk(self) -> bool:
        """ Returns True if palette data is present.

            Source: https://docs.wxpython.org/wx.Palette.html
        """

    ColoursCount: int  # See GetColoursCount
    RGB: tuple  # See GetRGB



class PaletteChangedEvent(Event):
    """ winid (wx.WindowID) â 

        Source: https://docs.wxpython.org/wx.PaletteChangedEvent.html
    """
    def __init__(self, winid: int=0) -> None:
        """ winid (wx.WindowID) â

            Source: https://docs.wxpython.org/wx.PaletteChangedEvent.html
        """

    def GetChangedWindow(self) -> 'Window':
        """ wx.Window

            Source: https://docs.wxpython.org/wx.PaletteChangedEvent.html
        """

    def SetChangedWindow(self, win: 'Window') -> None:
        """ win (wx.Window) â

            Source: https://docs.wxpython.org/wx.PaletteChangedEvent.html
        """

    ChangedWindow: 'Window'  # See GetChangedWindow and SetChangedWindow



class Panel(Window):
    """ A panel is a window on which controls are placed.

        Source: https://docs.wxpython.org/wx.Panel.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Panel.html
        """

    def AcceptsFocus(self) -> bool:
        """ This method is overridden from wx.Window.AcceptsFocus   and returns True only if there is no child window in the panel which can accept the focus.

            Source: https://docs.wxpython.org/wx.Panel.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=TAB_TRAVERSAL, name=PanelNameStr) -> bool:
        """ Used for two-step panel construction.

            Source: https://docs.wxpython.org/wx.Panel.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Panel.html
        """

    def InitDialog(self) -> None:
        """ Sends a   wx.InitDialogEvent, which in turn transfers data to the dialog via validators.

            Source: https://docs.wxpython.org/wx.Panel.html
        """

    def Layout(self) -> bool:
        """ See wx.Window.SetAutoLayout : when auto layout is on, this function gets called automatically when the window is resized.

            Source: https://docs.wxpython.org/wx.Panel.html
        """

    def SetFocus(self) -> None:
        """ Overrides wx.Window.SetFocus .

            Source: https://docs.wxpython.org/wx.Panel.html
        """

    def SetFocusIgnoringChildren(self) -> None:
        """ In contrast to SetFocus   (see above) this will set the focus to the panel even if there are child windows in the panel.

            Source: https://docs.wxpython.org/wx.Panel.html
        """



class PanGestureEvent(GestureEvent):
    """ This event is generated when the user moves a finger on the surface.

        Source: https://docs.wxpython.org/wx.PanGestureEvent.html
    """
    def __init__(self, winid: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PanGestureEvent.html
        """

    def GetDelta(self) -> 'Point':
        """ Returns the distance covered since the previous panning event.

            Source: https://docs.wxpython.org/wx.PanGestureEvent.html
        """

    def SetDelta(self, delta: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the distance covered since the previous panning event.

            Source: https://docs.wxpython.org/wx.PanGestureEvent.html
        """

    Delta: Union[tuple[int, int], 'Point']  # See GetDelta and SetDelta



EVT_GESTURE_PAN: int  # Process a  wxEVT_GESTURE_PAN . ^^

class PasswordEntryDialog(TextEntryDialog):
    """ This class represents a dialog that requests a one-line password
string from the user.

        Source: https://docs.wxpython.org/wx.PasswordEntryDialog.html
    """
    def __init__(self, parent, message, caption=GetPasswordFromUserPromptStr, defaultValue="", style=TextEntryDialogStyle, pos=DefaultPosition) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PasswordEntryDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.PasswordEntryDialog.html
        """



class PCXHandler(ImageHandler):
    """ This is the image handler for the PCX format.

        Source: https://docs.wxpython.org/wx.PCXHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.PCXHandler.

            Source: https://docs.wxpython.org/wx.PCXHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.PCXHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.PCXHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.PCXHandler.html
        """



class PenInfo:
    """ This class is a helper used for Pen creation using named parameter
idiom: it allows specifying various Pen attributes using the chained
calls to its clearly named methods instead of passing them in the
fixed order to Pen constructors.

        Source: https://docs.wxpython.org/wx.PenInfo.html
    """
    def __init__(*args, **kwargs) -> None:
        """ colour (wx.Colour) â

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def Cap(self, cap: PenCap) -> 'PenInfo':
        """ cap (PenCap) â

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def Colour(self, col: Union[int, str, 'Colour']) -> 'PenInfo':
        """ col (wx.Colour) â

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def GetCap(self) -> 'PenCap':
        """ wx.PenCap

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def GetColour(self) -> 'Colour':
        """ wx.Colour

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def GetJoin(self) -> 'PenJoin':
        """ wx.PenJoin

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def GetQuality(self) -> 'PenQuality':
        """ wx.PenQuality

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def GetStipple(self) -> 'Bitmap':
        """ wx.Bitmap

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def GetStyle(self) -> 'PenStyle':
        """ wx.PenStyle

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def GetWidth(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def HighQuality(self) -> 'PenInfo':
        """ Set high pen quality.

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def IsTransparent(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def Join(self, join: PenJoin) -> 'PenInfo':
        """ join (PenJoin) â

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def LowQuality(self) -> 'PenInfo':
        """ Set low pen quality.

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def Quality(self, quality: PenQuality) -> 'PenInfo':
        """ Set the pen quality.

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def Stipple(self, stipple: 'Bitmap') -> 'PenInfo':
        """ stipple (wx.Bitmap) â

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def Style(self, style: PenStyle) -> 'PenInfo':
        """ style (PenStyle) â

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """

    def Width(self, width: int) -> 'PenInfo':
        """ width (int) â

            Source: https://docs.wxpython.org/wx.PenInfo.html
        """



class PenList:
    """ There is only one instance of this class: ThePenList.

        Source: https://docs.wxpython.org/wx.PenList.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PenList.html
        """

    def FindOrCreatePen(self, colour, width=1, style=PENSTYLE_SOLID) -> 'Pen':
        """ Finds a pen with the specified attributes and returns it, else creates a new pen, adds it to the pen list, and returns it.

            Source: https://docs.wxpython.org/wx.PenList.html
        """



class PickerBase(Control):
    """ Base abstract class for all pickers which support an auxiliary text
control.

        Source: https://docs.wxpython.org/wx.PickerBase.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def CreateBase(self, parent, id=ID_ANY, text="", pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=ButtonNameStr) -> bool:
        """ parent (wx.Window) â

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def GetInternalMargin(self) -> int:
        """ Returns the margin (in pixel) between the picker and the text control.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def GetPickerCtrl(self) -> 'Control':
        """ Returns the native implementation of the real picker control.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def GetPickerCtrlProportion(self) -> int:
        """ Returns the proportion value of the picker.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def GetPickerStyle(self, style: int) -> int:
        """ style (long) â

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def GetTextCtrl(self) -> 'TextCtrl':
        """ Returns a pointer to the text control handled by this window or None if the  PB_USE_TEXTCTRL   style was not specified when this control was created.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def GetTextCtrlProportion(self) -> int:
        """ Returns the proportion value of the text control.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def GetTextCtrlStyle(self, style: int) -> int:
        """ style (long) â

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def HasTextCtrl(self) -> bool:
        """ Returns True if this window has a valid text control (i.e. if the  PB_USE_TEXTCTRL   style was given when creating this control).

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def IsPickerCtrlGrowable(self) -> bool:
        """ Returns True if the picker control is growable.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def IsTextCtrlGrowable(self) -> bool:
        """ Returns True if the text control is growable.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def PostCreation(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def SetInternalMargin(self, margin: int) -> None:
        """ Sets the margin (in pixel) between the picker and the text control.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def SetPickerCtrl(self, picker: 'Control') -> None:
        """ picker (wx.Control) â

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def SetPickerCtrlGrowable(self, grow: bool=True) -> None:
        """ Sets the picker control as growable when  grow   is True.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def SetPickerCtrlProportion(self, prop: int) -> None:
        """ Sets the proportion value of the picker.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def SetTextCtrl(self, text: 'TextCtrl') -> None:
        """ text (wx.TextCtrl) â

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def SetTextCtrlGrowable(self, grow: bool=True) -> None:
        """ Sets the text control as growable when  grow   is True.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def SetTextCtrlProportion(self, prop: int) -> None:
        """ Sets the proportion value of the text control.

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def UpdatePickerFromTextCtrl(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    def UpdateTextCtrlFromPicker(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PickerBase.html
        """

    InternalMargin: int  # See GetInternalMargin and SetInternalMargin
    PickerCtrl: 'Control'  # See GetPickerCtrl and SetPickerCtrl
    PickerCtrlProportion: int  # See GetPickerCtrlProportion and SetPickerCtrlProportion
    TextCtrl: 'TextCtrl'  # See GetTextCtrl and SetTextCtrl
    TextCtrlProportion: int  # See GetTextCtrlProportion and SetTextCtrlProportion



PB_USE_TEXTCTRL: int  # Creates a text control to the left of the picker which is completely managed by this   wx.PickerBase  class. ^^

class PixelDataBase:
    """ Return the height of the area this pixel data represents.

        Source: https://docs.wxpython.org/wx.PixelDataBase.html
    """
    def GetHeight(self) -> int:
        """ Return the height of the area this pixel data represents.

            Source: https://docs.wxpython.org/wx.PixelDataBase.html
        """

    def GetOrigin(self) -> 'Point':
        """ Return the origin of the area this pixel data represents.

            Source: https://docs.wxpython.org/wx.PixelDataBase.html
        """

    def GetRowStride(self) -> int:
        """ Returns the distance between the start of one row to the start of the next row.

            Source: https://docs.wxpython.org/wx.PixelDataBase.html
        """

    def GetSize(self) -> 'Size':
        """ Return the size of the area this pixel data represents.

            Source: https://docs.wxpython.org/wx.PixelDataBase.html
        """

    def GetWidth(self) -> int:
        """ Return the width of the area this pixel data represents.

            Source: https://docs.wxpython.org/wx.PixelDataBase.html
        """

    def __iter__(self) -> None:
        """ Create and return an iterator/generator object for traversing
this pixel data object.

            Source: https://docs.wxpython.org/wx.PixelDataBase.html
        """

    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PixelDataBase.html
        """

    Height: int  # See GetHeight
    Origin: 'Point'  # See GetOrigin
    RowStride: int  # See GetRowStride
    Size: 'Size'  # See GetSize
    Width: int  # See GetWidth



class PlatformId:
    """ Defines a very broad platform categorization.

        Source: https://docs.wxpython.org/wx.PlatformId.html
    """


class PlatformInformation:
    """ PlatformInfo()
PlatformInfo(pid, tkMajor=-1, tkMinor=-1, id=OS_UNKNOWN, osMajor=-1, osMinor=-1, bitness=BITNESS_INVALID, endian=ENDIAN_INVALID)

        Source: https://docs.wxpython.org/wx.PlatformInformation.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def CheckOSVersion(self, major, minor, micro=0) -> bool:
        """ Returns True if the OS version is at least  major.minor.micro .

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def CheckToolkitVersion(self, major, minor, micro=0) -> bool:
        """ Returns True if the toolkit version is at least  major.minor.micro .

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    @staticmethod
    def Get() -> PlatformInfo:
        """ Returns the global PlatformInfo       object, initialized with the values for the currently running platform.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    @staticmethod
    def GetArch(arch: str) -> 'Architecture':
        """ arch (string) â

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetArchName(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetArchitecture(self) -> 'Architecture':
        """ wx.Architecture

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetBitness(self) -> 'Bitness':
        """ Returns the architecture bitness ID of this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    @staticmethod
    def GetBitnessName(*args, **kw) -> str:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetCpuArchitectureName(self) -> str:
        """ Returns the CPU architecture name, if available.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetDesktopEnvironment(self) -> str:
        """ Returns the desktop environment associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetEndianness(self) -> 'Endianness':
        """ Returns the endianness ID of this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetEndiannessName(self) -> str:
        """ Returns the name for the endianness of this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetLinuxDistributionInfo(self) -> 'LinuxDistributionInfo':
        """ Returns the Linux distribution info associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetNativeCpuArchitectureName(self) -> str:
        """ Returns the native CPU architecture name, if available.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetOSMajorVersion(self) -> int:
        """ Returns the run-time major version of the OS associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetOSMicroVersion(self) -> int:
        """ Returns the run-time micro version of the OS associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetOSMinorVersion(self) -> int:
        """ Returns the run-time minor version of the OS associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetOperatingSystemDescription(self) -> str:
        """ Returns the description of the operating system of this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    @staticmethod
    def GetOperatingSystemDirectory() -> str:
        """ Returns the operating system directory.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetOperatingSystemFamilyName(self) -> str:
        """ Returns the operating system family name of the OS associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetOperatingSystemId(self) -> 'OperatingSystemId':
        """ Returns the operating system ID of this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetOperatingSystemIdName(self) -> str:
        """ Returns the operating system name of the OS associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetPortId(self) -> 'PortId':
        """ Returns the wxWidgets port ID associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetPortIdName(self) -> str:
        """ Returns the name of the wxWidgets port ID associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetPortIdShortName(self) -> str:
        """ Returns the short name of the wxWidgets port ID associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetToolkitMajorVersion(self) -> int:
        """ Returns the run-time major version of the toolkit associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetToolkitMicroVersion(self) -> int:
        """ Returns the run-time micro version of the toolkit associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def GetToolkitMinorVersion(self) -> int:
        """ Returns the run-time minor version of the toolkit associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def IsOk(self) -> bool:
        """ Returns True if this instance is fully initialized with valid values.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def IsUsingUniversalWidgets(self) -> bool:
        """ Returns True if this PlatformInfo       describes wxUniversal build.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetArchitecture(self, n: Architecture) -> None:
        """ n (Architecture) â

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetBitness(self, n: Bitness) -> None:
        """ Sets the architecture bitness enum value associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetDesktopEnvironment(self, de: str) -> None:
        """ Sets the desktop environment associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetEndianness(self, n: Endianness) -> None:
        """ Sets the endianness enum value associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetLinuxDistributionInfo(self, di: 'LinuxDistributionInfo') -> None:
        """ Sets the linux distribution info associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetOSVersion(self, major, minor, micro=0) -> None:
        """ Sets the version of the operating system associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetOperatingSystemDescription(self, desc: str) -> None:
        """ Sets the operating system description associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetOperatingSystemId(self, n: OperatingSystemId) -> None:
        """ Sets the operating system associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetPortId(self, n: PortId) -> None:
        """ Sets the wxWidgets port ID associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def SetToolkitVersion(self, major, minor, micro=0) -> None:
        """ Sets the version of the toolkit associated with this PlatformInfo       instance.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def __ne__(self, item: Any) -> bool:
        """ Inequality operator.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    def __eq__(self, item: Any) -> bool:
        """ Equality operator.

            Source: https://docs.wxpython.org/wx.PlatformInformation.html
        """

    ArchName: str  # See GetArchName
    Architecture: Architecture  # See GetArchitecture and SetArchitecture
    Bitness: Bitness  # See GetBitness and SetBitness
    BitnessName: str  # See GetBitnessName
    CpuArchitectureName: str  # See GetCpuArchitectureName
    DesktopEnvironment: str  # See GetDesktopEnvironment and SetDesktopEnvironment
    Endianness: Endianness  # See GetEndianness and SetEndianness
    EndiannessName: str  # See GetEndiannessName
    LinuxDistributionInfo: 'LinuxDistributionInfo'  # See GetLinuxDistributionInfo and SetLinuxDistributionInfo
    NativeCpuArchitectureName: str  # See GetNativeCpuArchitectureName
    OSMajorVersion: int  # See GetOSMajorVersion
    OSMicroVersion: int  # See GetOSMicroVersion
    OSMinorVersion: int  # See GetOSMinorVersion
    OperatingSystemDescription: str  # See GetOperatingSystemDescription and SetOperatingSystemDescription
    OperatingSystemFamilyName: str  # See GetOperatingSystemFamilyName
    OperatingSystemId: OperatingSystemId  # See GetOperatingSystemId and SetOperatingSystemId
    OperatingSystemIdName: str  # See GetOperatingSystemIdName
    PortId: PortId  # See GetPortId and SetPortId
    PortIdName: str  # See GetPortIdName
    PortIdShortName: str  # See GetPortIdShortName
    ToolkitMajorVersion: int  # See GetToolkitMajorVersion
    ToolkitMicroVersion: int  # See GetToolkitMicroVersion
    ToolkitMinorVersion: int  # See GetToolkitMinorVersion



class PNGHandler(ImageHandler):
    """ This is the image handler for the PNG format.

        Source: https://docs.wxpython.org/wx.PNGHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.PNGHandler.

            Source: https://docs.wxpython.org/wx.PNGHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.PNGHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.PNGHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.PNGHandler.html
        """



class PNMHandler(ImageHandler):
    """ This is the image handler for the PNM format.

        Source: https://docs.wxpython.org/wx.PNMHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.PNMHandler.

            Source: https://docs.wxpython.org/wx.PNMHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.PNMHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.PNMHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.PNMHandler.html
        """



class Point:
    """ A Point is a useful data structure for graphics operations.

        Source: https://docs.wxpython.org/wx.Point.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def Get(self) -> tuple:
        """ Return the x and y properties as a tuple.

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.Point object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def IsFullySpecified(self) -> bool:
        """ Returns True if neither of the point components is equal to DefaultCoord.

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def SetDefaults(self, pt: Union[tuple[int, int], 'Point']) -> None:
        """ Combine this object with another one replacing the uninitialized values.

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __eq__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __ne__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __iadd__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Point.html
        """

    def __isub__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Point.html
        """

    IM: None  # See GetIM
    x: Any  # A public C++ attribute of type int. x member.
    y: Any  # A public C++ attribute of type int. y member.



class Point2D:
    """  Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.Point2D.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def Get(self) -> Any:
        """ Get() . (x,y)

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetCrossProduct(self, vec: Point2DDouble) -> 'Double':
        """ vec (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetDistance(self, pt: Point2DDouble) -> 'Double':
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetDistanceSquare(self, pt: Point2DDouble) -> 'Double':
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetDotProduct(self, vec: Point2DDouble) -> 'Double':
        """ vec (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetFloor(self) -> tuple:
        """ tuple

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.Point2D object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetRounded(self) -> tuple:
        """ tuple

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetVectorAngle(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def GetVectorLength(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def Normalize(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def SetVectorAngle(self, degrees: 'Double') -> None:
        """ degrees (wx.Double) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def SetVectorLength(self, length: 'Double') -> None:
        """ length (wx.Double) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __ne__(self, item: Any) -> bool:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __imul__(self) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __iadd__(self) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __sub__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __isub__(self) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __idiv__(self) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    def __eq__(self, item: Any) -> bool:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Point2D.html
        """

    IM: None  # See GetIM
    VectorAngle: 'Double'  # See GetVectorAngle and SetVectorAngle
    VectorLength: 'Double'  # See GetVectorLength and SetVectorLength
    m_x: Any  # A public C++ attribute of type Double     .
    m_y: Any  # A public C++ attribute of type Double     .



class PopupTransientWindow(PopupWindow):
    """ A PopupWindow which disappears automatically when the user clicks
mouse outside it or if it loses focus in any other way.

        Source: https://docs.wxpython.org/wx.PopupTransientWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PopupTransientWindow.html
        """

    def Dismiss(self) -> None:
        """ Hide the window.

            Source: https://docs.wxpython.org/wx.PopupTransientWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.PopupTransientWindow.html
        """

    def OnDismiss(self) -> None:
        """ This is called when the popup is disappeared because of anything else but direct call to Dismiss .

            Source: https://docs.wxpython.org/wx.PopupTransientWindow.html
        """

    def Popup(self, focus: Optional['Window']=None) -> None:
        """ Popup the window (this will show it too).

            Source: https://docs.wxpython.org/wx.PopupTransientWindow.html
        """

    def ProcessLeftDown(self, event: 'MouseEvent') -> bool:
        """ Called when a mouse is pressed while the popup is shown.

            Source: https://docs.wxpython.org/wx.PopupTransientWindow.html
        """



class PopupWindow(NonOwnedWindow):
    """ A special kind of top level window used for popup menus, combobox
popups and such.

        Source: https://docs.wxpython.org/wx.PopupWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PopupWindow.html
        """

    def Create(self, parent, flags=BORDER_NONE) -> bool:
        """ Create method for two-step creation.

            Source: https://docs.wxpython.org/wx.PopupWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.PopupWindow.html
        """

    def Position(self, ptOrigin, sizePopup) -> None:
        """ Move the popup window to the right position, i.e. such that it is entirely visible.

            Source: https://docs.wxpython.org/wx.PopupWindow.html
        """



PU_CONTAINS_CONTROLS: int  # By default in wxMSW, a popup window will not take focus from its parent window. However many standard controls, including common ones such as   wx.TextCtrl, need focus to function correctly and will not work when placed on a default popup. This flag can be used to make the popup take focus and let all controls work but at the price of not allowing the parent window to keep focus while the popup is shown, which can also be sometimes desirable. This style is currently only implemented in MSW and simply does nothing under the other platforms (itâs new since wxWidgets 3.1.3). ^^

class Position:
    """ This class represents the position of an item in any kind of grid of
rows and columns such as GridBagSizer, or HVScrolledWindow.

        Source: https://docs.wxpython.org/wx.Position.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def Get(self) -> tuple:
        """ Return the row and col properties as a tuple.

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def GetCol(self) -> int:
        """ A synonym for GetColumn .

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def GetColumn(self) -> int:
        """ Get the current row value.

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.Position object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def GetRow(self) -> int:
        """ Get the current row value.

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def SetCol(self, column: int) -> None:
        """ A synonym for SetColumn .

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def SetColumn(self, column: int) -> None:
        """ Set a new column value.

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def SetRow(self, row: int) -> None:
        """ Set a new row value.

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __ne__(self, item: Any) -> bool:
        """ pos (wx.Position) â

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __add__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __iadd__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __sub__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __isub__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Position.html
        """

    def __eq__(self, item: Any) -> bool:
        """ pos (wx.Position) â

            Source: https://docs.wxpython.org/wx.Position.html
        """

    Col: int  # See GetCol and SetCol
    Column: int  # See GetColumn and SetColumn
    IM: None  # See GetIM
    Row: int  # See GetRow and SetRow



class PowerEvent(Event):
    """ The power events are generated when the system power state changes,
e.g.

        Source: https://docs.wxpython.org/wx.PowerEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PowerEvent.html
        """

    def IsVetoed(self) -> bool:
        """ Returns whether Veto has been called.

            Source: https://docs.wxpython.org/wx.PowerEvent.html
        """

    def Veto(self) -> None:
        """ Call this to prevent suspend from taking place in  wxEVT_POWER_SUSPENDING   handler (it is ignored for all the others).

            Source: https://docs.wxpython.org/wx.PowerEvent.html
        """



EVT_POWER_SUSPENDING: int

EVT_POWER_SUSPENDED: int  # System is about to suspend: normally the application should quickly (i.e. without user intervention) close all the open files and network connections here, possibly remembering them to reopen them later when the system is resumed.

EVT_POWER_SUSPEND_CANCEL: int  # System suspension was cancelled because some application vetoed it.

EVT_POWER_RESUME: int  # System resumed from suspend: normally the application should restore the state in which it had been before the suspension. ^^

class PowerResource:
    """ Helper functions for acquiring and releasing the given power resource.

        Source: https://docs.wxpython.org/wx.PowerResource.html
    """
    @staticmethod
    def Acquire(kind, reason="") -> bool:
        """ Acquire a power resource for the application.

            Source: https://docs.wxpython.org/wx.PowerResource.html
        """

    @staticmethod
    def Release(kind: PowerResourceKind) -> None:
        """ Release a previously acquired power resource.

            Source: https://docs.wxpython.org/wx.PowerResource.html
        """



class PowerResourceBlocker:
    """ Helper RAII class ensuring that power resources are released.

        Source: https://docs.wxpython.org/wx.PowerResourceBlocker.html
    """
    def __init__(self, kind, reason="") -> None:
        """ Acquires the power resource.

            Source: https://docs.wxpython.org/wx.PowerResourceBlocker.html
        """

    def IsInEffect(self) -> bool:
        """ Returns whether the power resource could be acquired.

            Source: https://docs.wxpython.org/wx.PowerResourceBlocker.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PowerResourceBlocker.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PowerResourceBlocker.html
        """



class PreferencesEditor:
    """ Manage preferences dialog.

        Source: https://docs.wxpython.org/wx.PreferencesEditor.html
    """
    def __init__(self, title: str="") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PreferencesEditor.html
        """

    def AddPage(self, page: 'PreferencesPage') -> None:
        """ Add a new page to the editor.

            Source: https://docs.wxpython.org/wx.PreferencesEditor.html
        """

    def Dismiss(self) -> None:
        """ Hide the currently shown dialog, if any.

            Source: https://docs.wxpython.org/wx.PreferencesEditor.html
        """

    @staticmethod
    def ShouldApplyChangesImmediately() -> bool:
        """ Returns whether changes to values in preferences pages should be applied immediately or only when the user clicks the wx.OK button.

            Source: https://docs.wxpython.org/wx.PreferencesEditor.html
        """

    def Show(self, parent: 'Window') -> None:
        """ Show the preferences dialog or bring it to the top if itâs already shown.

            Source: https://docs.wxpython.org/wx.PreferencesEditor.html
        """

    @staticmethod
    def ShownModally() -> bool:
        """ Returns whether the preferences dialog is shown modally.

            Source: https://docs.wxpython.org/wx.PreferencesEditor.html
        """



class PreferencesPage:
    """ One page of preferences dialog.

        Source: https://docs.wxpython.org/wx.PreferencesPage.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PreferencesPage.html
        """

    def CreateWindow(self, parent: 'Window') -> 'Window':
        """ Create a window for this page.

            Source: https://docs.wxpython.org/wx.PreferencesPage.html
        """

    def GetIcon(self) -> 'BitmapBundle':
        """ Return the icon to be used for the page on some platforms.

            Source: https://docs.wxpython.org/wx.PreferencesPage.html
        """

    def GetLargeIcon(self) -> 'Bitmap':
        """ wx.Bitmap

            Source: https://docs.wxpython.org/wx.PreferencesPage.html
        """

    def GetName(self) -> str:
        """ Return name of the page.

            Source: https://docs.wxpython.org/wx.PreferencesPage.html
        """

    Icon: 'BitmapBundle'  # See GetIcon
    LargeIcon: 'Bitmap'  # See GetLargeIcon
    Name: str  # See GetName



class PressAndTapEvent(GestureEvent):
    """ This event is generated when the user press the surface with one
finger and taps with another.

        Source: https://docs.wxpython.org/wx.PressAndTapEvent.html
    """
    def __init__(self, windid: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PressAndTapEvent.html
        """



EVT_PRESS_AND_TAP: int  # Process a  wxEVT_PRESS_AND_TAP . ^^

class PreviewCanvas(Scrolled):
    """ A preview canvas is the default canvas used by the print preview
system to display the preview.

        Source: https://docs.wxpython.org/wx.PreviewCanvas.html
    """
    def __init__(self, preview, parent, pos=DefaultPosition, size=DefaultSize, style=0, name="canvas") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PreviewCanvas.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.PreviewCanvas.html
        """

    def OnPaint(self, event: 'PaintEvent') -> None:
        """ Calls wx.PrintPreview.PaintPage   to refresh the canvas.

            Source: https://docs.wxpython.org/wx.PreviewCanvas.html
        """



class PreviewControlBar(Panel):
    """ This is the default implementation of the preview control bar, a panel
with buttons and a zoom control.

        Source: https://docs.wxpython.org/wx.PreviewControlBar.html
    """
    def __init__(self, preview, buttons, parent, pos=DefaultPosition, size=DefaultSize, style=0, name="panel") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PreviewControlBar.html
        """

    def CreateButtons(self) -> None:
        """ Creates buttons, according to value of the button style flags.

            Source: https://docs.wxpython.org/wx.PreviewControlBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.PreviewControlBar.html
        """

    def GetPrintPreview(self) -> 'PrintPreview':
        """ Gets the print preview object associated with the control bar.

            Source: https://docs.wxpython.org/wx.PreviewControlBar.html
        """

    def GetZoomControl(self) -> int:
        """ Gets the current zoom setting in percent.

            Source: https://docs.wxpython.org/wx.PreviewControlBar.html
        """

    def SetZoomControl(self, percent: int) -> None:
        """ Sets the zoom control.

            Source: https://docs.wxpython.org/wx.PreviewControlBar.html
        """

    PrintPreview: 'PrintPreview'  # See GetPrintPreview
    ZoomControl: int  # See GetZoomControl and SetZoomControl



PREVIEW_PRINT: int

PREVIEW_NEXT: int

PREVIEW_PREVIOUS: int

PREVIEW_ZOOM: int

PREVIEW_DEFAULT: int

class PreviewFrame(Frame):
    """ This class provides the default method of managing the print preview
interface.

        Source: https://docs.wxpython.org/wx.PreviewFrame.html
    """
    def __init__(self, preview, parent, title="PrintPreview", pos=DefaultPosition, size=DefaultSize, style=DEFAULT_FRAME_STYLE, name=FrameNameStr) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PreviewFrame.html
        """

    def CreateCanvas(self) -> None:
        """ Creates a   wx.PreviewCanvas.

            Source: https://docs.wxpython.org/wx.PreviewFrame.html
        """

    def CreateControlBar(self) -> None:
        """ Creates a   wx.PreviewControlBar.

            Source: https://docs.wxpython.org/wx.PreviewFrame.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.PreviewFrame.html
        """

    def Initialize(self) -> None:
        """ Initializes the frame elements and prepares for showing it.

            Source: https://docs.wxpython.org/wx.PreviewFrame.html
        """

    def InitializeWithModality(self, kind: PreviewFrameModalityKind) -> None:
        """ Initializes the frame elements and prepares for showing it with the given modality kind.

            Source: https://docs.wxpython.org/wx.PreviewFrame.html
        """

    def OnCloseWindow(self, event: 'CloseEvent') -> None:
        """ Enables any disabled frames in the application, and deletes the print preview object, implicitly deleting any printout objects associated with the print preview object.

            Source: https://docs.wxpython.org/wx.PreviewFrame.html
        """



class PrintAbortDialog(Dialog):
    """ The dialog created by default by the print framework that enables
aborting the printing process.

        Source: https://docs.wxpython.org/wx.PrintAbortDialog.html
    """
    def __init__(self, parent, documentTitle, pos=DefaultPosition, size=DefaultSize, style=DEFAULT_DIALOG_STYLE, name="dialog") -> None:
        """ parent (wx.Window) â

            Source: https://docs.wxpython.org/wx.PrintAbortDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.PrintAbortDialog.html
        """

    def SetProgress(self, currentPage, totalPages, currentCopy, totalCopies) -> None:
        """ currentPage (int) â

            Source: https://docs.wxpython.org/wx.PrintAbortDialog.html
        """



class PrintData(Object):
    """ This class holds a variety of information related to printers and
printer device contexts.

        Source: https://docs.wxpython.org/wx.PrintData.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetBin(self) -> 'PrintBin':
        """ Returns the current bin (papersource).

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetCollate(self) -> bool:
        """ Returns True if collation is on.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetColour(self) -> bool:
        """ Returns True if colour printing is on.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetDuplex(self) -> 'DuplexMode':
        """ Returns the duplex mode.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetFilename(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetNoCopies(self) -> int:
        """ Returns the number of copies requested by the user.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetOrientation(self) -> 'PrintOrientation':
        """ Gets the orientation.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetPaperId(self) -> 'PaperSize':
        """ Returns the paper size id.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetPaperSize(self) -> 'Size':
        """ wx.Size

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetPrintMode(self) -> 'PrintMode':
        """ wx.PrintMode

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetPrinterName(self) -> str:
        """ Returns the printer name.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetPrivData(self) -> Any:
        """ PyObject

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def GetQuality(self) -> 'PrintQuality':
        """ Returns the current print quality.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the print data is valid for using in print dialogs.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetBin(self, flag: PrintBin) -> None:
        """ Sets the current bin.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetCollate(self, flag: bool) -> None:
        """ Sets collation to on or off.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetColour(self, flag: bool) -> None:
        """ Sets colour printing on or off.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetDuplex(self, mode: DuplexMode) -> None:
        """ Returns the duplex mode.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetFilename(self, filename: str) -> None:
        """ filename (string) â

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetNoCopies(self, n: int) -> None:
        """ Sets the default number of copies to be printed out.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetOrientation(self, orientation: PrintOrientation) -> None:
        """ Sets the orientation.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetPaperId(self, paperId: PaperSize) -> None:
        """ Sets the paper id.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetPaperSize(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetPrintMode(self, printMode: PrintMode) -> None:
        """ printMode (PrintMode) â

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetPrinterName(self, printerName: str) -> None:
        """ Sets the printer name.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetPrivData(self, data) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def SetQuality(self, quality: 'PrintQuality') -> None:
        """ Sets the desired print quality.

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PrintData.html
        """

    Bin: PrintBin  # See GetBin and SetBin
    Collate: bool  # See GetCollate and SetCollate
    Colour: bool  # See GetColour and SetColour
    Duplex: DuplexMode  # See GetDuplex and SetDuplex
    Filename: str  # See GetFilename and SetFilename
    NoCopies: int  # See GetNoCopies and SetNoCopies
    Orientation: PrintOrientation  # See GetOrientation and SetOrientation
    PaperId: PaperSize  # See GetPaperId and SetPaperId
    PaperSize: Union[tuple[int, int], 'Size']  # See GetPaperSize and SetPaperSize
    PrintMode: PrintMode  # See GetPrintMode and SetPrintMode
    PrinterName: str  # See GetPrinterName and SetPrinterName
    PrivData: Any  # See GetPrivData and SetPrivData
    Quality: 'PrintQuality'  # See GetQuality and SetQuality



DUPLEX_SIMPLEX: int

DUPLEX_HORIZONTAL: int

DUPLEX_VERTICAL: int

LANDSCAPE: int

PORTRAIT: int

PRINT_QUALITY_HIGH: int

PRINT_QUALITY_MEDIUM: int

PRINT_QUALITY_LOW: int

PRINT_QUALITY_DRAFT: int

class PrintDialog(Object):
    """ This class represents the print and print setup common dialogs.

        Source: https://docs.wxpython.org/wx.PrintDialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PrintDialog.html
        """

    def GetPrintDC(self) -> 'DC':
        """ Returns the device context created by the print dialog, if any.

            Source: https://docs.wxpython.org/wx.PrintDialog.html
        """

    def GetPrintData(self) -> 'PrintData':
        """ Returns the print data  associated with the print dialog.

            Source: https://docs.wxpython.org/wx.PrintDialog.html
        """

    def GetPrintDialogData(self) -> 'PrintDialogData':
        """ Returns the print dialog data  associated with the print dialog.

            Source: https://docs.wxpython.org/wx.PrintDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning  ID_OK   if the user pressed wx.OK, and   ID_CANCEL   otherwise.

            Source: https://docs.wxpython.org/wx.PrintDialog.html
        """

    PrintDC: 'DC'  # See GetPrintDC
    PrintData: 'PrintData'  # See GetPrintData
    PrintDialogData: 'PrintDialogData'  # See GetPrintDialogData



class PrintDialogData(Object):
    """ This class holds information related to the visual characteristics of
PrintDialog.

        Source: https://docs.wxpython.org/wx.PrintDialogData.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def EnableHelp(self, flag: bool) -> None:
        """ Enables or disables the âHelpâ button.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def EnablePageNumbers(self, flag: bool) -> None:
        """ Enables or disables the âPage numbersâ controls.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def EnablePrintToFile(self, flag: bool) -> None:
        """ Enables or disables the âPrint to fileâ checkbox.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def EnableSelection(self, flag: bool) -> None:
        """ Enables or disables the âSelectionâ radio button.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetAllPages(self) -> bool:
        """ Returns True if the user requested that all pages be printed.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetCollate(self) -> bool:
        """ Returns True if the user requested that the document(s) be collated.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetFromPage(self) -> int:
        """ Returns the from  page number, as entered by the user.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetMaxPage(self) -> int:
        """ Returns the maximum  page number.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetMinPage(self) -> int:
        """ Returns the minimum  page number.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetNoCopies(self) -> int:
        """ Returns the number of copies requested by the user.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetPrintData(self) -> 'PrintData':
        """ Returns a reference to the internal   wx.PrintData  object.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetPrintToFile(self) -> bool:
        """ Returns True if the user has selected printing to a file.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetSelection(self) -> bool:
        """ Returns True if the user requested that the selection be printed (where âselectionâ is a concept specific to the application).

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def GetToPage(self) -> int:
        """ Returns the âprint toâ  page number, as entered by the user.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the print data is valid for using in print dialogs.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetCollate(self, flag: bool) -> None:
        """ Sets the âCollateâ checkbox to True or False.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetFromPage(self, page: int) -> None:
        """ Sets the from  page number.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetMaxPage(self, page: int) -> None:
        """ Sets the maximum  page number.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetMinPage(self, page: int) -> None:
        """ Sets the minimum  page number.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetNoCopies(self, n: int) -> None:
        """ Sets the default number of copies the user has requested to be printed out.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetPrintData(self, printData: 'PrintData') -> None:
        """ Sets the internal   wx.PrintData.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetPrintToFile(self, flag: bool) -> None:
        """ Sets the âPrint to fileâ checkbox to True or False.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetSelection(self, flag: bool) -> None:
        """ Selects the âSelectionâ radio button.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def SetToPage(self, page: int) -> None:
        """ Sets the âprint toâ  page number.

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PrintDialogData.html
        """

    AllPages: bool  # See GetAllPages
    Collate: bool  # See GetCollate and SetCollate
    FromPage: int  # See GetFromPage and SetFromPage
    MaxPage: int  # See GetMaxPage and SetMaxPage
    MinPage: int  # See GetMinPage and SetMinPage
    NoCopies: int  # See GetNoCopies and SetNoCopies
    PrintData: 'PrintData'  # See GetPrintData and SetPrintData
    PrintToFile: bool  # See GetPrintToFile and SetPrintToFile
    Selection: bool  # See GetSelection and SetSelection
    ToPage: int  # See GetToPage and SetToPage



class Printer(Object):
    """ This class represents the Windows or PostScript printer, and is the
vehicle through which printing may be launched by an application.

        Source: https://docs.wxpython.org/wx.Printer.html
    """
    def __init__(self, data: Optional['PrintDialogData']=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    def CreateAbortWindow(self, parent, printout) -> 'PrintAbortDialog':
        """ Creates the default printing abort window, with a cancel button.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    def GetAbort(self) -> bool:
        """ Returns True if the user has aborted the print job.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    @staticmethod
    def GetLastError() -> 'PrinterError':
        """ Return last error.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    def GetPrintDialogData(self) -> 'PrintDialogData':
        """ Returns the print data  associated with the printer object.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    def Print(self, parent, printout, prompt=True) -> bool:
        """ Starts the printing process.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    def PrintDialog(self, parent: 'Window') -> 'DC':
        """ Invokes the print dialog.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    def ReportError(self, parent, printout, message) -> None:
        """ Default error-reporting function.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    def Setup(self, parent: 'Window') -> bool:
        """ Invokes the print setup dialog.

            Source: https://docs.wxpython.org/wx.Printer.html
        """

    Abort: bool  # See GetAbort
    PrintDialogData: 'PrintDialogData'  # See GetPrintDialogData



PRINTER_NO_ERROR: int

PRINTER_CANCELLED: int

PRINTER_ERROR: int

class PrinterDC(DC):
    """ A printer device context is specific to MSW and Mac, and allows access
to any printer with a Windows or Macintosh driver.

        Source: https://docs.wxpython.org/wx.PrinterDC.html
    """
    def __init__(self, printData: 'PrintData') -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.PrinterDC.html
        """

    def GetPaperRect(self) -> 'Rect':
        """ Return the rectangle in device coordinates that corresponds to the full paper area, including the nonprinting regions of the paper.

            Source: https://docs.wxpython.org/wx.PrinterDC.html
        """

    PaperRect: 'Rect'  # See GetPaperRect



class Printout(Object):
    """ This class encapsulates the functionality of printing out an
application document.

        Source: https://docs.wxpython.org/wx.Printout.html
    """
    def __init__(self, title: str="Printout") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def FitThisSizeToPage(self, imageSize: Union[tuple[int, int], 'Size']) -> None:
        """ Set the user scale and device origin of the   wx.DC  associated with this   wx.Printout  so that the given image size fits entirely within the page rectangle and the origin is at the top left corner of the page rectangle.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def FitThisSizeToPageMargins(self, imageSize, pageSetupData) -> None:
        """ Set the user scale and device origin of the   wx.DC  associated with this   wx.Printout  so that the given image size fits entirely within the page margins set in the given   wx.PageSetupDialogData  object.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def FitThisSizeToPaper(self, imageSize: Union[tuple[int, int], 'Size']) -> None:
        """ Set the user scale and device origin of the   wx.DC  associated with this   wx.Printout  so that the given image size fits entirely within the paper and the origin is at the top left corner of the paper.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetDC(self) -> 'DC':
        """ Returns the device context associated with the printout (given to the printout at start of printing or previewing).

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetLogicalPageMarginsRect(self, pageSetupData: 'PageSetupDialogData') -> 'Rect':
        """ Return the rectangle corresponding to the page margins specified by the given   wx.PageSetupDialogData  object in the associated   wx.DCâs logical coordinates for the current user scale and device origin.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetLogicalPageRect(self) -> 'Rect':
        """ Return the rectangle corresponding to the page in the associated   wx.DC  âs logical coordinates for the current user scale and device origin.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetLogicalPaperRect(self) -> 'Rect':
        """ Return the rectangle corresponding to the paper in the associated   wx.DC  âs logical coordinates for the current user scale and device origin.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetPPIPrinter(self) -> None:
        """ Returns the number of pixels per logical inch of the printer device context.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetPPIScreen(self) -> None:
        """ Returns the number of pixels per logical inch of the screen device context.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetPageInfo(self) -> tuple:
        """ Called by the framework to obtain information from the application about minimum and maximum page values that the user can select, and the required page range to be printed.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetPageSizeMM(self) -> None:
        """ Returns the size of the printer page in millimetres.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetPageSizePixels(self) -> tuple:
        """ Returns the size of the printer page in pixels, called the page rectangle.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetPaperRectPixels(self) -> 'Rect':
        """ Returns the rectangle that corresponds to the entire paper in pixels, called the paper rectangle.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetPreview(self) -> 'PrintPreview':
        """ Returns the associated preview object if any.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def GetTitle(self) -> str:
        """ Returns the title of the printout.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def HasPage(self, pageNum: int) -> bool:
        """ Should be overridden to return True if the document has this page, or False if not.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def IsPreview(self) -> bool:
        """ Returns True if the printout is currently being used for previewing.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def MapScreenSizeToDevice(self) -> None:
        """ Set the user scale and device origin of the   wx.DC  associated with this   wx.Printout  so that one screen pixel maps to one device pixel on the DC.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def MapScreenSizeToPage(self) -> None:
        """ This sets the user scale of the   wx.DC  associated with this   wx.Printout  to the same scale as MapScreenSizeToPaper   but sets the logical origin to the top left corner of the page rectangle.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def MapScreenSizeToPageMargins(self, pageSetupData: 'PageSetupDialogData') -> None:
        """ This sets the user scale of the   wx.DC  associated with this   wx.Printout  to the same scale as MapScreenSizeToPageMargins   but sets the logical origin to the top left corner of the page margins specified by the given   wx.PageSetupDialogData  object.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def MapScreenSizeToPaper(self) -> None:
        """ Set the user scale and device origin of the   wx.DC  associated with this   wx.Printout  so that the printed page matches the screen size as closely as possible and the logical origin is in the top left corner of the paper rectangle.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def OffsetLogicalOrigin(self, xoff, yoff) -> None:
        """ Shift the device origin by an amount specified in logical coordinates.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def OnBeginDocument(self, startPage, endPage) -> bool:
        """ Called by the framework at the start of document printing.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def OnBeginPrinting(self) -> None:
        """ Called by the framework at the start of printing.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def OnEndDocument(self) -> None:
        """ Called by the framework at the end of document printing.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def OnEndPrinting(self) -> None:
        """ Called by the framework at the end of printing.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def OnPreparePrinting(self) -> None:
        """ Called once by the framework before any other demands are made of the   wx.Printout  object.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def OnPrintPage(self, pageNum: int) -> bool:
        """ Called by the framework when a page should be printed.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    def SetLogicalOrigin(self, x, y) -> None:
        """ Set the device origin of the associated   wx.DC  so that the current logical point becomes the new logical origin.

            Source: https://docs.wxpython.org/wx.Printout.html
        """

    DC: 'DC'  # See GetDC
    LogicalPageRect: 'Rect'  # See GetLogicalPageRect
    LogicalPaperRect: 'Rect'  # See GetLogicalPaperRect
    PaperRectPixels: 'Rect'  # See GetPaperRectPixels
    Preview: 'PrintPreview'  # See GetPreview
    Title: str  # See GetTitle



class PrintPreview(Object):
    """ Objects of this class manage the print preview process.

        Source: https://docs.wxpython.org/wx.PrintPreview.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def GetCanvas(self) -> 'PreviewCanvas':
        """ Gets the preview window used for displaying the print preview image.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def GetCurrentPage(self) -> int:
        """ Gets the page currently being previewed.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def GetFrame(self) -> 'Frame':
        """ Gets the frame used for displaying the print preview canvas and control bar.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def GetMaxPage(self) -> int:
        """ Returns the maximum page number.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def GetMinPage(self) -> int:
        """ Returns the minimum page number.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def GetPrintout(self) -> 'Printout':
        """ Gets the preview printout object associated with the   wx.PrintPreview  object.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def GetPrintoutForPrinting(self) -> 'Printout':
        """ Gets the printout object to be used for printing from within the preview interface, or None if none exists.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the   wx.PrintPreview  is valid, False otherwise.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def PaintPage(self, canvas, dc) -> bool:
        """ This refreshes the preview window with the preview image.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def Print(self, prompt: bool) -> bool:
        """ Invokes the print process using the second   wx.Printout  object supplied in the   wx.PrintPreview  constructor.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def RenderPage(self, pageNum: int) -> bool:
        """ Renders a page into a   wx.MemoryDC.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def SetCanvas(self, window: 'PreviewCanvas') -> None:
        """ Sets the window to be used for displaying the print preview image.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def SetCurrentPage(self, pageNum: int) -> bool:
        """ Sets the current page to be previewed.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def SetFrame(self, frame: 'Frame') -> None:
        """ Sets the frame to be used for displaying the print preview canvas and control bar.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def SetPrintout(self, printout: 'Printout') -> None:
        """ Associates a printout object with the   wx.PrintPreview  object.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def SetZoom(self, percent: int) -> None:
        """ Sets the percentage preview zoom, and refreshes the preview canvas accordingly.

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.PrintPreview.html
        """

    Canvas: 'PreviewCanvas'  # See GetCanvas and SetCanvas
    CurrentPage: int  # See GetCurrentPage and SetCurrentPage
    Frame: 'Frame'  # See GetFrame and SetFrame
    MaxPage: int  # See GetMaxPage
    MinPage: int  # See GetMinPage
    Printout: 'Printout'  # See GetPrintout and SetPrintout
    PrintoutForPrinting: 'Printout'  # See GetPrintoutForPrinting



class Process(EvtHandler):
    """ The objects of this class are used in conjunction with the Execute()
function.

        Source: https://docs.wxpython.org/wx.Process.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def Activate(self) -> bool:
        """ Activates a GUI process by bringing up its main window to the front.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def CloseOutput(self) -> None:
        """ Closes the output stream (the one connected to the stdin of the child process).

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def Detach(self) -> None:
        """ Detaches this event handler from the parent specified in the constructor (see wx.EvtHandler.Unlink   for a similar but not identical function).

            Source: https://docs.wxpython.org/wx.Process.html
        """

    @staticmethod
    def Exists(pid: int) -> bool:
        """ Returns True if the given process exists in the system.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def GetErrorStream(self) -> 'InputStream':
        """ Returns an input stream which corresponds to the standard error output (stderr) of the child process.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def GetInputStream(self) -> 'InputStream':
        """ It returns an input stream corresponding to the standard output stream of the subprocess.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def GetOutputStream(self) -> 'OutputStream':
        """ It returns an output stream corresponding to the input stream of the subprocess.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def GetPid(self) -> int:
        """ Returns the process ID of the process launched by Open   or set by wx.Execute       (if you passed this   wx.Process  as argument).

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def IsErrorAvailable(self) -> bool:
        """ Returns True if there is data to be read on the child process standard error stream.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def IsInputAvailable(self) -> bool:
        """ Returns True if there is data to be read on the child process standard output stream.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def IsInputOpened(self) -> bool:
        """ Returns True if the child process standard output stream is opened.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    @staticmethod
    def Kill(pid, sig=SIGTERM, flags=KILL_NOCHILDREN) -> 'KillError':
        """ Send the specified signal to the given process.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def OnTerminate(self, pid, status) -> None:
        """ It is called when the process with the pid pid  finishes.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    @staticmethod
    def Open(cmd, flags=EXEC_ASYNC) -> 'Process':
        """ This static method replaces the standard  popen()   function: it launches the process specified by the  cmd  parameter and returns the   wx.Process  object which can be used to retrieve the streams connected to the standard input, output and error output of the child process.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def Redirect(self) -> None:
        """ Turns on redirection.

            Source: https://docs.wxpython.org/wx.Process.html
        """

    def SetPriority(self, priority: Any) -> None:
        """ Sets the priority of the process, between 0 (lowest) and 100 (highest).

            Source: https://docs.wxpython.org/wx.Process.html
        """

    ErrorStream: 'InputStream'  # See GetErrorStream
    InputStream: 'InputStream'  # See GetInputStream
    OutputStream: 'OutputStream'  # See GetOutputStream
    Pid: int  # See GetPid



EVT_END_PROCESS: int  # Process a  wxEVT_END_PROCESS   event, sent by  wx.Process.OnTerminate   upon the external process termination. ^^

class ProcessEvent(Event):
    """ A process event is sent to the EvtHandler specified to Process
when a process is terminated.

        Source: https://docs.wxpython.org/wx.ProcessEvent.html
    """
    def __init__(self, id=0, pid=0, exitcode=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ProcessEvent.html
        """

    def GetExitCode(self) -> int:
        """ Returns the exist status.

            Source: https://docs.wxpython.org/wx.ProcessEvent.html
        """

    def GetPid(self) -> int:
        """ Returns the process id.

            Source: https://docs.wxpython.org/wx.ProcessEvent.html
        """

    ExitCode: int  # See GetExitCode
    Pid: int  # See GetPid



class ProgressDialog(GenericProgressDialog):
    """ If supported by the platform this class will provide the platformâs
native progress dialog, else it will simply be the
GenericProgressDialog.

        Source: https://docs.wxpython.org/wx.ProgressDialog.html
    """
    def __init__(self, title, message, maximum=100, parent=None, style=PD_APP_MODAL|PD_AUTO_HIDE) -> None:
        """ title (string) â

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def GetMessage(self) -> str:
        """ Returns the last message passed to the Update   function; if you always passed ââ to Update   then the message set through the constructor is returned.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def GetRange(self) -> int:
        """ Returns the maximum value of the progress meter, as passed to the constructor or  NOT_FOUND   if the dialog has no progress bar.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def GetValue(self) -> int:
        """ Returns the last value passed to the Update   function or  NOT_FOUND   if the dialog has no progress bar.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def Pulse(self, newmsg: str="") -> tuple:
        """ Like Update   but makes the gauge control run in indeterminate mode.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def Resume(self) -> None:
        """ Can be used to continue with the dialog, after the user had clicked the âAbortâ button.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def SetRange(self, maximum: int) -> None:
        """ Changes the maximum value of the progress meter given in the constructor.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def Update(self, value, newmsg="") -> tuple:
        """ Updates the dialog, setting the progress bar to the new value and updating the message if new one is specified.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def WasCancelled(self) -> bool:
        """ Returns True if the âCancelâ button was pressed.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    def WasSkipped(self) -> bool:
        """ Returns True if the âSkipâ button was pressed.

            Source: https://docs.wxpython.org/wx.ProgressDialog.html
        """

    Message: str  # See GetMessage
    Range: int  # See GetRange and SetRange
    Value: int  # See GetValue



class PropagateOnce:
    """ Helper class to temporarily lower propagation level.

        Source: https://docs.wxpython.org/wx.PropagateOnce.html
    """
    def __init__(self, event: 'Event') -> None:
        """ event (wx.Event) â

            Source: https://docs.wxpython.org/wx.PropagateOnce.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PropagateOnce.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PropagateOnce.html
        """



class PropagationDisabler:
    """ Helper class to temporarily change an event to not propagate.

        Source: https://docs.wxpython.org/wx.PropagationDisabler.html
    """
    def __init__(self, event: 'Event') -> None:
        """ event (wx.Event) â

            Source: https://docs.wxpython.org/wx.PropagationDisabler.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PropagationDisabler.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PropagationDisabler.html
        """



EVT_DIALUP_CONNECTED: int  # A connection with the network was established. See DialUpEvent     .

EVT_DIALUP_DISCONNECTED: int  # The connection with the network was lost. See DialUpEvent     .

class PyCommandEvent:
    """ PyCommandEvent can be used as a base class for implementing
custom event types in Python. You should derive from this class
instead of CommandEvent because this class is Python-aware
and is able to transport its Python bits safely through the
wxWidgets event system and have them still be there when the
event handler is invoked. Note that since PyCommandEvent is
taking care of preserving the extra attributes that have been set
then you do not need to override the Clone method in your
derived classes.

        Source: https://docs.wxpython.org/wx.PyCommandEvent.html
    """
    def __init__(self, eventType=wxEVT_NULL, id=0) -> None:
        """ eventType (wx.EventType) â

            Source: https://docs.wxpython.org/wx.PyCommandEvent.html
        """

    def Clone(self) -> None:
        """ Make a new instance of the event that is a copy of self.

            Source: https://docs.wxpython.org/wx.PyCommandEvent.html
        """

    def __delattr__(self, name: Any) -> None:
        """ name (PyObject) â

            Source: https://docs.wxpython.org/wx.PyCommandEvent.html
        """

    def __getattr__(self, name: Any) -> Any:
        """ name (PyObject) â

            Source: https://docs.wxpython.org/wx.PyCommandEvent.html
        """

    def __setattr__(self, name, value) -> None:
        """ name (PyObject) â

            Source: https://docs.wxpython.org/wx.PyCommandEvent.html
        """

    def _getAttrDict(self) -> Any:
        """ Gives access to the internal object that is tracking the eventâs python attributes.

            Source: https://docs.wxpython.org/wx.PyCommandEvent.html
        """



class PyEvent:
    """ PyEvent can be used as a base class for implementing custom
event types in Python. You should derive from this class instead
of Event because this class is Python-aware and is able to
transport its Python bits safely through the wxWidgets event
system and have them still be there when the event handler is
invoked. Note that since PyEvent is taking care of preserving
the extra attributes that have been set then you do not need to
override the Clone method in your derived classes.

        Source: https://docs.wxpython.org/wx.PyEvent.html
    """
    def __init__(self, id=0, eventType=wxEVT_NULL) -> None:
        """ id (int) â

            Source: https://docs.wxpython.org/wx.PyEvent.html
        """

    def Clone(self) -> None:
        """ Make a new instance of the event that is a copy of self.

            Source: https://docs.wxpython.org/wx.PyEvent.html
        """

    def __delattr__(self, name: Any) -> None:
        """ name (PyObject) â

            Source: https://docs.wxpython.org/wx.PyEvent.html
        """

    def __getattr__(self, name: Any) -> Any:
        """ name (PyObject) â

            Source: https://docs.wxpython.org/wx.PyEvent.html
        """

    def __setattr__(self, name, value) -> None:
        """ name (PyObject) â

            Source: https://docs.wxpython.org/wx.PyEvent.html
        """

    def _getAttrDict(self) -> Any:
        """ Gives access to the internal object that is tracking the eventâs python attributes.

            Source: https://docs.wxpython.org/wx.PyEvent.html
        """



class PyEventBinder:
    """ Instances of this class are used to bind specific events to event handlers.

        Source: https://docs.wxpython.org/wx.PyEventBinder.html
    """
    def __init__(self, evtType, expectedIDs=0) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PyEventBinder.html
        """

    def Bind(self, target, id1, id2, function) -> None:
        """ Bind this set of event types to target using its Connect() method.

            Source: https://docs.wxpython.org/wx.PyEventBinder.html
        """

    def Unbind(self, target, id1, id2, handler=None) -> None:
        """ Remove an event binding.

            Source: https://docs.wxpython.org/wx.PyEventBinder.html
        """

    def __call__(self, *args) -> None:
        """ For backwards compatibility with the old EVT_* functions.
Should be called with either (window, func), (window, ID,
func) or (window, ID1, ID2, func) parameters depending on the
type of the event.

            Source: https://docs.wxpython.org/wx.PyEventBinder.html
        """

    def _getEvtType(self) -> None:
        """ Make it easy to get to the default wxEventType typeID for this
event binder.

            Source: https://docs.wxpython.org/wx.PyEventBinder.html
        """

    typeId: Any  # See _getEvtType



class PyOnDemandOutputWindow:
    """ A class that can be used for redirecting Pythonâs stdout and
stderr streams.  It will do nothing until something is wrriten to
the stream at which point it will create a Frame with a text area
and write the text there.

        Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
    """
    def __init__(self, title="wxPython: stdout/stderr") -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
        """

    def CreateOutputWindow(self, txt) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
        """

    def OnCloseWindow(self, event) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
        """

    def SetParent(self, parent) -> None:
        """ Set the window to be used as the popup Frameâs parent.

            Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
        """

    def close(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
        """

    def flush(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
        """

    def write(self, text) -> None:
        """ Create the output window if needed and write the string to it.
If not called in the context of the gui thread then CallAfter is
used to do the work there.

            Source: https://docs.wxpython.org/wx.PyOnDemandOutputWindow.html
        """



class PySimpleApp(App):
    """ This class is deprecated.  Please use App instead.

        Source: https://docs.wxpython.org/wx.PySimpleApp.html
    """
    def __init__(self, *args, **kw) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.PySimpleApp.html
        """



class QueryNewPaletteEvent(Event):
    """ winid (wx.WindowID) â 

        Source: https://docs.wxpython.org/wx.QueryNewPaletteEvent.html
    """
    def __init__(self, winid: int=0) -> None:
        """ winid (wx.WindowID) â

            Source: https://docs.wxpython.org/wx.QueryNewPaletteEvent.html
        """

    def GetPaletteRealized(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.QueryNewPaletteEvent.html
        """

    def SetPaletteRealized(self, realized: bool) -> None:
        """ realized (bool) â

            Source: https://docs.wxpython.org/wx.QueryNewPaletteEvent.html
        """

    PaletteRealized: bool  # See GetPaletteRealized and SetPaletteRealized



class RadioBox(Control,ItemContainerImmutable):
    """ A radio box item is used to select one of number of mutually exclusive
choices.

        Source: https://docs.wxpython.org/wx.RadioBox.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, choices=[], majorDimension=0, style=RA_SPECIFY_COLS, validator=DefaultValidator, name=RadioBoxNameStr) -> bool:
        """ Creates the radiobox for two-step construction.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def EnableItem(self, n, enable=True) -> bool:
        """ Enables or disables an individual button in the radiobox.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def FindString(self, string, bCase=False) -> int:
        """ Finds a button matching the given string, returning the position if found, or  NOT_FOUND   if not found.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetColumnCount(self) -> int:
        """ Returns the number of columns in the radiobox.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetCount(self) -> int:
        """ Returns the number of items in the control.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetItemFromPoint(self, pt: Union[tuple[int, int], 'Point']) -> int:
        """ Returns a radio box item under the point, a zero-based item index, or  NOT_FOUND   if no item is under the point.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetItemHelpText(self, item: int) -> str:
        """ Returns the helptext associated with the specified item  if any or  "" .

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetItemLabel(self, n) -> None:
        """ Return the text of the nâth item in the radio box.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetItemToolTip(self, item: int) -> 'ToolTip':
        """ Returns the tooltip associated with the specified item  if any or None.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetRowCount(self) -> int:
        """ Returns the number of rows in the radiobox.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetSelection(self) -> int:
        """ Returns the index of the selected item.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def GetString(self, n: int) -> str:
        """ Returns the label of the item with the given index.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def IsItemEnabled(self, n: int) -> bool:
        """ Returns True if the item is enabled or False if it was disabled using Enable .

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def IsItemShown(self, n: int) -> bool:
        """ Returns True if the item is currently shown or False if it was hidden using Show .

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def SetItemHelpText(self, item, helptext) -> None:
        """ Sets the helptext for an item.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def SetItemLabel(self, n, text) -> None:
        """ SetItemLabel(self, n, text)

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def SetItemToolTip(self, item, text) -> None:
        """ Sets the tooltip text for the specified item in the radio group.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def SetSelection(self, n: int) -> None:
        """ Sets the selection to the given item.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def SetString(self, n, string) -> None:
        """ Sets the label for the given item.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    def ShowItem(self, item, show=True) -> bool:
        """ Shows or hides individual buttons.

            Source: https://docs.wxpython.org/wx.RadioBox.html
        """

    ColumnCount: int  # See GetColumnCount
    Count: int  # See GetCount
    RowCount: int  # See GetRowCount
    Selection: int  # See GetSelection and SetSelection



RA_SPECIFY_ROWS: int  # The major dimension parameter refers to the maximum number of rows.

RA_SPECIFY_COLS: int  # The major dimension parameter refers to the maximum number of columns. ^^

class RadioButton(Control):
    """ A radio button item is a button which usually denotes one of several
mutually exclusive options.

        Source: https://docs.wxpython.org/wx.RadioButton.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=RadioButtonNameStr) -> bool:
        """ Creates the choice for two-step construction.

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    def GetFirstInGroup(self) -> 'RadioButton':
        """ Returns the first button of the radio button group this button belongs to.

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    def GetLastInGroup(self) -> 'RadioButton':
        """ Returns the last button of the radio button group this button belongs to.

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    def GetNextInGroup(self) -> 'RadioButton':
        """ Returns the next radio button in the same group.

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    def GetPreviousInGroup(self) -> 'RadioButton':
        """ Returns the previous radio button in the same group.

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    def GetValue(self) -> bool:
        """ Returns True if the radio button is checked, False otherwise.

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    def SetValue(self, value: bool) -> None:
        """ Sets the radio button to checked or unchecked status.

            Source: https://docs.wxpython.org/wx.RadioButton.html
        """

    FirstInGroup: 'RadioButton'  # See GetFirstInGroup
    LastInGroup: 'RadioButton'  # See GetLastInGroup
    NextInGroup: 'RadioButton'  # See GetNextInGroup
    PreviousInGroup: 'RadioButton'  # See GetPreviousInGroup
    Value: bool  # See GetValue and SetValue



RB_GROUP: int  # Marks the beginning of a new group of radio buttons.

RB_SINGLE: int  # Creates a radio button which is not part of any radio button group. When this style is used, no other radio buttons will be turned off automatically when this button is turned on and such behaviour will need to be implemented manually, in the event handler for this button. ^^

class RealPoint:
    """ A RealPoint is a useful data structure for graphics operations.

        Source: https://docs.wxpython.org/wx.RealPoint.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def Get(self) -> tuple:
        """ Return the pointâs properties as a tuple.

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.RealPoint object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __eq__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __mul__(self, d) -> 'RealPoint':
        """ wx.RealPoint

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __ne__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __iadd__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    def __isub__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RealPoint.html
        """

    IM: None  # See GetIM
    x: Any  # A public C++ attribute of type float. X coordinate of this point.
    y: Any  # A public C++ attribute of type float. Y coordinate of this point.



class RearrangeCtrl(Panel):
    """ A composite control containing a RearrangeList and the buttons
allowing to move the items in it.

        Source: https://docs.wxpython.org/wx.RearrangeCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RearrangeCtrl.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, order=[], items=[], style=0, validator=DefaultValidator, name=RearrangeListNameStr) -> bool:
        """ Effectively creates the window for an object created using the default constructor.

            Source: https://docs.wxpython.org/wx.RearrangeCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.RearrangeCtrl.html
        """

    def GetList(self) -> 'RearrangeList':
        """ Return the listbox which is the main part of this control.

            Source: https://docs.wxpython.org/wx.RearrangeCtrl.html
        """

    List: 'RearrangeList'  # See GetList



class RearrangeList(CheckListBox):
    """ A listbox-like control allowing the user to rearrange the items and to
enable or disable them.

        Source: https://docs.wxpython.org/wx.RearrangeList.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    def CanMoveCurrentDown(self) -> bool:
        """ Return True if the currently selected item can be moved down.

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    def CanMoveCurrentUp(self) -> bool:
        """ Return True if the currently selected item can be moved up.

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, order=[], items=[], style=0, validator=DefaultValidator, name=RearrangeListNameStr) -> bool:
        """ Effectively creates the window for an object created using the default constructor.

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    def GetCurrentOrder(self) -> list[int]:
        """ Return the current order of the items.

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    def MoveCurrentDown(self) -> bool:
        """ Move the currently selected item one position below.

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    def MoveCurrentUp(self) -> bool:
        """ Move the currently selected item one position above.

            Source: https://docs.wxpython.org/wx.RearrangeList.html
        """

    CurrentOrder: list[int]  # See GetCurrentOrder



class RearrangeDialog(Dialog):
    """ A dialog allowing the user to rearrange the specified items.

        Source: https://docs.wxpython.org/wx.RearrangeDialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RearrangeDialog.html
        """

    def AddExtraControls(self, win: 'Window') -> None:
        """ Customize the dialog by adding extra controls to it.

            Source: https://docs.wxpython.org/wx.RearrangeDialog.html
        """

    def Create(self, parent, message, title="", order=[], items=[], pos=DefaultPosition, name=RearrangeDialogNameStr) -> bool:
        """ Effectively creates the dialog for an object created using the default constructor.

            Source: https://docs.wxpython.org/wx.RearrangeDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.RearrangeDialog.html
        """

    def GetList(self) -> 'RearrangeList':
        """ Return the list control used by the dialog.

            Source: https://docs.wxpython.org/wx.RearrangeDialog.html
        """

    def GetOrder(self) -> list[int]:
        """ Return the array describing the order of items after it was modified by the user.

            Source: https://docs.wxpython.org/wx.RearrangeDialog.html
        """

    List: 'RearrangeList'  # See GetList
    Order: list[int]  # See GetOrder



class Rect:
    """ Represents a rectangle with integer coordinates.

        Source: https://docs.wxpython.org/wx.Rect.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def CenterIn(self, r, dir=BOTH) -> 'Rect':
        """ Returns the rectangle having the same size as this one but centered relatively to the given rectangle r.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def CentreIn(self, r, dir=BOTH) -> 'Rect':
        """ Returns the rectangle having the same size as this one but centered relatively to the given rectangle r.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Contains(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Deflate(self, *args, **kw) -> 'Rect':
        """ Decrease the rectangle size.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Get(self) -> tuple:
        """ Return the rectangleâs properties as a tuple.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetBottom(self) -> int:
        """ Gets the bottom point of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetBottomLeft(self) -> 'Point':
        """ Gets the position of the bottom left corner.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetBottomRight(self) -> 'Point':
        """ Gets the position of the bottom right corner.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetHeight(self) -> int:
        """ Gets the height member.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.Rect object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetLeft(self) -> int:
        """ Gets the left point of the rectangle (the same as GetX ).

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetPosition(self) -> 'Point':
        """ Gets the position.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetRight(self) -> int:
        """ Gets the right point of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetSize(self) -> 'Size':
        """ Gets the size.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetTop(self) -> int:
        """ Gets the top point of the rectangle (the same as GetY ).

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetTopLeft(self) -> 'Point':
        """ Gets the position of the top left corner of the rectangle, same as GetPosition .

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetTopRight(self) -> 'Point':
        """ Gets the position of the top right corner.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetWidth(self) -> int:
        """ Gets the width member.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetX(self) -> int:
        """ Gets the x member.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def GetY(self) -> int:
        """ Gets the y member.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Inflate(self, *args, **kw) -> 'Rect':
        """ Increases the size of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Intersect(self, rect: 'Rect') -> 'Rect':
        """ Modifies this rectangle to contain the overlapping portion of this rectangle and the one passed in as parameter.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Intersects(self, rect: 'Rect') -> bool:
        """ Returns True if this rectangle has a non-empty intersection with the rectangle rect  and False otherwise.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if this rectangle has a width or height less than or equal to 0 and False otherwise.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Offset(self, *args, **kw) -> None:
        """ Moves the rectangle by the specified offset.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetBottom(self, bottom: int) -> None:
        """ Set the bottom edge of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetBottomLeft(self, p: Union[tuple[int, int], 'Point']) -> None:
        """ Set the bottom-left point of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetBottomRight(self, p: Union[tuple[int, int], 'Point']) -> None:
        """ Set the bottom-right point of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetHeight(self, height: int) -> None:
        """ Sets the height.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetLeft(self, left: int) -> None:
        """ Set the left side of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetPosition(self, pos: Union[tuple[int, int], 'Point']) -> None:
        """ Sets the position.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetRight(self, right: int) -> None:
        """ Set the right side of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetSize(self, s: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the size.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetTop(self, top: int) -> None:
        """ Set the top edge of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetTopLeft(self, p: Union[tuple[int, int], 'Point']) -> None:
        """ Set the top-left point of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetTopRight(self, p: Union[tuple[int, int], 'Point']) -> None:
        """ Set the top-right point of the rectangle.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetWidth(self, width: int) -> None:
        """ Sets the width.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetX(self, x: int) -> None:
        """ Sets the x position.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def SetY(self, y: int) -> None:
        """ Sets the y position.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def Union(self, rect: 'Rect') -> 'Rect':
        """ Modifies the rectangle to contain the bounding box of this rectangle and the one passed in as parameter.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __eq__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __ne__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __imul__(self) -> None:
        """ Returns the intersection of two rectangles (which may be empty).

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    def __iadd__(self) -> None:
        """ Like Union , but doesnât treat empty rectangles specially.

            Source: https://docs.wxpython.org/wx.Rect.html
        """

    Bottom: int  # See GetBottom and SetBottom
    BottomLeft: Union[tuple[int, int], 'Point']  # See GetBottomLeft and SetBottomLeft
    BottomRight: Union[tuple[int, int], 'Point']  # See GetBottomRight and SetBottomRight
    Height: int  # See GetHeight and SetHeight
    Left: int  # See GetLeft and SetLeft
    Position: Union[tuple[int, int], 'Point']  # See GetPosition and SetPosition
    Right: int  # See GetRight and SetRight
    Size: Union[tuple[int, int], 'Size']  # See GetSize and SetSize
    Top: int  # See GetTop and SetTop
    TopLeft: Union[tuple[int, int], 'Point']  # See GetTopLeft and SetTopLeft
    TopRight: Union[tuple[int, int], 'Point']  # See GetTopRight and SetTopRight
    Width: int  # See GetWidth and SetWidth
    X: int  # See GetX and SetX
    Y: int  # See GetY and SetY
    bottom: Any  # See GetBottom and SetBottom
    bottomLeft: Any  # See GetBottomLeft and SetBottomLeft
    bottomRight: Any  # See GetBottomRight and SetBottomRight
    height: Any  # A public C++ attribute of type int. Height member.
    left: Any  # See GetLeft and SetLeft
    right: Any  # See GetRight and SetRight
    top: Any  # See GetTop and SetTop
    topLeft: Any  # See GetTopLeft and SetTopLeft
    topRight: Any  # See GetTopRight and SetTopRight
    width: Any  # A public C++ attribute of type int. Width member.
    x: Any  # A public C++ attribute of type int. x coordinate of the top-left corner of the rectangle.
    y: Any  # A public C++ attribute of type int. y coordinate of the top-left corner of the rectangle.



class Rect2D:
    """  Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.Rect2D.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def ConstrainTo(self, rect: Rect2DDouble) -> None:
        """ rect (Rect2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Contains(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def CreateIntersection(self, otherRect: Rect2DDouble) -> Rect2DDouble:
        """ otherRect (Rect2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def CreateUnion(self, otherRect: Rect2DDouble) -> Rect2DDouble:
        """ otherRect (Rect2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Get(self) -> Any:
        """ Get() . (x, y, width, height)

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetBottom(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetCentre(self) -> Point2DDouble:
        """ Point2DDouble

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.Rect2D object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetLeft(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetLeftBottom(self) -> Point2DDouble:
        """ Point2DDouble

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetLeftTop(self) -> Point2DDouble:
        """ Point2DDouble

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetOutCode(self, pt: Point2DDouble) -> 'OutCode':
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetOutcode(self, pt: Point2DDouble) -> 'OutCode':
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetPosition(self) -> Point2DDouble:
        """ Point2DDouble

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetRight(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetRightBottom(self) -> Point2DDouble:
        """ Point2DDouble

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetRightTop(self) -> Point2DDouble:
        """ Point2DDouble

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetSize(self) -> 'Size':
        """ wx.Size

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def GetTop(self) -> 'Double':
        """ wx.Double

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def HaveEqualSize(self, rect: Rect2DDouble) -> bool:
        """ rect (Rect2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Inset(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Interpolate(self, widthfactor, heightfactor) -> Point2DDouble:
        """ widthfactor (wx.int) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Intersect(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Intersects(self, rect: Rect2DDouble) -> bool:
        """ rect (Rect2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def IsEmpty(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveBottomTo(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveCentreTo(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveLeftBottomTo(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveLeftTo(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveLeftTopTo(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveRightBottomTo(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveRightTo(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveRightTopTo(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def MoveTopTo(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Offset(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Scale(self: 'Double', *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetBottom(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetCentre(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetLeft(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetLeftBottom(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetLeftTop(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetRight(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetRightBottom(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetRightTop(self, pt: Point2DDouble) -> None:
        """ pt (Point2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def SetTop(self, n: 'Double') -> None:
        """ n (wx.Double) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def Union(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __ne__(self, item: Any) -> bool:
        """ rect (Rect2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    def __eq__(self, item: Any) -> bool:
        """ rect (Rect2DDouble) â

            Source: https://docs.wxpython.org/wx.Rect2D.html
        """

    Bottom: 'Double'  # See GetBottom and SetBottom
    Centre: Point2DDouble  # See GetCentre and SetCentre
    IM: None  # See GetIM
    Left: 'Double'  # See GetLeft and SetLeft
    LeftBottom: Point2DDouble  # See GetLeftBottom and SetLeftBottom
    LeftTop: Point2DDouble  # See GetLeftTop and SetLeftTop
    Position: Point2DDouble  # See GetPosition
    Right: 'Double'  # See GetRight and SetRight
    RightBottom: Point2DDouble  # See GetRightBottom and SetRightBottom
    RightTop: Point2DDouble  # See GetRightTop and SetRightTop
    Size: 'Size'  # See GetSize
    Top: 'Double'  # See GetTop and SetTop
    m_height: Any  # A public C++ attribute of type Double     .
    m_width: Any  # A public C++ attribute of type Double     .
    m_x: Any  # A public C++ attribute of type Double     .
    m_y: Any  # A public C++ attribute of type Double     .



class RefCounter:
    """ This class is used to manage reference-counting providing a simple
interface and a counter.

        Source: https://docs.wxpython.org/wx.RefCounter.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.RefCounter.html
        """

    def DecRef(self) -> None:
        """ Decrements the reference count associated with this shared data and, if it reaches zero, destroys this instance of   wx.RefCounter  releasing its memory.

            Source: https://docs.wxpython.org/wx.RefCounter.html
        """

    def GetRefCount(self) -> int:
        """ Returns the reference count associated with this shared data.

            Source: https://docs.wxpython.org/wx.RefCounter.html
        """

    def IncRef(self) -> None:
        """ Increments the reference count associated with this shared data.

            Source: https://docs.wxpython.org/wx.RefCounter.html
        """

    RefCount: int  # See GetRefCount



class Region(GDIObject):
    """ A Region represents a simple or complex region on a device context
or window.

        Source: https://docs.wxpython.org/wx.Region.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def Clear(self) -> None:
        """ Clears the current region.

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def Contains(self, *args, **kw) -> 'RegionContain':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def ConvertToBitmap(self) -> 'Bitmap':
        """ Convert the region to a black and white bitmap with the white pixels being inside the region.

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def GetBox(self) -> 'Rect':
        """ Returns the outer bounds of the region.

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def Intersect(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if the region is empty, False otherwise.

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def IsEqual(self, region: 'Region') -> bool:
        """ Returns True if the region is equal to, i.e. covers the same area as, another one.

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def Offset(self, *args, **kw) -> None:
        """ Moves the region by the specified offsets in horizontal and vertical directions.

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def Subtract(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def Union(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def Xor(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Region.html
        """

    def __iter__(self) -> None:
        """ Returns a rectangle iterator conforming to the Python iterator
protocol.

            Source: https://docs.wxpython.org/wx.Region.html
        """

    Box: 'Rect'  # See GetBox



class RegionIterator(Object):
    """ This class is used to iterate through the rectangles in a region,
typically when examining the damaged regions of a window within an
OnPaint call.

        Source: https://docs.wxpython.org/wx.RegionIterator.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def GetH(self) -> 'Coord':
        """ An alias for GetHeight .

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def GetHeight(self) -> 'Coord':
        """ Returns the height value for the current region.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def GetRect(self) -> 'Rect':
        """ Returns the current rectangle.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def GetW(self) -> 'Coord':
        """ An alias for GetWidth .

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def GetWidth(self) -> 'Coord':
        """ Returns the width value for the current region.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def GetX(self) -> 'Coord':
        """ Returns the x value for the current region.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def GetY(self) -> 'Coord':
        """ Returns the y value for the current region.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def HaveRects(self) -> bool:
        """ Returns True if there are still some rectangles; otherwise returns False.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def Next(self) -> None:
        """ Move the iterator to the next rectangle in the region.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def Reset(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def __bool__(self) -> int:
        """ Returns True while there are still rectangles available in the iteration.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    def __nonzero__(self) -> int:
        """ Returns True while there are still rectangles available in the iteration.

            Source: https://docs.wxpython.org/wx.RegionIterator.html
        """

    H: 'Coord'  # See GetH
    Height: 'Coord'  # See GetHeight
    Rect: 'Rect'  # See GetRect
    W: 'Coord'  # See GetW
    Width: 'Coord'  # See GetWidth
    X: 'Coord'  # See GetX
    Y: 'Coord'  # See GetY



class RendererVersion:
    """ This simple struct represents the RendererNative interface version
and is only used as the return value of
RendererNative.GetVersion().

        Source: https://docs.wxpython.org/wx.RendererVersion.html
    """
    def __init__(self, version_, age_) -> None:
        """ version_ (int) â

            Source: https://docs.wxpython.org/wx.RendererVersion.html
        """

    @staticmethod
    def IsCompatible(ver: 'RendererVersion') -> bool:
        """ Checks if the main program is compatible with the renderer having the version ver, returns True if it is and False otherwise.

            Source: https://docs.wxpython.org/wx.RendererVersion.html
        """

    age: Any  # A public C++ attribute of type int. The age component.
    version: Any  # A public C++ attribute of type int. The version component.



class RichMessageDialog:
    """ Extension of MessageDialog with additional functionality.

        Source: https://docs.wxpython.org/wx.RichMessageDialog.html
    """
    def __init__(self, parent, message, caption=MessageBoxCaptionStr, style=OK|CENTRE) -> None:
        """ Constructor specifying the rich message dialog properties.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def GetCheckBoxText(self) -> str:
        """ Retrieves the label for the checkbox.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def GetDetailedText(self) -> str:
        """ Retrieves the detailed text.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def GetFooterIcon(self) -> int:
        """ Retrieves the footer icon.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def GetFooterText(self) -> str:
        """ Retrieves the footer text.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def IsCheckBoxChecked(self) -> bool:
        """ Retrieves the state of the checkbox.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def SetFooterIcon(self, icon: int) -> None:
        """ Specify the footer icon set together with the footer text.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def SetFooterText(self, footerText: str) -> None:
        """ Shows or hides a footer text that is used at the bottom of the dialog together with an optional icon.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def ShowCheckBox(self, checkBoxText, checked=False) -> None:
        """ Shows a checkbox with a given label or hides it.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def ShowDetailedText(self, detailedText: str) -> None:
        """ Shows or hides a detailed text and an expander that is used to show or hide the detailed text.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning one of wx.ID_OK, wx.ID_CANCEL, wx.ID_YES, wx.ID_NO.

            Source: https://docs.wxpython.org/wx.RichMessageDialog.html
        """

    CheckBoxText: str  # See GetCheckBoxText
    DetailedText: str  # See GetDetailedText
    FooterIcon: int  # See GetFooterIcon and SetFooterIcon
    FooterText: str  # See GetFooterText and SetFooterText



class RotateGestureEvent(GestureEvent):
    """ This event is generated when two fingers move in opposite directions
on the surface.

        Source: https://docs.wxpython.org/wx.RotateGestureEvent.html
    """
    def __init__(self, windid: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.RotateGestureEvent.html
        """

    def GetRotationAngle(self) -> float:
        """ Returns the total angle of rotation in radians in clockwise direction since the gesture was first started i.e.

            Source: https://docs.wxpython.org/wx.RotateGestureEvent.html
        """

    def SetRotationAngle(self, rotationAngle: float) -> None:
        """ Sets the total angle of rotation in radians in clockwise direction since the gesture was first started i.e.

            Source: https://docs.wxpython.org/wx.RotateGestureEvent.html
        """

    RotationAngle: float  # See GetRotationAngle and SetRotationAngle



EVT_GESTURE_ROTATE: int  # Process a  wxEVT_GESTURE_ROTATE . ^^

class ScreenDC(DC):
    """ A ScreenDC can be used to paint on the screen.

        Source: https://docs.wxpython.org/wx.ScreenDC.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ScreenDC.html
        """

    @staticmethod
    def EndDrawingOnTop() -> bool:
        """ Use this in conjunction with StartDrawingOnTop .

            Source: https://docs.wxpython.org/wx.ScreenDC.html
        """

    @staticmethod
    def StartDrawingOnTop(*args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ScreenDC.html
        """



class ScrollBar(Control):
    """ A ScrollBar is a control that represents a horizontal or vertical
scrollbar.

        Source: https://docs.wxpython.org/wx.ScrollBar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=SB_HORIZONTAL, validator=DefaultValidator, name=ScrollBarNameStr) -> bool:
        """ Scrollbar creation function called by the scrollbar constructor.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def GetPageSize(self) -> int:
        """ Returns the page size of the scrollbar.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def GetRange(self) -> int:
        """ Returns the length of the scrollbar.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def GetThumbPosition(self) -> int:
        """ Returns the current position of the scrollbar thumb.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def GetThumbSize(self) -> int:
        """ Returns the thumb or âviewâ size.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def IsVertical(self) -> bool:
        """ Returns True for scrollbars that have the vertical style set.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def SetScrollbar(self, position, thumbSize, range, pageSize, refresh=True) -> None:
        """ Sets the scrollbar properties.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    def SetThumbPosition(self, viewStart: int) -> None:
        """ Sets the position of the scrollbar.

            Source: https://docs.wxpython.org/wx.ScrollBar.html
        """

    PageSize: int  # See GetPageSize
    Range: int  # See GetRange
    ThumbPosition: int  # See GetThumbPosition and SetThumbPosition
    ThumbSize: int  # See GetThumbSize



SB_HORIZONTAL: int  # Specifies a horizontal scrollbar.

SB_VERTICAL: int  # Specifies a vertical scrollbar. ^^

EVT_SCROLL: int  # Process all scroll events.

EVT_SCROLL_TOP: int  # Process  wxEVT_SCROLL_TOP   scroll to top or leftmost (minimum) position events.

EVT_SCROLL_BOTTOM: int  # Process  wxEVT_SCROLL_BOTTOM   scroll to bottom or rightmost (maximum) position events.

EVT_SCROLL_LINEUP: int  # Process  wxEVT_SCROLL_LINEUP   line up or left events.

EVT_SCROLL_LINEDOWN: int  # Process  wxEVT_SCROLL_LINEDOWN   line down or right events.

EVT_SCROLL_PAGEUP: int  # Process  wxEVT_SCROLL_PAGEUP   page up or left events.

EVT_SCROLL_PAGEDOWN: int  # Process  wxEVT_SCROLL_PAGEDOWN   page down or right events.

EVT_SCROLL_THUMBTRACK: int  # Process  wxEVT_SCROLL_THUMBTRACK   thumbtrack events (frequent events sent as the user drags the thumbtrack).

EVT_SCROLL_THUMBRELEASE: int  # Process  wxEVT_SCROLL_THUMBRELEASE   thumb release events.

EVT_SCROLL_CHANGED: int  # Process  wxEVT_SCROLL_CHANGED   end of scrolling events (MSW only).

EVT_COMMAND_SCROLL: int  # Process all scroll events.

EVT_COMMAND_SCROLL_TOP: int  # Process  wxEVT_SCROLL_TOP   scroll to top or leftmost (minimum) position events.

EVT_COMMAND_SCROLL_BOTTOM: int  # Process  wxEVT_SCROLL_BOTTOM   scroll to bottom or rightmost (maximum) position events.

EVT_COMMAND_SCROLL_LINEUP: int  # Process  wxEVT_SCROLL_LINEUP   line up or left events.

EVT_COMMAND_SCROLL_LINEDOWN: int  # Process  wxEVT_SCROLL_LINEDOWN   line down or right events.

EVT_COMMAND_SCROLL_PAGEUP: int  # Process  wxEVT_SCROLL_PAGEUP   page up or left events.

EVT_COMMAND_SCROLL_PAGEDOWN: int  # Process  wxEVT_SCROLL_PAGEDOWN   page down or right events.

EVT_COMMAND_SCROLL_THUMBTRACK: int  # Process  wxEVT_SCROLL_THUMBTRACK   thumbtrack events (frequent events sent as the user drags the thumbtrack).

EVT_COMMAND_SCROLL_THUMBRELEASE: int  # Process  wxEVT_SCROLL_THUMBRELEASE   thumb release events.

EVT_COMMAND_SCROLL_CHANGED: int  # Process  wxEVT_SCROLL_CHANGED   end of scrolling events (MSW only). ^^

class Scrolled:
    """ The Scrolled class manages scrolling for its client area,
transforming the coordinates according to the scrollbar positions, and
setting the scroll positions, thumb sizes and ranges according to the
area in view.

        Source: https://docs.wxpython.org/wx.Scrolled.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def AdjustScrollbars(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def CalcScrolledPosition(self, *args, **kw) -> 'Point':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def CalcUnscrolledPosition(self, *args, **kw) -> 'Point':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def Create(self, parent, id=-1, pos=DefaultPosition, size=DefaultSize, style=HSCROLL|VSCROLL, name="scrolledWindow") -> bool:
        """ Creates the window for two-step construction.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def DisableKeyboardScrolling(self) -> None:
        """ Disable use of keyboard keys for scrolling.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def DoPrepareDC(self, dc: 'DC') -> None:
        """ Call this function to prepare the device context for drawing a scrolled image.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def EnableScrolling(self, xScrolling, yScrolling) -> None:
        """ Enable or disable use of wx.Window.ScrollWindow   for scrolling.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetScaleX(self) -> float:
        """ float

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetScaleY(self) -> float:
        """ float

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetScrollLines(self, orient: int) -> int:
        """ orient (int) â

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetScrollPageSize(self, orient: int) -> int:
        """ orient (int) â

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetScrollPixelsPerUnit(self) -> tuple:
        """ Get the number of pixels per scroll unit (line), in each direction, as set by SetScrollbars .

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetSizeAvailableForScrollTarget(self, size: Union[tuple[int, int], 'Size']) -> 'Size':
        """ Function which must be overridden to implement the size available for the scroll target for the given size of the main window.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetTargetRect(self) -> 'Rect':
        """ wx.Rect

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetTargetWindow(self) -> 'Window':
        """ wx.Window

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def GetViewStart(self) -> tuple:
        """ Get the position at which the visible portion of the window starts.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def IsAutoScrolling(self) -> bool:
        """ Are we generating the autoscroll events?

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def IsRetained(self) -> bool:
        """ Motif only: True if the window has a backing bitmap.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def OnDraw(self, dc: 'DC') -> None:
        """ Called by the default paint event handler to allow the application to define painting behaviour without having to worry about calling DoPrepareDC .

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def PrepareDC(self, dc: 'DC') -> None:
        """ This function is for backwards compatibility only and simply calls DoPrepareDC   now.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def Scroll(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def SendAutoScrollEvents(self, event: 'ScrollWinEvent') -> bool:
        """ This method can be overridden in a derived class to forbid sending the auto scroll events - note that unlike StopAutoScrolling   it doesnât stop the timer, so it will be called repeatedly and will typically return different values depending on the current mouse position.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def SetScale(self, xs, ys) -> None:
        """ xs (float) â

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def SetScrollPageSize(self, orient, pageSize) -> None:
        """ orient (int) â

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def SetScrollRate(self, xstep, ystep) -> None:
        """ Set the horizontal and vertical scrolling increment only.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def SetScrollbars(self, pixelsPerUnitX, pixelsPerUnitY, noUnitsX, noUnitsY, xPos=0, yPos=0, noRefresh=False) -> None:
        """ Sets up vertical and/or horizontal scrollbars.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def SetTargetRect(self, rect: 'Rect') -> None:
        """ rect (wx.Rect) â

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def SetTargetWindow(self, window: 'Window') -> None:
        """ Call this function to tell   wx.Scrolled  to perform the actual scrolling on a different window (and not on itself).

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def ShouldScrollToChildOnFocus(self, child: 'Window') -> bool:
        """ This method can be overridden in a derived class to prevent scrolling the child window into view automatically when it gets focus.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def ShowScrollbars(self, horz, vert) -> None:
        """ Set the scrollbar visibility.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    def StopAutoScrolling(self) -> None:
        """ Stop generating the scroll events when mouse is held outside the window.

            Source: https://docs.wxpython.org/wx.Scrolled.html
        """

    ScaleX: float  # See GetScaleX
    ScaleY: float  # See GetScaleY
    TargetRect: 'Rect'  # See GetTargetRect and SetTargetRect
    TargetWindow: 'Window'  # See GetTargetWindow and SetTargetWindow



RETAINED: int  # Uses a backing pixmap to speed refreshes. Motif only. ^^

EVT_SCROLLWIN: int  # Process all scroll events.

EVT_SCROLLWIN_TOP: int  # Process  wxEVT_SCROLLWIN_TOP   scroll-to-top events.

EVT_SCROLLWIN_BOTTOM: int  # Process  wxEVT_SCROLLWIN_BOTTOM   scroll-to-bottom events.

EVT_SCROLLWIN_LINEUP: int  # Process  wxEVT_SCROLLWIN_LINEUP   line up events.

EVT_SCROLLWIN_LINEDOWN: int  # Process  wxEVT_SCROLLWIN_LINEDOWN   line down events.

EVT_SCROLLWIN_PAGEUP: int  # Process  wxEVT_SCROLLWIN_PAGEUP   page up events.

EVT_SCROLLWIN_PAGEDOWN: int  # Process  wxEVT_SCROLLWIN_PAGEDOWN   page down events.

EVT_SCROLLWIN_THUMBTRACK: int  # Process  wxEVT_SCROLLWIN_THUMBTRACK   thumbtrack events (frequent events sent as the user drags the thumbtrack).

EVT_SCROLLWIN_THUMBRELEASE: int  # Process  wxEVT_SCROLLWIN_THUMBRELEASE   thumb release events. ^^

SHOW_SB_ALWAYS: int

SHOW_SB_NEVER: int

SHOW_SB_DEFAULT: int

class ScrolledCanvas(Window,Scrolled):
    """ The ScrolledCanvas      class is a combination of the Window      and
Scrolled      classes, and manages scrolling for its client area,
transforming the coordinates according to the scrollbar positions,
and setting the scroll positions, thumb sizes and ranges according to
the area in view.

        Source: https://docs.wxpython.org/wx.ScrolledCanvas.html
    """


class ScrolledWindow:
    """ Scrolled window derived from Panel.

        Source: https://docs.wxpython.org/wx.ScrolledWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ScrolledWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ScrolledWindow.html
        """

    def SetFocusIgnoringChildren(self) -> None:
        """ In contrast to SetFocus() this will set the focus to the panel even if
there are child windows in the panel. This is only rarely needed.

            Source: https://docs.wxpython.org/wx.ScrolledWindow.html
        """



class ScrollEvent(CommandEvent):
    """ A scroll event holds information about events sent from stand-alone
scrollbars (see ScrollBar) and sliders (see Slider).

        Source: https://docs.wxpython.org/wx.ScrollEvent.html
    """
    def __init__(self, commandType=wxEVT_NULL, id=0, pos=0, orientation=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ScrollEvent.html
        """

    def GetOrientation(self) -> int:
        """ Returns wx.HORIZONTAL or wx.VERTICAL, depending on the orientation of the scrollbar.

            Source: https://docs.wxpython.org/wx.ScrollEvent.html
        """

    def GetPosition(self) -> int:
        """ Returns the position of the scrollbar.

            Source: https://docs.wxpython.org/wx.ScrollEvent.html
        """

    def SetOrientation(self, orient: int) -> None:
        """ orient (int) â

            Source: https://docs.wxpython.org/wx.ScrollEvent.html
        """

    def SetPosition(self, pos: int) -> None:
        """ pos (int) â

            Source: https://docs.wxpython.org/wx.ScrollEvent.html
        """

    Orientation: int  # See GetOrientation and SetOrientation
    Position: int  # See GetPosition and SetPosition



class Slider(Control):
    """ A slider is a control with a handle which can be pulled back and forth
to change the value.

        Source: https://docs.wxpython.org/wx.Slider.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def ClearSel(self) -> None:
        """ Clears the selection, for a slider with the wx.SL_SELRANGE  style.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def ClearTicks(self) -> None:
        """ Clears the ticks.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def Create(self, parent, id=ID_ANY, value=0, minValue=0, maxValue=100, point=DefaultPosition, size=DefaultSize, style=SL_HORIZONTAL, validator=DefaultValidator, name=SliderNameStr) -> bool:
        """ Used for two-step slider construction.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetLineSize(self) -> int:
        """ Returns the line size.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetMax(self) -> int:
        """ Gets the maximum slider value.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetMin(self) -> int:
        """ Gets the minimum slider value.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetPageSize(self) -> int:
        """ Returns the page size.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetRange(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetSelEnd(self) -> int:
        """ Returns the selection end point.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetSelStart(self) -> int:
        """ Returns the selection start point.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetThumbLength(self) -> int:
        """ Returns the thumb length.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetTickFreq(self) -> int:
        """ Returns the tick frequency.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def GetValue(self) -> int:
        """ Gets the current slider value.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetLineSize(self, lineSize: int) -> None:
        """ Sets the line size for the slider.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetMax(self, maxValue: int) -> None:
        """ Sets the maximum slider value.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetMin(self, minValue: int) -> None:
        """ Sets the minimum slider value.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetPageSize(self, pageSize: int) -> None:
        """ Sets the page size for the slider.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetRange(self, minValue, maxValue) -> None:
        """ Sets the minimum and maximum slider values.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetSelection(self, startPos, endPos) -> None:
        """ Sets the selection.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetThumbLength(self, len: int) -> None:
        """ Sets the slider thumb length.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetTick(self, tickPos: int) -> None:
        """ Sets a tick position.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetTickFreq(self, freq: int) -> None:
        """ Sets the tick mark frequency and position.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    def SetValue(self, value: int) -> None:
        """ Sets the slider position.

            Source: https://docs.wxpython.org/wx.Slider.html
        """

    LineSize: int  # See GetLineSize and SetLineSize
    Max: int  # See GetMax and SetMax
    Min: int  # See GetMin and SetMin
    PageSize: int  # See GetPageSize and SetPageSize
    Range: None  # See GetRange
    SelEnd: int  # See GetSelEnd
    SelStart: int  # See GetSelStart
    ThumbLength: int  # See GetThumbLength and SetThumbLength
    TickFreq: int  # See GetTickFreq and SetTickFreq
    Value: int  # See GetValue and SetValue



SL_HORIZONTAL: int  # Displays the slider horizontally (this is the default).

SL_VERTICAL: int  # Displays the slider vertically.

SL_AUTOTICKS: int  # Displays tick marks (Windows, GTK+ 2.16 and later).

SL_MIN_MAX_LABELS: int  # Displays minimum, maximum labels (new since wxWidgets 2.9.1).

SL_VALUE_LABEL: int  # Displays value label (new since wxWidgets 2.9.1).

SL_LABELS: int  # Displays minimum, maximum and value labels (same as wx.SL_VALUE_LABEL and wx.SL_MIN_MAX_LABELS together).

SL_LEFT: int  # Displays ticks on the left and forces the slider to be vertical (Windows and GTK+ 3 only).

SL_RIGHT: int  # Displays ticks on the right and forces the slider to be vertical.

SL_TOP: int  # Displays ticks on the top (Windows and GTK+ 3 only).

SL_BOTTOM: int  # Displays ticks on the bottom (this is the default).

SL_BOTH: int  # Displays ticks on both sides of the slider. Windows only.

SL_SELRANGE: int  # Displays a highlighted selection range. Windows only.

SL_INVERSE: int  # Inverses the minimum and maximum endpoints on the slider. Not compatible with wx.SL_SELRANGE. ^^

class ScrollWinEvent(Event):
    """ A scroll event holds information about events sent from scrolling
windows.

        Source: https://docs.wxpython.org/wx.ScrollWinEvent.html
    """
    def __init__(self, commandType=wxEVT_NULL, pos=0, orientation=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ScrollWinEvent.html
        """

    def GetOrientation(self) -> int:
        """ Returns wx.HORIZONTAL or wx.VERTICAL, depending on the orientation of the scrollbar.

            Source: https://docs.wxpython.org/wx.ScrollWinEvent.html
        """

    def GetPosition(self) -> int:
        """ Returns the position of the scrollbar for the thumb track and release events.

            Source: https://docs.wxpython.org/wx.ScrollWinEvent.html
        """

    def SetOrientation(self, orient: int) -> None:
        """ orient (int) â

            Source: https://docs.wxpython.org/wx.ScrollWinEvent.html
        """

    def SetPosition(self, pos: int) -> None:
        """ pos (int) â

            Source: https://docs.wxpython.org/wx.ScrollWinEvent.html
        """

    Orientation: int  # See GetOrientation and SetOrientation
    Position: int  # See GetPosition and SetPosition



class SearchCtrl(TextCtrl):
    """ A search control is a composite control with a search button, a text
control, and a cancel button.

        Source: https://docs.wxpython.org/wx.SearchCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def AppendText(self, text: str) -> None:
        """ Appends the text to the end of the text control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def AutoComplete(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def AutoCompleteDirectories(self) -> bool:
        """ Call this function to enable auto-completion of the text using the file system directories.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def AutoCompleteFileNames(self) -> bool:
        """ Call this function to enable auto-completion of the text typed in a single-line text control using all valid file system paths.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def CanCopy(self) -> bool:
        """ Returns True if the selection can be copied to the clipboard.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def CanCut(self) -> bool:
        """ Returns True if the selection can be cut to the clipboard.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def CanPaste(self) -> bool:
        """ Returns True if the contents of the clipboard can be pasted into the text control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def CanRedo(self) -> bool:
        """ Returns True if there is a redo facility available and the last operation can be redone.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def CanUndo(self) -> bool:
        """ Returns True if there is an undo facility available and the last operation can be undone.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def ChangeValue(self, value: str) -> None:
        """ Sets the new text control value.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Clear(self) -> None:
        """ Clears the text in the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Copy(self) -> None:
        """ Copies the selected text to the clipboard.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Create(self, parent, id=ID_ANY, value="", pos=DefaultPosition, size=DefaultSize, style=0, validator=DefaultValidator, name=SearchCtrlNameStr) -> bool:
        """ parent (wx.Window) â

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Cut(self) -> None:
        """ Copies the selected text to the clipboard and removes it from the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def ForceUpper(self) -> None:
        """ Convert all text entered into the control to upper case.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetDescriptiveText(self) -> str:
        """ Return the text displayed when there is not yet any user input.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetHint(self) -> str:
        """ Returns the current hint string.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetInsertionPoint(self) -> int:
        """ Returns the insertion point, or cursor, position.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetLastPosition(self) -> 'TextPos':
        """ Returns the zero based index of the last position in the text control, which is equal to the number of characters in the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetMargins(self) -> 'Point':
        """ Returns the margins used by the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetMenu(self) -> 'Menu':
        """ Returns a pointer to the search controlâs menu object or None if there is no menu attached.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetRange(self, from_, to_) -> str:
        """ Returns the string containing the text starting in the positions from  and up to to  in the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetSelection(self) -> tuple:
        """ Gets the current selection span.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetStringSelection(self) -> str:
        """ Gets the text currently selected in the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def GetValue(self) -> str:
        """ Gets the contents of the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def IsCancelButtonVisible(self) -> bool:
        """ Returns the cancel buttonâs visibility state.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def IsEditable(self) -> bool:
        """ Returns True if the controls contents may be edited by user (note that it always can be changed by the program).

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if the control is currently empty.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def IsSearchButtonVisible(self) -> bool:
        """ Returns the search button visibility value.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Paste(self) -> None:
        """ Pastes text from the clipboard to the text item.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Redo(self) -> None:
        """ If there is a redo facility and the last operation can be redone, redoes the last operation.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Remove(self, from_, to_) -> None:
        """ Removes the text starting at the first given position up to (but not including) the character at the last position.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Replace(self, from_, to_, value) -> None:
        """ Replaces the text starting at the first position up to (but not including) the character at the last position with the given text.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SelectAll(self) -> None:
        """ Selects all text in the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SelectNone(self) -> None:
        """ Deselects selected text in the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetCancelBitmap(self, bmp) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetDescriptiveText(self, text: str) -> None:
        """ Set the text to be displayed in the search control when the user has not yet typed anything in it.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetEditable(self, editable: bool) -> None:
        """ Makes the text item editable or read-only, overriding the wx.TE_READONLY  flag.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetHint(self, hint: str) -> bool:
        """ Sets a hint shown in an empty unfocused text control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetInsertionPoint(self, pos: int) -> None:
        """ Sets the insertion point at the given position.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetInsertionPointEnd(self) -> None:
        """ Sets the insertion point at the end of the text control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetMargins(self, *args, **kw) -> None:
        """ Attempts to set the control margins.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetMaxLength(self, len: int) -> None:
        """ This function sets the maximum number of characters the user can enter into the control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetMenu(self, menu: 'Menu') -> None:
        """ Sets the search controlâs menu object.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetSearchBitmap(self, bmp) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetSearchMenuBitmap(self, bmp) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetSelection(self, from_, to_) -> None:
        """ Selects the text starting at the first position up to (but not including) the character at the last position.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def SetValue(self, value: str) -> None:
        """ Sets the new text control value.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def ShowCancelButton(self, show: bool) -> None:
        """ Shows or hides the cancel button.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def ShowSearchButton(self, show: bool) -> None:
        """ Sets the search button visibility value on the search control.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def Undo(self) -> None:
        """ If there is an undo facility and the last operation can be undone, undoes the last operation.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    def WriteText(self, text: str) -> None:
        """ Writes the text into the text control at the current insertion position.

            Source: https://docs.wxpython.org/wx.SearchCtrl.html
        """

    CancelButtonVisible: Any  # See IsCancelButtonVisible and ShowCancelButton
    DescriptiveText: str  # See GetDescriptiveText and SetDescriptiveText
    Hint: str  # See GetHint and SetHint
    InsertionPoint: int  # See GetInsertionPoint and SetInsertionPoint
    LastPosition: 'TextPos'  # See GetLastPosition
    Margins: 'Point'  # See GetMargins and SetMargins
    Menu: 'Menu'  # See GetMenu and SetMenu
    SearchButtonVisible: Any  # See IsSearchButtonVisible and ShowSearchButton
    StringSelection: str  # See GetStringSelection
    Value: str  # See GetValue and SetValue



EVT_SEARCH: int  # Respond to a  wxEVT_SEARCH   event, generated when the search button is clicked. Note that this does not initiate a search on its own, you need to perform the appropriate action in your event handler. You may use:

EVT_SEARCH_CANCEL: int  # Respond to a  wxEVT_SEARCH_CANCEL   event, generated when the cancel button is clicked. ^^

class SetCursorEvent(Event):
    """ A SetCursorEvent is generated from Window when the mouse cursor is
about to be set as a result of mouse motion.

        Source: https://docs.wxpython.org/wx.SetCursorEvent.html
    """
    def __init__(self, x=0, y=0) -> None:
        """ Constructor, used by the library itself internally to initialize the event object.

            Source: https://docs.wxpython.org/wx.SetCursorEvent.html
        """

    def GetCursor(self) -> 'Cursor':
        """ Returns a reference to the cursor specified by this event.

            Source: https://docs.wxpython.org/wx.SetCursorEvent.html
        """

    def GetX(self) -> 'Coord':
        """ Returns the X coordinate of the mouse in client coordinates.

            Source: https://docs.wxpython.org/wx.SetCursorEvent.html
        """

    def GetY(self) -> 'Coord':
        """ Returns the Y coordinate of the mouse in client coordinates.

            Source: https://docs.wxpython.org/wx.SetCursorEvent.html
        """

    def HasCursor(self) -> bool:
        """ Returns True if the cursor specified by this event is a valid cursor.

            Source: https://docs.wxpython.org/wx.SetCursorEvent.html
        """

    def SetCursor(self, cursor: 'Cursor') -> None:
        """ Sets the cursor associated with this event.

            Source: https://docs.wxpython.org/wx.SetCursorEvent.html
        """

    Cursor: 'Cursor'  # See GetCursor and SetCursor
    X: 'Coord'  # See GetX
    Y: 'Coord'  # See GetY



class SettableHeaderColumn(HeaderColumn):
    """ Adds methods to set the column attributes to HeaderColumn.

        Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
    """
    def ChangeFlag(self, flag, set) -> None:
        """ Set or clear the given flag.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def ClearFlag(self, flag: int) -> None:
        """ Clear the specified flag for the column.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetAlignment(self, align: int) -> None:
        """ Set the alignment of the column header.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetBitmap(self, bitmap: 'BitmapBundle') -> None:
        """ Set the bitmap to be displayed in the column header.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetFlag(self, flag: int) -> None:
        """ Set the specified flag for the column.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetFlags(self, flags: int) -> None:
        """ Set the column flags.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetHidden(self, hidden: bool) -> None:
        """ Hide or show the column.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetMinWidth(self, minWidth: int) -> None:
        """ Set the minimal column width.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetReorderable(self, reorderable: bool) -> None:
        """ Allow changing the column order by dragging it.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetResizeable(self, resizable: bool) -> None:
        """ Call this to enable or disable interactive resizing of the column by the user.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetSortOrder(self, ascending: bool) -> None:
        """ Sets this column as the sort key for the associated control.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetSortable(self, sortable: bool) -> None:
        """ Allow clicking the column to sort the control contents by the field in this column.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetTitle(self, title: str) -> None:
        """ Set the text to display in the column header.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def SetWidth(self, width: int) -> None:
        """ Set the column width.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def ToggleFlag(self, flag: int) -> None:
        """ Toggle the specified flag for the column.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def ToggleSortOrder(self) -> None:
        """ Inverses the sort order.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    def UnsetAsSortKey(self) -> None:
        """ Donât use this column for sorting.

            Source: https://docs.wxpython.org/wx.SettableHeaderColumn.html
        """

    Alignment: int  # See GetAlignment and SetAlignment
    Bitmap: 'BitmapBundle'  # See GetBitmap and SetBitmap
    Flags: int  # See GetFlags and SetFlags
    Hidden: bool  # See IsHidden and SetHidden
    MinWidth: int  # See GetMinWidth and SetMinWidth
    Reorderable: bool  # See IsReorderable and SetReorderable
    Resizeable: bool  # See IsResizeable and SetResizeable
    Sortable: bool  # See IsSortable and SetSortable
    Title: str  # See GetTitle and SetTitle
    Width: int  # See GetWidth and SetWidth



ALIGN_NOT: int

COL_RESIZABLE: int

class SharedClientDataContainer:
    """ This class is a replacement for ClientDataContainer, and unlike
ClientDataContainer the SharedClientDataContainer client data is
copiable, so it can be copied when objects containing it are cloned.

        Source: https://docs.wxpython.org/wx.SharedClientDataContainer.html
    """
    def GetClientData(self) -> None:
        """ Get the untyped client data.

            Source: https://docs.wxpython.org/wx.SharedClientDataContainer.html
        """

    def GetClientObject(self) -> ClientData:
        """ Get a pointer to the client data object.

            Source: https://docs.wxpython.org/wx.SharedClientDataContainer.html
        """

    def SetClientData(self, data: Any) -> None:
        """ Set the untyped client data.

            Source: https://docs.wxpython.org/wx.SharedClientDataContainer.html
        """

    def SetClientObject(self, data: ClientData) -> None:
        """ Set the client data object.

            Source: https://docs.wxpython.org/wx.SharedClientDataContainer.html
        """

    ClientData: Any  # See GetClientData and SetClientData
    ClientObject: ClientData  # See GetClientObject and SetClientObject



class ShowEvent(Event):
    """ An event being sent when the window is shown or hidden.

        Source: https://docs.wxpython.org/wx.ShowEvent.html
    """
    def __init__(self, winid=0, show=False) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ShowEvent.html
        """

    def IsShown(self) -> bool:
        """ Return True if the window has been shown, False if it has been hidden.

            Source: https://docs.wxpython.org/wx.ShowEvent.html
        """

    def SetShow(self, show: bool) -> None:
        """ Set whether the windows was shown or hidden.

            Source: https://docs.wxpython.org/wx.ShowEvent.html
        """

    Show: bool  # See IsShown and SetShow



EVT_SHOW: int  # Process a  wxEVT_SHOW   event. ^^

class Simplebook(BookCtrlBase):
    """ Simplebook is a control showing exactly one of its several pages.

        Source: https://docs.wxpython.org/wx.Simplebook.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name="") -> bool:
        """ Really create the window of an object created using default constructor.

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """

    def SetEffect(self, effect: ShowEffect) -> None:
        """ Set the same effect to use for both showing and hiding the pages.

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """

    def SetEffectTimeout(self, timeout: Any) -> None:
        """ Set the same effect timeout to use for both showing and hiding the pages.

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """

    def SetEffects(self, showEffect, hideEffect) -> None:
        """ Set the effects to use for showing and hiding the pages.

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """

    def SetEffectsTimeouts(self, showTimeout, hideTimeout) -> None:
        """ Set the effect timeout to use for showing and hiding the pages.

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """

    def ShowNewPage(self, page: 'Window') -> bool:
        """ Add a new page and show it immediately.

            Source: https://docs.wxpython.org/wx.Simplebook.html
        """



class SimpleHelpProvider(HelpProvider):
    """ SimpleHelpProvider is an implementation of HelpProvider which
supports only plain text help strings, and shows the string associated
with the control (if any) in a tooltip.

        Source: https://docs.wxpython.org/wx.SimpleHelpProvider.html
    """


class SingleChoiceDialog(Dialog):
    """ PySingleChoiceDialog(parent, message, caption, choices, style=CHOICEDLG_STYLE, pos=DefaultPosition)

        Source: https://docs.wxpython.org/wx.SingleChoiceDialog.html
    """
    def __init__(self, parent, message, caption, choices, style=CHOICEDLG_STYLE, pos=DefaultPosition) -> None:
        """ Constructor, taking an array of String       choices and optional client data.

            Source: https://docs.wxpython.org/wx.SingleChoiceDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.SingleChoiceDialog.html
        """

    def GetSelection(self) -> int:
        """ Returns the index of selected item.

            Source: https://docs.wxpython.org/wx.SingleChoiceDialog.html
        """

    def GetStringSelection(self) -> str:
        """ Returns the selected string.

            Source: https://docs.wxpython.org/wx.SingleChoiceDialog.html
        """

    def SetSelection(self, selection: int) -> None:
        """ Sets the index of the initially selected item.

            Source: https://docs.wxpython.org/wx.SingleChoiceDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning either wx.ID_OK or wx.ID_CANCEL.

            Source: https://docs.wxpython.org/wx.SingleChoiceDialog.html
        """

    Selection: int  # See GetSelection and SetSelection
    StringSelection: str  # See GetStringSelection



class SingleInstanceChecker:
    """ SingleInstanceChecker class allows checking that only a single
instance of a program is running.

        Source: https://docs.wxpython.org/wx.SingleInstanceChecker.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SingleInstanceChecker.html
        """

    def Create(self, name, path="") -> bool:
        """ Initialize the object if it had been created using the default constructor.

            Source: https://docs.wxpython.org/wx.SingleInstanceChecker.html
        """

    def CreateDefault(self) -> bool:
        """ Calls Create   with default name.

            Source: https://docs.wxpython.org/wx.SingleInstanceChecker.html
        """

    def IsAnotherRunning(self) -> bool:
        """ Returns True if another copy of this program is already running and False otherwise.

            Source: https://docs.wxpython.org/wx.SingleInstanceChecker.html
        """



class Size:
    """ A Size is a useful data structure for graphics operations.

        Source: https://docs.wxpython.org/wx.Size.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def DecBy(self, *args, **kw) -> None:
        """ Decreases the size in both x and y directions.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def DecTo(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Decrements this object so that both of its dimensions are not greater than the corresponding dimensions of the size.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def DecToIfSpecified(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Decrements this object to be not bigger than the given size ignoring non-specified components.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def Get(self) -> tuple:
        """ Return the width and height properties as a tuple.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def GetHeight(self) -> int:
        """ Gets the height member.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def GetIM(self) -> None:
        """ Returns an immutable representation of the wx.Size object, based on namedtuple.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def GetWidth(self) -> int:
        """ Gets the width member.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def IncBy(self, *args, **kw) -> None:
        """ Increases the size in both x and y directions.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def IncTo(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Increments this object so that both of its dimensions are not less than the corresponding dimensions of the size.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def IsFullySpecified(self) -> bool:
        """ Returns True if neither of the size object components is equal to -1, which is used as default for the size values in wxWidgets (hence the predefined wx.DefaultSize       has both of its components equal to -1).

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def Scale(self, xscale, yscale) -> 'Size':
        """ Scales the dimensions of this object by the given factors.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def Set(self, width, height) -> None:
        """ Sets the width and height members.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def SetDefaults(self, sizeDefault: Union[tuple[int, int], 'Size']) -> None:
        """ Combine this size object with another one replacing the default (i.e. equal to -1) components of this object with those of the other.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def SetHeight(self, height: int) -> None:
        """ Sets the height.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def SetWidth(self, width: int) -> None:
        """ Sets the width.

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __bool__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __eq__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __getitem__(self, idx) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __len__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __ne__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __nonzero__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __reduce__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __setitem__(self, idx, val) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __str__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __imul__(self) -> None:
        """ factor (int) â

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __iadd__(self) -> None:
        """ sz (wx.Size) â

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __isub__(self) -> None:
        """ sz (wx.Size) â

            Source: https://docs.wxpython.org/wx.Size.html
        """

    def __idiv__(self) -> None:
        """ factor (int) â

            Source: https://docs.wxpython.org/wx.Size.html
        """

    Height: int  # See GetHeight and SetHeight
    Width: int  # See GetWidth and SetWidth
    height: Any  # See GetHeight and SetHeight
    width: Any  # See GetWidth and SetWidth
    x: Any  # See GetWidth and SetWidth
    y: Any  # See GetHeight and SetHeight



class SizeEvent(Event):
    """ A size event holds information about size change events of Window.

        Source: https://docs.wxpython.org/wx.SizeEvent.html
    """
    def __init__(self, sz, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.SizeEvent.html
        """

    def GetRect(self) -> 'Rect':
        """ wx.Rect

            Source: https://docs.wxpython.org/wx.SizeEvent.html
        """

    def GetSize(self) -> 'Size':
        """ Returns the entire size of the window generating the size change event.

            Source: https://docs.wxpython.org/wx.SizeEvent.html
        """

    def SetRect(self, rect: 'Rect') -> None:
        """ rect (wx.Rect) â

            Source: https://docs.wxpython.org/wx.SizeEvent.html
        """

    def SetSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ size (wx.Size) â

            Source: https://docs.wxpython.org/wx.SizeEvent.html
        """

    Rect: 'Rect'  # See GetRect and SetRect
    Size: Union[tuple[int, int], 'Size']  # See GetSize and SetSize



class SizerFlags:
    """ Container for sizer items flags providing readable names for them.

        Source: https://docs.wxpython.org/wx.SizerFlags.html
    """
    def __init__(self, proportion: int=0) -> None:
        """ Creates the   wx.Sizer  with the proportion specified by proportion.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Align(self, alignment: int) -> 'SizerFlags':
        """ Sets the alignment of this   wx.SizerFlags  to align.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Border(self, *args, **kw) -> 'SizerFlags':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Bottom(self) -> 'SizerFlags':
        """ Aligns the object to the bottom, similar for  Align(wxALIGN_BOTTOM) .

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Center(self) -> 'SizerFlags':
        """ Sets the object of the   wx.SizerFlags  to center itself in the area it is given.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def CenterHorizontal(self) -> 'SizerFlags':
        """ Same as CentreHorizontal .

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def CenterVertical(self) -> 'SizerFlags':
        """ Same as CentreVertical .

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Centre(self) -> 'SizerFlags':
        """ wx.Center       for people with the other dialect of English.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def CentreHorizontal(self) -> 'SizerFlags':
        """ Center an item only in horizontal direction.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def CentreVertical(self) -> 'SizerFlags':
        """ Center an item only in vertical direction.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    @staticmethod
    def DisableConsistencyChecks() -> None:
        """ Globally disable checks for sizer flag consistency in debug builds.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def DoubleBorder(self, direction: int=ALL) -> 'SizerFlags':
        """ Sets the border in the given direction  having twice the default border size.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def DoubleHorzBorder(self) -> 'SizerFlags':
        """ Sets the border in left and right directions having twice the default border size.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Expand(self) -> 'SizerFlags':
        """ Sets the object of the   wx.SizerFlags  to expand to fill as much area as it can.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def FixedMinSize(self) -> 'SizerFlags':
        """ Set the  FIXED_MINSIZE   flag which indicates that the initial size of the window should be also set as its minimal size.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    @staticmethod
    def GetDefaultBorder() -> int:
        """ Returns the border used by default in   wx.Border  method.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    @staticmethod
    def GetDefaultBorderFractional() -> float:
        """ Returns the border used by default, with fractional precision.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Left(self) -> 'SizerFlags':
        """ Aligns the object to the left, similar for  Align(wxALIGN_LEFT) .

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Proportion(self, proportion: int) -> 'SizerFlags':
        """ Sets the proportion of this   wx.SizerFlags  to proportion.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def ReserveSpaceEvenIfHidden(self) -> 'SizerFlags':
        """ Set the  RESERVE_SPACE_EVEN_IF_HIDDEN   flag.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Right(self) -> 'SizerFlags':
        """ Aligns the object to the right, similar for  Align(wxALIGN_RIGHT) .

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Shaped(self) -> 'SizerFlags':
        """ Set the  _SHAPED   flag which indicates that the elements should always keep the fixed width to height ratio equal to its original value.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def Top(self) -> 'SizerFlags':
        """ Aligns the object to the top, similar for  Align(wxALIGN_TOP) .

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """

    def TripleBorder(self, direction: int=ALL) -> 'SizerFlags':
        """ Sets the border in the given direction  having thrice the default border size.

            Source: https://docs.wxpython.org/wx.SizerFlags.html
        """



class SizerItem(Object):
    """ The SizerItem class is used to track the position, size and other
attributes of each item managed by a Sizer.

        Source: https://docs.wxpython.org/wx.SizerItem.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def AssignSizer(self, sizer: 'Sizer') -> None:
        """ Set the sizer tracked by this item.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def AssignSpacer(self, *args, **kw) -> None:
        """ Set the size of the spacer tracked by this item.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def AssignWindow(self, window: 'Window') -> None:
        """ Set the window to be tracked by this item.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def CalcMin(self) -> 'Size':
        """ Calculates the minimum desired size for the item, including any space needed by borders.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def DeleteWindows(self) -> None:
        """ Destroy the window or the windows in a subsizer, depending on the type of item.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def DetachSizer(self) -> None:
        """ Enable deleting the SizerItem without destroying the contained sizer.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetBorder(self) -> int:
        """ Return the border attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetFlag(self) -> int:
        """ Return the flags attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetId(self) -> int:
        """ Return the numeric id of   wx.SizerItem, or  ID_NONE   if the id has not been set.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetMinSize(self) -> 'Size':
        """ Get the minimum size needed for the item.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetPosition(self) -> 'Point':
        """ What is the current position of the item, as set in the last Layout.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetProportion(self) -> int:
        """ Get the proportion item attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetRatio(self) -> float:
        """ Get the ratio item attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetRect(self) -> 'Rect':
        """ Get the rectangle of the item on the parent window, excluding borders.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetSize(self) -> 'Size':
        """ Get the current size of the item, as set in the last Layout.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetSizer(self) -> 'Sizer':
        """ If this item is tracking a sizer, return it.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetSpacer(self) -> 'Size':
        """ If this item is tracking a spacer, return its size.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetUserData(self) -> PyUserData:
        """ Get the userData item attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def GetWindow(self) -> 'Window':
        """ If this item is tracking a window then return it.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def IsShown(self) -> bool:
        """ Returns True if this item is a window or a spacer and it is shown or if this item is a sizer and not all of its elements are hidden.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def IsSizer(self) -> bool:
        """ Is this item a sizer?

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def IsSpacer(self) -> bool:
        """ Is this item a spacer?

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def IsWindow(self) -> bool:
        """ Is this item a window?

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetBorder(self, border: int) -> None:
        """ Set the border item attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetDimension(self, pos, size) -> None:
        """ Set the position and size of the space allocated to the sizer, and adjust the position and size of the item to be within that space taking alignment and borders into account.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetFlag(self, flag: int) -> None:
        """ Set the flag item attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetId(self, id: int) -> None:
        """ Sets the numeric id of the   wx.SizerItem  to id.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetInitSize(self, x, y) -> None:
        """ Sets the minimum size to be allocated for this item.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetMinSize(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetProportion(self, proportion: int) -> None:
        """ Set the proportion item attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetRatio(self, *args, **kw) -> None:
        """ Set the ratio item attribute.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def SetUserData(self, userData: PyUserData) -> None:
        """ userData (PyUserData) â

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    def Show(self, show: bool) -> None:
        """ Set the show item attribute, which sizers use to determine if the item is to be made part of the layout or not.

            Source: https://docs.wxpython.org/wx.SizerItem.html
        """

    Border: int  # See GetBorder and SetBorder
    Flag: int  # See GetFlag and SetFlag
    Id: int  # See GetId and SetId
    MinSize: Union[tuple[int, int], 'Size']  # See GetMinSize and SetMinSize
    Position: 'Point'  # See GetPosition
    Proportion: int  # See GetProportion and SetProportion
    Ratio: float  # See GetRatio and SetRatio
    Rect: 'Rect'  # See GetRect
    Size: 'Size'  # See GetSize
    Sizer: 'Sizer'  # See GetSizer
    Spacer: 'Size'  # See GetSpacer
    UserData: PyUserData  # See GetUserData and SetUserData
    Window: 'Window'  # See GetWindow



class SpinButton(Control):
    """ A SpinButton has two small up and down (or left and right) arrow
buttons.

        Source: https://docs.wxpython.org/wx.SpinButton.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def Create(self, parent, id=-1, pos=DefaultPosition, size=DefaultSize, style=SP_VERTICAL, name="wxSpinButton") -> bool:
        """ Scrollbar creation function called by the spin button constructor.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def GetIncrement(self) -> int:
        """ Get the value for increment for a spin control.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def GetMax(self) -> int:
        """ Returns the maximum permissible value.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def GetMin(self) -> int:
        """ Returns the minimum permissible value.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def GetRange(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def GetValue(self) -> int:
        """ Returns the current spin button value.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def SetIncrement(self, value: int) -> None:
        """ Sets the increment for the control.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def SetMax(self, maxVal) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def SetMin(self, minVal) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def SetRange(self, min, max) -> None:
        """ Sets the range of the spin button.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    def SetValue(self, value: int) -> None:
        """ Sets the value of the spin button.

            Source: https://docs.wxpython.org/wx.SpinButton.html
        """

    Increment: int  # See GetIncrement and SetIncrement
    Max: int  # See GetMax and SetMax
    Min: int  # See GetMin and SetMin
    Range: None  # See GetRange
    Value: int  # See GetValue and SetValue



SP_HORIZONTAL: int  # Specifies a horizontal spin button (note that this style is not supported in wxGTK).

SP_VERTICAL: int  # Specifies a vertical spin button.

SP_ARROW_KEYS: int  # The user can use arrow keys to change the value.

SP_WRAP: int  # The value wraps at the minimum and maximum. ^^

EVT_SPIN: int  # Generated whenever pressing an arrow changed the spin button value.

EVT_SPIN_UP: int  # Generated whenever pressing left/up arrow changed the spin button value.

EVT_SPIN_DOWN: int  # Generated whenever pressing right/down arrow changed the spin button value. ^^

UP: int

DOWN: int

class SpinCtrl(Control):
    """ SpinCtrl combines TextCtrl and SpinButton in one control.

        Source: https://docs.wxpython.org/wx.SpinCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def Create(self, parent, id=ID_ANY, value="", pos=DefaultPosition, size=DefaultSize, style=SP_ARROW_KEYS, min=0, max=100, initial=0, name="wxSpinCtrl") -> bool:
        """ Creation function called by the spin control constructor.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def GetBase(self) -> int:
        """ Returns the numerical base being currently used, 10 by default.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def GetIncrement(self) -> int:
        """ Get the value for increment for a spin control.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def GetMax(self) -> int:
        """ Gets maximal allowable value.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def GetMin(self) -> int:
        """ Gets minimal allowable value.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def GetRange(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def GetTextValue(self) -> str:
        """ Returns the text in the text entry part of the control.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def GetValue(self) -> int:
        """ Gets the value of the spin control.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def SetBase(self, base: int) -> bool:
        """ Sets the base to use for the numbers in this control.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def SetIncrement(self, value: int) -> None:
        """ Sets the increment for the control.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def SetMax(self, maxVal) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def SetMin(self, minVal) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def SetRange(self, minVal, maxVal) -> None:
        """ Sets range of allowable values.

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def SetSelection(self, from_, to_) -> None:
        """ Select the text in the text part of the control between positions from  (inclusive) and to  (exclusive).

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    def SetValue(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SpinCtrl.html
        """

    Base: int  # See GetBase and SetBase
    Increment: int  # See GetIncrement and SetIncrement
    Max: int  # See GetMax and SetMax
    Min: int  # See GetMin and SetMin
    Range: None  # See GetRange
    TextValue: str  # See GetTextValue
    Value: str  # See GetValue and SetValue



EVT_SPINCTRL: int  # Process a wxEVT_SPINCTRL event, which is generated whenever the numeric value of the spin control is updated. ^^

class SpinCtrlDouble(Control):
    """ SpinCtrlDouble combines TextCtrl and SpinButton in one control
and displays a real number.

        Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def Create(self, parent, id=ID_ANY, value="", pos=DefaultPosition, size=DefaultSize, style=SP_ARROW_KEYS, min=0, max=100, initial=0, inc=1, name="wxSpinCtrlDouble") -> bool:
        """ Creation function called by the spin control constructor.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def GetDigits(self) -> int:
        """ Gets precision of the value of the spin control.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def GetIncrement(self) -> float:
        """ Gets the increment value.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def GetMax(self) -> float:
        """ Gets maximal allowable value.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def GetMin(self) -> float:
        """ Gets minimal allowable value.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def GetRange(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def GetTextValue(self) -> str:
        """ Returns the text in the text entry part of the control.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def GetValue(self) -> float:
        """ Gets the value of the spin control.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def SetDigits(self, digits: int) -> None:
        """ Sets precision of the value of the spin control.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def SetIncrement(self, inc: float) -> None:
        """ Sets the increment value.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def SetMax(self, maxVal) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def SetMin(self, minVal) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def SetRange(self, minVal, maxVal) -> None:
        """ Sets range of allowable values.

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    def SetValue(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SpinCtrlDouble.html
        """

    Digits: int  # See GetDigits and SetDigits
    Increment: float  # See GetIncrement and SetIncrement
    Max: float  # See GetMax and SetMax
    Min: float  # See GetMin and SetMin
    Range: None  # See GetRange
    TextValue: str  # See GetTextValue
    Value: str  # See GetValue and SetValue



EVT_SPINCTRLDOUBLE: int  # Generated whenever the numeric value of the spin control is changed, that is, when the up/down spin button is clicked, when ENTER is pressed, or the control loses focus and the new value is different from the last. See   wx.SpinDoubleEvent. ^^

class SpinDoubleEvent(NotifyEvent):
    """ This event class is used for the events generated by SpinCtrlDouble.

        Source: https://docs.wxpython.org/wx.SpinDoubleEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SpinDoubleEvent.html
        """

    def GetValue(self) -> float:
        """ Returns the value associated with this spin control event.

            Source: https://docs.wxpython.org/wx.SpinDoubleEvent.html
        """

    def SetValue(self, value: float) -> None:
        """ Set the value associated with the event.

            Source: https://docs.wxpython.org/wx.SpinDoubleEvent.html
        """

    Value: float  # See GetValue and SetValue



class SpinEvent(NotifyEvent):
    """ This event class is used for the events generated by SpinButton and
SpinCtrl.

        Source: https://docs.wxpython.org/wx.SpinEvent.html
    """
    def __init__(self, commandType=wxEVT_NULL, id=0) -> None:
        """ The constructor is not normally used by the user code.

            Source: https://docs.wxpython.org/wx.SpinEvent.html
        """

    def GetPosition(self) -> int:
        """ Retrieve the current spin button or control value.

            Source: https://docs.wxpython.org/wx.SpinEvent.html
        """

    def SetPosition(self, pos: int) -> None:
        """ Set the value associated with the event.

            Source: https://docs.wxpython.org/wx.SpinEvent.html
        """

    Position: int  # See GetPosition and SetPosition



class SplitterEvent(NotifyEvent):
    """ This class represents the events generated by a splitter control.

        Source: https://docs.wxpython.org/wx.SplitterEvent.html
    """
    def __init__(self, eventType=wxEVT_NULL, splitter=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    def GetOldSize(self) -> int:
        """ Returns the old size before the update.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    def GetSashPosition(self) -> int:
        """ Returns the new sash position.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    def GetWindowBeingRemoved(self) -> 'Window':
        """ Returns a pointer to the window being removed when a splitter window is unsplit.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    def GetX(self) -> int:
        """ Returns the x coordinate of the double-click point.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    def GetY(self) -> int:
        """ Returns the y coordinate of the double-click point.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    def SetSashPosition(self, pos: int) -> None:
        """ In the case of  wxEVT_SPLITTER_SASH_POS_CHANGED   events, sets the new sash position.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    def SetSize(self, oldSize, newSize) -> None:
        """ Sets the size values of the window size.

            Source: https://docs.wxpython.org/wx.SplitterEvent.html
        """

    OldSize: int  # See GetOldSize
    SashPosition: int  # See GetSashPosition and SetSashPosition
    WindowBeingRemoved: 'Window'  # See GetWindowBeingRemoved
    X: int  # See GetX
    Y: int  # See GetY



EVT_SPLITTER_SASH_POS_CHANGING: int  # The sash position is in the process of being changed. May be used to modify the position of the tracking bar to properly reflect the position that would be set if the drag were to be completed at this point. Processes a  wxEVT_SPLITTER_SASH_POS_CHANGING   event.

EVT_SPLITTER_SASH_POS_CHANGED: int  # The sash position was changed. May be used to modify the sash position before it is set, or to prevent the change from taking place. Processes a  wxEVT_SPLITTER_SASH_POS_CHANGED   event.

EVT_SPLITTER_UNSPLIT: int  # The splitter has been just unsplit. Processes a  wxEVT_SPLITTER_UNSPLIT   event.

EVT_SPLITTER_DCLICK: int  # The sash was double clicked. The default behaviour is to unsplit the window when this happens (unless the minimum pane size has been set to a value greater than zero). Processes a  wxEVT_SPLITTER_DOUBLECLICKED   event. ^^

class SplitterRenderParams:
    """ This is just a simple struct used as a return value of
RendererNative.GetSplitterParams().

        Source: https://docs.wxpython.org/wx.SplitterRenderParams.html
    """
    def __init__(self, widthSash_, border_, isSens_) -> None:
        """ The only way to initialize this struct is by using this constructor.

            Source: https://docs.wxpython.org/wx.SplitterRenderParams.html
        """

    border: Any  # A public C++ attribute of type int. The width of the border drawn by the splitter inside it, may be 0.
    isHotSensitive: Any  # A public C++ attribute of type bool. True if the sash changes appearance when the mouse passes over it, False otherwise.
    widthSash: Any  # A public C++ attribute of type int. The width of the splitter sash.



class SplitterWindow(Window):
    """ This class manages up to two subwindows.

        Source: https://docs.wxpython.org/wx.SplitterWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def Create(self, parent, id=ID_ANY, point=DefaultPosition, size=DefaultSize, style=SP_3D, name="splitter") -> bool:
        """ Creation function, for two-step construction.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetDefaultSashSize(self) -> int:
        """ Returns the default sash size in pixels.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetMinimumPaneSize(self) -> int:
        """ Returns the current minimum pane size (defaults to zero).

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetSashGravity(self) -> float:
        """ Returns the current sash gravity.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetSashPosition(self) -> int:
        """ Returns the current sash position.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetSashSize(self) -> int:
        """ Returns the default sash size in pixels or 0 if it is invisible.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetSplitMode(self) -> 'SplitMode':
        """ Gets the split mode.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetWindow1(self) -> 'Window':
        """ Returns the left/top or only pane.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def GetWindow2(self) -> 'Window':
        """ Returns the right/bottom pane.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def Initialize(self, window: 'Window') -> None:
        """ Initializes the splitter window to have one pane.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def IsSashInvisible(self) -> bool:
        """ Returns True if the sash is invisible even when the window is split, False otherwise.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def IsSplit(self) -> bool:
        """ Returns True if the window is split, False otherwise.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def ReplaceWindow(self, winOld, winNew) -> bool:
        """ This function replaces one of the windows managed by the   wx.SplitterWindow  with another one.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def SetMinimumPaneSize(self, paneSize: int) -> None:
        """ Sets the minimum pane size.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def SetSashGravity(self, gravity: float) -> None:
        """ Sets the sash gravity.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def SetSashInvisible(self, invisible: bool=True) -> None:
        """ Sets whether the sash should be invisible, even when the window is split.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def SetSashPosition(self, position, redraw=True) -> None:
        """ Sets the sash position.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def SetSplitMode(self, mode: int) -> None:
        """ Sets the split mode.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def SplitHorizontally(self, window1, window2, sashPosition=0) -> bool:
        """ Initializes the top and bottom panes of the splitter window.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def SplitVertically(self, window1, window2, sashPosition=0) -> bool:
        """ Initializes the left and right panes of the splitter window.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def Unsplit(self, toRemove: Optional['Window']=None) -> bool:
        """ Unsplits the window.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    def UpdateSize(self) -> None:
        """ Causes any pending sizing of the sash and child panes to take place immediately.

            Source: https://docs.wxpython.org/wx.SplitterWindow.html
        """

    DefaultSashSize: int  # See GetDefaultSashSize
    MinimumPaneSize: int  # See GetMinimumPaneSize and SetMinimumPaneSize
    SashGravity: float  # See GetSashGravity and SetSashGravity
    SashInvisible: bool  # See IsSashInvisible and SetSashInvisible
    SashPosition: int  # See GetSashPosition and SetSashPosition
    SashSize: int  # See GetSashSize
    SplitMode: int  # See GetSplitMode and SetSplitMode
    Window1: 'Window'  # See GetWindow1
    Window2: 'Window'  # See GetWindow2



SP_3D: int  # Draws a 3D effect border and sash.

SP_THIN_SASH: int  # Draws a thin sash.

SP_3DSASH: int  # Draws a 3D effect sash (part of default style).

SP_3DBORDER: int  # Synonym for wx.SP_BORDER.

SP_BORDER: int  # Draws a standard border.

SP_NOBORDER: int  # No border (default).

SP_NO_XP_THEME: int  # Under Windows, switches off the attempt to draw the splitter using Windows theming, so the borders and sash will take on the pre-XP look.

SP_PERMIT_UNSPLIT: int  # Always allow to unsplit, even with the minimum pane size other than zero.

SP_LIVE_UPDATE: int  # Donât draw wx.XOR line but resize the child windows immediately. ^^

EVT_SPLITTER_SASH_POS_RESIZE: int  # The sash position is in the process of being updated. May be used to modify the position of the tracking bar to properly reflect the position that would be set if the update were to be completed. This can happen e.g. when the window is resized and the sash is moved according to the gravity setting. This event is sent when the window is resized and allows the application to select the desired new sash position. If it doesnât process the event, the position is determined by the gravity setting. Processes a  wxEVT_SPLITTER_SASH_POS_RESIZE   event and is only available in wxWidgets 3.1.6 or newer.

XOR: int

SPLIT_VERTICAL: int

SPLIT_HORIZONTAL: int

class StandardPaths:
    """ StandardPaths returns the standard locations in the file system and
should be used by applications to find their data files in a portable
way.

        Source: https://docs.wxpython.org/wx.StandardPaths.html
    """
    @staticmethod
    def Get() -> 'StandardPaths':
        """ Returns reference to the unique global standard paths object.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetAppDocumentsDir(self) -> str:
        """ Return the directory for the document files used by this application.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetConfigDir(self) -> str:
        """ Return the directory containing the system config files.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetDataDir(self) -> str:
        """ Return the location of the applications global, i.e. not user-specific, data files.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetDocumentsDir(self) -> str:
        """ Same as calling GetUserDir   with Dir_Documents parameter.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetExecutablePath(self) -> str:
        """ Return the directory and the filename for the current executable.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetFileLayout(self) -> 'StandardPaths.FileLayout':
        """ Returns the current file layout.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetInstallPrefix(self) -> str:
        """ Return the program installation prefix, e.g.  /usr ,   /opt   or   /home/zeitlin .

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetLocalDataDir(self) -> str:
        """ Return the location for application data files which are host-specific and canât, or shouldnât, be shared with the other machines.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetLocalizedResourcesDir(self, lang, category=ResourceCat_None) -> str:
        """ Return the localized resources directory containing the resource files of the specified category for the given language.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetPluginsDir(self) -> str:
        """ Return the directory where the loadable modules (plugins) live.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetResourcesDir(self) -> str:
        """ Return the directory where the application resource files are located.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetTempDir(self) -> str:
        """ Return the directory for storing temporary files, for the current user.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetUserConfigDir(self) -> str:
        """ Return the directory for the user config files.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetUserDataDir(self) -> str:
        """ Return the directory for the user-dependent application data files:

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetUserDir(self, userDir: Dir) -> str:
        """ Return the path of the specified user data directory.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def GetUserLocalDataDir(self) -> str:
        """ Return the directory for user data files which shouldnât be shared with the other machines.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    @staticmethod
    def MSWGetShellDir(csidl: int) -> str:
        """ Returns location of Windows shell special folder.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def MakeConfigFileName(self, basename, conv=ConfigFileConv_Ext) -> str:
        """ Return the file name which would be used by   wx.FileConfig  if it were constructed with basename.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def SetFileLayout(self, layout: FileLayout) -> None:
        """ Sets the current file layout.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def SetInstallPrefix(self, prefix: str) -> None:
        """ Lets   wx.StandardPaths  know about the real program installation prefix on a Unix system.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def UseAppInfo(self, info: int) -> None:
        """ Controls what application information is used when constructing paths that should be unique to this program, such as the application data directory, the plugins directory on Unix, etc.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    def __init__(self) -> None:
        """ Protected default constructor.

            Source: https://docs.wxpython.org/wx.StandardPaths.html
        """

    AppDocumentsDir: str  # See GetAppDocumentsDir
    ConfigDir: str  # See GetConfigDir
    DataDir: str  # See GetDataDir
    DocumentsDir: str  # See GetDocumentsDir
    ExecutablePath: str  # See GetExecutablePath
    InstallPrefix: str  # See GetInstallPrefix and SetInstallPrefix
    LocalDataDir: str  # See GetLocalDataDir
    PluginsDir: str  # See GetPluginsDir
    ResourcesDir: str  # See GetResourcesDir
    TempDir: str  # See GetTempDir
    UserConfigDir: str  # See GetUserConfigDir
    UserDataDir: str  # See GetUserDataDir
    UserLocalDataDir: str  # See GetUserLocalDataDir



class StaticBitmap(Control):
    """ A static bitmap control displays a bitmap.

        Source: https://docs.wxpython.org/wx.StaticBitmap.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    def Create(self, parent, id=ID_ANY, bitmap=NullBitmap, pos=DefaultPosition, size=DefaultSize, style=0, name=StaticBitmapNameStr) -> bool:
        """ Creation function, for two-step construction.

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    def GetBitmap(self) -> 'Bitmap':
        """ Returns the bitmap currently used in the control.

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    def GetIcon(self) -> 'Icon':
        """ Returns the icon currently used in the control.

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    def GetScaleMode(self) -> 'StaticBitmap.ScaleMode':
        """ Returns the scale mode currently used in the control.

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    def SetBitmap(self, label: Union['Bitmap', 'BitmapBundle']) -> None:
        """ Sets the bitmap label.

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    def SetIcon(self, label: 'Icon') -> None:
        """ Sets the label to the given icon.

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    def SetScaleMode(self, scaleMode: ScaleMode) -> None:
        """ Sets the scale mode.

            Source: https://docs.wxpython.org/wx.StaticBitmap.html
        """

    Bitmap: 'BitmapBundle'  # See GetBitmap and SetBitmap
    Icon: 'Icon'  # See GetIcon and SetIcon



class StaticBox(Control):
    """ A static box is a rectangle drawn around other windows to denote a
logical grouping of items.

        Source: https://docs.wxpython.org/wx.StaticBox.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.StaticBox.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=0, name=StaticBoxNameStr) -> bool:
        """ Creates the static box for two-step construction.

            Source: https://docs.wxpython.org/wx.StaticBox.html
        """

    def Enable(self, enable: bool=True) -> bool:
        """ Enables or disables the box without affecting its label window, if any.

            Source: https://docs.wxpython.org/wx.StaticBox.html
        """

    def GetBordersForSizer(self) -> tuple:
        """ Returns extra space that may be needed for borders within a StaticBox.

            Source: https://docs.wxpython.org/wx.StaticBox.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.StaticBox.html
        """



class StaticBoxSizer(BoxSizer):
    """ StaticBoxSizer is a sizer derived from BoxSizer but adds a static
box around the sizer.

        Source: https://docs.wxpython.org/wx.StaticBoxSizer.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.StaticBoxSizer.html
        """

    def CalcMin(self) -> 'Size':
        """ Implements the calculation of a box sizerâs minimal.

            Source: https://docs.wxpython.org/wx.StaticBoxSizer.html
        """

    def GetStaticBox(self) -> 'StaticBox':
        """ Returns the static box associated with the sizer.

            Source: https://docs.wxpython.org/wx.StaticBoxSizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Method which must be overridden in the derived sizer classes.

            Source: https://docs.wxpython.org/wx.StaticBoxSizer.html
        """

    StaticBox: 'StaticBox'  # See GetStaticBox



class StaticLine(Control):
    """ A static line is just a line which may be used in a dialog to separate
the groups of controls.

        Source: https://docs.wxpython.org/wx.StaticLine.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.StaticLine.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=LI_HORIZONTAL, name=StaticLineNameStr) -> bool:
        """ Creates the static line for two-step construction.

            Source: https://docs.wxpython.org/wx.StaticLine.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.StaticLine.html
        """

    @staticmethod
    def GetDefaultSize() -> int:
        """ This static function returns the size which will be given to the smaller dimension of the static line, i.e.

            Source: https://docs.wxpython.org/wx.StaticLine.html
        """

    def IsVertical(self) -> bool:
        """ Returns True if the line is vertical, False if horizontal.

            Source: https://docs.wxpython.org/wx.StaticLine.html
        """



LI_HORIZONTAL: int  # Creates a horizontal line.

LI_VERTICAL: int  # Creates a vertical line. ^^

class StaticText(Control):
    """ A static text control displays one or more lines of read-only text.

        Source: https://docs.wxpython.org/wx.StaticText.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.StaticText.html
        """

    def Create(self, parent, id=ID_ANY, label="", pos=DefaultPosition, size=DefaultSize, style=0, name=StaticTextNameStr) -> bool:
        """ Creation function, for two-step construction.

            Source: https://docs.wxpython.org/wx.StaticText.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.StaticText.html
        """

    def IsEllipsized(self) -> bool:
        """ Returns True if the window styles for this control contains one of the  ST_ELLIPSIZE_START ,   ST_ELLIPSIZE_MIDDLE   or   ST_ELLIPSIZE_END   styles.

            Source: https://docs.wxpython.org/wx.StaticText.html
        """

    def SetLabel(self, label: str) -> None:
        """ Change the label shown in the control.

            Source: https://docs.wxpython.org/wx.StaticText.html
        """

    def Wrap(self, width: int) -> None:
        """ This functions wraps the controls label so that each of its lines becomes at most width  pixels wide if possible (the lines are broken at words boundaries so it might not be the case if words are too long).

            Source: https://docs.wxpython.org/wx.StaticText.html
        """



ST_NO_AUTORESIZE: int  # By default, the control will adjust its size to exactly fit to the size of the text when SetLabel  is called. If this style flag is given, the control will not change its size (this style is especially useful with controls which also have the  ALIGN_RIGHT   or the   ALIGN_CENTRE_HORIZONTAL   style because otherwise they wonât make sense any longer after a call to  SetLabel).

ST_ELLIPSIZE_START: int  # If the labeltext width exceeds the control width, replace the beginning of the label with an ellipsis; uses wx.Control.Ellipsize .

ST_ELLIPSIZE_MIDDLE: int  # If the label text width exceeds the control width, replace the middle of the label with an ellipsis; uses wx.Control.Ellipsize .

ST_ELLIPSIZE_END: int  # If the label text width exceeds the control width, replace the end of the label with an ellipsis; uses wx.Control.Ellipsize . ^^

class StatusBar(Control):
    """ A status bar is a narrow window that can be placed along the bottom of
a frame to give small amounts of status information.

        Source: https://docs.wxpython.org/wx.StatusBar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def Create(self, parent, id=ID_ANY, style=STB_DEFAULT_STYLE, name=StatusBarNameStr) -> bool:
        """ Creates the window, for two-step construction.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def GetBorders(self) -> 'Size':
        """ Returns the horizontal and vertical borders used when rendering the field text inside the field area.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def GetField(self, n: int) -> 'StatusBarPane':
        """ Returns the   wx.StatusBarPane  representing the n-th  field.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def GetFieldRect(self, i) -> 'Rect':
        """ Returns the size and position of a fieldâs internal bounding rectangle.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def GetFieldsCount(self) -> int:
        """ Returns the number of fields in the status bar.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def GetStatusStyle(self, n: int) -> int:
        """ Returns the style of the n-th  field.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def GetStatusText(self, i: int=0) -> str:
        """ Returns the string associated with a status bar field.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def GetStatusWidth(self, n: int) -> int:
        """ Returns the width of the n-th  field.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def PopStatusText(self, field: int=0) -> None:
        """ Restores the text to the value it had before the last call to PushStatusText .

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def PushStatusText(self, string, field=0) -> None:
        """ Saves the current field text in a per-field stack, and sets the field text to the string passed as argument.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def SetFieldsCount(self, number=1, widths=None) -> None:
        """ Sets the number of fields, and optionally the field widths.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def SetMinHeight(self, height: int) -> None:
        """ Sets the minimal possible height for the status bar.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def SetStatusStyles(self, styles) -> None:
        """ Sets the styles of the fields in the status line which can make fields appear flat or raised instead of the standard sunken 3D border.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def SetStatusText(self, text, i=0) -> None:
        """ Sets the status text for the i-th  field.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    def SetStatusWidths(self, widths: list[int]) -> None:
        """ Sets the widths of the fields in the status line.

            Source: https://docs.wxpython.org/wx.StatusBar.html
        """

    Borders: 'Size'  # See GetBorders
    FieldRect: 'Rect'  # See GetFieldRect
    FieldsCount: int  # See GetFieldsCount and SetFieldsCount
    StatusText: str  # See GetStatusText and SetStatusText



STB_SIZEGRIP: int  # Displays a gripper at the right-hand side of the status bar which can be used to resize the parent window.

STB_SHOW_TIPS: int  # Displays tooltips for those panes whose status text has been ellipsized/truncated because the status text doesnât fit the pane width. Note that this style has effect only on wxGTK (with GTK+ >= 2.12) currently.

STB_ELLIPSIZE_START: int  # Replace the beginning of the status texts with an ellipsis when the status text widths exceed the status bar paneâs widths (uses wx.Control.Ellipsize ).

STB_ELLIPSIZE_MIDDLE: int  # Replace the middle of the status texts with an ellipsis when the status text widths exceed the status bar paneâs widths (uses wx.Control.Ellipsize ).

STB_ELLIPSIZE_END: int  # Replace the end of the status texts with an ellipsis when the status text widths exceed the status bar paneâs widths (uses wx.Control.Ellipsize ).

STB_DEFAULT_STYLE: int  # The default style: includes  STB_SIZEGRIP|wxSTB_SHOW_TIPS|wxSTB_ELLIPSIZE_END|wxFULL_REPAINT_ON_RESIZE . ^^

class StatusBarPane:
    """ A status bar pane data container used by StatusBar.

        Source: https://docs.wxpython.org/wx.StatusBarPane.html
    """
    def __init__(self, style=SB_NORMAL, width=0) -> None:
        """ Constructs the pane with the given style  and width.

            Source: https://docs.wxpython.org/wx.StatusBarPane.html
        """

    def GetStyle(self) -> int:
        """ Returns the pane style.

            Source: https://docs.wxpython.org/wx.StatusBarPane.html
        """

    def GetText(self) -> str:
        """ Returns the text currently shown in this pane.

            Source: https://docs.wxpython.org/wx.StatusBarPane.html
        """

    def GetWidth(self) -> int:
        """ Returns the pane width; it maybe negative, indicating a variable-width field.

            Source: https://docs.wxpython.org/wx.StatusBarPane.html
        """

    Style: int  # See GetStyle
    Text: str  # See GetText
    Width: int  # See GetWidth



class StdDialogButtonSizer(BoxSizer):
    """ This class creates button layouts which conform to the standard button
spacing and ordering defined by the platform or toolkitâs user
interface guidelines (if such things exist).

        Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
    """
    def __init__(self) -> None:
        """ Constructor for a   wx.StdDialogButtonSizer.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """

    def AddButton(self, button: 'Button') -> None:
        """ Adds a button to the   wx.StdDialogButtonSizer.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """

    def CalcMin(self) -> 'Size':
        """ Implements the calculation of a box sizerâs minimal.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """

    def Realize(self) -> None:
        """ Rearranges the buttons and applies proper spacing between buttons to make them match the platform or toolkitâs interface guidelines.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Method which must be overridden in the derived sizer classes.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """

    def SetAffirmativeButton(self, button: 'Button') -> None:
        """ Sets the affirmative button for the sizer.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """

    def SetCancelButton(self, button: 'Button') -> None:
        """ Sets the cancel button for the sizer.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """

    def SetNegativeButton(self, button: 'Button') -> None:
        """ Sets the negative button for the sizer.

            Source: https://docs.wxpython.org/wx.StdDialogButtonSizer.html
        """



class StockPreferencesPage(PreferencesPage):
    """ Specialization of PreferencesPage useful for certain commonly used
preferences page.

        Source: https://docs.wxpython.org/wx.StockPreferencesPage.html
    """
    def __init__(self, kind: Kind) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.StockPreferencesPage.html
        """

    def GetIcon(self) -> 'BitmapBundle':
        """ Reimplemented to return stock icon on macOS.

            Source: https://docs.wxpython.org/wx.StockPreferencesPage.html
        """

    def GetKind(self) -> 'StockPreferencesPage.Kind':
        """ Returns the pageâs kind.

            Source: https://docs.wxpython.org/wx.StockPreferencesPage.html
        """

    def GetName(self) -> str:
        """ Reimplemented to return suitable name for the pageâs kind.

            Source: https://docs.wxpython.org/wx.StockPreferencesPage.html
        """

    Icon: 'BitmapBundle'  # See GetIcon
    Name: str  # See GetName



class StopWatch:
    """ The StopWatch class allow you to measure time intervals.

        Source: https://docs.wxpython.org/wx.StopWatch.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.StopWatch.html
        """

    def Pause(self) -> None:
        """ Pauses the stop watch.

            Source: https://docs.wxpython.org/wx.StopWatch.html
        """

    def Resume(self) -> None:
        """ Resumes the stop watch which had been paused with Pause .

            Source: https://docs.wxpython.org/wx.StopWatch.html
        """

    def Start(self, milliseconds: int=0) -> None:
        """ (Re)starts the stop watch with a given initial value.

            Source: https://docs.wxpython.org/wx.StopWatch.html
        """

    def Time(self) -> int:
        """ Returns the time in milliseconds since the start (or restart) or the last call of Pause .

            Source: https://docs.wxpython.org/wx.StopWatch.html
        """

    def TimeInMicro(self) -> int:
        """ Returns elapsed time in microseconds.

            Source: https://docs.wxpython.org/wx.StopWatch.html
        """



class StreamBase:
    """ This class is the base class of most stream related classes in
wxWidgets.

        Source: https://docs.wxpython.org/wx.StreamBase.html
    """
    def __init__(self) -> None:
        """ Creates a dummy stream object.

            Source: https://docs.wxpython.org/wx.StreamBase.html
        """

    def GetLastError(self) -> 'StreamError':
        """ This function returns the last error.

            Source: https://docs.wxpython.org/wx.StreamBase.html
        """

    def GetLength(self) -> 'FileOffset':
        """ Returns the length of the stream in bytes.

            Source: https://docs.wxpython.org/wx.StreamBase.html
        """

    def GetSize(self) -> int:
        """ This function returns the size of the stream.

            Source: https://docs.wxpython.org/wx.StreamBase.html
        """

    def IsOk(self) -> bool:
        """ Returns True if no error occurred on the stream.

            Source: https://docs.wxpython.org/wx.StreamBase.html
        """

    def IsSeekable(self) -> bool:
        """ Returns True if the stream supports seeking to arbitrary offsets.

            Source: https://docs.wxpython.org/wx.StreamBase.html
        """

    def Reset(self, error: StreamError=STREAM_NO_ERROR) -> None:
        """ Resets the stream state.

            Source: https://docs.wxpython.org/wx.StreamBase.html
        """

    LastError: 'StreamError'  # See GetLastError
    Length: 'FileOffset'  # See GetLength
    Size: int  # See GetSize



class SVGBitmapEmbedHandler(SVGBitmapHandler):
    """ Handler embedding bitmaps as base64-encoded PNGs into the SVG.

        Source: https://docs.wxpython.org/wx.SVGBitmapEmbedHandler.html
    """
    def ProcessBitmap(self, bitmap, x, y, stream) -> bool:
        """ Writes the bitmap representation as SVG to the given stream.

            Source: https://docs.wxpython.org/wx.SVGBitmapEmbedHandler.html
        """



class SVGBitmapFileHandler(SVGBitmapHandler):
    """ Handler saving bitmaps to external PNG files and linking to it from
the SVG.

        Source: https://docs.wxpython.org/wx.SVGBitmapFileHandler.html
    """
    def __init__(self, path: str) -> None:
        """ Create a   wx.SVGBitmapFileHandler  and specify the location where the file will be saved.

            Source: https://docs.wxpython.org/wx.SVGBitmapFileHandler.html
        """

    def ProcessBitmap(self, bitmap, x, y, stream) -> bool:
        """ Writes the bitmap representation as SVG to the given stream.

            Source: https://docs.wxpython.org/wx.SVGBitmapFileHandler.html
        """



class SVGBitmapHandler:
    """ Abstract base class for handling bitmaps inside a SVGFileDC.

        Source: https://docs.wxpython.org/wx.SVGBitmapHandler.html
    """
    def ProcessBitmap(self, bitmap, x, y, stream) -> bool:
        """ Writes the bitmap representation as SVG to the given stream.

            Source: https://docs.wxpython.org/wx.SVGBitmapHandler.html
        """



class SVGFileDC(DC):
    """ A SVGFileDC is a device context onto which graphics and text can be
drawn, and the output produced as a vector file, in SVG format.

        Source: https://docs.wxpython.org/wx.SVGFileDC.html
    """
    def __init__(self, filename, width=320, height=240, dpi=72, title="") -> None:
        """ Initializes a   wx.SVGFileDC  with the given filename, width  and height  at dpi  resolution, and an optional title.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def Clear(self) -> None:
        """ Draws a rectangle the size of the SVG using the wx.DC.SetBackground   brush.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def CrossHair(self, x, y) -> None:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def DestroyClippingRegion(self) -> None:
        """ Destroys the current clipping region so that none of the DC is clipped.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def EndDoc(self) -> None:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def EndPage(self) -> None:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def FloodFill(self, x, y, colour, style=FLOOD_SURFACE) -> bool:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def GetDepth(self) -> int:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def GetLogicalFunction(self) -> 'RasterOperationMode':
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def GetPixel(self, x, y, colour) -> bool:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def SetBitmapHandler(self, handler: 'SVGBitmapHandler') -> None:
        """ Replaces the default bitmap handler with handler.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def SetLogicalFunction(self, function: RasterOperationMode) -> None:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def SetPalette(self, palette: 'Palette') -> None:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def SetShapeRenderingMode(self, renderingMode: SVGShapeRenderingMode) -> None:
        """ Set the shape rendering mode of the generated SVG.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def StartDoc(self, message: str) -> bool:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    def StartPage(self) -> None:
        """ Function not implemented in this DC class.

            Source: https://docs.wxpython.org/wx.SVGFileDC.html
        """

    Depth: int  # See GetDepth
    LogicalFunction: RasterOperationMode  # See GetLogicalFunction and SetLogicalFunction



SVG_SHAPE_RENDERING_AUTO: int

class SysColourChangedEvent(Event):
    """ This class is used for system colour change events, which are
generated when the user changes the colour settings or when the system
theme changes (e.g.

        Source: https://docs.wxpython.org/wx.SysColourChangedEvent.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.SysColourChangedEvent.html
        """



class SystemAppearance:
    """ Provides information about the current system appearance.

        Source: https://docs.wxpython.org/wx.SystemAppearance.html
    """
    def GetName(self) -> str:
        """ Return the name if available or empty string otherwise.

            Source: https://docs.wxpython.org/wx.SystemAppearance.html
        """

    def IsDark(self) -> bool:
        """ Return True if the current system there is explicitly recognized as being a dark theme or if the default window background is dark.

            Source: https://docs.wxpython.org/wx.SystemAppearance.html
        """

    def IsUsingDarkBackground(self) -> bool:
        """ Return True if the default window background is significantly darker than foreground.

            Source: https://docs.wxpython.org/wx.SystemAppearance.html
        """

    Name: str  # See GetName



class SystemOptions(Object):
    """ SystemOptions stores option/value pairs that wxWidgets itself or
applications can use to alter behaviour at run-time.

        Source: https://docs.wxpython.org/wx.SystemOptions.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.SystemOptions.html
        """

    @staticmethod
    def GetOption(name: str) -> str:
        """ Gets an option.

            Source: https://docs.wxpython.org/wx.SystemOptions.html
        """

    @staticmethod
    def GetOptionInt(name: str) -> int:
        """ Gets an option as an integer.

            Source: https://docs.wxpython.org/wx.SystemOptions.html
        """

    @staticmethod
    def HasOption(name: str) -> bool:
        """ Returns True if the given option is present.

            Source: https://docs.wxpython.org/wx.SystemOptions.html
        """

    @staticmethod
    def IsFalse(name: str) -> bool:
        """ Returns True if the option with the given name  had been set to 0 value.

            Source: https://docs.wxpython.org/wx.SystemOptions.html
        """

    @staticmethod
    def SetOption(*args, **kw) -> None:
        """ Sets an option.

            Source: https://docs.wxpython.org/wx.SystemOptions.html
        """



BG_STYLE_COLOUR: int

class SystemSettings:
    """ SystemSettings allows the application to ask for details about the
system.

        Source: https://docs.wxpython.org/wx.SystemSettings.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.SystemSettings.html
        """

    @staticmethod
    def GetAppearance() -> 'SystemAppearance':
        """ Returns the object describing the current system appearance.

            Source: https://docs.wxpython.org/wx.SystemSettings.html
        """

    @staticmethod
    def GetColour(index: SystemColour) -> 'Colour':
        """ Returns a system colour.

            Source: https://docs.wxpython.org/wx.SystemSettings.html
        """

    @staticmethod
    def GetFont(index: SystemFont) -> 'Font':
        """ Returns a system font.

            Source: https://docs.wxpython.org/wx.SystemSettings.html
        """

    @staticmethod
    def GetMetric(index, win=None) -> int:
        """ Returns the value of a system metric, or -1 if the metric is not supported on the current system.

            Source: https://docs.wxpython.org/wx.SystemSettings.html
        """

    @staticmethod
    def GetScreenType() -> 'SystemScreenType':
        """ Returns the screen type.

            Source: https://docs.wxpython.org/wx.SystemSettings.html
        """

    @staticmethod
    def HasFeature(index: SystemFeature) -> bool:
        """ Returns True if the port has certain feature.

            Source: https://docs.wxpython.org/wx.SystemSettings.html
        """



SYS_CAPTION_Y: int

SYS_CURSOR_X: int

class TextAttr:
    """ TextAttr represents the character and paragraph attributes, or
style, for a range of text in a TextCtrl or RichTextCtrl.

        Source: https://docs.wxpython.org/wx.TextAttr.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Constructors.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def Apply(self, style, compareWith=None) -> bool:
        """ Applies the attributes in style  to the original object, but not those attributes from style  that are the same as those in compareWith  (if passed).

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def EqPartial(self, attr, weakTest=True) -> bool:
        """ Partial equality test.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetAlignment(self) -> int:
        """ Returns the alignment flags.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetBackgroundColour(self) -> 'Colour':
        """ Returns the background colour.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetBulletFont(self) -> str:
        """ Returns a string containing the name of the font associated with the bullet symbol.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetBulletName(self) -> str:
        """ Returns the standard bullet name, applicable if the bullet style is wx.TEXT_ATTR_BULLET_STYLE_STANDARD.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetBulletNumber(self) -> int:
        """ Returns the bullet number.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetBulletStyle(self) -> int:
        """ Returns the bullet style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetBulletText(self) -> str:
        """ Returns the bullet text, which could be a symbol, or (for example) cached outline text.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetCharacterStyleName(self) -> str:
        """ Returns the name of the character style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFlags(self) -> int:
        """ Returns flags indicating which attributes are applicable.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFont(self) -> 'Font':
        """ Creates and returns a font specified by the font attributes in the   wx.TextAttr  object.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontAttributes(self, font, flags=TEXT_ATTR_FONT) -> bool:
        """ Gets the font attributes from the given font, using only the attributes specified by flags.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontEncoding(self) -> int:
        """ Returns the font encoding.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontFaceName(self) -> str:
        """ Returns the font face name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontFamily(self) -> int:
        """ Returns the font family.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontSize(self) -> int:
        """ Returns the font size in points.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontStyle(self) -> int:
        """ Returns the font style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontUnderlined(self) -> bool:
        """ Returns True if the font is underlined.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetFontWeight(self) -> int:
        """ Returns the font weight.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetLeftIndent(self) -> int:
        """ Returns the left indent in tenths of a millimetre.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetLeftSubIndent(self) -> int:
        """ Returns the left sub-indent in tenths of a millimetre.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetLineSpacing(self) -> int:
        """ Returns the line spacing value, one of   wx.TextAttrLineSpacing  values.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetListStyleName(self) -> str:
        """ Returns the name of the list style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetOutlineLevel(self) -> int:
        """ Returns the outline level.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetParagraphSpacingAfter(self) -> int:
        """ Returns the space in tenths of a millimeter after the paragraph.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetParagraphSpacingBefore(self) -> int:
        """ Returns the space in tenths of a millimeter before the paragraph.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetParagraphStyleName(self) -> str:
        """ Returns the name of the paragraph style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetRightIndent(self) -> int:
        """ Returns the right indent in tenths of a millimeter.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetTabs(self) -> list[int]:
        """ Returns an array of tab stops, each expressed in tenths of a millimeter.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetTextColour(self) -> 'Colour':
        """ Returns the text foreground colour.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetTextEffectFlags(self) -> int:
        """ Returns the text effect bits of interest.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetTextEffects(self) -> int:
        """ Returns the text effects, a bit list of styles.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetURL(self) -> str:
        """ Returns the URL for the content.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetUnderlineColour(self) -> 'Colour':
        """ Returns the underline color used.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def GetUnderlineType(self) -> 'TextAttrUnderlineType':
        """ Returns the underline type, which is one of the TextAttrUnderlineType values.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasAlignment(self) -> bool:
        """ Returns True if the attribute object specifies alignment.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasBackgroundColour(self) -> bool:
        """ Returns True if the attribute object specifies a background colour.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasBulletName(self) -> bool:
        """ Returns True if the attribute object specifies a standard bullet name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasBulletNumber(self) -> bool:
        """ Returns True if the attribute object specifies a bullet number.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasBulletStyle(self) -> bool:
        """ Returns True if the attribute object specifies a bullet style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasBulletText(self) -> bool:
        """ Returns True if the attribute object specifies bullet text (usually specifying a symbol).

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasCharacterStyleName(self) -> bool:
        """ Returns True if the attribute object specifies a character style name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFlag(self, flag: int) -> bool:
        """ Returns True if the flag  is present in the attribute objectâs flag bitlist.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFont(self) -> bool:
        """ Returns True if the attribute object specifies any font attributes.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontEncoding(self) -> bool:
        """ Returns True if the attribute object specifies an encoding.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontFaceName(self) -> bool:
        """ Returns True if the attribute object specifies a font face name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontFamily(self) -> bool:
        """ Returns True if the attribute object specifies a font family.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontItalic(self) -> bool:
        """ Returns True if the attribute object specifies italic style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontPixelSize(self) -> bool:
        """ Returns True if the attribute object specifies a font pixel size.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontPointSize(self) -> bool:
        """ Returns True if the attribute object specifies a font point size.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontSize(self) -> bool:
        """ Returns True if the attribute object specifies a font point or pixel size.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontUnderlined(self) -> bool:
        """ Returns True if the attribute object specifies either underlining or no underlining.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasFontWeight(self) -> bool:
        """ Returns True if the attribute object specifies font weight (bold, light or normal).

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasLeftIndent(self) -> bool:
        """ Returns True if the attribute object specifies a left indent.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasLineSpacing(self) -> bool:
        """ Returns True if the attribute object specifies line spacing.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasListStyleName(self) -> bool:
        """ Returns True if the attribute object specifies a list style name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasOutlineLevel(self) -> bool:
        """ Returns True if the attribute object specifies an outline level.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasPageBreak(self) -> bool:
        """ Returns True if the attribute object specifies a page break before this paragraph.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasParagraphSpacingAfter(self) -> bool:
        """ Returns True if the attribute object specifies spacing after a paragraph.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasParagraphSpacingBefore(self) -> bool:
        """ Returns True if the attribute object specifies spacing before a paragraph.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasParagraphStyleName(self) -> bool:
        """ Returns True if the attribute object specifies a paragraph style name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasRightIndent(self) -> bool:
        """ Returns True if the attribute object specifies a right indent.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasTabs(self) -> bool:
        """ Returns True if the attribute object specifies tab stops.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasTextColour(self) -> bool:
        """ Returns True if the attribute object specifies a text foreground colour.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasTextEffects(self) -> bool:
        """ Returns True if the attribute object specifies text effects.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def HasURL(self) -> bool:
        """ Returns True if the attribute object specifies a URL.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def IsCharacterStyle(self) -> bool:
        """ Returns True if the object represents a character style, that is, the flags specify a font or a text background or foreground colour.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def IsDefault(self) -> bool:
        """ Returns False if we have any attributes set, True otherwise.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def IsParagraphStyle(self) -> bool:
        """ Returns True if the object represents a paragraph style, that is, the flags specify alignment, indentation, tabs, paragraph spacing, or bullet style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def Merge(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetAlignment(self, alignment: int) -> None:
        """ Sets the paragraph alignment.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetBackgroundColour(self, colBack: Union[int, str, 'Colour']) -> None:
        """ Sets the background colour.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetBulletFont(self, font: str) -> None:
        """ Sets the name of the font associated with the bullet symbol.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetBulletName(self, name: str) -> None:
        """ Sets the standard bullet name, applicable if the bullet style is wx.TEXT_ATTR_BULLET_STYLE_STANDARD.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetBulletNumber(self, n: int) -> None:
        """ Sets the bullet number.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetBulletStyle(self, style: int) -> None:
        """ Sets the bullet style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetBulletText(self, text: str) -> None:
        """ Sets the bullet text, which could be a symbol, or (for example) cached outline text.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetCharacterStyleName(self, name: str) -> None:
        """ Sets the character style name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFlags(self, flags: int) -> None:
        """ Sets the flags determining which styles are being specified.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFont(self, font, flags=TEXT_ATTR_FONT & ~TEXT_ATTR_FONT_PIXEL_SIZE) -> None:
        """ Sets the attributes for the given font.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontEncoding(self, encoding: int) -> None:
        """ Sets the font encoding.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontFaceName(self, faceName: str) -> None:
        """ Sets the font face name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontFamily(self, family: int) -> None:
        """ Sets the font family.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontPixelSize(self, pixelSize: int) -> None:
        """ Sets the font size in pixels.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontPointSize(self, pointSize: int) -> None:
        """ Sets the font size in points.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontSize(self, pointSize: int) -> None:
        """ Sets the font size in points.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontStyle(self, fontStyle: int) -> None:
        """ Sets the font style (normal, italic or slanted).

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontUnderlined(self, underlined: bool) -> None:
        """ Sets the font underlining (solid line, text colour).

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontUnderlineType(self, type, colour=NullColour) -> None:
        """ Sets the font underlining.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetFontWeight(self, fontWeight: int) -> None:
        """ Sets the font weight.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetLeftIndent(self, indent, subIndent=0) -> None:
        """ Sets the left indent and left subindent in tenths of a millimetre.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetLineSpacing(self, spacing: int) -> None:
        """ Sets the line spacing.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetListStyleName(self, name: str) -> None:
        """ Sets the list style name.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetOutlineLevel(self, level: int) -> None:
        """ Specifies the outline level.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetPageBreak(self, pageBreak: bool=True) -> None:
        """ Specifies a page break before this paragraph.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetParagraphSpacingAfter(self, spacing: int) -> None:
        """ Sets the spacing after a paragraph, in tenths of a millimetre.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetParagraphSpacingBefore(self, spacing: int) -> None:
        """ Sets the spacing before a paragraph, in tenths of a millimetre.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetParagraphStyleName(self, name: str) -> None:
        """ Sets the name of the paragraph style.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetRightIndent(self, indent: int) -> None:
        """ Sets the right indent in tenths of a millimetre.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetTabs(self, tabs: list[int]) -> None:
        """ Sets the tab stops, expressed in tenths of a millimetre.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetTextColour(self, colText: Union[int, str, 'Colour']) -> None:
        """ Sets the text foreground colour.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetTextEffectFlags(self, flags: int) -> None:
        """ Sets the text effect bits of interest.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetTextEffects(self, effects: int) -> None:
        """ Sets the text effects, a bit list of styles.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    def SetURL(self, url: str) -> None:
        """ Sets the URL for the content.

            Source: https://docs.wxpython.org/wx.TextAttr.html
        """

    Alignment: int  # See GetAlignment and SetAlignment
    BackgroundColour: Union[int, str, 'Colour']  # See GetBackgroundColour and SetBackgroundColour
    BulletFont: str  # See GetBulletFont and SetBulletFont
    BulletName: str  # See GetBulletName and SetBulletName
    BulletNumber: int  # See GetBulletNumber and SetBulletNumber
    BulletStyle: int  # See GetBulletStyle and SetBulletStyle
    BulletText: str  # See GetBulletText and SetBulletText
    CharacterStyleName: str  # See GetCharacterStyleName and SetCharacterStyleName
    Flags: int  # See GetFlags and SetFlags
    Font: 'Font'  # See GetFont and SetFont
    FontEncoding: int  # See GetFontEncoding and SetFontEncoding
    FontFaceName: str  # See GetFontFaceName and SetFontFaceName
    FontFamily: int  # See GetFontFamily and SetFontFamily
    FontSize: int  # See GetFontSize and SetFontSize
    FontStyle: int  # See GetFontStyle and SetFontStyle
    FontUnderlined: bool  # See GetFontUnderlined and SetFontUnderlined
    FontWeight: int  # See GetFontWeight and SetFontWeight
    LeftIndent: int  # See GetLeftIndent and SetLeftIndent
    LeftSubIndent: int  # See GetLeftSubIndent
    LineSpacing: int  # See GetLineSpacing and SetLineSpacing
    ListStyleName: str  # See GetListStyleName and SetListStyleName
    OutlineLevel: int  # See GetOutlineLevel and SetOutlineLevel
    ParagraphSpacingAfter: int  # See GetParagraphSpacingAfter and SetParagraphSpacingAfter
    ParagraphSpacingBefore: int  # See GetParagraphSpacingBefore and SetParagraphSpacingBefore
    ParagraphStyleName: str  # See GetParagraphStyleName and SetParagraphStyleName
    RightIndent: int  # See GetRightIndent and SetRightIndent
    Tabs: list[int]  # See GetTabs and SetTabs
    TextColour: Union[int, str, 'Colour']  # See GetTextColour and SetTextColour
    TextEffectFlags: int  # See GetTextEffectFlags and SetTextEffectFlags
    TextEffects: int  # See GetTextEffects and SetTextEffects
    URL: str  # See GetURL and SetURL
    UnderlineColour: 'Colour'  # See GetUnderlineColour
    UnderlineType: 'TextAttrUnderlineType'  # See GetUnderlineType



TEXT_ATTR_BULLET_STYLE_STANDARD: int

TEXT_ATTR_URL: int

TEXT_ALIGNMENT_JUSTIFIED: int

TEXT_ATTR_BULLET_STYLE_BITMAP: int

TEXT_ATTR_UNDERLINE_DOUBLE: int

TEXT_ATTR_UNDERLINE_SOLID: int

TEXT_ATTR_UNDERLINE_SPECIAL: int

TEXT_ATTR_EFFECTS: int

TEXT_ATTR_EFFECT_CAPITALS: int

TEXT_ATTR_EFFECT_STRIKETHROUGH: int

TEXT_ATTR_EFFECT_SUPERSCRIPT: int

TEXT_ATTR_EFFECT_SUBSCRIPT: int

class TextCompleter:
    """ Base class for custom text completer objects.

        Source: https://docs.wxpython.org/wx.TextCompleter.html
    """
    def GetNext(self) -> str:
        """ Called to retrieve the next completion.

            Source: https://docs.wxpython.org/wx.TextCompleter.html
        """

    def Start(self, prefix: str) -> bool:
        """ Function called to start iteration over the completions for the given prefix.

            Source: https://docs.wxpython.org/wx.TextCompleter.html
        """

    Next: str  # See GetNext



class TextCompleterSimple(TextCompleter):
    """ A simpler base class for custom completer objects.

        Source: https://docs.wxpython.org/wx.TextCompleterSimple.html
    """
    def GetCompletions(self, prefix: str) -> res:
        """ Pure virtual method returning all possible completions for the given prefix.

            Source: https://docs.wxpython.org/wx.TextCompleterSimple.html
        """

    def GetNext(self) -> str:
        """ Called to retrieve the next completion.

            Source: https://docs.wxpython.org/wx.TextCompleterSimple.html
        """

    def Start(self, prefix: str) -> bool:
        """ Function called to start iteration over the completions for the given prefix.

            Source: https://docs.wxpython.org/wx.TextCompleterSimple.html
        """

    Next: str  # See GetNext



class TextDataObject(DataObjectSimple):
    """ TextDataObject is a specialization of DataObjectSimple for text
data.

        Source: https://docs.wxpython.org/wx.TextDataObject.html
    """
    def __init__(self, text: str="") -> None:
        """ Constructor, may be used to initialise the text (otherwise SetText   should be used later).

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    def GetFormat(self) -> 'DataFormat':
        """ Returns the preferred format supported by this object.

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    def GetFormatCount(self, dir: int=DataObject.Get) -> int:
        """ Returns 2 under Mac and wxGTK, where text data coming from the clipboard may be provided as ANSI ( DF_TEXT ) or as Unicode text ( DF_UNICODETEXT , but only when   USE_UNICODE==1 ).

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    def GetText(self) -> str:
        """ Returns the text associated with the data object.

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    def GetTextLength(self) -> int:
        """ Returns the data size.

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    def SetData(self, format, buf) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    def SetText(self, strText: str) -> None:
        """ Sets the text associated with the data object.

            Source: https://docs.wxpython.org/wx.TextDataObject.html
        """

    AllFormats: None  # See GetAllFormats
    Format: 'DataFormat'  # See GetFormat
    FormatCount: int  # See GetFormatCount
    Text: str  # See GetText and SetText
    TextLength: int  # See GetTextLength



class TextDropTarget(DropTarget):
    """ A predefined drop target for dealing with text data.

        Source: https://docs.wxpython.org/wx.TextDropTarget.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.TextDropTarget.html
        """

    def OnDrop(self, x, y) -> bool:
        """ See wx.DropTarget.OnDrop .

            Source: https://docs.wxpython.org/wx.TextDropTarget.html
        """

    def OnDropText(self, x, y, data) -> bool:
        """ Override this function to receive dropped text.

            Source: https://docs.wxpython.org/wx.TextDropTarget.html
        """



class TextEntry:
    """ Common base class for single line text entry fields.

        Source: https://docs.wxpython.org/wx.TextEntry.html
    """
    def AppendText(self, text: str) -> None:
        """ Appends the text to the end of the text control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def AutoComplete(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def AutoCompleteDirectories(self) -> bool:
        """ Call this function to enable auto-completion of the text using the file system directories.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def AutoCompleteFileNames(self) -> bool:
        """ Call this function to enable auto-completion of the text typed in a single-line text control using all valid file system paths.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def CanCopy(self) -> bool:
        """ Returns True if the selection can be copied to the clipboard.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def CanCut(self) -> bool:
        """ Returns True if the selection can be cut to the clipboard.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def CanPaste(self) -> bool:
        """ Returns True if the contents of the clipboard can be pasted into the text control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def CanRedo(self) -> bool:
        """ Returns True if there is a redo facility available and the last operation can be redone.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def CanUndo(self) -> bool:
        """ Returns True if there is an undo facility available and the last operation can be undone.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def ChangeValue(self, value: str) -> None:
        """ Sets the new text control value.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Clear(self) -> None:
        """ Clears the text in the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Copy(self) -> None:
        """ Copies the selected text to the clipboard.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Cut(self) -> None:
        """ Copies the selected text to the clipboard and removes it from the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def ForceUpper(self) -> None:
        """ Convert all text entered into the control to upper case.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetHint(self) -> str:
        """ Returns the current hint string.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetInsertionPoint(self) -> int:
        """ Returns the insertion point, or cursor, position.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetLastPosition(self) -> 'TextPos':
        """ Returns the zero based index of the last position in the text control, which is equal to the number of characters in the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetMargins(self) -> 'Point':
        """ Returns the margins used by the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetRange(self, from_, to_) -> str:
        """ Returns the string containing the text starting in the positions from  and up to to  in the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetSelection(self) -> tuple:
        """ Gets the current selection span.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetStringSelection(self) -> str:
        """ Gets the text currently selected in the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def GetValue(self) -> str:
        """ Gets the contents of the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def IsEditable(self) -> bool:
        """ Returns True if the controls contents may be edited by user (note that it always can be changed by the program).

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if the control is currently empty.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Paste(self) -> None:
        """ Pastes text from the clipboard to the text item.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Redo(self) -> None:
        """ If there is a redo facility and the last operation can be redone, redoes the last operation.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Remove(self, from_, to_) -> None:
        """ Removes the text starting at the first given position up to (but not including) the character at the last position.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Replace(self, from_, to_, value) -> None:
        """ Replaces the text starting at the first position up to (but not including) the character at the last position with the given text.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SelectAll(self) -> None:
        """ Selects all text in the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SelectNone(self) -> None:
        """ Deselects selected text in the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetEditable(self, editable: bool) -> None:
        """ Makes the text item editable or read-only, overriding the wx.TE_READONLY  flag.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetHint(self, hint: str) -> bool:
        """ Sets a hint shown in an empty unfocused text control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetInsertionPoint(self, pos: int) -> None:
        """ Sets the insertion point at the given position.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetInsertionPointEnd(self) -> None:
        """ Sets the insertion point at the end of the text control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetMargins(self, *args, **kw) -> None:
        """ Attempts to set the control margins.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetMaxLength(self, len: int) -> None:
        """ This function sets the maximum number of characters the user can enter into the control.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetSelection(self, from_, to_) -> None:
        """ Selects the text starting at the first position up to (but not including) the character at the last position.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def SetValue(self, value: str) -> None:
        """ Sets the new text control value.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def Undo(self) -> None:
        """ If there is an undo facility and the last operation can be undone, undoes the last operation.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    def WriteText(self, text: str) -> None:
        """ Writes the text into the text control at the current insertion position.

            Source: https://docs.wxpython.org/wx.TextEntry.html
        """

    Hint: str  # See GetHint and SetHint
    InsertionPoint: int  # See GetInsertionPoint and SetInsertionPoint
    LastPosition: 'TextPos'  # See GetLastPosition
    Margins: 'Point'  # See GetMargins and SetMargins
    StringSelection: str  # See GetStringSelection
    Value: str  # See GetValue and SetValue



class TextEntryDialog(Dialog):
    """ This class represents a dialog that requests a one-line text string
from the user.

        Source: https://docs.wxpython.org/wx.TextEntryDialog.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    def Create(self, parent, message, caption=GetTextFromUserPromptStr, value="", style=TextEntryDialogStyle, pos=DefaultPosition) -> bool:
        """ parent (wx.Window) â Parent window.

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    def ForceUpper(self) -> None:
        """ Convert all text entered into the text control used by the dialog to upper case.

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    def GetValue(self) -> str:
        """ Returns the text that the user has entered if the user has pressed wx.OK, or the original value if the user has pressed Cancel.

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    def SetMaxLength(self, len: int) -> None:
        """ This function sets the maximum number of characters the user can enter into this dialog.

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    def SetValue(self, value: str) -> None:
        """ Sets the default text value.

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    def ShowModal(self) -> int:
        """ Shows the dialog, returning wx.ID_OK if the user pressed wx.OK, and wx.ID_CANCEL otherwise.

            Source: https://docs.wxpython.org/wx.TextEntryDialog.html
        """

    Value: str  # See GetValue and SetValue



class TextUrlEvent(CommandEvent):
    """  Overloaded Implementations:

        Source: https://docs.wxpython.org/wx.TextUrlEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TextUrlEvent.html
        """

    def Clone(self) -> 'Event':
        """ Returns a copy of the event.

            Source: https://docs.wxpython.org/wx.TextUrlEvent.html
        """

    def GetMouseEvent(self) -> 'MouseEvent':
        """ wx.MouseEvent

            Source: https://docs.wxpython.org/wx.TextUrlEvent.html
        """

    def GetURLEnd(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.TextUrlEvent.html
        """

    def GetURLStart(self) -> int:
        """ long

            Source: https://docs.wxpython.org/wx.TextUrlEvent.html
        """

    MouseEvent: 'MouseEvent'  # See GetMouseEvent
    URLEnd: int  # See GetURLEnd
    URLStart: int  # See GetURLStart



class TGAHandler(ImageHandler):
    """ This is the image handler for the TGA format.

        Source: https://docs.wxpython.org/wx.TGAHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.TGAHandler.

            Source: https://docs.wxpython.org/wx.TGAHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.TGAHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.TGAHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.TGAHandler.html
        """



class TIFFHandler(ImageHandler):
    """ This is the image handler for the TIFF format.

        Source: https://docs.wxpython.org/wx.TIFFHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.TIFFHandler.

            Source: https://docs.wxpython.org/wx.TIFFHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.TIFFHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.TIFFHandler.html
        """



class TimerEvent(Event):
    """ TimerEvent object is passed to the event handler of timer events
(see Timer.SetOwner).

        Source: https://docs.wxpython.org/wx.TimerEvent.html
    """
    def __init__(self, timer: 'Timer') -> None:
        """ timer (wx.Timer) â

            Source: https://docs.wxpython.org/wx.TimerEvent.html
        """

    def GetInterval(self) -> int:
        """ Returns the interval of the timer which generated this event.

            Source: https://docs.wxpython.org/wx.TimerEvent.html
        """

    def GetTimer(self) -> 'Timer':
        """ Returns the timer object which generated this event.

            Source: https://docs.wxpython.org/wx.TimerEvent.html
        """

    Interval: int  # See GetInterval
    Timer: 'Timer'  # See GetTimer



class TimerRunner:
    """ Starts the timer in its constructor, stops in the dtor.

        Source: https://docs.wxpython.org/wx.TimerRunner.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TimerRunner.html
        """

    def Start(self, milli, oneShot=False) -> None:
        """ milli (int) â

            Source: https://docs.wxpython.org/wx.TimerRunner.html
        """



class TimeSpan:
    """ TimeSpan class represents a time interval.

        Source: https://docs.wxpython.org/wx.TimeSpan.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def Abs(self) -> 'TimeSpan':
        """ Returns the absolute value of the timespan: does not modify the object.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def Add(self, diff: 'TimeSpan') -> 'TimeSpan':
        """ Adds the given   wx.TimeSpan  to this   wx.TimeSpan  and returns a reference to itself.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Day() -> 'TimeSpan':
        """ Returns the timespan for one day.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Days(days: int) -> 'TimeSpan':
        """ Returns the timespan for the given number of days.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def Format(self, format: str=DefaultTimeSpanFormat) -> str:
        """ Returns the string containing the formatted representation of the time span.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def GetDays(self) -> int:
        """ Returns the difference in number of days.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def GetHours(self) -> int:
        """ Returns the difference in number of hours.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def GetMilliseconds(self) -> int:
        """ Returns the difference in number of milliseconds.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def GetMinutes(self) -> int:
        """ Returns the difference in number of minutes.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def GetSeconds(self) -> int:
        """ Returns the difference in number of seconds.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def GetValue(self) -> int:
        """ Returns the internal representation of timespan.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def GetWeeks(self) -> int:
        """ Returns the difference in number of weeks.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Hour() -> 'TimeSpan':
        """ Returns the timespan for one hour.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Hours(hours: int) -> 'TimeSpan':
        """ Returns the timespan for the given number of hours.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def IsEqualTo(self, ts: 'TimeSpan') -> bool:
        """ Returns True if two timespans are equal.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def IsLongerThan(self, ts: 'TimeSpan') -> bool:
        """ Compares two timespans: works with the absolute values, i.e. -2 hours is longer than 1 hour.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def IsNegative(self) -> bool:
        """ Returns True if the timespan is negative.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def IsNull(self) -> bool:
        """ Returns True if the timespan is empty.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def IsPositive(self) -> bool:
        """ Returns True if the timespan is positive.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def IsShorterThan(self, ts: 'TimeSpan') -> bool:
        """ Compares two timespans: works with the absolute values, i.e. 1 hour is shorter than -2 hours.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Millisecond() -> 'TimeSpan':
        """ Returns the timespan for one millisecond.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Milliseconds(ms: int) -> 'TimeSpan':
        """ Returns the timespan for the given number of milliseconds.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Minute() -> 'TimeSpan':
        """ Returns the timespan for one minute.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Minutes(min: int) -> 'TimeSpan':
        """ Returns the timespan for the given number of minutes.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def Multiply(self, n: int) -> 'TimeSpan':
        """ Multiplies this time span by n.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def Neg(self) -> 'TimeSpan':
        """ Negate the value of the timespan.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def Negate(self) -> 'TimeSpan':
        """ Returns timespan with inverted sign.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Second() -> 'TimeSpan':
        """ Returns the timespan for one second.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Seconds(sec: int) -> 'TimeSpan':
        """ Returns the timespan for the given number of seconds.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    def Subtract(self, diff: 'TimeSpan') -> 'TimeSpan':
        """ Subtracts the given   wx.TimeSpan  to this   wx.TimeSpan  and returns a reference to itself.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Week() -> 'TimeSpan':
        """ Returns the timespan for one week.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """

    @staticmethod
    def Weeks(weeks: int) -> 'TimeSpan':
        """ Returns the timespan for the given number of weeks.

            Source: https://docs.wxpython.org/wx.TimeSpan.html
        """



class TipWindow(Window):
    """ Shows simple text in a popup tip window on creation.

        Source: https://docs.wxpython.org/wx.TipWindow.html
    """
    def __init__(self, parent, text, maxLength=100) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.TipWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.TipWindow.html
        """

    def SetBoundingRect(self, rectBound: 'Rect') -> None:
        """ By default, the tip window disappears when the user clicks the mouse or presses a keyboard key or if it loses focus in any other way - for example because the user switched to another application window.

            Source: https://docs.wxpython.org/wx.TipWindow.html
        """



class ToolBar(Control):
    """ A toolbar is a bar of buttons and/or other controls usually placed
below the menu bar in a Frame.

        Source: https://docs.wxpython.org/wx.ToolBar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddCheckTool(self, toolId, label, bitmap1, bmpDisabled=NullBitmap, shortHelp="", longHelp="", clientData=None) -> 'ToolBarToolBase':
        """ Adds a new check (or toggle) tool to the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddControl(self, control, label="") -> 'ToolBarToolBase':
        """ Adds any control to the toolbar, typically e.g. a   wx.ComboBox.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddLabelTool(self, id, label, bitmap, bmpDisabled=wx.NullBitmap, kind=wx.ITEM_NORMAL, shortHelp="", longHelp="", clientData=None) -> None:
        """ Old style method to add a tool in the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddRadioTool(self, toolId, label, bitmap1, bmpDisabled=NullBitmap, shortHelp="", longHelp="", clientData=None) -> 'ToolBarToolBase':
        """ Adds a new radio tool to the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddSeparator(self) -> 'ToolBarToolBase':
        """ Adds a separator for spacing groups of tools.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddSimpleTool(self, toolId, bitmap, shortHelpString="", longHelpString="", isToggle=0) -> None:
        """ Old style method to add a tool to the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddStretchableSpace(self) -> 'ToolBarToolBase':
        """ Adds a stretchable space to the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def AddTool(self, *args, **kw) -> 'ToolBarToolBase':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def ClearTools(self) -> None:
        """ Deletes all the tools in the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def CreateSeparator(self) -> 'ToolBarToolBase':
        """ Factory function to create a new separator toolbar tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def CreateTool(self, *args, **kw) -> 'ToolBarToolBase':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def DeleteTool(self, toolId: int) -> bool:
        """ Removes the specified tool from the toolbar and deletes it.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def DeleteToolByPos(self, pos: int) -> bool:
        """ This function behaves like DeleteTool   but it deletes the tool at the specified position and not the one with the given id.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def EnableTool(self, toolId, enable) -> None:
        """ Enables or disables the tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def FindById(self, id: int) -> 'ToolBarToolBase':
        """ Returns a pointer to the tool identified by id  or None if no corresponding tool is found.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def FindControl(self, id: int) -> 'Control':
        """ Returns a pointer to the control identified by id  or None if no corresponding control is found.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def FindToolForPosition(self, x, y) -> 'ToolBarToolBase':
        """ Finds a tool for the given mouse position.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetMargins(self) -> 'Size':
        """ Returns the left/right and top/bottom margins, which are also used for inter-toolspacing.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolBitmapSize(self) -> 'Size':
        """ Returns the size of bitmap that the toolbar expects to have.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolByPos(self, pos: int) -> 'ToolBarToolBase':
        """ Returns a pointer to the tool at ordinal position pos.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolClientData(self, toolId: int) -> PyUserData:
        """ Get any client data associated with the tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolEnabled(self, toolId: int) -> bool:
        """ Called to determine whether a tool is enabled (responds to user input).

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolLongHelp(self, toolId: int) -> str:
        """ Returns the long help for the given tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolPacking(self) -> int:
        """ Returns the value used for packing tools.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolPos(self, toolId: int) -> int:
        """ Returns the tool position in the toolbar, or  NOT_FOUND   if the tool is not found.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolSeparation(self) -> int:
        """ Returns the default separator size.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolShortHelp(self, toolId: int) -> str:
        """ Returns the short help for the given tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolSize(self) -> 'Size':
        """ Returns the size of a whole button, which is usually larger than a tool bitmap because of added 3D effects.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolState(self, toolId: int) -> bool:
        """ Gets the on/off state of a toggle tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def GetToolsCount(self) -> int:
        """ Returns the number of tools in the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def InsertControl(self, pos, control, label="") -> 'ToolBarToolBase':
        """ Inserts the control into the toolbar at the given position.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def InsertLabelTool(self, pos, id, label, bitmap, bmpDisabled=wx.NullBitmap, kind=wx.ITEM_NORMAL, shortHelp="", longHelp="", clientData=None) -> None:
        """ Old style method to insert a tool in the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def InsertSeparator(self, pos: int) -> 'ToolBarToolBase':
        """ Inserts the separator into the toolbar at the given position.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def InsertSimpleTool(self, pos, toolId, bitmap, shortHelpString="", longHelpString="", isToggle=0) -> None:
        """ Old style method to insert a tool in the toolbar.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def InsertStretchableSpace(self, pos: int) -> 'ToolBarToolBase':
        """ Inserts a stretchable space at the given position.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def InsertTool(self, *args, **kw) -> None:
        """ Inserts the tool with the specified attributes into the toolbar at the given position.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def Realize(self) -> bool:
        """ This function should be called after you have added tools.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def RemoveTool(self, id: int) -> 'ToolBarToolBase':
        """ Removes the given tool from the toolbar but doesnât delete it.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetDropdownMenu(self, id, menu) -> bool:
        """ Sets the dropdown menu for the tool given by its id.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetMargins(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolBitmapSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ Sets the default size of each tool bitmap.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolClientData(self, id, clientData) -> None:
        """ Sets the client data associated with the tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolDisabledBitmap(self, id, bitmap) -> None:
        """ Sets the bitmap to be used by the tool with the given ID when the tool is in a disabled state.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolLongHelp(self, toolId, helpString) -> None:
        """ Sets the long help for the given tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolNormalBitmap(self, id, bitmap) -> None:
        """ Sets the bitmap to be used by the tool with the given ID.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolPacking(self, packing: int) -> None:
        """ Sets the value used for spacing tools.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolSeparation(self, separation: int) -> None:
        """ Sets the default separator size.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def SetToolShortHelp(self, toolId, helpString) -> None:
        """ Sets the short help for the given tool.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    def ToggleTool(self, toolId, toggle) -> None:
        """ Toggles a tool on or off.

            Source: https://docs.wxpython.org/wx.ToolBar.html
        """

    Margins: 'Size'  # See GetMargins and SetMargins
    ToolBitmapSize: Union[tuple[int, int], 'Size']  # See GetToolBitmapSize and SetToolBitmapSize
    ToolPacking: int  # See GetToolPacking and SetToolPacking
    ToolSeparation: int  # See GetToolSeparation and SetToolSeparation
    ToolSize: 'Size'  # See GetToolSize
    ToolsCount: int  # See GetToolsCount



TB_FLAT: int  # Gives the toolbar a flat look (Windows and GTK only).

TB_DOCKABLE: int  # Makes the toolbar floatable and dockable (GTK only).

TB_HORIZONTAL: int  # Specifies horizontal layout (default).

TB_VERTICAL: int  # Specifies vertical layout.

TB_TEXT: int  # Shows the text in the toolbar buttons; by default only icons are shown.

TB_NOICONS: int  # Specifies no icons in the toolbar buttons; by default they are shown.

TB_NODIVIDER: int  # Specifies no divider (border) above the toolbar (Windows only)

TB_NOALIGN: int  # Specifies no alignment with the parent window (Windows only, not very useful).

TB_HORZ_LAYOUT: int  # Shows the text and the icons alongside, not vertically stacked (Windows and GTK 2 only). This style must be used with  TB_TEXT .

TB_HORZ_TEXT: int  # Combination of  TB_HORZ_LAYOUT   and   TB_TEXT .

TB_NO_TOOLTIPS: int  # Donât show the short help tooltips for the tools when the mouse hovers over them.

TB_BOTTOM: int  # Align the toolbar at the bottom of parent window.

TB_RIGHT: int  # Align the toolbar at the right side of parent window.

TB_DEFAULT_STYLE: int  # The  TB_HORIZONTAL   style. This style is new since wxWidgets 2.9.5. ^^

EVT_TOOL_DROPDOWN: int  # Process a  wxEVT_TOOL_DROPDOWN   event. If unhandled, displays the default dropdown menu set using  wx.ToolBar.SetDropdownMenu . ^^

class ToolBarToolBase(Object):
    """ A toolbar tool represents one item on the toolbar.

        Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def Attach(self, tbar: 'ToolBar') -> None:
        """ tbar (wx.ToolBar) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def CanBeToggled(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def Detach(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def Enable(self, enable: bool) -> bool:
        """ enable (bool) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetBitmap(self) -> 'Bitmap':
        """ wx.Bitmap

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetClientData(self) -> PyUserData:
        """ PyUserData

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetControl(self) -> 'Control':
        """ wx.Control

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetDisabledBitmap(self) -> 'Bitmap':
        """ wx.Bitmap

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetDisabledBitmapBundle(self) -> 'BitmapBundle':
        """ Return the bundle containing disabled tool bitmaps.

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetDropdownMenu(self) -> 'Menu':
        """ wx.Menu

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetId(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetKind(self) -> 'ItemKind':
        """ wx.ItemKind

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetLabel(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetLongHelp(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetNormalBitmap(self) -> 'Bitmap':
        """ wx.Bitmap

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetNormalBitmapBundle(self) -> 'BitmapBundle':
        """ Return the bundle containing normal tool bitmaps.

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetShortHelp(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetStyle(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def GetToolBar(self) -> 'ToolBar':
        """ Return the toolbar this tool is a member of.

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def IsButton(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def IsControl(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def IsEnabled(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def IsSeparator(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def IsStretchable(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def IsStretchableSpace(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def IsToggled(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def MakeStretchable(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetClientData(self, clientData: PyUserData) -> None:
        """ clientData (PyUserData) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetDisabledBitmap(self, bmp: 'BitmapBundle') -> None:
        """ bmp (wx.BitmapBundle) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetDropdownMenu(self, menu: 'Menu') -> None:
        """ menu (wx.Menu) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetLabel(self, label: str) -> None:
        """ label (string) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetLongHelp(self, help: str) -> bool:
        """ help (string) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetNormalBitmap(self, bmp: 'BitmapBundle') -> None:
        """ bmp (wx.BitmapBundle) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetShortHelp(self, help: str) -> bool:
        """ help (string) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def SetToggle(self, toggle: bool) -> bool:
        """ toggle (bool) â

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    def Toggle(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.ToolBarToolBase.html
        """

    Bitmap: 'Bitmap'  # See GetBitmap
    ClientData: PyUserData  # See GetClientData and SetClientData
    Control: 'Control'  # See GetControl
    DisabledBitmap: 'BitmapBundle'  # See GetDisabledBitmap and SetDisabledBitmap
    DisabledBitmapBundle: 'BitmapBundle'  # See GetDisabledBitmapBundle
    DropdownMenu: 'Menu'  # See GetDropdownMenu and SetDropdownMenu
    Id: int  # See GetId
    Kind: 'ItemKind'  # See GetKind
    Label: str  # See GetLabel and SetLabel
    LongHelp: str  # See GetLongHelp and SetLongHelp
    NormalBitmap: 'BitmapBundle'  # See GetNormalBitmap and SetNormalBitmap
    NormalBitmapBundle: 'BitmapBundle'  # See GetNormalBitmapBundle
    ShortHelp: str  # See GetShortHelp and SetShortHelp
    Style: int  # See GetStyle
    ToolBar: 'ToolBar'  # See GetToolBar



class Toolbook(BookCtrlBase):
    """ Toolbook is a class similar to Notebook but which uses a ToolBar
to show the labels instead of the tabs.

        Source: https://docs.wxpython.org/wx.Toolbook.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Constructs a choicebook control.

            Source: https://docs.wxpython.org/wx.Toolbook.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name="") -> bool:
        """ Create the tool book control that has already been constructed with the default constructor.

            Source: https://docs.wxpython.org/wx.Toolbook.html
        """

    def EnablePage(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Toolbook.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.Toolbook.html
        """

    def GetToolBar(self) -> 'ToolBar':
        """ Return the toolbar used for page selection.

            Source: https://docs.wxpython.org/wx.Toolbook.html
        """

    ToolBar: 'ToolBar'  # See GetToolBar



TBK_BUTTONBAR: int  # Use ButtonToolBar-based implementation under macOS (ignored under other platforms).

TBK_HORZ_LAYOUT: int  # Shows the text and the icons alongside, not vertically stacked (only implement under Windows and GTK 2 platforms as it relies on  TB_HORZ_LAYOUT   flag support). ^^

EVT_TOOLBOOK_PAGE_CHANGED: int  # The page selection was changed. Processes a  wxEVT_TOOLBOOK_PAGE_CHANGED   event.

EVT_TOOLBOOK_PAGE_CHANGING: int  # The page selection is about to be changed. Processes a  wxEVT_TOOLBOOK_PAGE_CHANGING   event. This event can be vetoed (using  wx.NotifyEvent.Veto ). ^^

class ToolTip(Object):
    """ This class holds information about a tooltip associated with a window
(see Window.SetToolTip()).

        Source: https://docs.wxpython.org/wx.ToolTip.html
    """
    def __init__(self, tip: str) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    @staticmethod
    def Enable(flag: bool) -> None:
        """ Enable or disable tooltips globally.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    def GetTip(self) -> str:
        """ Get the tooltip text.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    def GetWindow(self) -> 'Window':
        """ Get the associated window.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    @staticmethod
    def SetAutoPop(msecs: int) -> None:
        """ Set the delay after which the tooltip disappears or how long a tooltip remains visible.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    @staticmethod
    def SetDelay(msecs: int) -> None:
        """ Set the delay after which the tooltip appears.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    @staticmethod
    def SetMaxWidth(width: int) -> None:
        """ Set tooltip maximal width in pixels.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    @staticmethod
    def SetReshow(msecs: int) -> None:
        """ Set the delay between subsequent tooltips to appear.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    def SetTip(self, tip: str) -> None:
        """ Set the tooltip text.

            Source: https://docs.wxpython.org/wx.ToolTip.html
        """

    Tip: str  # See GetTip and SetTip
    Window: 'Window'  # See GetWindow



class TopLevelWindow(NonOwnedWindow):
    """ TopLevelWindow is a common base class for Dialog and Frame.

        Source: https://docs.wxpython.org/wx.TopLevelWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def CanSetTransparent(self) -> bool:
        """ Returns True if the platform supports making the window translucent.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def CenterOnScreen(self, direction: int=BOTH) -> None:
        """ A synonym for CentreOnScreen .

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def CentreOnScreen(self, direction: int=BOTH) -> None:
        """ Centres the window on screen.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def Create(self, parent, id=ID_ANY, title="", pos=DefaultPosition, size=DefaultSize, style=DEFAULT_FRAME_STYLE, name=FrameNameStr) -> bool:
        """ Creates the top level window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def EnableCloseButton(self, enable: bool=True) -> bool:
        """ Enables or disables the Close button (most often in the right upper corner of a dialog) and the Close entry of the system menu (most often in the left upper corner of the dialog).

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def EnableFullScreenView(self, enable=True, style=FULLSCREEN_ALL) -> bool:
        """ Enables the zoom button to toggle full screen mode.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def EnableMaximizeButton(self, enable: bool=True) -> bool:
        """ Enables or disables the Maximize button (in the right or left upper corner of a frame or dialog).

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def EnableMinimizeButton(self, enable: bool=True) -> bool:
        """ Enables or disables the Minimize button (in the right or left upper corner of a frame or dialog).

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def GetContentProtection(self) -> 'ContentProtection':
        """ Get the current content protection of the window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def GetDefaultItem(self) -> 'Window':
        """ Returns a pointer to the button which is the default for this window, or

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    @staticmethod
    def GetDefaultSize() -> 'Size':
        """ Get the default size for a new top level window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def GetIcon(self) -> 'Icon':
        """ Returns the standard icon of the window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def GetIcons(self) -> 'IconBundle':
        """ Returns all icons associated with the window, there will be none of them if neither SetIcon   nor SetIcons   had been called before.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def GetTitle(self) -> str:
        """ Gets a string containing the window title.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def GetTmpDefaultItem(self) -> 'Window':
        """ wx.Window

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def Iconize(self, iconize: bool=True) -> None:
        """ Iconizes or restores the window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def IsActive(self) -> bool:
        """ Returns True if this window is currently active, i.e. if the user is currently working with it.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def IsAlwaysMaximized(self) -> bool:
        """ Returns True if this window is expected to be always maximized, either due to platform policy or due to local policy regarding particular class.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def IsFullScreen(self) -> bool:
        """ Returns True if the window is in fullscreen mode.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def IsIconized(self) -> bool:
        """ Returns True if the window is iconized.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def IsMaximized(self) -> bool:
        """ Returns True if the window is maximized.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def Layout(self) -> bool:
        """ Lays out the children using the window sizer or resizes the only child of the window to cover its entire area.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def MacGetMetalAppearance(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def MacGetTopLevelWindowRef(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def MacGetUnifiedAppearance(self) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def MacSetMetalAppearance(self, on) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def Maximize(self, maximize: bool=True) -> None:
        """ Maximizes or restores the window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def OSXIsModified(self) -> bool:
        """ Returns the current modified state of the   wx.TopLevelWindow  on macOS.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def OSXSetModified(self, modified: bool) -> None:
        """ This function sets the   wx.TopLevelWindowâs modified state on macOS, which currently draws a black dot in the   wx.TopLevelWindowâs close button.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def RequestUserAttention(self, flags: int=USER_ATTENTION_INFO) -> None:
        """ Use a system-dependent way to attract users attention to the window when it is in background.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def Restore(self) -> None:
        """ Restore a previously iconized or maximized window to its normal state.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def RestoreToGeometry(self, ser: 'TopLevelWindow.GeometrySerializer') -> bool:
        """ Restores the window to the previously saved geometry.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SaveGeometry(self, ser: 'TopLevelWindow.GeometrySerializer') -> bool:
        """ Save the current window geometry to allow restoring it later.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetContentProtection(self, contentProtection: ContentProtection) -> bool:
        """ Set content protection for the window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetDefaultItem(self, win: 'Window') -> 'Window':
        """ Changes the default item for the panel, usually win  is a button.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetIcon(self, icon: 'Icon') -> None:
        """ Sets the icon for this window.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetIcons(self, icons: 'IconBundle') -> None:
        """ Sets several icons of different sizes for this window: this allows using different icons for different situations (e.g.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetMaxSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ A simpler interface for setting the size hints than SetSizeHints .

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetMinSize(self, size: Union[tuple[int, int], 'Size']) -> None:
        """ A simpler interface for setting the size hints than SetSizeHints .

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetRepresentedFilename(self, filename: str) -> None:
        """ Sets the file name represented by this   wx.TopLevelWindow.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetSizeHints(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetTitle(self, title: str) -> None:
        """ Sets the window title.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetTmpDefaultItem(self, win: 'Window') -> 'Window':
        """ win (wx.Window) â

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def SetTransparent(self, alpha: 'Byte') -> bool:
        """ If the platform supports it will set the window to be translucent.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def ShouldPreventAppExit(self) -> bool:
        """ This virtual function is not meant to be called directly but can be overridden to return False (it returns True by default) to allow the application to close even if this, presumably not very important, window is still opened.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def ShowFullScreen(self, show, style=FULLSCREEN_ALL) -> bool:
        """ Depending on the value of show  parameter the window is either shown full screen or restored to its normal state.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    def ShowWithoutActivating(self) -> None:
        """ Show the   wx.TopLevelWindow, but do not give it keyboard focus.

            Source: https://docs.wxpython.org/wx.TopLevelWindow.html
        """

    DefaultItem: 'Window'  # See GetDefaultItem and SetDefaultItem
    Icon: 'Icon'  # See GetIcon and SetIcon
    MacMetalAppearance: Any  # See MacGetMetalAppearance and MacSetMetalAppearance
    OSXModified: Any  # See OSXIsModified and OSXSetModified
    Title: str  # See GetTitle and SetTitle
    TmpDefaultItem: 'Window'  # See GetTmpDefaultItem and SetTmpDefaultItem



class Trackable:
    """ Add-on base class for a trackable object.

        Source: https://docs.wxpython.org/wx.Trackable.html
    """


class Translations:
    """ This class allows getting translations for strings.

        Source: https://docs.wxpython.org/wx.Translations.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def AddCatalog(self, domain, msgIdLanguage=LANGUAGE_ENGLISH_US) -> bool:
        """ Add a catalog for use with the current locale.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def AddStdCatalog(self) -> bool:
        """ Add standard wxWidgets catalogs (âwxstdâ and possible port-specific catalogs).

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    @staticmethod
    def Get() -> 'Translations':
        """ Returns current translations object, may return None.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def GetAvailableTranslations(self, domain: str) -> list[str]:
        """ Returns list of all translations of domain  that were found.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def GetBestTranslation(self, *args, **kw) -> None:
        """ Returns the best UI language for the domain.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def GetHeaderValue(self, header, domain="") -> str:
        """ Returns the header value for header header.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def GetTranslatedString(self, *args, **kw) -> str:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def IsLoaded(self, domain: str) -> bool:
        """ Check if the given catalog is loaded, and returns True if it is.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    @staticmethod
    def Set(t: 'Translations') -> None:
        """ Sets current translations object.

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def SetLanguage(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.Translations.html
        """

    def SetLoader(self, loader: 'TranslationsLoader') -> None:
        """ Changes loader use to read catalogs to a non-default one.

            Source: https://docs.wxpython.org/wx.Translations.html
        """



class TreeCtrl(Control,WithImages):
    """ A tree control presents information as a hierarchy, with items that
may be expanded to show further items.

        Source: https://docs.wxpython.org/wx.TreeCtrl.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def AddRoot(self, text, image=-1, selImage=-1, data=None) -> 'TreeItemId':
        """ Adds the root node to the tree, returning the new item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def AppendItem(self, parent, text, image=-1, selImage=-1, data=None) -> 'TreeItemId':
        """ Appends an item to the end of the branch identified by parent, return a new item id.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def AssignStateImageList(self, imageList: 'ImageList') -> None:
        """ Sets the state image list.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def ClearFocusedItem(self) -> None:
        """ Clears the currently focused item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def Collapse(self, item: 'TreeItemId') -> None:
        """ Collapses the given item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def CollapseAll(self) -> None:
        """ Collapses the root item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def CollapseAllChildren(self, item: 'TreeItemId') -> None:
        """ Collapses this item and all of its children, recursively.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def CollapseAndReset(self, item: 'TreeItemId') -> None:
        """ Collapses the given item and removes all children.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=TR_DEFAULT_STYLE, validator=DefaultValidator, name=TreeCtrlNameStr) -> bool:
        """ Creates the tree control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def Delete(self, item: 'TreeItemId') -> None:
        """ Deletes the specified item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def DeleteAllItems(self) -> None:
        """ Deletes all items in the control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def DeleteChildren(self, item: 'TreeItemId') -> None:
        """ Deletes all children of the given item (but not the item itself).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def EditLabel(self, item: 'TreeItemId') -> 'TextCtrl':
        """ Starts editing the label of the given item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def EnableBellOnNoMatch(self, on: bool=True) -> None:
        """ Enable or disable a beep if there is no match for the currently entered text when searching for the item from keyboard.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def EnableSystemTheme(self, enable: bool=True) -> None:
        """ Can be used to disable the system theme of controls using it by default.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def EndEditLabel(self, item, discardChanges=False) -> None:
        """ Ends label editing.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def EnsureVisible(self, item: 'TreeItemId') -> None:
        """ Scrolls and/or expands items to ensure that the given item is visible.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def Expand(self, item: 'TreeItemId') -> None:
        """ Expands the given item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def ExpandAll(self) -> None:
        """ Expands all items in the tree.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def ExpandAllChildren(self, item: 'TreeItemId') -> None:
        """ Expands the given item and all its children recursively.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetBoundingRect(self, item, textOnly=False) -> Any:
        """ Returns the rectangle bounding the item. If textOnly is True,
only the rectangle around the itemâs label will be returned, otherwise
the itemâs image is also taken into account. The return value may be None
if the rectangle was not successfully retrieved, such as if the item is
currently not visible.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetChildrenCount(self, item, recursively=True) -> int:
        """ Returns the number of items in the branch.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetCount(self) -> int:
        """ Returns the number of items in the control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetEditControl(self) -> 'TextCtrl':
        """ Returns the edit control being currently used to edit a label.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetFirstChild(self, item) -> tuple['TreeItemId', str]:
        """ Returns the first child; call GetNextChild   for the next child.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetFirstVisibleItem(self) -> 'TreeItemId':
        """ Returns the first visible item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetFocusedItem(self) -> 'TreeItemId':
        """ Returns the item last clicked or otherwise selected.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetIndent(self) -> int:
        """ Returns the current tree control indentation.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemBackgroundColour(self, item: 'TreeItemId') -> 'Colour':
        """ Returns the background colour of the item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemData(self, item) -> Any:
        """ Returns the tree item data associated with the item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemFont(self, item: 'TreeItemId') -> 'Font':
        """ Returns the font of the item label.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemImage(self, item, which=TreeItemIcon_Normal) -> int:
        """ Gets the specified item image.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemParent(self, item: 'TreeItemId') -> 'TreeItemId':
        """ Returns the itemâs parent.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemState(self, item: 'TreeItemId') -> int:
        """ Gets the specified item state.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemText(self, item: 'TreeItemId') -> str:
        """ Returns the item label.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetItemTextColour(self, item: 'TreeItemId') -> 'Colour':
        """ Returns the colour of the item label.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetLastChild(self, item: 'TreeItemId') -> 'TreeItemId':
        """ Returns the last child of the item (or an invalid tree item if this item has no children).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetNextChild(self, item, cookie) -> tuple['TreeItemId', str]:
        """ Returns the next child; call GetFirstChild   for the first child.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetNextSibling(self, item: 'TreeItemId') -> 'TreeItemId':
        """ Returns the next sibling of the specified item; call GetPrevSibling   for the previous sibling.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetNextVisible(self, item: 'TreeItemId') -> 'TreeItemId':
        """ Returns the next visible item or an invalid item if this item is the last visible one.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetPrevSibling(self, item: 'TreeItemId') -> 'TreeItemId':
        """ Returns the previous sibling of the specified item; call GetNextSibling   for the next sibling.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetPrevVisible(self, item: 'TreeItemId') -> 'TreeItemId':
        """ Returns the previous visible item or an invalid item if this item is the first visible one.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetQuickBestSize(self) -> bool:
        """ Returns True if the control will use a quick calculation for the best size, looking only at the first and last items.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetRootItem(self) -> 'TreeItemId':
        """ Returns the root item for the tree control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetSelection(self) -> 'TreeItemId':
        """ Returns the selection, or an invalid item if there is no selection.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetSelections(self) -> Any:
        """ Returns a list of currently selected items in the tree.  This function can be called only if the control has the wx.``wx.TR_MULTIPLE`` style.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetSpacing(self) -> int:
        """ Returns the current tree control spacing.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def GetStateImageList(self) -> 'ImageList':
        """ Returns the state image list (from which application-defined state images are taken).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def HitTest(self, point, flags) -> None:
        """ Calculates which (if any) item is under the given point, returning the tree item id at this point plus extra information flags.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def InsertItem(self, *args, **kw) -> 'TreeItemId':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def IsBold(self, item: 'TreeItemId') -> bool:
        """ Returns True if the given item is in bold state.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def IsEmpty(self) -> bool:
        """ Returns True if the control is empty (i.e. has no items, even no root one).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def IsExpanded(self, item: 'TreeItemId') -> bool:
        """ Returns True if the item is expanded (only makes sense if it has children).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def IsSelected(self, item: 'TreeItemId') -> bool:
        """ Returns True if the item is selected.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def IsVisible(self, item: 'TreeItemId') -> bool:
        """ Returns True if the item is visible on the screen.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def ItemHasChildren(self, item: 'TreeItemId') -> bool:
        """ Returns True if the item has children.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def OnCompareItems(self, item1, item2) -> int:
        """ Override this function in the derived class to change the sort order of the items in the tree control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def PrependItem(self, parent, text, image=-1, selImage=-1, data=None) -> 'TreeItemId':
        """ Appends an item as the first child of parent, return a new item id.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def ScrollTo(self, item: 'TreeItemId') -> None:
        """ Scrolls the specified item into view.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SelectChildren(self, parent: 'TreeItemId') -> None:
        """ Select all the immediate children of the given parent.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SelectItem(self, item, select=True) -> None:
        """ Selects the given item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetFocusedItem(self, item: 'TreeItemId') -> None:
        """ Sets the currently focused item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetIndent(self, indent: int) -> None:
        """ Sets the indentation for the tree control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemBackgroundColour(self, item, col) -> None:
        """ Sets the colour of the itemâs background.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemBold(self, item, bold=True) -> None:
        """ Makes item appear in bold font if bold  parameter is True or resets it to the normal state.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemData(self, item, data) -> None:
        """ Sets the item client data.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemDropHighlight(self, item, highlight=True) -> None:
        """ Gives the item the visual feedback for DragânâDrop actions, which is useful if something is dragged from the outside onto the tree control (as opposed to a DnD operation within the tree control, which already is implemented internally).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemFont(self, item, font) -> None:
        """ Sets the itemâs font.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemHasChildren(self, item, hasChildren=True) -> None:
        """ Force appearance of the button next to the item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemImage(self, item, image, which=TreeItemIcon_Normal) -> None:
        """ Sets the specified itemâs image.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemState(self, item, state) -> None:
        """ Sets the specified item state.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemText(self, item, text) -> None:
        """ Sets the item label.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetItemTextColour(self, item, col) -> None:
        """ Sets the colour of the itemâs text.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetQuickBestSize(self, quickBestSize: bool) -> None:
        """ If True is passed, specifies that the control will use a quick calculation for the best size, looking only at the first and last items.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetSpacing(self, spacing: int) -> None:
        """ Sets the spacing for the tree control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetStateImageList(self, imageList: 'ImageList') -> None:
        """ Sets the state image list (from which application-defined state images are taken).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SetWindowStyle(self, styles: int) -> None:
        """ Sets the mode flags associated with the display of the tree control.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def SortChildren(self, item: 'TreeItemId') -> None:
        """ Sorts the children of the given item using OnCompareItems .

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def Toggle(self, item: 'TreeItemId') -> None:
        """ Toggles the given item between collapsed and expanded states.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def ToggleItemSelection(self, item: 'TreeItemId') -> None:
        """ Toggles the given item between selected and unselected states.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def Unselect(self) -> None:
        """ Removes the selection from the currently selected item (if any).

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def UnselectAll(self) -> None:
        """ This function either behaves the same as Unselect   if the control doesnât have  TR_MULTIPLE   style, or removes the selection from all items if it does have this style.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    def UnselectItem(self, item: 'TreeItemId') -> None:
        """ Unselects the given item.

            Source: https://docs.wxpython.org/wx.TreeCtrl.html
        """

    BoundingRect: Any  # See GetBoundingRect
    Count: int  # See GetCount
    EditControl: 'TextCtrl'  # See GetEditControl
    FirstVisibleItem: 'TreeItemId'  # See GetFirstVisibleItem
    FocusedItem: 'TreeItemId'  # See GetFocusedItem and SetFocusedItem
    Indent: int  # See GetIndent and SetIndent
    QuickBestSize: bool  # See GetQuickBestSize and SetQuickBestSize
    RootItem: 'TreeItemId'  # See GetRootItem
    Selection: 'TreeItemId'  # See GetSelection
    Selections: Any  # See GetSelections
    Spacing: int  # See GetSpacing and SetSpacing
    StateImageList: 'ImageList'  # See GetStateImageList and SetStateImageList



TR_EDIT_LABELS: int  # Use this style if you wish the user to be able to edit labels in the tree control.

TR_NO_BUTTONS: int  # For convenience to document that no buttons are to be drawn.

TR_HAS_BUTTONS: int  # Use this style to show + and - buttons to the left of parent items.

TR_TWIST_BUTTONS: int  # Selects alternative style of  +/ -   buttons  and shows rotating (âtwistingâ) arrows instead. Currently this style is only implemented under Microsoft Windows Vista and later Windows versions and is ignored under the other platforms as enabling it is equivalent to using  SystemThemedControl.EnableSystemTheme .

TR_NO_LINES: int  # Use this style to hide vertical level connectors.

TR_FULL_ROW_HIGHLIGHT: int  # Use this style to have the background colour and the selection highlight extend over the entire horizontal row of the tree control window. (This flag is ignored under Windows unless you specify  TR_NO_LINES   as well.)

TR_LINES_AT_ROOT: int  # Use this style to show lines leading to the root nodes (unless no  TR_NO_LINES   is also used, in which case no lines are shown). Note that in the MSW version, if this style is omitted, not only the lines, but also the button used for expanding the root item is not shown, which can be unexpected, so it is recommended to always use it.

TR_HIDE_ROOT: int  # Use this style to suppress the display of the root node, effectively causing the first-level nodes to appear as a series of root nodes.

TR_ROW_LINES: int  # Use this style to draw a contrasting border between displayed rows.

TR_HAS_VARIABLE_ROW_HEIGHT: int  # Use this style to cause row heights to be just big enough to fit the content. If not set, all rows use the largest row height. The default is that this flag is unset. Generic only.

TR_SINGLE: int  # For convenience to document that only one item may be selected at a time. Selecting another item causes the current selection, if any, to be deselected. This is the default.

TR_MULTIPLE: int  # Use this style to allow a range of items to be selected. If a second range is selected, the current range, if any, is deselected.

TR_DEFAULT_STYLE: int  # The set of flags that are closest to the defaults for the native control for a particular toolkit. ^^

EVT_TREE_BEGIN_DRAG: int  # Begin dragging with the left mouse button. If you want to enable left-dragging you need to intercept this event and explicitly call wx.TreeEvent.Allow , as itâs vetoed by default. Processes a  wxEVT_TREE_BEGIN_DRAG   event type.

EVT_TREE_BEGIN_RDRAG: int  # Begin dragging with the right mouse button. If you want to enable right-dragging you need to intercept this event and explicitly call wx.TreeEvent.Allow , as itâs vetoed by default. Processes a  wxEVT_TREE_BEGIN_RDRAG   event type.

EVT_TREE_END_DRAG: int  # End dragging with the left or right mouse button. Processes a  wxEVT_TREE_END_DRAG   event type.

EVT_TREE_BEGIN_LABEL_EDIT: int  # Begin editing a label. This can be prevented by calling Veto(). Processes a  wxEVT_TREE_BEGIN_LABEL_EDIT   event type.

EVT_TREE_END_LABEL_EDIT: int  # Finish editing a label. This can be prevented by calling Veto(). Processes a  wxEVT_TREE_END_LABEL_EDIT   event type.

EVT_TREE_DELETE_ITEM: int  # An item was deleted. Processes a  wxEVT_TREE_DELETE_ITEM   event type.

EVT_TREE_GET_INFO: int  # Request information from the application. Processes a  wxEVT_TREE_GET_INFO   event type.

EVT_TREE_SET_INFO: int  # Information is being supplied. Processes a  wxEVT_TREE_SET_INFO   event type.

EVT_TREE_ITEM_ACTIVATED: int  # The item has been activated, i.e. chosen by double clicking it with mouse or from keyboard. Processes a  wxEVT_TREE_ITEM_ACTIVATED   event type.

EVT_TREE_ITEM_COLLAPSED: int  # The item has been collapsed. Processes a  wxEVT_TREE_ITEM_COLLAPSED   event type.

EVT_TREE_ITEM_COLLAPSING: int  # The item is being collapsed. This can be prevented by calling Veto(). Processes a  wxEVT_TREE_ITEM_COLLAPSING   event type.

EVT_TREE_ITEM_EXPANDED: int  # The item has been expanded. Processes a  wxEVT_TREE_ITEM_EXPANDED   event type.

EVT_TREE_ITEM_EXPANDING: int  # The item is being expanded. This can be prevented by calling Veto(). Processes a  wxEVT_TREE_ITEM_EXPANDING   event type.

EVT_TREE_ITEM_RIGHT_CLICK: int  # The user has clicked the item with the right mouse button. Processes a  wxEVT_TREE_ITEM_RIGHT_CLICK   event type.

EVT_TREE_ITEM_MIDDLE_CLICK: int  # The user has clicked the item with the middle mouse button. This is only supported by the generic control. Processes a  wxEVT_TREE_ITEM_MIDDLE_CLICK   event type.

EVT_TREE_SEL_CHANGED: int  # Selection has changed. Processes a  wxEVT_TREE_SEL_CHANGED   event type.

EVT_TREE_SEL_CHANGING: int  # Selection is changing. This can be prevented by calling Veto(). Processes a  wxEVT_TREE_SEL_CHANGING   event type.

EVT_TREE_KEY_DOWN: int  # A key has been pressed. Processes a  wxEVT_TREE_KEY_DOWN   event type.

EVT_TREE_ITEM_GETTOOLTIP: int  # The opportunity to set the item tooltip is being given to the application (call wx.TreeEvent.SetToolTip ). Windows only. Processes a  wxEVT_TREE_ITEM_GETTOOLTIP   event type.

EVT_TREE_ITEM_MENU: int  # The context menu for the selected item has been requested, either by a right click or by using the menu key. Notice that these events always carry a valid tree item and so are not generated when (right) clicking outside of the items area. If you need to handle such events, consider using  wxEVT_CONTEXT_MENU   instead. Processes a   wxEVT_TREE_ITEM_MENU   event type.

EVT_TREE_STATE_IMAGE_CLICK: int  # The state image has been clicked. Processes a  wxEVT_TREE_STATE_IMAGE_CLICK   event type. ^^

class TreeEvent(NotifyEvent):
    """ A tree event holds information about events associated with TreeCtrl
objects.

        Source: https://docs.wxpython.org/wx.TreeEvent.html
    """
    def __init__(*args, **kwargs) -> None:
        """ Constructor, used by wxWidgets itself only.

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def GetItem(self) -> 'TreeItemId':
        """ Returns the item.

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def GetKeyCode(self) -> int:
        """ Returns the key code if the event is a key event.

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def GetKeyEvent(self) -> 'KeyEvent':
        """ Returns the key event for  EVT_TREE_KEY_DOWN   events.

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def GetLabel(self) -> str:
        """ Returns the label if the event is a begin or end edit label event.

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def GetOldItem(self) -> 'TreeItemId':
        """ Returns the old item index (valid for  EVT_TREE_SEL_CHANGING   and   EVT_TREE_SEL_CHANGED   events).

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def GetPoint(self) -> 'Point':
        """ Returns the position of the mouse pointer if the event is a drag or menu-context event.

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def IsEditCancelled(self) -> bool:
        """ Returns True if the label edit was cancelled.

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    def SetToolTip(self, tooltip: str) -> None:
        """ Set the tooltip for the item (valid for  EVT_TREE_ITEM_GETTOOLTIP   events).

            Source: https://docs.wxpython.org/wx.TreeEvent.html
        """

    Item: 'TreeItemId'  # See GetItem
    KeyCode: int  # See GetKeyCode
    KeyEvent: 'KeyEvent'  # See GetKeyEvent
    Label: str  # See GetLabel
    OldItem: 'TreeItemId'  # See GetOldItem
    Point: 'Point'  # See GetPoint



class TreeItemId:
    """ An opaque reference to a tree item.

        Source: https://docs.wxpython.org/wx.TreeItemId.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def GetID(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def IsOk(self) -> bool:
        """ Returns True if this instance is referencing a valid tree item.

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def Unset(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def __eq__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def __hash__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def __ne__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.TreeItemId.html
        """

    ID: None  # See GetID



class TwoFingerTapEvent(GestureEvent):
    """ This event is generated when two fingers touch the surface at the same
time.

        Source: https://docs.wxpython.org/wx.TwoFingerTapEvent.html
    """
    def __init__(self, windid: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.TwoFingerTapEvent.html
        """



EVT_TWO_FINGER_TAP: int  # Process a  wxEVT_TWO_FINGER_TAP . ^^

class UIActionSimulator:
    """ UIActionSimulator is a class used to simulate user interface actions
such as a mouse click or a key press.

        Source: https://docs.wxpython.org/wx.UIActionSimulator.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def Char(self, keycode, modifiers=MOD_NONE) -> bool:
        """ Press and release a key.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def KeyDown(self, keycode, modifiers=MOD_NONE) -> bool:
        """ Press a key.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def KeyUp(self, keycode, modifiers=MOD_NONE) -> bool:
        """ Release a key.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def MouseClick(self, button: int=MOUSE_BTN_LEFT) -> bool:
        """ Click a mouse button.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def MouseDblClick(self, button: int=MOUSE_BTN_LEFT) -> bool:
        """ Double-click a mouse button.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def MouseDown(self, button: int=MOUSE_BTN_LEFT) -> bool:
        """ Press a mouse button.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def MouseDragDrop(self, x1, y1, x2, y2, button=MOUSE_BTN_LEFT) -> bool:
        """ Perform a drag and drop operation.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def MouseMove(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def MouseUp(self, button: int=MOUSE_BTN_LEFT) -> bool:
        """ Release a mouse button.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def Select(self, text: str) -> bool:
        """ Simulate selection of an item with the given text.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """

    def Text(self, text: int) -> bool:
        """ Emulate typing in the keys representing the given string.

            Source: https://docs.wxpython.org/wx.UIActionSimulator.html
        """



class UniChar:
    """ This class represents a single Unicode character.

        Source: https://docs.wxpython.org/wx.UniChar.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    def GetAsChar(self, c: int) -> bool:
        """ Returns True if the character is representable as a single byte in the current locale encoding.

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    def GetValue(self) -> value_type:
        """ Returns Unicode code point value of the character.

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    def HighSurrogate(self, *args, **kw) -> 'Uint16':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    def IsAscii(self) -> bool:
        """ Returns True if the character is an ASCII character (i.e. if its value is less than 128).

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    def IsBMP(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    def IsSupplementary(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    def LowSurrogate(self, *args, **kw) -> 'Uint16':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.UniChar.html
        """

    Value: value_type  # See GetValue



class UpdateUIEvent(CommandEvent):
    """ This class is used for pseudo-events which are called by wxWidgets to
give an application the chance to update various user interface
elements.

        Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
    """
    def __init__(self, commandId: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    @staticmethod
    def CanUpdate(window: 'Window') -> bool:
        """ Returns True if it is appropriate to update (send UI update events to) this window.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def Check(self, check: bool) -> None:
        """ Check or uncheck the UI element.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def Enable(self, enable: bool) -> None:
        """ Enable or disable the UI element.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetChecked(self) -> bool:
        """ Returns True if the UI element should be checked.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetEnabled(self) -> bool:
        """ Returns True if the UI element should be enabled.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    @staticmethod
    def GetMode() -> 'UpdateUIMode':
        """ Static function returning a value specifying how wxWidgets will send update events: to all windows, or only to those which specify that they will process the events.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetSetChecked(self) -> bool:
        """ Returns True if the application has called Check .

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetSetEnabled(self) -> bool:
        """ Returns True if the application has called Enable .

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetSetShown(self) -> bool:
        """ Returns True if the application has called Show .

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetSetText(self) -> bool:
        """ Returns True if the application has called SetText .

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetShown(self) -> bool:
        """ Returns True if the UI element should be shown.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def GetText(self) -> str:
        """ Returns the text that should be set for the UI element.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    @staticmethod
    def GetUpdateInterval() -> int:
        """ Returns the current interval between updates in milliseconds.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def IsCheckable(self) -> bool:
        """ Returns True if the UI element can be checked.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    @staticmethod
    def ResetUpdateTime() -> None:
        """ Used internally to reset the last-updated time to the current time.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    @staticmethod
    def SetMode(mode: UpdateUIMode) -> None:
        """ Specify how wxWidgets will send update events: to all windows, or only to those which specify that they will process the events.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def SetText(self, text: str) -> None:
        """ Sets the text for this UI element.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    @staticmethod
    def SetUpdateInterval(updateInterval: int) -> None:
        """ Sets the interval between updates in milliseconds.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    def Show(self, show: bool) -> None:
        """ Show or hide the UI element.

            Source: https://docs.wxpython.org/wx.UpdateUIEvent.html
        """

    Checked: bool  # See GetChecked and Check
    Enabled: bool  # See GetEnabled and Enable
    Shown: bool  # See GetShown and Show
    Text: str  # See GetText and SetText



EVT_UPDATE_UI: int  # Process a  wxEVT_UPDATE_UI   event for the command with the given id.

EVT_UPDATE_UI_RANGE: int  # Process a  wxEVT_UPDATE_UI   event for any command with id included in the given range. ^^

UPDATE_UI_PROCESS_SPECIFIED: int

UPDATE_UI_PROCESS_ALL: int

class URLDataObject(DataObject):
    """ URLDataObject is a DataObject containing an URL and can be used
e.g.

        Source: https://docs.wxpython.org/wx.URLDataObject.html
    """
    def __init__(self, url: str="") -> None:
        """ Constructor, may be used to initialize the URL.

            Source: https://docs.wxpython.org/wx.URLDataObject.html
        """

    def GetAllFormats(self, dir=DataObject.Get) -> None:
        """ Returns a list of wx.DataFormat objects which this data object
supports transferring in the given direction.

            Source: https://docs.wxpython.org/wx.URLDataObject.html
        """

    def GetURL(self) -> str:
        """ Returns the URL stored by this object, as a string.

            Source: https://docs.wxpython.org/wx.URLDataObject.html
        """

    def SetData(self, format, buf) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.URLDataObject.html
        """

    def SetURL(self, url: str) -> None:
        """ Sets the URL stored by this object.

            Source: https://docs.wxpython.org/wx.URLDataObject.html
        """

    AllFormats: None  # See GetAllFormats
    URL: str  # See GetURL and SetURL



class Validator(EvtHandler):
    """ Validator is the base class for a family of validator classes that
mediate between a class of control, and application data.

        Source: https://docs.wxpython.org/wx.Validator.html
    """
    def __init__(self) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    def Clone(self) -> 'Window':
        """ All validator classes must implement the Clone   function, which returns an identical copy of itself.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    def GetWindow(self) -> 'Window':
        """ Returns the window associated with the validator.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    @staticmethod
    def IsSilent() -> bool:
        """ Returns if the error sound is currently disabled.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    def SetWindow(self, window: 'Window') -> None:
        """ Associates a window with the validator.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    @staticmethod
    def SuppressBellOnError(suppress: bool=True) -> None:
        """ This functions switches on or turns off the error sound produced by the validators if an invalid key is pressed.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    def TransferFromWindow(self) -> bool:
        """ This overridable function is called when the value in the window must be transferred to the validator.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    def TransferToWindow(self) -> bool:
        """ This overridable function is called when the value associated with the validator must be transferred to the window.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    def Validate(self, parent: 'Window') -> bool:
        """ This overridable function is called when the value in the associated window must be validated.

            Source: https://docs.wxpython.org/wx.Validator.html
        """

    Window: 'Window'  # See GetWindow and SetWindow



class VarHScrollHelper(VarScrollHelperBase):
    """ This class provides functions wrapping the VarScrollHelperBase
class, targeted for horizontal-specific scrolling.

        Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
    """
    def __init__(self, winToScroll: 'Window') -> None:
        """ Constructor taking the target window to be scrolled by this helper class.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def EstimateTotalWidth(self) -> 'Coord':
        """ This class forwards calls from EstimateTotalSize   to this function so derived classes can override either just the height or the width estimation, or just estimate both differently if desired in any   wx.HVScrolledWindow  derived class.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def GetColumnCount(self) -> int:
        """ Returns the number of columns the target window contains.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def GetVisibleColumnsBegin(self) -> int:
        """ Returns the index of the first visible column based on the scroll position.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def GetVisibleColumnsEnd(self) -> int:
        """ Returns the index of the last visible column based on the scroll position.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def IsColumnVisible(self, column: int) -> bool:
        """ Returns True if the given column is currently visible (even if only partially visible) or False otherwise.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def OnGetColumnWidth(self, column: int) -> 'Coord':
        """ This function must be overridden in the derived class, and should return the width of the given column in pixels.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def OnGetColumnsWidthHint(self, columnMin, columnMax) -> None:
        """ This function doesnât have to be overridden but it may be useful to do so if calculating the columnsâ sizes is a relatively expensive operation as it gives your code a chance to calculate several of them at once and cache the result if necessary.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def RefreshColumn(self, column: int) -> None:
        """ Triggers a refresh for just the given columnâs area of the window if itâs visible.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def RefreshColumns(self, from_, to_) -> None:
        """ Triggers a refresh for the area between the specified range of columns given (inclusively).

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def ScrollColumnPages(self, pages: int) -> bool:
        """ Scroll by the specified number of pages which may be positive (to scroll right) or negative (to scroll left).

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def ScrollColumns(self, columns: int) -> bool:
        """ Scroll by the specified number of columns which may be positive (to scroll right) or negative (to scroll left).

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def ScrollToColumn(self, column: int) -> bool:
        """ Scroll to the specified column.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    def SetColumnCount(self, columnCount: int) -> None:
        """ Set the number of columns the window contains.

            Source: https://docs.wxpython.org/wx.VarHScrollHelper.html
        """

    ColumnCount: int  # See GetColumnCount and SetColumnCount
    VisibleColumnsBegin: int  # See GetVisibleColumnsBegin
    VisibleColumnsEnd: int  # See GetVisibleColumnsEnd



class VarScrollHelperBase:
    """ This class provides all common base functionality for scroll
calculations shared among all variable scrolled window implementations
as well as automatic scrollbar functionality, saved scroll positions,
controlling target windows to be scrolled, as well as defining all
required virtual functions that need to be implemented for any
orientation specific work.

        Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
    """
    def __init__(self, winToScroll: 'Window') -> None:
        """ Constructor taking the target window to be scrolled by this helper class.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def CalcScrolledPosition(self, coord: int) -> int:
        """ Translates the logical coordinate given to the current device coordinate.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def CalcUnscrolledPosition(self, coord: int) -> int:
        """ Translates the device coordinate given to the corresponding logical coordinate.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def EnablePhysicalScrolling(self, scrolling: bool=True) -> None:
        """ With physical scrolling on (when this is True), the device origin is changed properly when a   wx.PaintDC  is prepared, children are actually moved and laid out properly, and the contents of the window (pixels) are actually moved.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def EstimateTotalSize(self) -> 'Coord':
        """ When the number of scroll units change, we try to estimate the total size of all units when the full window size is needed (i.e.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def GetNonOrientationTargetSize(self) -> int:
        """ This function needs to be overridden in the in the derived class to return the window size with respect to the opposing orientation.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def GetOrientation(self) -> 'Orientation':
        """ This function need to be overridden to return the orientation that this helper is working with, either  HORIZONTAL   or   VERTICAL .

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def GetOrientationTargetSize(self) -> int:
        """ This function needs to be overridden in the in the derived class to return the window size with respect to the orientation this helper is working with.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def GetTargetWindow(self) -> 'Window':
        """ This function will return the target window this helper class is currently scrolling.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def GetVisibleBegin(self) -> int:
        """ Returns the index of the first visible unit based on the scroll position.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def GetVisibleEnd(self) -> int:
        """ Returns the index of the last visible unit based on the scroll position.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def IsVisible(self, unit: int) -> bool:
        """ Returns True if the given scroll unit is currently visible (even if only partially visible) or False otherwise.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def OnGetUnitSize(self, unit: int) -> 'Coord':
        """ This function must be overridden in the derived class, and should return the size of the given unit in pixels.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def OnGetUnitsSizeHint(self, unitMin, unitMax) -> None:
        """ This function doesnât have to be overridden but it may be useful to do so if calculating the unitsâ sizes is a relatively expensive operation as it gives your code a chance to calculate several of them at once and cache the result if necessary.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def RefreshAll(self) -> None:
        """ Recalculate all parameters and repaint all units.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def SetTargetWindow(self, target: 'Window') -> None:
        """ Normally the window will scroll itself, but in some rare occasions you might want it to scroll (part of) another window (e.g.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def UpdateScrollbar(self) -> None:
        """ Update the thumb size shown by the scrollbar.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    def VirtualHitTest(self, coord: int) -> int:
        """ Returns the virtual scroll unit under the device unit given accounting for scroll position or  NOT_FOUND   if none (i.e.

            Source: https://docs.wxpython.org/wx.VarScrollHelperBase.html
        """

    NonOrientationTargetSize: int  # See GetNonOrientationTargetSize
    Orientation: 'Orientation'  # See GetOrientation
    OrientationTargetSize: int  # See GetOrientationTargetSize
    TargetWindow: 'Window'  # See GetTargetWindow and SetTargetWindow
    VisibleBegin: int  # See GetVisibleBegin
    VisibleEnd: int  # See GetVisibleEnd



class VarHVScrollHelper(VarVScrollHelper,VarHScrollHelper):
    """ This class provides functions wrapping the VarHScrollHelper and
VarVScrollHelper classes, targeted for scrolling a window in both
axis.

        Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
    """
    def __init__(self, winToScroll: 'Window') -> None:
        """ Constructor taking the target window to be scrolled by this helper class.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def EnablePhysicalScrolling(self, vscrolling=True, hscrolling=True) -> None:
        """ With physical scrolling on (when this is True), the device origin is changed properly when a   wx.PaintDC  is prepared, children are actually moved and laid out properly, and the contents of the window (pixels) are actually moved.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def GetRowColumnCount(self) -> 'Size':
        """ Returns the number of columns and rows the target window contains.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def GetVisibleBegin(self) -> 'Position':
        """ Returns the index of the first visible column and row based on the current scroll position.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def GetVisibleEnd(self) -> 'Position':
        """ Returns the index of the last visible column and row based on the scroll position.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def IsVisible(self, *args, **kw) -> bool:
        """ Returns True if both the given row and column are currently visible (even if only partially visible) or False otherwise.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def RefreshRowColumn(self, *args, **kw) -> None:
        """ Triggers a refresh for just the area shared between the given row and column of the window if it is visible.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def RefreshRowsColumns(self, *args, **kw) -> None:
        """ Triggers a refresh for the visible area shared between all given rows and columns (inclusive) of the window.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def ScrollToRowColumn(self, *args, **kw) -> bool:
        """ Scroll to the specified row and column.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def SetRowColumnCount(self, rowCount, columnCount) -> None:
        """ Set the number of rows and columns the target window will contain.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    def VirtualHitTest(self, *args, **kw) -> 'Position':
        """ Returns the virtual scroll unit under the device unit given accounting for scroll position or  NOT_FOUND   (for the row, column, or possibly both values) if none.

            Source: https://docs.wxpython.org/wx.VarHVScrollHelper.html
        """

    RowColumnCount: 'Size'  # See GetRowColumnCount and SetRowColumnCount
    VisibleBegin: 'Position'  # See GetVisibleBegin
    VisibleEnd: 'Position'  # See GetVisibleEnd



class VarVScrollHelper(VarScrollHelperBase):
    """ This class provides functions wrapping the VarScrollHelperBase
class, targeted for vertical-specific scrolling.

        Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
    """
    def __init__(self, winToScroll: 'Window') -> None:
        """ Constructor taking the target window to be scrolled by this helper class.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def EstimateTotalHeight(self) -> 'Coord':
        """ This class forwards calls from EstimateTotalSize   to this function so derived classes can override either just the height or the width estimation, or just estimate both differently if desired in any   wx.HVScrolledWindow  derived class.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def GetRowCount(self) -> int:
        """ Returns the number of rows the target window contains.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def GetVisibleRowsBegin(self) -> int:
        """ Returns the index of the first visible row based on the scroll position.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def GetVisibleRowsEnd(self) -> int:
        """ Returns the index of the last visible row based on the scroll position.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def IsRowVisible(self, row: int) -> bool:
        """ Returns True if the given row is currently visible (even if only partially visible) or False otherwise.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def OnGetRowHeight(self, row: int) -> 'Coord':
        """ This function must be overridden in the derived class, and should return the height of the given row in pixels.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def OnGetRowsHeightHint(self, rowMin, rowMax) -> None:
        """ This function doesnât have to be overridden but it may be useful to do so if calculating the rowsâ sizes is a relatively expensive operation as it gives your code a chance to calculate several of them at once and cache the result if necessary.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def RefreshRow(self, row: int) -> None:
        """ Triggers a refresh for just the given rowâs area of the window if itâs visible.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def RefreshRows(self, from_, to_) -> None:
        """ Triggers a refresh for the area between the specified range of rows given (inclusively).

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def ScrollRowPages(self, pages: int) -> bool:
        """ Scroll by the specified number of pages which may be positive (to scroll down) or negative (to scroll up).

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def ScrollRows(self, rows: int) -> bool:
        """ Scroll by the specified number of rows which may be positive (to scroll down) or negative (to scroll up).

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def ScrollToRow(self, row: int) -> bool:
        """ Scroll to the specified row.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    def SetRowCount(self, rowCount: int) -> None:
        """ Set the number of rows the window contains.

            Source: https://docs.wxpython.org/wx.VarVScrollHelper.html
        """

    RowCount: int  # See GetRowCount and SetRowCount
    VisibleRowsBegin: int  # See GetVisibleRowsBegin
    VisibleRowsEnd: int  # See GetVisibleRowsEnd



class VersionInfo:
    """ VersionInfo contains version information.

        Source: https://docs.wxpython.org/wx.VersionInfo.html
    """
    def __init__(self, name="", major=0, minor=0, micro=0, revision=0, description="", copyright="") -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetCopyright(self) -> str:
        """ Get the copyright string.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetDescription(self) -> str:
        """ Get the description string.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetMajor(self) -> int:
        """ Get the major version number.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetMicro(self) -> int:
        """ Get the micro version, or release number.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetMinor(self) -> int:
        """ Get the minor version number.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetName(self) -> str:
        """ Get the name of the object (library).

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetRevision(self) -> int:
        """ Get the revision version, or build number.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def GetVersionString(self) -> str:
        """ Get the string representation.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def HasCopyright(self) -> bool:
        """ Returns True if a copyright string has been specified.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def HasDescription(self) -> bool:
        """ Return True if a description string has been specified.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    def ToString(self) -> str:
        """ Get the string representation of this version object.

            Source: https://docs.wxpython.org/wx.VersionInfo.html
        """

    Copyright: str  # See GetCopyright
    Description: str  # See GetDescription
    Major: int  # See GetMajor
    Micro: int  # See GetMicro
    Minor: int  # See GetMinor
    Name: str  # See GetName
    Revision: int  # See GetRevision
    VersionString: str  # See GetVersionString



class VideoMode:
    """ Determines the sizes and locations of displays connected to the
system.

        Source: https://docs.wxpython.org/wx.VideoMode.html
    """
    def __init__(self, width=0, height=0, depth=0, freq=0) -> None:
        """ Constructs this class using the given parameters.

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def GetDepth(self) -> int:
        """ Returns bits per pixel (e.g. 32), 1 is monochrome and 0 means unspecified/known.

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def GetHeight(self) -> int:
        """ Returns the screen height in pixels (e.g. 480), 0 means unspecified.

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def GetWidth(self) -> int:
        """ Returns the screen width in pixels (e.g. 640), 0 means unspecified.

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the object has been initialized.

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def Matches(self, other: 'VideoMode') -> bool:
        """ Returns True if this mode matches the other one in the sense that all non zero fields of the other mode have the same value in this one (except for refresh which is allowed to have a greater value).

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def __bool__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def __nonzero__(self) -> int:
        """ int

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def __ne__(self, item: Any) -> bool:
        """ mode (wx.VideoMode) â

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    def __eq__(self, item: Any) -> bool:
        """ m (wx.VideoMode) â

            Source: https://docs.wxpython.org/wx.VideoMode.html
        """

    Depth: int  # See GetDepth
    Height: int  # See GetHeight
    Width: int  # See GetWidth
    bpp: Any  # A public C++ attribute of type int. Bits per pixel (e.g. 32), 1 is monochrome and 0 means unspecified/known.
    h: Any  # A public C++ attribute of type int. The screen height in pixels (e.g. 480), 0 means unspecified.
    refresh: Any  # A public C++ attribute of type int. Refresh frequency in Hz, 0 means unspecified/unknown.
    w: Any  # A public C++ attribute of type int. The screen width in pixels (e.g. 640), 0 means unspecified.



class VisualAttributes:
    """ Struct containing all the visual attributes of a control.

        Source: https://docs.wxpython.org/wx.VisualAttributes.html
    """
    colBg: Any  # A public C++ attribute of type Colour     . The background colour.
    colFg: Any  # A public C++ attribute of type Colour     . The foreground colour.
    font: Any  # A public C++ attribute of type Font     . The font used for control label/text inside it.



class VListBox(VScrolledWindow):
    """ VListBox is a ListBox-like control with the following two main
differences from a regular ListBox: it can have an arbitrarily huge
number of items because it doesnât store them itself but uses the
OnDrawItem() callback to draw them (so it is a virtual listbox) and
its items can have variable height as determined by OnMeasureItem()
(so it is also a listbox with the lines of variable height).

        Source: https://docs.wxpython.org/wx.VListBox.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def Clear(self) -> None:
        """ Deletes all items from the control.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name=VListBoxNameStr) -> bool:
        """ Creates the control.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def DeselectAll(self) -> bool:
        """ Deselects all the items in the listbox.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetFirstSelected(self) -> tuple:
        """ Returns the index of the first selected item in the listbox or  NOT_FOUND   if no items are currently selected.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetItemCount(self) -> int:
        """ Get the number of items in the control.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetItemRect(self, item: int) -> 'Rect':
        """ Returns the rectangle occupied by this item in physical coordinates.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetMargins(self) -> 'Point':
        """ Returns the margins used by the control.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetNextSelected(self, cookie: int) -> tuple:
        """ Returns the index of the next selected item or  NOT_FOUND   if there are no more.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetSelectedCount(self) -> int:
        """ Returns the number of the items currently selected.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetSelection(self) -> int:
        """ Get the currently selected item or  NOT_FOUND   if there is no selection.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def GetSelectionBackground(self) -> 'Colour':
        """ Returns the background colour used for the selected cells.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def HasMultipleSelection(self) -> bool:
        """ Returns True if the listbox was created with  LB_MULTIPLE   style and so supports multiple selection or False if it is a single selection listbox.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def IsCurrent(self, item: int) -> bool:
        """ Returns True if this item is the current one, False otherwise.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def IsSelected(self, item: int) -> bool:
        """ Returns True if this item is selected, False otherwise.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def OnDrawBackground(self, dc, rect, n) -> None:
        """ This method is used to draw the itemâs background and, maybe, a border around it.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def OnDrawItem(self, dc, rect, n) -> None:
        """ The derived class must implement this function to actually draw the item with the given index on the provided DC.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def OnDrawSeparator(self, dc, rect, n) -> None:
        """ This method may be used to draw separators between the lines.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def OnMeasureItem(self, n: int) -> 'Coord':
        """ The derived class must implement this method to return the height of the specified item (in pixels).

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def Select(self, item, select=True) -> bool:
        """ Selects or deselects the specified item which must be valid (i.e. not equal to  NOT_FOUND ).

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def SelectAll(self) -> bool:
        """ Selects all the items in the listbox.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def SelectRange(self, from_, to_) -> bool:
        """ Selects all items in the specified range which may be given in any order.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def SetItemCount(self, count: int) -> None:
        """ Set the number of items to be shown in the control.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def SetMargins(self, *args, **kw) -> None:
        """ Set the margins: horizontal margin is the distance between the window border and the item contents while vertical margin is half of the distance between items.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def SetSelection(self, selection: int) -> None:
        """ Set the selection to the specified item, if it is -1 the selection is unset.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def SetSelectionBackground(self, col: Union[int, str, 'Colour']) -> None:
        """ Sets the colour to be used for the selected cells background.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    def Toggle(self, item: int) -> None:
        """ Toggles the state of the specified item, i.e. selects it if it was unselected and deselects it if it was selected.

            Source: https://docs.wxpython.org/wx.VListBox.html
        """

    ItemCount: int  # See GetItemCount and SetItemCount
    Margins: Union[tuple[int, int], 'Point']  # See GetMargins and SetMargins
    SelectedCount: int  # See GetSelectedCount
    Selection: int  # See GetSelection and SetSelection
    SelectionBackground: Union[int, str, 'Colour']  # See GetSelectionBackground and SetSelectionBackground



class VScrolledWindow(Panel,VarVScrollHelper):
    """ In the name of this class, âVâ may stand for âvariableâ because it can
be used for scrolling rows of variable heights; âvirtualâ, because it
is not necessary to know the heights of all rows in advance  only
those which are shown on the screen need to be measured; or even
âverticalâ, because this class only supports scrolling vertically.

        Source: https://docs.wxpython.org/wx.VScrolledWindow.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def Create(self, parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=0, name=PanelNameStr) -> bool:
        """ Same as the non-default constructor, but returns a status code: True if ok, False if the window couldnât be created.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> 'VisualAttributes':
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def GetFirstVisibleLine(self) -> int:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def GetLastVisibleLine(self) -> int:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def GetLineCount(self) -> int:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def HitTest(self, *args) -> None:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def RefreshLine(self, line) -> None:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def RefreshLines(self, from_, to_) -> None:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def ScrollLines(self, lines) -> bool:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def ScrollPages(self, pages) -> bool:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def ScrollToLine(self, line) -> bool:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    def SetLineCount(self, count) -> None:
        """ Deprecated compatibility helper.

            Source: https://docs.wxpython.org/wx.VScrolledWindow.html
        """

    FirstVisibleLine: int  # See GetFirstVisibleLine
    LastVisibleLine: int  # See GetLastVisibleLine
    LineCount: int  # See GetLineCount and SetLineCount



class WindowBase:
    """ child (wx.WindowBase) â 

        Source: https://docs.wxpython.org/wx.WindowBase.html
    """
    def AddChild(self, child: 'WindowBase') -> None:
        """ child (wx.WindowBase) â

            Source: https://docs.wxpython.org/wx.WindowBase.html
        """

    def RemoveChild(self, child: 'WindowBase') -> None:
        """ child (wx.WindowBase) â

            Source: https://docs.wxpython.org/wx.WindowBase.html
        """



class WindowCreateEvent(CommandEvent):
    """ This event is sent just after the actual window associated with a
Window object has been created.

        Source: https://docs.wxpython.org/wx.WindowCreateEvent.html
    """
    def __init__(self, win: Optional['Window']=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.WindowCreateEvent.html
        """

    def GetWindow(self) -> 'Window':
        """ Return the window being created.

            Source: https://docs.wxpython.org/wx.WindowCreateEvent.html
        """

    Window: 'Window'  # See GetWindow



EVT_WINDOW_CREATE: int  # Process a  wxEVT_CREATE   event. ^^

class WindowDC(DC):
    """ A WindowDC must be constructed if an application wishes to paint on
the whole area of a window (client and decorations).

        Source: https://docs.wxpython.org/wx.WindowDC.html
    """
    def __init__(self, window: 'Window') -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.WindowDC.html
        """



class WindowDestroyEvent(CommandEvent):
    """ This event is sent as early as possible during the window destruction
process.

        Source: https://docs.wxpython.org/wx.WindowDestroyEvent.html
    """
    def __init__(self, win: Optional['Window']=None) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.WindowDestroyEvent.html
        """

    def GetWindow(self) -> 'Window':
        """ Return the window being destroyed.

            Source: https://docs.wxpython.org/wx.WindowDestroyEvent.html
        """

    Window: 'Window'  # See GetWindow



class WindowDisabler:
    """ This class disables all top level windows of the application (maybe
with the exception of one of them) in its constructor and enables them
back in its destructor.

        Source: https://docs.wxpython.org/wx.WindowDisabler.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.WindowDisabler.html
        """

    def __enter__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.WindowDisabler.html
        """

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.WindowDisabler.html
        """



class WindowIDRef:
    """ A WindowIDRef object wraps an ID value and marks it as being in-use
until all references to that ID are gone.

        Source: https://docs.wxpython.org/wx.WindowIDRef.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def GetId(self) -> int:
        """ Alias for GetValue allowing the IDRef to be passed as the source parameter to wx.EvtHandler.Bind.

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def GetValue(self) -> int:
        """ Get the ID value

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __eq__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __ge__(self, id) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __gt__(self, id) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __hash__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __index__(self) -> int:
        """ See __int__

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __int__(self) -> int:
        """ Alias for GetValue allowing the IDRef to be passed as the WindowID parameter when creating widgets or other places an integer type is needed.

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __le__(self, id) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __lt__(self, id) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __ne__(self, item: Any) -> bool:
        """ bool

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    def __repr__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.WindowIDRef.html
        """

    Id: int  # See GetId
    Value: int  # See GetValue



class WindowModalDialogEvent(CommandEvent):
    """ Event sent by Dialog.ShowWindowModal() when the dialog closes.

        Source: https://docs.wxpython.org/wx.WindowModalDialogEvent.html
    """
    def __init__(self, commandType=wxEVT_NULL, id=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.WindowModalDialogEvent.html
        """

    def Clone(self) -> 'Event':
        """ Clone the event.

            Source: https://docs.wxpython.org/wx.WindowModalDialogEvent.html
        """

    def GetDialog(self) -> 'Dialog':
        """ Return the corresponding dialog.

            Source: https://docs.wxpython.org/wx.WindowModalDialogEvent.html
        """

    def GetReturnCode(self) -> int:
        """ Return the dialogâs return code.

            Source: https://docs.wxpython.org/wx.WindowModalDialogEvent.html
        """

    Dialog: 'Dialog'  # See GetDialog
    ReturnCode: int  # See GetReturnCode



class WithImages:
    """ A mixin class to be used with other classes that use a ImageList.

        Source: https://docs.wxpython.org/wx.WithImages.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    def AssignImageList(self, imageList: 'ImageList') -> None:
        """ Sets the image list for the page control and takes ownership of the list.

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    def GetImageCount(self) -> int:
        """ Return the number of images in this control.

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    def GetImageList(self) -> 'ImageList':
        """ Returns the associated image list, may be None.

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    def GetUpdatedImageListFor(self, win: 'Window') -> 'ImageList':
        """ Returns the image list updated to reflect the DPI scaling used for the given window if possible.

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    def HasImages(self) -> bool:
        """ Return True if the control has any images associated with it.

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    def SetImageList(self, imageList: 'ImageList') -> None:
        """ Sets the image list to use.

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    def SetImages(self, images: Vector) -> None:
        """ Set the images to use for the items in the control.

            Source: https://docs.wxpython.org/wx.WithImages.html
        """

    ImageCount: int  # See GetImageCount
    ImageList: 'ImageList'  # See GetImageList and SetImageList



NO_IMAGE: int

class WrapSizer(BoxSizer):
    """ A wrap sizer lays out its items in a single line, like a box sizer  as
long as there is space available in that direction.

        Source: https://docs.wxpython.org/wx.WrapSizer.html
    """
    def __init__(self, orient=HORIZONTAL, flags=WRAPSIZER_DEFAULT_FLAGS) -> None:
        """ Constructor for a   wx.WrapSizer.

            Source: https://docs.wxpython.org/wx.WrapSizer.html
        """

    def CalcMin(self) -> 'Size':
        """ Implements the calculation of a box sizerâs minimal.

            Source: https://docs.wxpython.org/wx.WrapSizer.html
        """

    def InformFirstDirection(self, direction, size, availableOtherDir) -> bool:
        """ Not used by an application.

            Source: https://docs.wxpython.org/wx.WrapSizer.html
        """

    def IsSpaceItem(self, item: 'SizerItem') -> bool:
        """ Can be overridden in the derived classes to treat some normal items as spacers.

            Source: https://docs.wxpython.org/wx.WrapSizer.html
        """

    def RepositionChildren(self, minSize: Union[tuple[int, int], 'Size']) -> None:
        """ Method which must be overridden in the derived sizer classes.

            Source: https://docs.wxpython.org/wx.WrapSizer.html
        """



class XPMHandler(ImageHandler):
    """ This is the image handler for the XPM format.

        Source: https://docs.wxpython.org/wx.XPMHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor for   wx.XPMHandler.

            Source: https://docs.wxpython.org/wx.XPMHandler.html
        """

    def DoCanRead(self, stream: 'InputStream') -> bool:
        """ Called to test if this handler can read an image from the given stream.

            Source: https://docs.wxpython.org/wx.XPMHandler.html
        """

    def LoadFile(self, image, stream, verbose=True, index=-1) -> bool:
        """ Loads an image from a stream, putting the resulting data into image.

            Source: https://docs.wxpython.org/wx.XPMHandler.html
        """

    def SaveFile(self, image, stream, verbose=True) -> bool:
        """ Saves an image in the output stream.

            Source: https://docs.wxpython.org/wx.XPMHandler.html
        """



class ZoomGestureEvent(GestureEvent):
    """ This event is generated when two fingers pinch the surface to zoom in
or out.

        Source: https://docs.wxpython.org/wx.ZoomGestureEvent.html
    """
    def __init__(self, windid: int=0) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.ZoomGestureEvent.html
        """

    def GetZoomFactor(self) -> float:
        """ Returns the zoom Factor since the gesture started.

            Source: https://docs.wxpython.org/wx.ZoomGestureEvent.html
        """

    def SetZoomFactor(self, zoomFactor: float) -> None:
        """ Sets the zoom Factor.

            Source: https://docs.wxpython.org/wx.ZoomGestureEvent.html
        """

    ZoomFactor: float  # See GetZoomFactor and SetZoomFactor



EVT_GESTURE_ZOOM: int  # Process a  wxEVT_GESTURE_ZOOM . ^^

BATTERY_NORMAL_STATE: int

BATTERY_LOW_STATE: int

BATTERY_CRITICAL_STATE: int

BATTERY_SHUTDOWN_STATE: int

BATTERY_UNKNOWN_STATE: int

WXK_NONE: int

WXK_CONTROL_A: int

WXK_CONTROL_B: int

WXK_CONTROL_C: int

WXK_CONTROL_D: int

WXK_CONTROL_E: int

WXK_CONTROL_F: int

WXK_CONTROL_G: int

WXK_CONTROL_H: int

WXK_CONTROL_I: int

WXK_CONTROL_J: int

WXK_CONTROL_K: int

WXK_CONTROL_L: int

WXK_CONTROL_M: int

WXK_CONTROL_N: int

WXK_CONTROL_O: int

WXK_CONTROL_P: int

WXK_CONTROL_Q: int

WXK_CONTROL_R: int

WXK_CONTROL_S: int

WXK_CONTROL_T: int

WXK_CONTROL_U: int

WXK_CONTROL_V: int

WXK_CONTROL_W: int

WXK_CONTROL_X: int

WXK_CONTROL_Y: int

WXK_CONTROL_Z: int

WXK_START: int

WXK_LBUTTON: int

WXK_RBUTTON: int

WXK_MBUTTON: int

WXK_CONTROL: int

WXK_RAW_CONTROL: int

WXK_NUMPAD0: int

WXK_NUMPAD1: int

WXK_NUMPAD2: int

WXK_NUMPAD3: int

WXK_NUMPAD4: int

WXK_NUMPAD5: int

WXK_NUMPAD6: int

WXK_NUMPAD7: int

WXK_NUMPAD8: int

WXK_NUMPAD9: int

WXK_MULTIPLY: int

WXK_F1: int

WXK_F2: int

WXK_F3: int

WXK_F4: int

WXK_F5: int

WXK_F6: int

WXK_F7: int

WXK_F8: int

WXK_F9: int

WXK_F10: int

WXK_F11: int

WXK_F12: int

WXK_F13: int

WXK_F14: int

WXK_F15: int

WXK_F16: int

WXK_F17: int

WXK_F18: int

WXK_F19: int

WXK_F20: int

WXK_F21: int

WXK_F22: int

WXK_F23: int

WXK_F24: int

WXK_NUMPAD_F1: int

WXK_NUMPAD_F2: int

WXK_NUMPAD_F3: int

WXK_NUMPAD_F4: int

WXK_SPECIAL1: int

WXK_SPECIAL2: int

WXK_SPECIAL3: int

WXK_SPECIAL4: int

WXK_SPECIAL5: int

WXK_SPECIAL6: int

WXK_SPECIAL7: int

WXK_SPECIAL8: int

WXK_SPECIAL9: int

WXK_SPECIAL10: int

WXK_SPECIAL11: int

WXK_SPECIAL12: int

WXK_SPECIAL13: int

WXK_SPECIAL14: int

WXK_SPECIAL15: int

WXK_SPECIAL16: int

WXK_SPECIAL17: int

WXK_SPECIAL18: int

WXK_SPECIAL19: int

WXK_SPECIAL20: int

WXK_BROWSER_BACK: int

WXK_BROWSER_FORWARD: int

WXK_BROWSER_REFRESH: int

WXK_BROWSER_STOP: int

WXK_BROWSER_SEARCH: int

WXK_BROWSER_FAVORITES: int

WXK_BROWSER_HOME: int

WXK_VOLUME_MUTE: int

WXK_VOLUME_DOWN: int

WXK_VOLUME_UP: int

WXK_MEDIA_NEXT_TRACK: int

WXK_MEDIA_PREV_TRACK: int

WXK_MEDIA_STOP: int

WXK_MEDIA_PLAY_PAUSE: int

WXK_LAUNCH_MAIL: int

WXK_LAUNCH_APP1: int

WXK_LAUNCH_APP2: int

WXK_LAUNCH_0: int

WXK_LAUNCH_1: int

WXK_LAUNCH_2: int

WXK_LAUNCH_3: int

WXK_LAUNCH_4: int

WXK_LAUNCH_5: int

WXK_LAUNCH_6: int

WXK_LAUNCH_7: int

WXK_LAUNCH_8: int

WXK_LAUNCH_9: int

WXK_LAUNCH_A: int

WXK_LAUNCH_B: int

WXK_LAUNCH_C: int

WXK_LAUNCH_D: int

WXK_LAUNCH_E: int

WXK_LAUNCH_F: int

OS_UNKNOWN: int

OS_MAC_OS: int

OS_MAC_OSX_DARWIN: int

OS_MAC: int

OS_WINDOWS_NT: int

OS_WINDOWS: int

OS_UNIX_LINUX: int

OS_UNIX_FREEBSD: int

OS_UNIX_OPENBSD: int

OS_UNIX_NETBSD: int

OS_UNIX_SOLARIS: int

OS_UNIX_AIX: int

OS_UNIX_HPUX: int

OS_UNIX: int

POWER_SOCKET: int

POWER_BATTERY: int

POWER_UNKNOWN: int

SIGNONE: int

SIGHUP: int

SIGINT: int

SIGQUIT: int

SIGILL: int

SIGTRAP: int

SIGABRT: int

SIGEMT: int

SIGFPE: int

SIGKILL: int

SIGBUS: int

SIGSEGV: int

SIGSYS: int

SIGPIPE: int

SIGALRM: int

SIGTERM: int

KILL_OK: int

KILL_BAD_SIGNAL: int

KILL_ACCESS_DENIED: int

KILL_NO_PROCESS: int

KILL_ERROR: int

ACCEL_NORMAL: int

ACCEL_ALT: int

ACCEL_CTRL: int

ACCEL_SHIFT: int

ACCEL_RAW_CTRL: int

ACCEL_CMD: int

ACC_FAIL: int

ACC_FALSE: int

ACC_NOT_IMPLEMENTED: int

ACC_INVALID_ARG: int

NAVDIR_FIRSTCHILD: int

NAVDIR_LASTCHILD: int

NAVDIR_DOWN: int

NAVDIR_LEFT: int

NAVDIR_NEXT: int

NAVDIR_PREVIOUS: int

NAVDIR_RIGHT: int

NAVDIR_UP: int

OBJID_WINDOW: int

OBJID_SYSMENU: int

OBJID_TITLEBAR: int

OBJID_MENU: int

OBJID_CLIENT: int

OBJID_VSCROLL: int

OBJID_HSCROLL: int

OBJID_SIZEGRIP: int

OBJID_CARET: int

OBJID_CURSOR: int

OBJID_ALERT: int

OBJID_SOUND: int

ACC_SEL_NONE: int

ACC_SEL_TAKEFOCUS: int

ACC_SEL_TAKESELECTION: int

ACC_SEL_EXTENDSELECTION: int

ACC_SEL_ADDSELECTION: int

ACC_SEL_REMOVESELECTION: int

WS_EX_BLOCK_EVENTS: int

ID_OK: int

ID_ANY: int

ID_HIGHEST: int

ID_LOWEST: int

WINDOW_VARIANT_NORMAL: int

WINDOW_VARIANT_SMALL: int

WINDOW_VARIANT_MINI: int

WINDOW_VARIANT_LARGE: int

WINDOW_VARIANT_MAX: int

BITMAP_TYPE_INVALID: int

BITMAP_TYPE_XBM: int

BITMAP_TYPE_XBM_DATA: int

BITMAP_TYPE_XPM_DATA: int

BITMAP_TYPE_TIF: int

BITMAP_TYPE_PICT: int

BITMAP_TYPE_ICON: int

BITMAP_TYPE_IFF: int

BITMAP_TYPE_MACCURSOR: int

BITMAP_TYPE_BMP_RESOURCE: int

BITMAP_TYPE_BMP: int

BITMAP_TYPE_XPM: int

BITMAP_TYPE_XBM: int

BITMAP_TYPE_ICO_RESOURCE: int

BITMAP_TYPE_ICO: int

BITMAP_TYPE_CUR_RESOURCE: int

BITMAP_TYPE_CUR: int

PORT_UNKNOWN: int

PORT_BASE: int

PORT_MSW: int

PORT_MOTIF: int

PORT_DFB: int

PORT_X11: int

PORT_MAC: int

PORT_COCOA: int

PORT_QT: int

ID_ABOUT: int

ID_ADD: int

ID_APPLY: int

ID_BACKWARD: int

ID_BOLD: int

ID_BOTTOM: int

ID_CANCEL: int

ID_CDROM: int

ID_CLEAR: int

ID_CLOSE: int

ID_CONVERT: int

ID_COPY: int

ID_CUT: int

ID_DELETE: int

ID_DOWN: int

ID_EDIT: int

ID_EXECUTE: int

ID_EXIT: int

ID_FILE: int

ID_FIND: int

ID_FIRST: int

ID_FLOPPY: int

ID_FORWARD: int

ID_HARDDISK: int

ID_HELP: int

ID_HOME: int

ID_INDENT: int

ID_INDEX: int

ID_INFO: int

ID_ITALIC: int

ID_JUMP_TO: int

ID_JUSTIFY_CENTER: int

ID_JUSTIFY_FILL: int

ID_JUSTIFY_LEFT: int

ID_JUSTIFY_RIGHT: int

ID_LAST: int

ID_NETWORK: int

ID_NEW: int

ID_NO: int

ID_OPEN: int

ID_PASTE: int

ID_PREFERENCES: int

ID_PREVIEW: int

ID_PRINT: int

ID_PROPERTIES: int

ID_REDO: int

ID_REFRESH: int

ID_REMOVE: int

ID_REPLACE: int

ID_REVERT_TO_SAVED: int

ID_SAVE: int

ID_SAVEAS: int

ID_SELECTALL: int

ID_SELECT_COLOR: int

ID_SELECT_FONT: int

ID_SORT_ASCENDING: int

ID_SORT_DESCENDING: int

ID_SPELL_CHECK: int

ID_STOP: int

ID_STRIKETHROUGH: int

ID_TOP: int

ID_UNDELETE: int

ID_UNDERLINE: int

ID_UNDO: int

ID_UNINDENT: int

ID_UP: int

ID_YES: int

ID_ZOOM_100: int

ID_ZOOM_FIT: int

ID_ZOOM_IN: int

ID_ZOOM_OUT: int

CLEAR: int

INVERT: int

OR_REVERSE: int

OR: int

AND_REVERSE: int

AND: int

AND_INVERT: int

NO_OP: int

NOR: int

EQUIV: int

SRC_INVERT: int

OR_INVERT: int

NAND: int

SET: int

MM_TEXT: int

MM_METRIC: int

MM_LOMETRIC: int

MM_TWIPS: int

MM_POINTS: int

NORTH: int

SOUTH: int

WEST: int

EAST: int

DIRECTION_MASK: int

DragCopy: int

DragMove: int

BK_TOP: int

BK_BOTTOM: int

BK_LEFT: int

BK_RIGHT: int

BK_DEFAULT: int

def Add(window, proportion=0, flag=0, border=0, userData=None) -> 'SizerItem':
    """ Appends a child to the sizer.

        Source: https://docs.wxpython.org/sizers_overview.html
    """


TOP: int

BOTTOM: int

LEFT: int

RIGHT: int

ALL: int

EXPAND: int

SHAPED: int

FIXED_MINSIZE: int

RESERVE_SPACE_EVEN_IF_HIDDEN: int

ALIGN_CENTER: int

ALIGN_CENTRE: int

ALIGN_LEFT: int

ALIGN_RIGHT: int

ALIGN_TOP: int

ALIGN_BOTTOM: int

ALIGN_CENTER_VERTICAL: int

ALIGN_CENTRE_VERTICAL: int

ALIGN_CENTER_HORIZONTAL: int

ALIGN_CENTRE_HORIZONTAL: int

GROW: int

NORTH: int

WEST: int

BRUSHSTYLE_INVALID: int

BRUSHSTYLE_SOLID: int

BRUSHSTYLE_STIPPLE_MASK_OPAQUE: int

BRUSHSTYLE_STIPPLE_MASK: int

BRUSHSTYLE_STIPPLE: int

BRUSHSTYLE_BDIAGONAL_HATCH: int

BRUSHSTYLE_CROSSDIAG_HATCH: int

BRUSHSTYLE_FDIAGONAL_HATCH: int

BRUSHSTYLE_CROSS_HATCH: int

BRUSHSTYLE_HORIZONTAL_HATCH: int

BRUSHSTYLE_VERTICAL_HATCH: int

BRUSHSTYLE_FIRST_HATCH: int

BRUSHSTYLE_LAST_HATCH: int

CHK_UNCHECKED: int

CHK_CHECKED: int

HT_NOWHERE: int

HT_SCROLLBAR_FIRST: int

HT_SCROLLBAR_ARROW_LINE_1: int

HT_SCROLLBAR_ARROW_LINE_2: int

HT_SCROLLBAR_ARROW_PAGE_1: int

HT_SCROLLBAR_ARROW_PAGE_2: int

HT_SCROLLBAR_THUMB: int

HT_SCROLLBAR_BAR_1: int

HT_SCROLLBAR_BAR_2: int

HT_SCROLLBAR_LAST: int

HT_WINDOW_OUTSIDE: int

HT_WINDOW_INSIDE: int

HT_WINDOW_VERT_SCROLLBAR: int

HT_WINDOW_HORZ_SCROLLBAR: int

HT_WINDOW_CORNER: int

HT_MAX: int

EVT_CLOSE: int

FD_OPEN: int

FD_SAVE: int

FD_OVERWRITE_PROMPT: int

FD_HIDE_READONLY: int

FD_FILE_MUST_EXIST: int

FD_MULTIPLE: int

FD_CHANGE_DIR: int

ID_FILE1: int

ID_FILE9: int

EVT_PAINT: int

DefaultSize: int

EVT_SIZE: int

BG_STYLE_ERASE: int

BG_STYLE_SYSTEM: int

BG_STYLE_TRANSPARENT: int

SHOW_EFFECT_ROLL_TO_LEFT: int

SHOW_EFFECT_ROLL_TO_RIGHT: int

SHOW_EFFECT_ROLL_TO_TOP: int

SHOW_EFFECT_ROLL_TO_BOTTOM: int

SHOW_EFFECT_SLIDE_TO_LEFT: int

SHOW_EFFECT_SLIDE_TO_RIGHT: int

SHOW_EFFECT_BLEND: int

SHOW_EFFECT_EXPAND: int

SHOW_EFFECT_MAX: int

VERTICAL: int

HORIZONTAL: int

UPDATE_UI_NONE: int

UPDATE_UI_RECURSE: int

ELLIPSIZE_NONE: int

ELLIPSIZE_START: int

ELLIPSIZE_MIDDLE: int

ELLIPSIZE_END: int

ELLIPSIZE_FLAGS_NONE: int

ELLIPSIZE_FLAGS_PROCESS_MNEMONICS: int

ELLIPSIZE_FLAGS_EXPAND_TABS: int

ELLIPSIZE_FLAGS_DEFAULT: int

DF_SYLK: int

DF_DIF: int

DF_TIFF: int

DF_OEMTEXT: int

DF_DIB: int

DF_PALETTE: int

DF_PENDATA: int

DF_RIFF: int

DF_WAVE: int

DF_ENHMETAFILE: int

DF_LOCALE: int

DF_PRIVATE: int

DF_MAX: int

HDR_SORT_ICON_NONE: int

HDR_SORT_ICON_UP: int

HDR_SORT_ICON_DOWN: int

ORIENTATION_MASK: int

DIALOG_ADAPTATION_MODE_DEFAULT: int

DIALOG_ADAPTATION_MODE_ENABLED: int

DIALOG_ADAPTATION_MODE_DISABLED: int

DIALOG_ADAPTATION_MODE_DEFAULT: int

DIALOG_ADAPTATION_MODE_ENABLED: int

DIALOG_ADAPTATION_MODE_DISABLED: int

FH_PATH_SHOW_IF_DIFFERENT: int

FH_PATH_SHOW_NEVER: int

FH_PATH_SHOW_ALWAYS: int

FSW_WARNING_NONE: int

FSW_WARNING_GENERAL: int

FSW_WARNING_OVERFLOW: int

FR_DOWN: int

FR_WHOLEWORD: int

FR_MATCHCASE: int

DEFAULT: int

DECORATIVE: int

ROMAN: int

SCRIPT: int

SWISS: int

MODERN: int

NORMAL: int

SLANT: int

ITALIC: int

LIGHT: int

BOLD: int

FONTENCODING_XXX: int

FONTENCODING_SYSTEM: int

FONTENCODING_DEFAULT: int

FONTENCODING_KOI8: int

FONTENCODING_ISO8859_5: int

FONTENCODING_CP1251: int

FONTENCODING_CP1250: int

FONTENCODING_CP1252: int

FONTSIZE_XX_SMALL: int

FONTSIZE_X_SMALL: int

FONTSIZE_SMALL: int

FONTSIZE_MEDIUM: int

FONTSIZE_LARGE: int

FONTSIZE_X_LARGE: int

FONTSIZE_XX_LARGE: int

FONTFLAG_DEFAULT: int

FONTFLAG_ITALIC: int

FONTFLAG_SLANT: int

FONTFLAG_LIGHT: int

FONTFLAG_BOLD: int

FONTFLAG_ANTIALIASED: int

FONTFLAG_NOT_ANTIALIASED: int

FONTFLAG_UNDERLINED: int

FONTFLAG_STRIKETHROUGH: int

FONTFLAG_MASK: int

ANTIALIAS_NONE: int

ANTIALIAS_DEFAULT: int

COMPOSITION_INVALID: int

COMPOSITION_CLEAR: int

COMPOSITION_SOURCE: int

COMPOSITION_OVER: int

COMPOSITION_IN: int

COMPOSITION_OUT: int

COMPOSITION_ATOP: int

COMPOSITION_DEST: int

COMPOSITION_DEST_OVER: int

COMPOSITION_DEST_IN: int

COMPOSITION_DEST_OUT: int

COMPOSITION_DEST_ATOP: int

COMPOSITION_XOR: int

COMPOSITION_ADD: int

COMPOSITION_DIFF: int

INTERPOLATION_DEFAULT: int

INTERPOLATION_NONE: int

INTERPOLATION_FAST: int

INTERPOLATION_GOOD: int

INTERPOLATION_BEST: int

PENSTYLE_INVALID: int

PENSTYLE_SOLID: int

PENSTYLE_DOT: int

PENSTYLE_LONG_DASH: int

PENSTYLE_SHORT_DASH: int

PENSTYLE_DOT_DASH: int

PENSTYLE_USER_DASH: int

PENSTYLE_STIPPLE_MASK_OPAQUE: int

PENSTYLE_STIPPLE_MASK: int

PENSTYLE_STIPPLE: int

PENSTYLE_BDIAGONAL_HATCH: int

PENSTYLE_CROSSDIAG_HATCH: int

PENSTYLE_FDIAGONAL_HATCH: int

PENSTYLE_CROSS_HATCH: int

PENSTYLE_HORIZONTAL_HATCH: int

PENSTYLE_VERTICAL_HATCH: int

PENSTYLE_FIRST_HATCH: int

PENSTYLE_LAST_HATCH: int

CAP_INVALID: int

CAP_ROUND: int

CAP_PROJECTING: int

CAP_BUTT: int

JOIN_INVALID: int

JOIN_BEVEL: int

JOIN_MITER: int

JOIN_ROUND: int

PEN_QUALITY_DEFAULT: int

PEN_QUALITY_LOW: int

PEN_QUALITY_HIGH: int

GRADIENT_NONE: int

GRADIENT_LINEAR: int

GRADIENT_RADIAL: int

ALIGN_INVALID: int

ALIGN_MASK: int

HELP_SEARCH_INDEX: int

HELP_SEARCH_ALL: int

IMAGE_ALPHA_BLEND_OVER: int

IMAGE_ALPHA_BLEND_COMPOSE: int

IMAGE_QUALITY_NEAREST: int

IMAGE_QUALITY_BILINEAR: int

IMAGE_QUALITY_BICUBIC: int

IMAGE_QUALITY_BOX_AVERAGE: int

IMAGE_QUALITY_NORMAL: int

IMAGE_QUALITY_HIGH: int

MOD_NONE: int

MOD_ALTGR: int

MOD_META: int

MOD_RAW_CONTROL: int

MOD_CMD: int

MOD_ALL: int

WXK_CATEGORY_ARROW: int

WXK_CATEGORY_PAGING: int

WXK_CATEGORY_JUMP: int

WXK_CATEGORY_TAB: int

WXK_CATEGORY_CUT: int

WXK_CATEGORY_NAVIGATION: int

LIST_FORMAT_LEFT: int

LIST_FORMAT_RIGHT: int

LIST_FORMAT_CENTRE: int

LIST_FORMAT_CENTER: int

LOCALE_THOUSANDS_SEP: int

LOCALE_DECIMAL_POINT: int

LOCALE_SHORT_DATE_FMT: int

LOCALE_LONG_DATE_FMT: int

LOCALE_DATE_TIME_FMT: int

LOCALE_TIME_FMT: int

LOCALE_CAT_NUMBER: int

LOCALE_CAT_DATE: int

LOCALE_CAT_MONEY: int

ITEM_SEPARATOR: int

ITEM_NORMAL: int

ITEM_CHECK: int

ITEM_RADIO: int

ITEM_DROPDOWN: int

ITEM_MAX: int

MOUSE_BTN_ANY: int

MOUSE_BTN_NONE: int

MOUSE_BTN_LEFT: int

MOUSE_BTN_MIDDLE: int

MOUSE_BTN_RIGHT: int

MOUSE_BTN_AUX1: int

MOUSE_BTN_AUX2: int

MOUSE_BTN_MAX: int

MOUSE_WHEEL_VERTICAL: int

MOUSE_WHEEL_HORIZONTAL: int

PAPER_10X11: int

PAPER_10X14: int

PAPER_11X17: int

PAPER_12X11: int

PAPER_15X11: int

PAPER_9X11: int

PAPER_A2: int

PAPER_A3: int

PAPER_A3_EXTRA: int

PAPER_A3_EXTRA_TRANSVERSE: int

PAPER_A3_ROTATED: int

PAPER_A3_TRANSVERSE: int

PAPER_A4: int

PAPER_A4SMALL: int

PAPER_A4_EXTRA: int

PAPER_A4_PLUS: int

PAPER_A4_ROTATED: int

PAPER_A4_TRANSVERSE: int

PAPER_A5: int

PAPER_A5_EXTRA: int

PAPER_A5_ROTATED: int

PAPER_A5_TRANSVERSE: int

PAPER_A6: int

PAPER_A6_ROTATED: int

PAPER_A_PLUS: int

PAPER_B4: int

PAPER_B4_JIS_ROTATED: int

PAPER_B5: int

PAPER_B5_EXTRA: int

PAPER_B5_JIS_ROTATED: int

PAPER_B5_TRANSVERSE: int

PAPER_B6_JIS: int

PAPER_B6_JIS_ROTATED: int

PAPER_B_PLUS: int

PAPER_CSHEET: int

PAPER_DBL_JAPANESE_POSTCARD: int

PAPER_DBL_JAPANESE_POSTCARD_ROTATED: int

PAPER_DSHEET: int

PAPER_ENV_10: int

PAPER_ENV_11: int

PAPER_ENV_12: int

PAPER_ENV_14: int

PAPER_ENV_9: int

PAPER_ENV_B4: int

PAPER_ENV_B5: int

PAPER_ENV_B6: int

PAPER_ENV_C3: int

PAPER_ENV_C4: int

PAPER_ENV_C5: int

PAPER_ENV_C6: int

PAPER_ENV_C65: int

PAPER_ENV_DL: int

PAPER_ENV_INVITE: int

PAPER_ENV_ITALY: int

PAPER_ENV_MONARCH: int

PAPER_ENV_PERSONAL: int

PAPER_ESHEET: int

PAPER_EXECUTIVE: int

PAPER_FANFOLD_LGL_GERMAN: int

PAPER_FANFOLD_STD_GERMAN: int

PAPER_FANFOLD_US: int

PAPER_FOLIO: int

PAPER_ISO_B4: int

PAPER_JAPANESE_POSTCARD: int

PAPER_JAPANESE_POSTCARD_ROTATED: int

PAPER_JENV_CHOU3: int

PAPER_JENV_CHOU3_ROTATED: int

PAPER_JENV_CHOU4: int

PAPER_JENV_CHOU4_ROTATED: int

PAPER_JENV_KAKU2: int

PAPER_JENV_KAKU2_ROTATED: int

PAPER_JENV_KAKU3: int

PAPER_JENV_KAKU3_ROTATED: int

PAPER_JENV_YOU4: int

PAPER_JENV_YOU4_ROTATED: int

PAPER_LEDGER: int

PAPER_LEGAL: int

PAPER_LEGAL_EXTRA: int

PAPER_LETTER: int

PAPER_LETTERSMALL: int

PAPER_LETTER_EXTRA: int

PAPER_LETTER_EXTRA_TRANSVERSE: int

PAPER_LETTER_PLUS: int

PAPER_LETTER_ROTATED: int

PAPER_LETTER_TRANSVERSE: int

PAPER_NONE: int

PAPER_NOTE: int

PAPER_P16K: int

PAPER_P16K_ROTATED: int

PAPER_P32K: int

PAPER_P32KBIG: int

PAPER_P32KBIG_ROTATED: int

PAPER_P32K_ROTATED: int

PAPER_PENV_1: int

PAPER_PENV_10: int

PAPER_PENV_10_ROTATED: int

PAPER_PENV_1_ROTATED: int

PAPER_PENV_2: int

PAPER_PENV_2_ROTATED: int

PAPER_PENV_3: int

PAPER_PENV_3_ROTATED: int

PAPER_PENV_4: int

PAPER_PENV_4_ROTATED: int

PAPER_PENV_5: int

PAPER_PENV_5_ROTATED: int

PAPER_PENV_6: int

PAPER_PENV_6_ROTATED: int

PAPER_PENV_7: int

PAPER_PENV_7_ROTATED: int

PAPER_PENV_8: int

PAPER_PENV_8_ROTATED: int

PAPER_PENV_9: int

PAPER_PENV_9_ROTATED: int

PAPER_QUARTO: int

PAPER_STATEMENT: int

PAPER_TABLOID: int

PAPER_TABLOID_EXTRA: int

BITNESS_INVALID: int

BITNESS_32: int

BITNESS_64: int

BITNESS_MAX: int

ENDIAN_INVALID: int

ENDIAN_BIG: int

ENDIAN_LITTLE: int

ENDIAN_PDP: int

ENDIAN_MAX: int

ARCH_INVALID: int

ARCH_32: int

ARCH_64: int

ARCH_MAX: int

POWER_RESOURCE_SCREEN: int

POWER_RESOURCE_SYSTEM: int

PRINTBIN_DEFAULT: int

PRINTBIN_ONLYONE: int

PRINTBIN_LOWER: int

PRINTBIN_MIDDLE: int

PRINTBIN_MANUAL: int

PRINTBIN_ENVELOPE: int

PRINTBIN_ENVMANUAL: int

PRINTBIN_AUTO: int

PRINTBIN_TRACTOR: int

PRINTBIN_SMALLFMT: int

PRINTBIN_LARGEFMT: int

PRINTBIN_LARGECAPACITY: int

PRINTBIN_CASSETTE: int

PRINTBIN_FORMSOURCE: int

PRINTBIN_USER: int

PRINT_MODE_NONE: int

PRINT_MODE_PREVIEW: int

PRINT_MODE_FILE: int

PRINT_MODE_PRINTER: int

PRINT_MODE_STREAM: int

APP_ASSERT_SUPPRESS: int

APP_ASSERT_EXCEPTION: int

APP_ASSERT_DIALOG: int

APP_ASSERT_LOG: int

SP_3D: int

STREAM_NO_ERROR: int

STREAM_EOF: int

STREAM_WRITE_ERROR: int

STREAM_READ_ERROR: int

SVG_SHAPE_RENDERING_OPTIMIZE_SPEED: int

SVG_SHAPE_RENDERING_CRISP_EDGES: int

SVG_SHAPE_RENDERING_GEOMETRIC_PRECISION: int

SVG_SHAPE_RENDERING_OPTIMISE_SPEED: int

SYS_COLOUR_SCROLLBAR: int

SYS_COLOUR_DESKTOP: int

SYS_COLOUR_ACTIVECAPTION: int

SYS_COLOUR_INACTIVECAPTION: int

SYS_COLOUR_MENU: int

SYS_COLOUR_WINDOW: int

SYS_COLOUR_WINDOWFRAME: int

SYS_COLOUR_MENUTEXT: int

SYS_COLOUR_WINDOWTEXT: int

SYS_COLOUR_CAPTIONTEXT: int

SYS_COLOUR_ACTIVEBORDER: int

SYS_COLOUR_INACTIVEBORDER: int

SYS_COLOUR_APPWORKSPACE: int

SYS_COLOUR_HIGHLIGHT: int

SYS_COLOUR_HIGHLIGHTTEXT: int

SYS_COLOUR_BTNFACE: int

SYS_COLOUR_BTNSHADOW: int

SYS_COLOUR_GRAYTEXT: int

SYS_COLOUR_BTNTEXT: int

SYS_COLOUR_INACTIVECAPTIONTEXT: int

SYS_COLOUR_BTNHIGHLIGHT: int

SYS_COLOUR_3DDKSHADOW: int

SYS_COLOUR_3DLIGHT: int

SYS_COLOUR_INFOTEXT: int

SYS_COLOUR_INFOBK: int

SYS_COLOUR_LISTBOX: int

SYS_COLOUR_HOTLIGHT: int

SYS_COLOUR_GRADIENTACTIVECAPTION: int

SYS_COLOUR_GRADIENTINACTIVECAPTION: int

SYS_COLOUR_MENUHILIGHT: int

SYS_COLOUR_MENUBAR: int

SYS_COLOUR_LISTBOXTEXT: int

SYS_COLOUR_LISTBOXHIGHLIGHTTEXT: int

SYS_COLOUR_BACKGROUND: int

SYS_COLOUR_3DFACE: int

SYS_COLOUR_3DSHADOW: int

SYS_COLOUR_BTNHILIGHT: int

SYS_COLOUR_3DHIGHLIGHT: int

SYS_COLOUR_3DHILIGHT: int

SYS_COLOUR_FRAMEBK: int

SYS_OEM_FIXED_FONT: int

SYS_ANSI_FIXED_FONT: int

SYS_ANSI_VAR_FONT: int

SYS_SYSTEM_FONT: int

SYS_DEVICE_DEFAULT_FONT: int

SYS_DEFAULT_GUI_FONT: int

SYS_MOUSE_BUTTONS: int

SYS_BORDER_X: int

SYS_BORDER_Y: int

SYS_CURSOR_Y: int

SYS_DCLICK_X: int

SYS_DCLICK_Y: int

SYS_DRAG_X: int

SYS_DRAG_Y: int

SYS_EDGE_X: int

SYS_EDGE_Y: int

SYS_HSCROLL_ARROW_X: int

SYS_HSCROLL_ARROW_Y: int

SYS_HTHUMB_X: int

SYS_ICON_X: int

SYS_ICON_Y: int

SYS_ICONSPACING_X: int

SYS_ICONSPACING_Y: int

SYS_WINDOWMIN_X: int

SYS_WINDOWMIN_Y: int

SYS_SCREEN_X: int

SYS_SCREEN_Y: int

SYS_FRAMESIZE_X: int

SYS_FRAMESIZE_Y: int

SYS_SMALLICON_X: int

SYS_SMALLICON_Y: int

SYS_HSCROLL_Y: int

SYS_VSCROLL_X: int

SYS_VSCROLL_ARROW_X: int

SYS_VSCROLL_ARROW_Y: int

SYS_VTHUMB_Y: int

SYS_MENU_Y: int

SYS_NETWORK_PRESENT: int

SYS_PENWINDOWS_PRESENT: int

SYS_SHOW_SOUNDS: int

SYS_SWAP_BUTTONS: int

SYS_DCLICK_MSEC: int

SYS_CARET_ON_MSEC: int

SYS_CARET_OFF_MSEC: int

SYS_CARET_TIMEOUT_MSEC: int

SYS_SCREEN_NONE: int

SYS_SCREEN_TINY: int

SYS_SCREEN_PDA: int

SYS_SCREEN_SMALL: int

SYS_SCREEN_DESKTOP: int

SYS_CAN_DRAW_FRAME_DECORATIONS: int

SYS_CAN_ICONIZE_FRAME: int

SYS_TABLET_PRESENT: int

TEXT_ATTR_LINE_SPACING_NORMAL: int

TEXT_ATTR_LINE_SPACING_HALF: int

TEXT_ATTR_LINE_SPACING_TWICE: int

TEXT_ALIGNMENT_DEFAULT: int

TEXT_ALIGNMENT_LEFT: int

TEXT_ALIGNMENT_CENTRE: int

TEXT_ALIGNMENT_CENTER: int

TEXT_ALIGNMENT_RIGHT: int

TEXT_ATTR_BULLET_STYLE_NONE: int

TEXT_ATTR_BULLET_STYLE_ARABIC: int

TEXT_ATTR_BULLET_STYLE_LETTERS_UPPER: int

TEXT_ATTR_BULLET_STYLE_LETTERS_LOWER: int

TEXT_ATTR_BULLET_STYLE_ROMAN_UPPER: int

TEXT_ATTR_BULLET_STYLE_ROMAN_LOWER: int

TEXT_ATTR_BULLET_STYLE_SYMBOL: int

TEXT_ATTR_BULLET_STYLE_PARENTHESES: int

TEXT_ATTR_BULLET_STYLE_PERIOD: int

TEXT_ATTR_BULLET_STYLE_RIGHT_PARENTHESIS: int

TEXT_ATTR_BULLET_STYLE_OUTLINE: int

TEXT_ATTR_BULLET_STYLE_ALIGN_LEFT: int

TEXT_ATTR_BULLET_STYLE_ALIGN_RIGHT: int

TEXT_ATTR_BULLET_STYLE_ALIGN_CENTRE: int

TEXT_ATTR_BULLET_STYLE_CONTINUATION: int

TEXT_ATTR_UNDERLINE_NONE: int

TEXT_ATTR_TEXT_COLOUR: int

TEXT_ATTR_BACKGROUND_COLOUR: int

TEXT_ATTR_FONT_FACE: int

TEXT_ATTR_FONT_POINT_SIZE: int

TEXT_ATTR_FONT_PIXEL_SIZE: int

TEXT_ATTR_FONT_WEIGHT: int

TEXT_ATTR_FONT_ITALIC: int

TEXT_ATTR_FONT_UNDERLINE: int

TEXT_ATTR_FONT_STRIKETHROUGH: int

TEXT_ATTR_FONT_ENCODING: int

TEXT_ATTR_FONT_FAMILY: int

TEXT_ATTR_FONT_SIZE: int

TEXT_ATTR_FONT: int

TEXT_ATTR_ALIGNMENT: int

TEXT_ATTR_LEFT_INDENT: int

TEXT_ATTR_RIGHT_INDENT: int

TEXT_ATTR_TABS: int

TEXT_ATTR_PARA_SPACING_AFTER: int

TEXT_ATTR_PARA_SPACING_BEFORE: int

TEXT_ATTR_LINE_SPACING: int

TEXT_ATTR_CHARACTER_STYLE_NAME: int

TEXT_ATTR_PARAGRAPH_STYLE_NAME: int

TEXT_ATTR_LIST_STYLE_NAME: int

TEXT_ATTR_BULLET_STYLE: int

TEXT_ATTR_BULLET_NUMBER: int

TEXT_ATTR_BULLET_TEXT: int

TEXT_ATTR_BULLET_NAME: int

TEXT_ATTR_BULLET: int

TEXT_ATTR_PAGE_BREAK: int

TEXT_ATTR_OUTLINE_LEVEL: int

TEXT_ATTR_AVOID_PAGE_BREAK_BEFORE: int

TEXT_ATTR_AVOID_PAGE_BREAK_AFTER: int

TEXT_ATTR_CHARACTER: int

TEXT_ATTR_PARAGRAPH: int

TEXT_ATTR_ALL: int

TEXT_ATTR_EFFECT_NONE: int

TEXT_ATTR_EFFECT_SMALL_CAPITALS: int

TEXT_ATTR_EFFECT_DOUBLE_STRIKETHROUGH: int

TEXT_ATTR_EFFECT_SHADOW: int

TEXT_ATTR_EFFECT_EMBOSS: int

TEXT_ATTR_EFFECT_OUTLINE: int

TEXT_ATTR_EFFECT_ENGRAVE: int

TEXT_ATTR_EFFECT_RTL: int

TEXT_ATTR_EFFECT_SUPPRESS_HYPHENATION: int

TE_HT_UNKNOWN: int

TE_HT_BEFORE: int

TE_HT_ON_TEXT: int

TE_HT_BELOW: int

TE_HT_BEYOND: int

CONTENT_PROTECTION_NONE: int

CONTENT_PROTECTION_ENABLED: int

EVT_TREE_ITEM_EXPANDING: int

ID_NONE: int

def HtmlWinParser_AddTagHandler(tagHandlerClass) -> None:
    """ 

        Source: https://docs.wxpython.org/wx.html.functions.html
    """


GROW: int  # Synonym of wx.EXPAND

RA_HORIZONTAL: int  # Synonym of wx.HORIZONTAL

RA_VERTICAL: int  # Synonym of wx.VERTICAL

NORMAL: int

DEFAULT: int

wxEVT_COMMAND_BUTTON_CLICKED: int

RED: int

YELLOW: int

BLACK: int

WHITE: int

BLUE: int

GREEN: int

CYAN: int

OPEN: int

EVT_TIMER: int

class FrozenWindow(ContextManager):
    """ Freeze the window and all its children.
    """
    def __init__(self, window: 'Window') -> None:
        """ Constructor
        """

    def __enter__(self) -> None:
        """ Enter the context manager.
        """

    def __exit__(self, *args, **kwargs) -> None:
        """ Exit the context manager.
        """



NullCursor: 'Cursor'

LIST_AUTOSIZE: int

